//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    State Space Processor is used for implementing discrete (digital) linear systems, such as
//    finite impulse response filters, infinite impulse response filters, multiple input and output
//    systems, and general state space equations.
//  
//  Architecture:
//  
//    The State Space Processor is designed with a small logic footprint for area limited
//    applications.  The processor requires two external memories: one for program instructions
//    and the other for constants (coefficients) used in calculation.  The processor maintains a
//    register file of 16 N-bit registers used to retain state information and for processing intermediate
//    results.  The register file is also used for handling input and output; registers can be written
//    from an external source and all registers are available as outputs.  For convenience, register 0
//    is wired to ground (0) and instructions updating r0 have no effect on the register file.
//  
//    The processor runs calculations on a cycle basis:
//      1. The external environment writes inputs into the register file.
//      2. The external environment signals a "Cycle" to run the program and calculate a cycle.
//      3. The external environment waits for "Done", then reads output from the register file.
//  
//  Instruction Set:
//  
//    There are 4 instruction types and a total of 8 instructions.  Each instruction is 16-bits.
//    The types include:
//      Unary Operation  : OpCode [15:12], Operand Reg A [11:8], Not Used [7:4], Result Reg X [3:0]
//      Binary Operation : OpCode [15:12], Operand Reg A [11:8], Operand Reg B [7:4], Result Reg X [3:0]
//      Constant Load    : OpCode [15:12], Constant Memory Address [11:4], Result Reg X [3:0]
//      Halt             : OpCode [15:12], Not Used [11:0]
//  
//    Unary Operations (OpCode):
//  
//      ShiftLeft  (0000) : RegX <- lsbs RegA '++' '0'
//                          Flag <- Flag
//      ShiftRight (0001) : RegX <- msb RegA '++' msbs RegA
//                          Flag <- lsb RegA
//      ShiftClip  (0010) : RegX <- lsbs RegA '++' '0' when top 2 bits of RegA == '00' or '11' else
//                                  '0111...1'         when top 2 bits of RegA == '01'         else
//                                  '1000...0'         when top 2 bits of RegA == '10'
//                          Flag <- Flag
//                          Performs a limited/clipped multiplication by 2.
//  
//    Binary Operations (OpCode):
//  
//      Add        (0011) : RegX <- RegA '+' RegB
//                          Flag <- msb Result
//      AddCond    (0100) : RegX <- RegA '+' RegB when Flag == '1' else RegA
//                          Flag <- Flag
//      Sub        (0101) : RegX <- RegA '-' RegB
//                          Flag <- msb Result
//      Switch     (0110) : RegX <- RegA when Flag == '1' else RegB
//                          Flag <- Flag
//  
//    Constant Load Instruction (OpCode):
//  
//      Constant   (0111) : RegX <- Data from constant memory.
//                          Flag <- Flag
//  
//    Halt Instruction (OpCode):
//  
//      Halt       (1---) : Halts processor (prevents further register updates).
//  
//    Booth multiplication can be performed using ShiftRight and AddCond with an accumulation register.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_state_i : Reset all state registers (register file and ALU flag).
//  
//    Inputs:
//      cycle_i      : Input pulse to perform a cycle (sample) calculation.
//      instr_data_i : Instruction data from instruction memory.
//      const_data_i : Constant data from constant memory.
//      load_write_i : Write enable for writing to register file.
//      load_addr_i  : Address (4-bits) for writing to register file.
//      load_data_i  : Data for writing to register file.
//  
//    Outputs:
//      done_o       : Output flag signaling processor is done calculating cycle (active high).
//      instr_addr_o : Address to instruction memory.
//      const_addr_o : Address to constant memory (8-bits).
//      reg_0_o      : Register 0 value.
//      reg_1_o      : Register 1 value.
//      ...
//      reg_f_o      : Register F value.
//  
//  Built In Parameters:
//  
//    Data Width                = 16
//    Instruction Address Width = 8
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:51:06 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_ssp_16_8
//    Clock Domains : clock_c  
//    Vector Input  : reset_state_i(1)
//    Vector Input  : cycle_i(1)
//    Vector Input  : instr_data_i(16)
//    Vector Input  : const_data_i(16)
//    Vector Input  : load_write_i(1)
//    Vector Input  : load_addr_i(4)
//    Vector Input  : load_data_i(16)
//    Vector Output : done_o(1)
//    Vector Output : instr_addr_o(8)
//    Vector Output : const_addr_o(8)
//    Vector Output : reg_0_o(16)
//    Vector Output : reg_1_o(16)
//    Vector Output : reg_2_o(16)
//    Vector Output : reg_3_o(16)
//    Vector Output : reg_4_o(16)
//    Vector Output : reg_5_o(16)
//    Vector Output : reg_6_o(16)
//    Vector Output : reg_7_o(16)
//    Vector Output : reg_8_o(16)
//    Vector Output : reg_9_o(16)
//    Vector Output : reg_a_o(16)
//    Vector Output : reg_b_o(16)
//    Vector Output : reg_c_o(16)
//    Vector Output : reg_d_o(16)
//    Vector Output : reg_e_o(16)
//    Vector Output : reg_f_o(16)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_ssp_16_8.h"

static unsigned char n620[1];
static unsigned char n611[1];
static unsigned char n610[1];
static unsigned char *reg_f_o;
static unsigned char *reg_e_o;
static unsigned char *reg_d_o;
static unsigned char *reg_c_o;
static unsigned char *reg_b_o;
static unsigned char *reg_a_o;
static unsigned char *reg_9_o;
static unsigned char *reg_8_o;
static unsigned char *reg_7_o;
static unsigned char *reg_6_o;
static unsigned char *reg_5_o;
static unsigned char *reg_4_o;
static unsigned char *reg_3_o;
static unsigned char *reg_2_o;
static unsigned char *reg_1_o;
static unsigned char *instr_addr_o;
static unsigned char n510[1];
static unsigned char n509[1];
static unsigned char n508[1];
static unsigned char n507[1];
static unsigned char n506[1];
static unsigned char n505[1];
static unsigned char n497[1];
static unsigned char n496[1];
static unsigned char n495[1];
static unsigned char n494[1];
static unsigned char n493[1];
static unsigned char n492[1];
static unsigned char n491[1];
static unsigned char n490[1];
static unsigned char n489[1];
static unsigned char n488[1];
static unsigned char n487[1];
static unsigned char n486[1];
static unsigned char n485[1];
static unsigned char n484[1];
static unsigned char n483[1];
static unsigned char n482[1];
static unsigned char n481[1];
static unsigned char n383[1];
static unsigned char n382[1];
static unsigned char n375[1];
static unsigned char n372[1];
static unsigned char n369[1];
static unsigned char n359[1];
static unsigned char n310[1];
static unsigned char n309[1];
static unsigned char n280[1];
static unsigned char n279[1];
static unsigned char n226[2];
static unsigned char n193[1];
static unsigned char n191[1];
static unsigned char n189[1];
static unsigned char n187[1];
static unsigned char n185[1];
static unsigned char n183[1];
static unsigned char n181[1];
static unsigned char n179[1];
static unsigned char n177[1];
static unsigned char n175[1];
static unsigned char n173[1];
static unsigned char n171[1];
static unsigned char n169[1];
static unsigned char n167[1];
static unsigned char n165[1];
static unsigned char n163[1];
static unsigned char n161[1];
static unsigned char n159[1];
static unsigned char n157[1];
static unsigned char n155[1];
static unsigned char n153[1];
static unsigned char n151[1];
static unsigned char n149[1];
static unsigned char n147[1];
static unsigned char n145[1];
static unsigned char n143[1];
static unsigned char n141[1];
static unsigned char n139[1];
static unsigned char n137[1];
static unsigned char n135[1];
static unsigned char n133[1];
static unsigned char n132[2];
static unsigned char n131[2];
static unsigned char n130[2];
static unsigned char n129[2];
static unsigned char n128[2];
static unsigned char n127[2];
static unsigned char n126[2];
static unsigned char n125[2];
static unsigned char n124[2];
static unsigned char n123[2];
static unsigned char n122[2];
static unsigned char n121[2];
static unsigned char n120[2];
static unsigned char n119[2];
static unsigned char n118[2];
static unsigned char n117[2];
static unsigned char n116[2];
static unsigned char n61[1];
static unsigned char n60[1];
static unsigned char n59[1];
static unsigned char n58[1];
static unsigned char n57[1];
static unsigned char n56[1];
static unsigned char n55[1];
static unsigned char n54[1];
static unsigned char n49[1];
static unsigned char n48[1];
static unsigned char n47[1];
static unsigned char n46[1];
static unsigned char n45[1];
static unsigned char n44[1];
static unsigned char n43[1];
static unsigned char n42[1];
static unsigned char n41[1];
static unsigned char n40[1];
static unsigned char n39[1];
static unsigned char n38[1];
static unsigned char n37[1];
static unsigned char n36[1];
static unsigned char n35[1];
static unsigned char n10[1];
static unsigned char *load_data_i;
static unsigned char *load_addr_i;
static unsigned char *load_write_i;
static unsigned char *const_data_i;
static unsigned char *instr_data_i;
static unsigned char *reset_state_i;
static unsigned char *cycle_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char *reg_0_o;
static unsigned char n389[1];
static unsigned char n388[1];
static unsigned char n376[1];
static unsigned char n373[1];
static unsigned char n370[1];
static unsigned char n320[1];
static unsigned char n319[1];
static unsigned char n318[2];
static unsigned char n317[2];
static unsigned char n316[2];
static unsigned char n315[2];
static unsigned char n314[2];
static unsigned char n313[2];
static unsigned char n312[2];
static unsigned char n311[2];
static unsigned char n290[1];
static unsigned char n289[1];
static unsigned char n288[2];
static unsigned char n287[2];
static unsigned char n286[2];
static unsigned char n285[2];
static unsigned char n284[2];
static unsigned char n283[2];
static unsigned char n282[2];
static unsigned char n281[2];
static unsigned char n114[1];
static unsigned char n112[1];
static unsigned char n104[1];
static unsigned char n103[1];
static unsigned char n102[1];
static unsigned char n101[1];
static unsigned char n33[1];
static unsigned char n32[1];
static unsigned char n32r[1];
static unsigned char n32e[1];
static unsigned char n32d[1];
static unsigned char n25[1];
static unsigned char n25r[1];
static unsigned char n25e[1];
static unsigned char n25d[1];
static unsigned char n13[1];
static unsigned char *const_addr_o;
static unsigned char n393[1];
static unsigned char n338[1];
static unsigned char n338r[1];
static unsigned char n338e[1];
static unsigned char n338d[1];
static unsigned char n326[1];
static unsigned char n325[1];
static unsigned char n324[2];
static unsigned char n323[2];
static unsigned char n322[2];
static unsigned char n321[2];
static unsigned char n308[1];
static unsigned char n308r[1];
static unsigned char n308e[1];
static unsigned char n308d[1];
static unsigned char n296[1];
static unsigned char n295[1];
static unsigned char n294[2];
static unsigned char n293[2];
static unsigned char n292[2];
static unsigned char n291[2];
static unsigned char n278[1];
static unsigned char n278r[1];
static unsigned char n278e[1];
static unsigned char n278d[1];
static unsigned char n111[1];
static unsigned char n111r[1];
static unsigned char n111e[1];
static unsigned char n111d[1];
static unsigned char n34[1];
static unsigned char n18[1];
static unsigned char n18r[1];
static unsigned char n18e[1];
static unsigned char n18d[1];
static unsigned char n330[1];
static unsigned char n328[2];
static unsigned char n327[2];
static unsigned char n300[1];
static unsigned char n298[2];
static unsigned char n297[2];
static unsigned char n67[1];
static unsigned char n331[2];
static unsigned char n301[2];
static unsigned char n90[1];
static unsigned char n89[1];
static unsigned char n88[1];
static unsigned char n87[1];
static unsigned char n74[1];
static unsigned char n73[1];
static unsigned char n72[1];
static unsigned char n71[1];
static unsigned char n70[1];
static unsigned char n69[1];
static unsigned char n68[1];
static unsigned char n381[2];
static unsigned char n371[1];
static unsigned char n368[2];
static unsigned char n367[2];
static unsigned char n364[1];
static unsigned char n362[2];
static unsigned char n361[1];
static unsigned char n358[2];
static unsigned char n339[1];
static unsigned char n97[1];
static unsigned char n75[1];
static unsigned char n387[2];
static unsigned char n380[2];
static unsigned char n377[1];
static unsigned char n374[1];
static unsigned char n365[1];
static unsigned char n363[2];
static unsigned char n360[2];
static unsigned char n340[1];
static unsigned char n98[1];
static unsigned char n76[1];
static unsigned char n395[1];
static unsigned char n386[2];
static unsigned char n384[2];
static unsigned char n343[1];
static unsigned char n99[1];
static unsigned char n77[1];
static unsigned char n396[1];
static unsigned char n391[2];
static unsigned char n344[1];
static unsigned char n100[1];
static unsigned char n78[1];
static unsigned char n479[1];
static unsigned char n397[1];
static unsigned char n345[1];
static unsigned char n113[1];
static unsigned char n79[1];
static unsigned char n520[1];
static unsigned char n402[1];
static unsigned char n402r[1];
static unsigned char n402e[1];
static unsigned char n402d[1];
static unsigned char n346[1];
static unsigned char n115[1];
static unsigned char n80[1];
static unsigned char n551[1];
static unsigned char n550[1];
static unsigned char n549[1];
static unsigned char n548[1];
static unsigned char n530[1];
static unsigned char n529[1];
static unsigned char n528[1];
static unsigned char n527[1];
static unsigned char n526[1];
static unsigned char n525[1];
static unsigned char n524[1];
static unsigned char n523[1];
static unsigned char n522[1];
static unsigned char n521[1];
static unsigned char n347[1];
static unsigned char n194[1];
static unsigned char n192[1];
static unsigned char n190[1];
static unsigned char n188[1];
static unsigned char n186[1];
static unsigned char n184[1];
static unsigned char n182[1];
static unsigned char n180[1];
static unsigned char n178[1];
static unsigned char n176[1];
static unsigned char n174[1];
static unsigned char n172[1];
static unsigned char n170[1];
static unsigned char n168[1];
static unsigned char n166[1];
static unsigned char n164[1];
static unsigned char n162[1];
static unsigned char n160[1];
static unsigned char n158[1];
static unsigned char n156[1];
static unsigned char n154[1];
static unsigned char n152[1];
static unsigned char n150[1];
static unsigned char n148[1];
static unsigned char n146[1];
static unsigned char n144[1];
static unsigned char n142[1];
static unsigned char n140[1];
static unsigned char n138[1];
static unsigned char n136[1];
static unsigned char n134[1];
static unsigned char n81[1];
static unsigned char n566[1];
static unsigned char n533[1];
static unsigned char n348[1];
static unsigned char n195[2];
static unsigned char n86[1];
static unsigned char n86r[1];
static unsigned char n86e[1];
static unsigned char n86d[1];
static unsigned char n567[1];
static unsigned char n534[1];
static unsigned char n349[1];
static unsigned char n196[2];
static unsigned char n568[1];
static unsigned char n535[1];
static unsigned char n350[2];
static unsigned char n197[2];
static unsigned char n569[1];
static unsigned char n536[1];
static unsigned char n351[2];
static unsigned char n198[2];
static unsigned char *done_o;
static unsigned char n537[1];
static unsigned char n352[2];
static unsigned char n199[2];
static unsigned char n538[1];
static unsigned char n353[2];
static unsigned char n200[2];
static unsigned char n539[1];
static unsigned char n354[2];
static unsigned char n201[2];
static unsigned char n540[1];
static unsigned char n355[2];
static unsigned char n202[2];
static unsigned char n541[1];
static unsigned char n356[2];
static unsigned char n203[2];
static unsigned char n542[1];
static unsigned char n357[2];
static unsigned char n204[2];
static unsigned char n547[1];
static unsigned char n547r[1];
static unsigned char n547e[1];
static unsigned char n547d[1];
static unsigned char n366[2];
static unsigned char n205[2];
static unsigned char n385[2];
static unsigned char n206[2];
static unsigned char n390[2];
static unsigned char n207[2];
static unsigned char n394[2];
static unsigned char n208[2];
static unsigned char n403[2];
static unsigned char n209[2];
static unsigned char n210[2];
static unsigned char n211[2];
static unsigned char n212[2];
static unsigned char n213[2];
static unsigned char n214[2];
static unsigned char n215[2];
static unsigned char n216[2];
static unsigned char n217[2];
static unsigned char n218[2];
static unsigned char n219[2];
static unsigned char n220[2];
static unsigned char n221[2];
static unsigned char n222[2];
static unsigned char n223[2];
static unsigned char n224[2];
static unsigned char n225[2];
static unsigned char n269[1];
static unsigned char n266[1];
static unsigned char n263[1];
static unsigned char n260[1];
static unsigned char n257[1];
static unsigned char n254[1];
static unsigned char n251[1];
static unsigned char n248[1];
static unsigned char n245[1];
static unsigned char n242[1];
static unsigned char n239[1];
static unsigned char n236[1];
static unsigned char n233[1];
static unsigned char n230[1];
static unsigned char n227[1];
static unsigned char n478[2];
static unsigned char n478r[1];
static unsigned char n478e[1];
static unsigned char n478d[2];
static unsigned char n473[2];
static unsigned char n473r[1];
static unsigned char n473e[1];
static unsigned char n473d[2];
static unsigned char n468[2];
static unsigned char n468r[1];
static unsigned char n468e[1];
static unsigned char n468d[2];
static unsigned char n463[2];
static unsigned char n463r[1];
static unsigned char n463e[1];
static unsigned char n463d[2];
static unsigned char n458[2];
static unsigned char n458r[1];
static unsigned char n458e[1];
static unsigned char n458d[2];
static unsigned char n453[2];
static unsigned char n453r[1];
static unsigned char n453e[1];
static unsigned char n453d[2];
static unsigned char n448[2];
static unsigned char n448r[1];
static unsigned char n448e[1];
static unsigned char n448d[2];
static unsigned char n443[2];
static unsigned char n443r[1];
static unsigned char n443e[1];
static unsigned char n443d[2];
static unsigned char n438[2];
static unsigned char n438r[1];
static unsigned char n438e[1];
static unsigned char n438d[2];
static unsigned char n433[2];
static unsigned char n433r[1];
static unsigned char n433e[1];
static unsigned char n433d[2];
static unsigned char n428[2];
static unsigned char n428r[1];
static unsigned char n428e[1];
static unsigned char n428d[2];
static unsigned char n423[2];
static unsigned char n423r[1];
static unsigned char n423e[1];
static unsigned char n423d[2];
static unsigned char n418[2];
static unsigned char n418r[1];
static unsigned char n418e[1];
static unsigned char n418d[2];
static unsigned char n413[2];
static unsigned char n413r[1];
static unsigned char n413e[1];
static unsigned char n413d[2];
static unsigned char n408[2];
static unsigned char n408r[1];
static unsigned char n408e[1];
static unsigned char n408d[2];

void cf_ssp_16_8_ports(unsigned char* port_reset_state_i, unsigned char* port_cycle_i, unsigned char* port_instr_data_i, unsigned char* port_const_data_i, unsigned char* port_load_write_i, unsigned char* port_load_addr_i, unsigned char* port_load_data_i, unsigned char* port_done_o, unsigned char* port_instr_addr_o, unsigned char* port_const_addr_o, unsigned char* port_reg_0_o, unsigned char* port_reg_1_o, unsigned char* port_reg_2_o, unsigned char* port_reg_3_o, unsigned char* port_reg_4_o, unsigned char* port_reg_5_o, unsigned char* port_reg_6_o, unsigned char* port_reg_7_o, unsigned char* port_reg_8_o, unsigned char* port_reg_9_o, unsigned char* port_reg_a_o, unsigned char* port_reg_b_o, unsigned char* port_reg_c_o, unsigned char* port_reg_d_o, unsigned char* port_reg_e_o, unsigned char* port_reg_f_o) {
  reset_state_i = port_reset_state_i;
  cycle_i = port_cycle_i;
  instr_data_i = port_instr_data_i;
  const_data_i = port_const_data_i;
  load_write_i = port_load_write_i;
  load_addr_i = port_load_addr_i;
  load_data_i = port_load_data_i;
  done_o = port_done_o;
  instr_addr_o = port_instr_addr_o;
  const_addr_o = port_const_addr_o;
  reg_0_o = port_reg_0_o;
  reg_1_o = port_reg_1_o;
  reg_2_o = port_reg_2_o;
  reg_3_o = port_reg_3_o;
  reg_4_o = port_reg_4_o;
  reg_5_o = port_reg_5_o;
  reg_6_o = port_reg_6_o;
  reg_7_o = port_reg_7_o;
  reg_8_o = port_reg_8_o;
  reg_9_o = port_reg_9_o;
  reg_a_o = port_reg_a_o;
  reg_b_o = port_reg_b_o;
  reg_c_o = port_reg_c_o;
  reg_d_o = port_reg_d_o;
  reg_e_o = port_reg_e_o;
  reg_f_o = port_reg_f_o;
}

void cf_ssp_16_8_calc() {
  n620[0] = 0;
  n611[0] = 1;
  n610[0] = 1;
  reg_f_o[0] = n478[0];
  reg_f_o[1] = n478[1];
  reg_e_o[0] = n473[0];
  reg_e_o[1] = n473[1];
  reg_d_o[0] = n468[0];
  reg_d_o[1] = n468[1];
  reg_c_o[0] = n463[0];
  reg_c_o[1] = n463[1];
  reg_b_o[0] = n458[0];
  reg_b_o[1] = n458[1];
  reg_a_o[0] = n453[0];
  reg_a_o[1] = n453[1];
  reg_9_o[0] = n448[0];
  reg_9_o[1] = n448[1];
  reg_8_o[0] = n443[0];
  reg_8_o[1] = n443[1];
  reg_7_o[0] = n438[0];
  reg_7_o[1] = n438[1];
  reg_6_o[0] = n433[0];
  reg_6_o[1] = n433[1];
  reg_5_o[0] = n428[0];
  reg_5_o[1] = n428[1];
  reg_4_o[0] = n423[0];
  reg_4_o[1] = n423[1];
  reg_3_o[0] = n418[0];
  reg_3_o[1] = n418[1];
  reg_2_o[0] = n413[0];
  reg_2_o[1] = n413[1];
  reg_1_o[0] = n408[0];
  reg_1_o[1] = n408[1];
  instr_addr_o[0] = n18[0];
  n510[0] = 12;
  n509[0] = 8;
  n508[0] = 4;
  n507[0] = 0;
  n506[0] = 1;
  n505[0] = 1;
  n497[0] = 6;
  n496[0] = 2;
  n495[0] = 13;
  n494[0] = 9;
  n493[0] = 5;
  n492[0] = 1;
  n491[0] = 12;
  n490[0] = 8;
  n489[0] = 4;
  n488[0] = 0;
  n487[0] = 0;
  n486[0] = 1;
  n485[0] = 1;
  n484[0] = 2;
  n483[0] = 1;
  n482[0] = 0;
  n481[0] = 2;
  n383[0] = (1 & (n338[0]));
  n382[0] = (1 & (n338[0] >> 1)) | (2 & (n338[0] >> 1));
  n375[0] = 5;
  n372[0] = 3;
  n369[0] = 1;
  n359[0] = 0;
  n310[0] = (1 & (n308[0]));
  n309[0] = (1 & (n308[0] >> 1)) | (2 & (n308[0] >> 1)) | (4 & (n308[0] >> 1));
  n280[0] = (1 & (n278[0]));
  n279[0] = (1 & (n278[0] >> 1)) | (2 & (n278[0] >> 1)) | (4 & (n278[0] >> 1));
  n226[0] = 0;
  n226[1] = 0;
  n193[0] = 30;
  n191[0] = 29;
  n189[0] = 28;
  n187[0] = 27;
  n185[0] = 26;
  n183[0] = 25;
  n181[0] = 24;
  n179[0] = 23;
  n177[0] = 22;
  n175[0] = 21;
  n173[0] = 20;
  n171[0] = 19;
  n169[0] = 18;
  n167[0] = 17;
  n165[0] = 16;
  n163[0] = 15;
  n161[0] = 14;
  n159[0] = 13;
  n157[0] = 12;
  n155[0] = 11;
  n153[0] = 10;
  n151[0] = 9;
  n149[0] = 8;
  n147[0] = 7;
  n145[0] = 6;
  n143[0] = 5;
  n141[0] = 4;
  n139[0] = 3;
  n137[0] = 2;
  n135[0] = 1;
  n133[0] = 0;
  n132[0] = 0;
  n132[1] = 0;
  n131[0] = 1;
  n131[1] = 0;
  n130[0] = 2;
  n130[1] = 0;
  n129[0] = 4;
  n129[1] = 0;
  n128[0] = 8;
  n128[1] = 0;
  n127[0] = 16;
  n127[1] = 0;
  n126[0] = 32;
  n126[1] = 0;
  n125[0] = 64;
  n125[1] = 0;
  n124[0] = 128;
  n124[1] = 0;
  n123[0] = 0;
  n123[1] = 1;
  n122[0] = 0;
  n122[1] = 2;
  n121[0] = 0;
  n121[1] = 4;
  n120[0] = 0;
  n120[1] = 8;
  n119[0] = 0;
  n119[1] = 16;
  n118[0] = 0;
  n118[1] = 32;
  n117[0] = 0;
  n117[1] = 64;
  n116[0] = 0;
  n116[1] = 128;
  n61[0] = 6;
  n60[0] = 4;
  n59[0] = 2;
  n58[0] = 0;
  n57[0] = 0;
  n56[0] = 0;
  n55[0] = 0;
  n54[0] = 0;
  n49[0] = 5;
  n48[0] = 3;
  n47[0] = 1;
  n46[0] = 6;
  n45[0] = 4;
  n44[0] = 2;
  n43[0] = 0;
  n42[0] = 0;
  n41[0] = 0;
  n40[0] = 1;
  n39[0] = 0;
  n38[0] = 1;
  n37[0] = 0;
  n36[0] = 1;
  n35[0] = 0;
  n10[0] = 1;
  n2[0] = 0;
  n1[0] = 1;
  reg_0_o[0] = n226[0];
  reg_0_o[1] = n226[1];
  n389[0] = (1 & (n382[0]));
  n388[0] = (1 & (n382[0] >> 1));
  n376[0] = n338[0] == n375[0] ? 1 : 0;
  n373[0] = n338[0] == n372[0] ? 1 : 0;
  n370[0] = n338[0] == n369[0] ? 1 : 0;
  n320[0] = (1 & (n309[0]));
  n319[0] = (1 & (n309[0] >> 1)) | (2 & (n309[0] >> 1));
  if (n310[0]) {
    n318[0] = n478[0];
    n318[1] = n478[1];
  }
  else {
    n318[0] = n473[0];
    n318[1] = n473[1];
  }
  if (n310[0]) {
    n317[0] = n468[0];
    n317[1] = n468[1];
  }
  else {
    n317[0] = n463[0];
    n317[1] = n463[1];
  }
  if (n310[0]) {
    n316[0] = n458[0];
    n316[1] = n458[1];
  }
  else {
    n316[0] = n453[0];
    n316[1] = n453[1];
  }
  if (n310[0]) {
    n315[0] = n448[0];
    n315[1] = n448[1];
  }
  else {
    n315[0] = n443[0];
    n315[1] = n443[1];
  }
  if (n310[0]) {
    n314[0] = n438[0];
    n314[1] = n438[1];
  }
  else {
    n314[0] = n433[0];
    n314[1] = n433[1];
  }
  if (n310[0]) {
    n313[0] = n428[0];
    n313[1] = n428[1];
  }
  else {
    n313[0] = n423[0];
    n313[1] = n423[1];
  }
  if (n310[0]) {
    n312[0] = n418[0];
    n312[1] = n418[1];
  }
  else {
    n312[0] = n413[0];
    n312[1] = n413[1];
  }
  if (n310[0]) {
    n311[0] = n408[0];
    n311[1] = n408[1];
  }
  else {
    n311[0] = n226[0];
    n311[1] = n226[1];
  }
  n290[0] = (1 & (n279[0]));
  n289[0] = (1 & (n279[0] >> 1)) | (2 & (n279[0] >> 1));
  if (n280[0]) {
    n288[0] = n478[0];
    n288[1] = n478[1];
  }
  else {
    n288[0] = n473[0];
    n288[1] = n473[1];
  }
  if (n280[0]) {
    n287[0] = n468[0];
    n287[1] = n468[1];
  }
  else {
    n287[0] = n463[0];
    n287[1] = n463[1];
  }
  if (n280[0]) {
    n286[0] = n458[0];
    n286[1] = n458[1];
  }
  else {
    n286[0] = n453[0];
    n286[1] = n453[1];
  }
  if (n280[0]) {
    n285[0] = n448[0];
    n285[1] = n448[1];
  }
  else {
    n285[0] = n443[0];
    n285[1] = n443[1];
  }
  if (n280[0]) {
    n284[0] = n438[0];
    n284[1] = n438[1];
  }
  else {
    n284[0] = n433[0];
    n284[1] = n433[1];
  }
  if (n280[0]) {
    n283[0] = n428[0];
    n283[1] = n428[1];
  }
  else {
    n283[0] = n423[0];
    n283[1] = n423[1];
  }
  if (n280[0]) {
    n282[0] = n418[0];
    n282[1] = n418[1];
  }
  else {
    n282[0] = n413[0];
    n282[1] = n413[1];
  }
  if (n280[0]) {
    n281[0] = n408[0];
    n281[1] = n408[1];
  }
  else {
    n281[0] = n226[0];
    n281[1] = n226[1];
  }
  if (load_write_i[0]) {
    n114[0] = load_addr_i[0];
  }
  else {
    n114[0] = n111[0];
  }
  n112[0] = (1 & (instr_data_i[0] >> 4)) | (2 & (instr_data_i[0] >> 4)) | (4 & (instr_data_i[0] >> 4)) | (8 & (instr_data_i[0] >> 4)) | (16 & (instr_data_i[1] << 4)) | (32 & (instr_data_i[1] << 4)) | (64 & (instr_data_i[1] << 4)) | (128 & (instr_data_i[1] << 4));
  n104[0] = (1 & (instr_data_i[0])) | (2 & (instr_data_i[0])) | (4 & (instr_data_i[0])) | (8 & (instr_data_i[0]));
  n103[0] = (1 & (instr_data_i[0] >> 4)) | (2 & (instr_data_i[0] >> 4)) | (4 & (instr_data_i[0] >> 4)) | (8 & (instr_data_i[0] >> 4));
  n102[0] = (1 & (instr_data_i[1])) | (2 & (instr_data_i[1])) | (4 & (instr_data_i[1])) | (8 & (instr_data_i[1]));
  n101[0] = (1 & (instr_data_i[1] >> 4)) | (2 & (instr_data_i[1] >> 4)) | (4 & (instr_data_i[1] >> 4));
  n33[0] = (1 & (instr_data_i[1] >> 7));
  n32r[0] = n2[0];
  n32e[0] = n1[0];
  n32d[0] = n25[0];
  n25r[0] = n2[0];
  n25e[0] = n1[0];
  n25d[0] = cycle_i[0];
  { unsigned int tmp; (tmp = (unsigned int) n18[0] + (unsigned int) n10[0], n13[0] = 255 & (unsigned char) tmp); }
  const_addr_o[0] = n112[0];
  n393[0] = (1 & (n388[0]));
  n338r[0] = n2[0];
  n338e[0] = n1[0];
  n338d[0] = n101[0];
  n326[0] = (1 & (n319[0]));
  n325[0] = (1 & (n319[0] >> 1));
  if (n320[0]) {
    n324[0] = n318[0];
    n324[1] = n318[1];
  }
  else {
    n324[0] = n317[0];
    n324[1] = n317[1];
  }
  if (n320[0]) {
    n323[0] = n316[0];
    n323[1] = n316[1];
  }
  else {
    n323[0] = n315[0];
    n323[1] = n315[1];
  }
  if (n320[0]) {
    n322[0] = n314[0];
    n322[1] = n314[1];
  }
  else {
    n322[0] = n313[0];
    n322[1] = n313[1];
  }
  if (n320[0]) {
    n321[0] = n312[0];
    n321[1] = n312[1];
  }
  else {
    n321[0] = n311[0];
    n321[1] = n311[1];
  }
  n308r[0] = reset_state_i[0];
  n308e[0] = n1[0];
  n308d[0] = n103[0];
  n296[0] = (1 & (n289[0]));
  n295[0] = (1 & (n289[0] >> 1));
  if (n290[0]) {
    n294[0] = n288[0];
    n294[1] = n288[1];
  }
  else {
    n294[0] = n287[0];
    n294[1] = n287[1];
  }
  if (n290[0]) {
    n293[0] = n286[0];
    n293[1] = n286[1];
  }
  else {
    n293[0] = n285[0];
    n293[1] = n285[1];
  }
  if (n290[0]) {
    n292[0] = n284[0];
    n292[1] = n284[1];
  }
  else {
    n292[0] = n283[0];
    n292[1] = n283[1];
  }
  if (n290[0]) {
    n291[0] = n282[0];
    n291[1] = n282[1];
  }
  else {
    n291[0] = n281[0];
    n291[1] = n281[1];
  }
  n278r[0] = reset_state_i[0];
  n278e[0] = n1[0];
  n278d[0] = n102[0];
  n111r[0] = n2[0];
  n111e[0] = n1[0];
  n111d[0] = n104[0];
  n34[0] = 255 & (n32[0] << 1 | n33[0]);
  n18r[0] = cycle_i[0];
  n18e[0] = n1[0];
  n18d[0] = n13[0];
  n330[0] = (1 & (n325[0]));
  if (n326[0]) {
    n328[0] = n324[0];
    n328[1] = n324[1];
  }
  else {
    n328[0] = n323[0];
    n328[1] = n323[1];
  }
  if (n326[0]) {
    n327[0] = n322[0];
    n327[1] = n322[1];
  }
  else {
    n327[0] = n321[0];
    n327[1] = n321[1];
  }
  n300[0] = (1 & (n295[0]));
  if (n296[0]) {
    n298[0] = n294[0];
    n298[1] = n294[1];
  }
  else {
    n298[0] = n293[0];
    n298[1] = n293[1];
  }
  if (n296[0]) {
    n297[0] = n292[0];
    n297[1] = n292[1];
  }
  else {
    n297[0] = n291[0];
    n297[1] = n291[1];
  }
  n67[0] = 255 & (n34[0] << 1 | n86[0]);
  if (n330[0]) {
    n331[0] = n328[0];
    n331[1] = n328[1];
  }
  else {
    n331[0] = n327[0];
    n331[1] = n327[1];
  }
  if (n300[0]) {
    n301[0] = n298[0];
    n301[1] = n298[1];
  }
  else {
    n301[0] = n297[0];
    n301[1] = n297[1];
  }
  n90[0] = n67[0] == n61[0] ? 1 : 0;
  n89[0] = n67[0] == n60[0] ? 1 : 0;
  n88[0] = n67[0] == n59[0] ? 1 : 0;
  n87[0] = n67[0] == n58[0] ? 1 : 0;
  n74[0] = n67[0] == n49[0] ? 1 : 0;
  n73[0] = n67[0] == n48[0] ? 1 : 0;
  n72[0] = n67[0] == n47[0] ? 1 : 0;
  n71[0] = n67[0] == n46[0] ? 1 : 0;
  n70[0] = n67[0] == n45[0] ? 1 : 0;
  n69[0] = n67[0] == n44[0] ? 1 : 0;
  n68[0] = n67[0] == n43[0] ? 1 : 0;
  if (n402[0]) {
    n381[0] = n301[0];
    n381[1] = n301[1];
  }
  else {
    n381[0] = n331[0];
    n381[1] = n331[1];
  }
  n371[0] = (1 & (n301[0]));
  { unsigned int tmp; (tmp = (unsigned int) n301[1] - (unsigned int) n331[1] - (tmp = (unsigned int) n301[0] - (unsigned int) n331[0], n368[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n368[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n301[1] + (unsigned int) n331[1] + (tmp = (unsigned int) n301[0] + (unsigned int) n331[0], n367[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n367[1] = 255 & (unsigned char) tmp); }
  n364[0] = (1 & (n301[1] >> 6));
  n362[0] = (1 & (n301[0] >> 1)) | (2 & (n301[0] >> 1)) | (4 & (n301[0] >> 1)) | (8 & (n301[0] >> 1)) | (16 & (n301[0] >> 1)) | (32 & (n301[0] >> 1)) | (64 & (n301[0] >> 1)) | (128 & (n301[1] << 7));
  n362[1] = (1 & (n301[1] >> 1)) | (2 & (n301[1] >> 1)) | (4 & (n301[1] >> 1)) | (8 & (n301[1] >> 1)) | (16 & (n301[1] >> 1)) | (32 & (n301[1] >> 1)) | (64 & (n301[1] >> 1));
  n361[0] = (1 & (n301[1] >> 7));
  n358[0] = (1 & (n301[0])) | (2 & (n301[0])) | (4 & (n301[0])) | (8 & (n301[0])) | (16 & (n301[0])) | (32 & (n301[0])) | (64 & (n301[0])) | (128 & (n301[0]));
  n358[1] = (1 & (n301[1])) | (2 & (n301[1])) | (4 & (n301[1])) | (8 & (n301[1])) | (16 & (n301[1])) | (32 & (n301[1])) | (64 & (n301[1]));
  n339[0] = (1 & (n301[1] >> 7));
  if (n90[0]) {
    n97[0] = n54[0];
  }
  else {
    n97[0] = n610[0];
  }
  if (n74[0]) {
    n75[0] = n36[0];
  }
  else {
    n75[0] = n35[0];
  }
  if (n383[0]) {
    n387[0] = const_data_i[0];
    n387[1] = const_data_i[1];
  }
  else {
    n387[0] = n381[0];
    n387[1] = n381[1];
  }
  if (n402[0]) {
    n380[0] = n367[0];
    n380[1] = n367[1];
  }
  else {
    n380[0] = n301[0];
    n380[1] = n301[1];
  }
  n377[0] = (1 & (n368[1] >> 7));
  n374[0] = (1 & (n367[1] >> 7));
  n365[0] = n339[0] ^ n364[0];
  n363[0] = n362[0];
  n363[1] = 255 & (n361[0] << 7 | n362[1]);
  n360[0] = 255 & (n358[0] << 1 | n359[0]);
  n360[1] = 255 & (n358[1] << 1 | n358[0] >> 7);
  n340[0] = 1 & ~n339[0];
  if (n89[0]) {
    n98[0] = n55[0];
  }
  else {
    n98[0] = n97[0];
  }
  if (n73[0]) {
    n76[0] = n37[0];
  }
  else {
    n76[0] = n75[0];
  }
  if (n376[0]) {
    n395[0] = n377[0];
  }
  else {
    n395[0] = n402[0];
  }
  if (n383[0]) {
    n386[0] = n368[0];
    n386[1] = n368[1];
  }
  else {
    n386[0] = n380[0];
    n386[1] = n380[1];
  }
  if (n383[0]) {
    n384[0] = n363[0];
    n384[1] = n363[1];
  }
  else {
    n384[0] = n360[0];
    n384[1] = n360[1];
  }
  n343[0] = 255 & (n340[0] << 1 | n340[0]);
  if (n88[0]) {
    n99[0] = n56[0];
  }
  else {
    n99[0] = n98[0];
  }
  if (n72[0]) {
    n77[0] = n38[0];
  }
  else {
    n77[0] = n76[0];
  }
  if (n373[0]) {
    n396[0] = n374[0];
  }
  else {
    n396[0] = n395[0];
  }
  if (n389[0]) {
    n391[0] = n387[0];
    n391[1] = n387[1];
  }
  else {
    n391[0] = n386[0];
    n391[1] = n386[1];
  }
  n344[0] = 255 & (n340[0] << 2 | n343[0]);
  if (n87[0]) {
    n100[0] = n57[0];
  }
  else {
    n100[0] = n99[0];
  }
  if (n71[0]) {
    n78[0] = n39[0];
  }
  else {
    n78[0] = n77[0];
  }
  n479[0] = 255 & (cycle_i[0] << 1 | n100[0]);
  if (n370[0]) {
    n397[0] = n371[0];
  }
  else {
    n397[0] = n396[0];
  }
  n345[0] = 255 & (n340[0] << 3 | n344[0]);
  n113[0] = load_write_i[0] | n100[0];
  if (n70[0]) {
    n79[0] = n40[0];
  }
  else {
    n79[0] = n78[0];
  }
  n520[0] = 255 & (n479[0] << 2 | n547[0]);
  n402r[0] = reset_state_i[0];
  n402e[0] = n1[0];
  n402d[0] = n397[0];
  n346[0] = 255 & (n340[0] << 4 | n345[0]);
  n115[0] = 255 & (n113[0] << 4 | n114[0]);
  if (n69[0]) {
    n80[0] = n41[0];
  }
  else {
    n80[0] = n79[0];
  }
  n551[0] = n520[0] == n510[0] ? 1 : 0;
  n550[0] = n520[0] == n509[0] ? 1 : 0;
  n549[0] = n520[0] == n508[0] ? 1 : 0;
  n548[0] = n520[0] == n507[0] ? 1 : 0;
  n530[0] = n520[0] == n497[0] ? 1 : 0;
  n529[0] = n520[0] == n496[0] ? 1 : 0;
  n528[0] = n520[0] == n495[0] ? 1 : 0;
  n527[0] = n520[0] == n494[0] ? 1 : 0;
  n526[0] = n520[0] == n493[0] ? 1 : 0;
  n525[0] = n520[0] == n492[0] ? 1 : 0;
  n524[0] = n520[0] == n491[0] ? 1 : 0;
  n523[0] = n520[0] == n490[0] ? 1 : 0;
  n522[0] = n520[0] == n489[0] ? 1 : 0;
  n521[0] = n520[0] == n488[0] ? 1 : 0;
  n347[0] = 255 & (n340[0] << 5 | n346[0]);
  n194[0] = n115[0] == n193[0] ? 1 : 0;
  n192[0] = n115[0] == n191[0] ? 1 : 0;
  n190[0] = n115[0] == n189[0] ? 1 : 0;
  n188[0] = n115[0] == n187[0] ? 1 : 0;
  n186[0] = n115[0] == n185[0] ? 1 : 0;
  n184[0] = n115[0] == n183[0] ? 1 : 0;
  n182[0] = n115[0] == n181[0] ? 1 : 0;
  n180[0] = n115[0] == n179[0] ? 1 : 0;
  n178[0] = n115[0] == n177[0] ? 1 : 0;
  n176[0] = n115[0] == n175[0] ? 1 : 0;
  n174[0] = n115[0] == n173[0] ? 1 : 0;
  n172[0] = n115[0] == n171[0] ? 1 : 0;
  n170[0] = n115[0] == n169[0] ? 1 : 0;
  n168[0] = n115[0] == n167[0] ? 1 : 0;
  n166[0] = n115[0] == n165[0] ? 1 : 0;
  n164[0] = n115[0] == n163[0] ? 1 : 0;
  n162[0] = n115[0] == n161[0] ? 1 : 0;
  n160[0] = n115[0] == n159[0] ? 1 : 0;
  n158[0] = n115[0] == n157[0] ? 1 : 0;
  n156[0] = n115[0] == n155[0] ? 1 : 0;
  n154[0] = n115[0] == n153[0] ? 1 : 0;
  n152[0] = n115[0] == n151[0] ? 1 : 0;
  n150[0] = n115[0] == n149[0] ? 1 : 0;
  n148[0] = n115[0] == n147[0] ? 1 : 0;
  n146[0] = n115[0] == n145[0] ? 1 : 0;
  n144[0] = n115[0] == n143[0] ? 1 : 0;
  n142[0] = n115[0] == n141[0] ? 1 : 0;
  n140[0] = n115[0] == n139[0] ? 1 : 0;
  n138[0] = n115[0] == n137[0] ? 1 : 0;
  n136[0] = n115[0] == n135[0] ? 1 : 0;
  n134[0] = n115[0] == n133[0] ? 1 : 0;
  if (n68[0]) {
    n81[0] = n42[0];
  }
  else {
    n81[0] = n80[0];
  }
  if (n551[0]) {
    n566[0] = n505[0];
  }
  else {
    n566[0] = n620[0];
  }
  if (n530[0]) {
    n533[0] = n481[0];
  }
  else {
    n533[0] = n611[0];
  }
  n348[0] = 255 & (n340[0] << 6 | n347[0]);
  if (n194[0]) {
    n195[0] = n117[0];
    n195[1] = n117[1];
  }
  else {
    n195[0] = n116[0];
    n195[1] = n116[1];
  }
  n86r[0] = n2[0];
  n86e[0] = n1[0];
  n86d[0] = n81[0];
  if (n550[0]) {
    n567[0] = n505[0];
  }
  else {
    n567[0] = n566[0];
  }
  if (n529[0]) {
    n534[0] = n482[0];
  }
  else {
    n534[0] = n533[0];
  }
  n349[0] = 255 & (n340[0] << 7 | n348[0]);
  if (n192[0]) {
    n196[0] = n118[0];
    n196[1] = n118[1];
  }
  else {
    n196[0] = n195[0];
    n196[1] = n195[1];
  }
  if (n549[0]) {
    n568[0] = n506[0];
  }
  else {
    n568[0] = n567[0];
  }
  if (n528[0]) {
    n535[0] = n483[0];
  }
  else {
    n535[0] = n534[0];
  }
  n350[0] = n349[0];
  n350[1] = n340[0];
  if (n190[0]) {
    n197[0] = n119[0];
    n197[1] = n119[1];
  }
  else {
    n197[0] = n196[0];
    n197[1] = n196[1];
  }
  if (n548[0]) {
    n569[0] = n506[0];
  }
  else {
    n569[0] = n568[0];
  }
  if (n527[0]) {
    n536[0] = n483[0];
  }
  else {
    n536[0] = n535[0];
  }
  n351[0] = n350[0];
  n351[1] = 255 & (n340[0] << 1 | n350[1]);
  if (n188[0]) {
    n198[0] = n120[0];
    n198[1] = n120[1];
  }
  else {
    n198[0] = n197[0];
    n198[1] = n197[1];
  }
  done_o[0] = n569[0];
  if (n526[0]) {
    n537[0] = n484[0];
  }
  else {
    n537[0] = n536[0];
  }
  n352[0] = n351[0];
  n352[1] = 255 & (n340[0] << 2 | n351[1]);
  if (n186[0]) {
    n199[0] = n121[0];
    n199[1] = n121[1];
  }
  else {
    n199[0] = n198[0];
    n199[1] = n198[1];
  }
  if (n525[0]) {
    n538[0] = n485[0];
  }
  else {
    n538[0] = n537[0];
  }
  n353[0] = n352[0];
  n353[1] = 255 & (n340[0] << 3 | n352[1]);
  if (n184[0]) {
    n200[0] = n122[0];
    n200[1] = n122[1];
  }
  else {
    n200[0] = n199[0];
    n200[1] = n199[1];
  }
  if (n524[0]) {
    n539[0] = n486[0];
  }
  else {
    n539[0] = n538[0];
  }
  n354[0] = n353[0];
  n354[1] = 255 & (n340[0] << 4 | n353[1]);
  if (n182[0]) {
    n201[0] = n123[0];
    n201[1] = n123[1];
  }
  else {
    n201[0] = n200[0];
    n201[1] = n200[1];
  }
  if (n523[0]) {
    n540[0] = n486[0];
  }
  else {
    n540[0] = n539[0];
  }
  n355[0] = n354[0];
  n355[1] = 255 & (n340[0] << 5 | n354[1]);
  if (n180[0]) {
    n202[0] = n124[0];
    n202[1] = n124[1];
  }
  else {
    n202[0] = n201[0];
    n202[1] = n201[1];
  }
  if (n522[0]) {
    n541[0] = n487[0];
  }
  else {
    n541[0] = n540[0];
  }
  n356[0] = n355[0];
  n356[1] = 255 & (n340[0] << 6 | n355[1]);
  if (n178[0]) {
    n203[0] = n125[0];
    n203[1] = n125[1];
  }
  else {
    n203[0] = n202[0];
    n203[1] = n202[1];
  }
  if (n521[0]) {
    n542[0] = n487[0];
  }
  else {
    n542[0] = n541[0];
  }
  n357[0] = n356[0];
  n357[1] = 255 & (n339[0] << 7 | n356[1]);
  if (n176[0]) {
    n204[0] = n126[0];
    n204[1] = n126[1];
  }
  else {
    n204[0] = n203[0];
    n204[1] = n203[1];
  }
  n547r[0] = n2[0];
  n547e[0] = n1[0];
  n547d[0] = n542[0];
  if (n365[0]) {
    n366[0] = n357[0];
    n366[1] = n357[1];
  }
  else {
    n366[0] = n360[0];
    n366[1] = n360[1];
  }
  if (n174[0]) {
    n205[0] = n127[0];
    n205[1] = n127[1];
  }
  else {
    n205[0] = n204[0];
    n205[1] = n204[1];
  }
  if (n383[0]) {
    n385[0] = n367[0];
    n385[1] = n367[1];
  }
  else {
    n385[0] = n366[0];
    n385[1] = n366[1];
  }
  if (n172[0]) {
    n206[0] = n128[0];
    n206[1] = n128[1];
  }
  else {
    n206[0] = n205[0];
    n206[1] = n205[1];
  }
  if (n389[0]) {
    n390[0] = n385[0];
    n390[1] = n385[1];
  }
  else {
    n390[0] = n384[0];
    n390[1] = n384[1];
  }
  if (n170[0]) {
    n207[0] = n129[0];
    n207[1] = n129[1];
  }
  else {
    n207[0] = n206[0];
    n207[1] = n206[1];
  }
  if (n393[0]) {
    n394[0] = n391[0];
    n394[1] = n391[1];
  }
  else {
    n394[0] = n390[0];
    n394[1] = n390[1];
  }
  if (n168[0]) {
    n208[0] = n130[0];
    n208[1] = n130[1];
  }
  else {
    n208[0] = n207[0];
    n208[1] = n207[1];
  }
  if (load_write_i[0]) {
    n403[0] = load_data_i[0];
    n403[1] = load_data_i[1];
  }
  else {
    n403[0] = n394[0];
    n403[1] = n394[1];
  }
  if (n166[0]) {
    n209[0] = n131[0];
    n209[1] = n131[1];
  }
  else {
    n209[0] = n208[0];
    n209[1] = n208[1];
  }
  if (n164[0]) {
    n210[0] = n132[0];
    n210[1] = n132[1];
  }
  else {
    n210[0] = n209[0];
    n210[1] = n209[1];
  }
  if (n162[0]) {
    n211[0] = n132[0];
    n211[1] = n132[1];
  }
  else {
    n211[0] = n210[0];
    n211[1] = n210[1];
  }
  if (n160[0]) {
    n212[0] = n132[0];
    n212[1] = n132[1];
  }
  else {
    n212[0] = n211[0];
    n212[1] = n211[1];
  }
  if (n158[0]) {
    n213[0] = n132[0];
    n213[1] = n132[1];
  }
  else {
    n213[0] = n212[0];
    n213[1] = n212[1];
  }
  if (n156[0]) {
    n214[0] = n132[0];
    n214[1] = n132[1];
  }
  else {
    n214[0] = n213[0];
    n214[1] = n213[1];
  }
  if (n154[0]) {
    n215[0] = n132[0];
    n215[1] = n132[1];
  }
  else {
    n215[0] = n214[0];
    n215[1] = n214[1];
  }
  if (n152[0]) {
    n216[0] = n132[0];
    n216[1] = n132[1];
  }
  else {
    n216[0] = n215[0];
    n216[1] = n215[1];
  }
  if (n150[0]) {
    n217[0] = n132[0];
    n217[1] = n132[1];
  }
  else {
    n217[0] = n216[0];
    n217[1] = n216[1];
  }
  if (n148[0]) {
    n218[0] = n132[0];
    n218[1] = n132[1];
  }
  else {
    n218[0] = n217[0];
    n218[1] = n217[1];
  }
  if (n146[0]) {
    n219[0] = n132[0];
    n219[1] = n132[1];
  }
  else {
    n219[0] = n218[0];
    n219[1] = n218[1];
  }
  if (n144[0]) {
    n220[0] = n132[0];
    n220[1] = n132[1];
  }
  else {
    n220[0] = n219[0];
    n220[1] = n219[1];
  }
  if (n142[0]) {
    n221[0] = n132[0];
    n221[1] = n132[1];
  }
  else {
    n221[0] = n220[0];
    n221[1] = n220[1];
  }
  if (n140[0]) {
    n222[0] = n132[0];
    n222[1] = n132[1];
  }
  else {
    n222[0] = n221[0];
    n222[1] = n221[1];
  }
  if (n138[0]) {
    n223[0] = n132[0];
    n223[1] = n132[1];
  }
  else {
    n223[0] = n222[0];
    n223[1] = n222[1];
  }
  if (n136[0]) {
    n224[0] = n132[0];
    n224[1] = n132[1];
  }
  else {
    n224[0] = n223[0];
    n224[1] = n223[1];
  }
  if (n134[0]) {
    n225[0] = n132[0];
    n225[1] = n132[1];
  }
  else {
    n225[0] = n224[0];
    n225[1] = n224[1];
  }
  n269[0] = (1 & (n225[1] >> 7));
  n266[0] = (1 & (n225[1] >> 6));
  n263[0] = (1 & (n225[1] >> 5));
  n260[0] = (1 & (n225[1] >> 4));
  n257[0] = (1 & (n225[1] >> 3));
  n254[0] = (1 & (n225[1] >> 2));
  n251[0] = (1 & (n225[1] >> 1));
  n248[0] = (1 & (n225[1]));
  n245[0] = (1 & (n225[0] >> 7));
  n242[0] = (1 & (n225[0] >> 6));
  n239[0] = (1 & (n225[0] >> 5));
  n236[0] = (1 & (n225[0] >> 4));
  n233[0] = (1 & (n225[0] >> 3));
  n230[0] = (1 & (n225[0] >> 2));
  n227[0] = (1 & (n225[0] >> 1));
  n478r[0] = reset_state_i[0];
  n478e[0] = n269[0];
  n478d[0] = n403[0];
  n478d[1] = n403[1];
  n473r[0] = reset_state_i[0];
  n473e[0] = n266[0];
  n473d[0] = n403[0];
  n473d[1] = n403[1];
  n468r[0] = reset_state_i[0];
  n468e[0] = n263[0];
  n468d[0] = n403[0];
  n468d[1] = n403[1];
  n463r[0] = reset_state_i[0];
  n463e[0] = n260[0];
  n463d[0] = n403[0];
  n463d[1] = n403[1];
  n458r[0] = reset_state_i[0];
  n458e[0] = n257[0];
  n458d[0] = n403[0];
  n458d[1] = n403[1];
  n453r[0] = reset_state_i[0];
  n453e[0] = n254[0];
  n453d[0] = n403[0];
  n453d[1] = n403[1];
  n448r[0] = reset_state_i[0];
  n448e[0] = n251[0];
  n448d[0] = n403[0];
  n448d[1] = n403[1];
  n443r[0] = reset_state_i[0];
  n443e[0] = n248[0];
  n443d[0] = n403[0];
  n443d[1] = n403[1];
  n438r[0] = reset_state_i[0];
  n438e[0] = n245[0];
  n438d[0] = n403[0];
  n438d[1] = n403[1];
  n433r[0] = reset_state_i[0];
  n433e[0] = n242[0];
  n433d[0] = n403[0];
  n433d[1] = n403[1];
  n428r[0] = reset_state_i[0];
  n428e[0] = n239[0];
  n428d[0] = n403[0];
  n428d[1] = n403[1];
  n423r[0] = reset_state_i[0];
  n423e[0] = n236[0];
  n423d[0] = n403[0];
  n423d[1] = n403[1];
  n418r[0] = reset_state_i[0];
  n418e[0] = n233[0];
  n418d[0] = n403[0];
  n418d[1] = n403[1];
  n413r[0] = reset_state_i[0];
  n413e[0] = n230[0];
  n413d[0] = n403[0];
  n413d[1] = n403[1];
  n408r[0] = reset_state_i[0];
  n408e[0] = n227[0];
  n408d[0] = n403[0];
  n408d[1] = n403[1];
}

void cf_ssp_16_8_init() {
  n620[0] = 0;
  n611[0] = 0;
  n610[0] = 0;
  n510[0] = 0;
  n509[0] = 0;
  n508[0] = 0;
  n507[0] = 0;
  n506[0] = 0;
  n505[0] = 0;
  n497[0] = 0;
  n496[0] = 0;
  n495[0] = 0;
  n494[0] = 0;
  n493[0] = 0;
  n492[0] = 0;
  n491[0] = 0;
  n490[0] = 0;
  n489[0] = 0;
  n488[0] = 0;
  n487[0] = 0;
  n486[0] = 0;
  n485[0] = 0;
  n484[0] = 0;
  n483[0] = 0;
  n482[0] = 0;
  n481[0] = 0;
  n383[0] = 0;
  n382[0] = 0;
  n375[0] = 0;
  n372[0] = 0;
  n369[0] = 0;
  n359[0] = 0;
  n310[0] = 0;
  n309[0] = 0;
  n280[0] = 0;
  n279[0] = 0;
  { int index; for (index = 2; index > 0;) n226[--index] = 0; }
  n193[0] = 0;
  n191[0] = 0;
  n189[0] = 0;
  n187[0] = 0;
  n185[0] = 0;
  n183[0] = 0;
  n181[0] = 0;
  n179[0] = 0;
  n177[0] = 0;
  n175[0] = 0;
  n173[0] = 0;
  n171[0] = 0;
  n169[0] = 0;
  n167[0] = 0;
  n165[0] = 0;
  n163[0] = 0;
  n161[0] = 0;
  n159[0] = 0;
  n157[0] = 0;
  n155[0] = 0;
  n153[0] = 0;
  n151[0] = 0;
  n149[0] = 0;
  n147[0] = 0;
  n145[0] = 0;
  n143[0] = 0;
  n141[0] = 0;
  n139[0] = 0;
  n137[0] = 0;
  n135[0] = 0;
  n133[0] = 0;
  { int index; for (index = 2; index > 0;) n132[--index] = 0; }
  { int index; for (index = 2; index > 0;) n131[--index] = 0; }
  { int index; for (index = 2; index > 0;) n130[--index] = 0; }
  { int index; for (index = 2; index > 0;) n129[--index] = 0; }
  { int index; for (index = 2; index > 0;) n128[--index] = 0; }
  { int index; for (index = 2; index > 0;) n127[--index] = 0; }
  { int index; for (index = 2; index > 0;) n126[--index] = 0; }
  { int index; for (index = 2; index > 0;) n125[--index] = 0; }
  { int index; for (index = 2; index > 0;) n124[--index] = 0; }
  { int index; for (index = 2; index > 0;) n123[--index] = 0; }
  { int index; for (index = 2; index > 0;) n122[--index] = 0; }
  { int index; for (index = 2; index > 0;) n121[--index] = 0; }
  { int index; for (index = 2; index > 0;) n120[--index] = 0; }
  { int index; for (index = 2; index > 0;) n119[--index] = 0; }
  { int index; for (index = 2; index > 0;) n118[--index] = 0; }
  { int index; for (index = 2; index > 0;) n117[--index] = 0; }
  { int index; for (index = 2; index > 0;) n116[--index] = 0; }
  n61[0] = 0;
  n60[0] = 0;
  n59[0] = 0;
  n58[0] = 0;
  n57[0] = 0;
  n56[0] = 0;
  n55[0] = 0;
  n54[0] = 0;
  n49[0] = 0;
  n48[0] = 0;
  n47[0] = 0;
  n46[0] = 0;
  n45[0] = 0;
  n44[0] = 0;
  n43[0] = 0;
  n42[0] = 0;
  n41[0] = 0;
  n40[0] = 0;
  n39[0] = 0;
  n38[0] = 0;
  n37[0] = 0;
  n36[0] = 0;
  n35[0] = 0;
  n10[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  n389[0] = 0;
  n388[0] = 0;
  n376[0] = 0;
  n373[0] = 0;
  n370[0] = 0;
  n320[0] = 0;
  n319[0] = 0;
  { int index; for (index = 2; index > 0;) n318[--index] = 0; }
  { int index; for (index = 2; index > 0;) n317[--index] = 0; }
  { int index; for (index = 2; index > 0;) n316[--index] = 0; }
  { int index; for (index = 2; index > 0;) n315[--index] = 0; }
  { int index; for (index = 2; index > 0;) n314[--index] = 0; }
  { int index; for (index = 2; index > 0;) n313[--index] = 0; }
  { int index; for (index = 2; index > 0;) n312[--index] = 0; }
  { int index; for (index = 2; index > 0;) n311[--index] = 0; }
  n290[0] = 0;
  n289[0] = 0;
  { int index; for (index = 2; index > 0;) n288[--index] = 0; }
  { int index; for (index = 2; index > 0;) n287[--index] = 0; }
  { int index; for (index = 2; index > 0;) n286[--index] = 0; }
  { int index; for (index = 2; index > 0;) n285[--index] = 0; }
  { int index; for (index = 2; index > 0;) n284[--index] = 0; }
  { int index; for (index = 2; index > 0;) n283[--index] = 0; }
  { int index; for (index = 2; index > 0;) n282[--index] = 0; }
  { int index; for (index = 2; index > 0;) n281[--index] = 0; }
  n114[0] = 0;
  n112[0] = 0;
  n104[0] = 0;
  n103[0] = 0;
  n102[0] = 0;
  n101[0] = 0;
  n33[0] = 0;
  n32[0] = 0;
  n32r[0] = 0;
  n32e[0] = 0;
  n32d[0] = 0;
  n25[0] = 0;
  n25r[0] = 0;
  n25e[0] = 0;
  n25d[0] = 0;
  n13[0] = 0;
  n393[0] = 0;
  n338[0] = 0;
  n338r[0] = 0;
  n338e[0] = 0;
  n338d[0] = 0;
  n326[0] = 0;
  n325[0] = 0;
  { int index; for (index = 2; index > 0;) n324[--index] = 0; }
  { int index; for (index = 2; index > 0;) n323[--index] = 0; }
  { int index; for (index = 2; index > 0;) n322[--index] = 0; }
  { int index; for (index = 2; index > 0;) n321[--index] = 0; }
  n308[0] = 0;
  n308r[0] = 0;
  n308e[0] = 0;
  n308d[0] = 0;
  n296[0] = 0;
  n295[0] = 0;
  { int index; for (index = 2; index > 0;) n294[--index] = 0; }
  { int index; for (index = 2; index > 0;) n293[--index] = 0; }
  { int index; for (index = 2; index > 0;) n292[--index] = 0; }
  { int index; for (index = 2; index > 0;) n291[--index] = 0; }
  n278[0] = 0;
  n278r[0] = 0;
  n278e[0] = 0;
  n278d[0] = 0;
  n111[0] = 0;
  n111r[0] = 0;
  n111e[0] = 0;
  n111d[0] = 0;
  n34[0] = 0;
  n18[0] = 0;
  n18r[0] = 0;
  n18e[0] = 0;
  n18d[0] = 0;
  n330[0] = 0;
  { int index; for (index = 2; index > 0;) n328[--index] = 0; }
  { int index; for (index = 2; index > 0;) n327[--index] = 0; }
  n300[0] = 0;
  { int index; for (index = 2; index > 0;) n298[--index] = 0; }
  { int index; for (index = 2; index > 0;) n297[--index] = 0; }
  n67[0] = 0;
  { int index; for (index = 2; index > 0;) n331[--index] = 0; }
  { int index; for (index = 2; index > 0;) n301[--index] = 0; }
  n90[0] = 0;
  n89[0] = 0;
  n88[0] = 0;
  n87[0] = 0;
  n74[0] = 0;
  n73[0] = 0;
  n72[0] = 0;
  n71[0] = 0;
  n70[0] = 0;
  n69[0] = 0;
  n68[0] = 0;
  { int index; for (index = 2; index > 0;) n381[--index] = 0; }
  n371[0] = 0;
  { int index; for (index = 2; index > 0;) n368[--index] = 0; }
  { int index; for (index = 2; index > 0;) n367[--index] = 0; }
  n364[0] = 0;
  { int index; for (index = 2; index > 0;) n362[--index] = 0; }
  n361[0] = 0;
  { int index; for (index = 2; index > 0;) n358[--index] = 0; }
  n339[0] = 0;
  n97[0] = 0;
  n75[0] = 0;
  { int index; for (index = 2; index > 0;) n387[--index] = 0; }
  { int index; for (index = 2; index > 0;) n380[--index] = 0; }
  n377[0] = 0;
  n374[0] = 0;
  n365[0] = 0;
  { int index; for (index = 2; index > 0;) n363[--index] = 0; }
  { int index; for (index = 2; index > 0;) n360[--index] = 0; }
  n340[0] = 0;
  n98[0] = 0;
  n76[0] = 0;
  n395[0] = 0;
  { int index; for (index = 2; index > 0;) n386[--index] = 0; }
  { int index; for (index = 2; index > 0;) n384[--index] = 0; }
  n343[0] = 0;
  n99[0] = 0;
  n77[0] = 0;
  n396[0] = 0;
  { int index; for (index = 2; index > 0;) n391[--index] = 0; }
  n344[0] = 0;
  n100[0] = 0;
  n78[0] = 0;
  n479[0] = 0;
  n397[0] = 0;
  n345[0] = 0;
  n113[0] = 0;
  n79[0] = 0;
  n520[0] = 0;
  n402[0] = 0;
  n402r[0] = 0;
  n402e[0] = 0;
  n402d[0] = 0;
  n346[0] = 0;
  n115[0] = 0;
  n80[0] = 0;
  n551[0] = 0;
  n550[0] = 0;
  n549[0] = 0;
  n548[0] = 0;
  n530[0] = 0;
  n529[0] = 0;
  n528[0] = 0;
  n527[0] = 0;
  n526[0] = 0;
  n525[0] = 0;
  n524[0] = 0;
  n523[0] = 0;
  n522[0] = 0;
  n521[0] = 0;
  n347[0] = 0;
  n194[0] = 0;
  n192[0] = 0;
  n190[0] = 0;
  n188[0] = 0;
  n186[0] = 0;
  n184[0] = 0;
  n182[0] = 0;
  n180[0] = 0;
  n178[0] = 0;
  n176[0] = 0;
  n174[0] = 0;
  n172[0] = 0;
  n170[0] = 0;
  n168[0] = 0;
  n166[0] = 0;
  n164[0] = 0;
  n162[0] = 0;
  n160[0] = 0;
  n158[0] = 0;
  n156[0] = 0;
  n154[0] = 0;
  n152[0] = 0;
  n150[0] = 0;
  n148[0] = 0;
  n146[0] = 0;
  n144[0] = 0;
  n142[0] = 0;
  n140[0] = 0;
  n138[0] = 0;
  n136[0] = 0;
  n134[0] = 0;
  n81[0] = 0;
  n566[0] = 0;
  n533[0] = 0;
  n348[0] = 0;
  { int index; for (index = 2; index > 0;) n195[--index] = 0; }
  n86[0] = 0;
  n86r[0] = 0;
  n86e[0] = 0;
  n86d[0] = 0;
  n567[0] = 0;
  n534[0] = 0;
  n349[0] = 0;
  { int index; for (index = 2; index > 0;) n196[--index] = 0; }
  n568[0] = 0;
  n535[0] = 0;
  { int index; for (index = 2; index > 0;) n350[--index] = 0; }
  { int index; for (index = 2; index > 0;) n197[--index] = 0; }
  n569[0] = 0;
  n536[0] = 0;
  { int index; for (index = 2; index > 0;) n351[--index] = 0; }
  { int index; for (index = 2; index > 0;) n198[--index] = 0; }
  n537[0] = 0;
  { int index; for (index = 2; index > 0;) n352[--index] = 0; }
  { int index; for (index = 2; index > 0;) n199[--index] = 0; }
  n538[0] = 0;
  { int index; for (index = 2; index > 0;) n353[--index] = 0; }
  { int index; for (index = 2; index > 0;) n200[--index] = 0; }
  n539[0] = 0;
  { int index; for (index = 2; index > 0;) n354[--index] = 0; }
  { int index; for (index = 2; index > 0;) n201[--index] = 0; }
  n540[0] = 0;
  { int index; for (index = 2; index > 0;) n355[--index] = 0; }
  { int index; for (index = 2; index > 0;) n202[--index] = 0; }
  n541[0] = 0;
  { int index; for (index = 2; index > 0;) n356[--index] = 0; }
  { int index; for (index = 2; index > 0;) n203[--index] = 0; }
  n542[0] = 0;
  { int index; for (index = 2; index > 0;) n357[--index] = 0; }
  { int index; for (index = 2; index > 0;) n204[--index] = 0; }
  n547[0] = 0;
  n547r[0] = 0;
  n547e[0] = 0;
  n547d[0] = 0;
  { int index; for (index = 2; index > 0;) n366[--index] = 0; }
  { int index; for (index = 2; index > 0;) n205[--index] = 0; }
  { int index; for (index = 2; index > 0;) n385[--index] = 0; }
  { int index; for (index = 2; index > 0;) n206[--index] = 0; }
  { int index; for (index = 2; index > 0;) n390[--index] = 0; }
  { int index; for (index = 2; index > 0;) n207[--index] = 0; }
  { int index; for (index = 2; index > 0;) n394[--index] = 0; }
  { int index; for (index = 2; index > 0;) n208[--index] = 0; }
  { int index; for (index = 2; index > 0;) n403[--index] = 0; }
  { int index; for (index = 2; index > 0;) n209[--index] = 0; }
  { int index; for (index = 2; index > 0;) n210[--index] = 0; }
  { int index; for (index = 2; index > 0;) n211[--index] = 0; }
  { int index; for (index = 2; index > 0;) n212[--index] = 0; }
  { int index; for (index = 2; index > 0;) n213[--index] = 0; }
  { int index; for (index = 2; index > 0;) n214[--index] = 0; }
  { int index; for (index = 2; index > 0;) n215[--index] = 0; }
  { int index; for (index = 2; index > 0;) n216[--index] = 0; }
  { int index; for (index = 2; index > 0;) n217[--index] = 0; }
  { int index; for (index = 2; index > 0;) n218[--index] = 0; }
  { int index; for (index = 2; index > 0;) n219[--index] = 0; }
  { int index; for (index = 2; index > 0;) n220[--index] = 0; }
  { int index; for (index = 2; index > 0;) n221[--index] = 0; }
  { int index; for (index = 2; index > 0;) n222[--index] = 0; }
  { int index; for (index = 2; index > 0;) n223[--index] = 0; }
  { int index; for (index = 2; index > 0;) n224[--index] = 0; }
  { int index; for (index = 2; index > 0;) n225[--index] = 0; }
  n269[0] = 0;
  n266[0] = 0;
  n263[0] = 0;
  n260[0] = 0;
  n257[0] = 0;
  n254[0] = 0;
  n251[0] = 0;
  n248[0] = 0;
  n245[0] = 0;
  n242[0] = 0;
  n239[0] = 0;
  n236[0] = 0;
  n233[0] = 0;
  n230[0] = 0;
  n227[0] = 0;
  { int index; for (index = 2; index > 0;) n478[--index] = 0; }
  n478r[0] = 0;
  n478e[0] = 0;
  { int index; for (index = 2; index > 0;) n478d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n473[--index] = 0; }
  n473r[0] = 0;
  n473e[0] = 0;
  { int index; for (index = 2; index > 0;) n473d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n468[--index] = 0; }
  n468r[0] = 0;
  n468e[0] = 0;
  { int index; for (index = 2; index > 0;) n468d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n463[--index] = 0; }
  n463r[0] = 0;
  n463e[0] = 0;
  { int index; for (index = 2; index > 0;) n463d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n458[--index] = 0; }
  n458r[0] = 0;
  n458e[0] = 0;
  { int index; for (index = 2; index > 0;) n458d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n453[--index] = 0; }
  n453r[0] = 0;
  n453e[0] = 0;
  { int index; for (index = 2; index > 0;) n453d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n448[--index] = 0; }
  n448r[0] = 0;
  n448e[0] = 0;
  { int index; for (index = 2; index > 0;) n448d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n443[--index] = 0; }
  n443r[0] = 0;
  n443e[0] = 0;
  { int index; for (index = 2; index > 0;) n443d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n438[--index] = 0; }
  n438r[0] = 0;
  n438e[0] = 0;
  { int index; for (index = 2; index > 0;) n438d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n433[--index] = 0; }
  n433r[0] = 0;
  n433e[0] = 0;
  { int index; for (index = 2; index > 0;) n433d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n428[--index] = 0; }
  n428r[0] = 0;
  n428e[0] = 0;
  { int index; for (index = 2; index > 0;) n428d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n423[--index] = 0; }
  n423r[0] = 0;
  n423e[0] = 0;
  { int index; for (index = 2; index > 0;) n423d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n418[--index] = 0; }
  n418r[0] = 0;
  n418e[0] = 0;
  { int index; for (index = 2; index > 0;) n418d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n413[--index] = 0; }
  n413r[0] = 0;
  n413e[0] = 0;
  { int index; for (index = 2; index > 0;) n413d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n408[--index] = 0; }
  n408r[0] = 0;
  n408e[0] = 0;
  { int index; for (index = 2; index > 0;) n408d[--index] = 0; }
  cf_ssp_16_8_calc();
}

void cf_ssp_16_8_cycle_clock()
{
  if (n18r[0]) {
    n18[0] = 0;
  }
  else if (n18e[0]) {
    n18[0] = n18d[0];
  }
  if (n25r[0]) {
    n25[0] = 0;
  }
  else if (n25e[0]) {
    n25[0] = n25d[0];
  }
  if (n32r[0]) {
    n32[0] = 0;
  }
  else if (n32e[0]) {
    n32[0] = n32d[0];
  }
  if (n86r[0]) {
    n86[0] = 0;
  }
  else if (n86e[0]) {
    n86[0] = n86d[0];
  }
  if (n111r[0]) {
    n111[0] = 0;
  }
  else if (n111e[0]) {
    n111[0] = n111d[0];
  }
  if (n278r[0]) {
    n278[0] = 0;
  }
  else if (n278e[0]) {
    n278[0] = n278d[0];
  }
  if (n308r[0]) {
    n308[0] = 0;
  }
  else if (n308e[0]) {
    n308[0] = n308d[0];
  }
  if (n338r[0]) {
    n338[0] = 0;
  }
  else if (n338e[0]) {
    n338[0] = n338d[0];
  }
  if (n402r[0]) {
    n402[0] = 0;
  }
  else if (n402e[0]) {
    n402[0] = n402d[0];
  }
  if (n408r[0]) {
    n408[0] = 0;
    n408[1] = 0;
  }
  else if (n408e[0]) {
    n408[0] = n408d[0];
    n408[1] = n408d[1];
  }
  if (n413r[0]) {
    n413[0] = 0;
    n413[1] = 0;
  }
  else if (n413e[0]) {
    n413[0] = n413d[0];
    n413[1] = n413d[1];
  }
  if (n418r[0]) {
    n418[0] = 0;
    n418[1] = 0;
  }
  else if (n418e[0]) {
    n418[0] = n418d[0];
    n418[1] = n418d[1];
  }
  if (n423r[0]) {
    n423[0] = 0;
    n423[1] = 0;
  }
  else if (n423e[0]) {
    n423[0] = n423d[0];
    n423[1] = n423d[1];
  }
  if (n428r[0]) {
    n428[0] = 0;
    n428[1] = 0;
  }
  else if (n428e[0]) {
    n428[0] = n428d[0];
    n428[1] = n428d[1];
  }
  if (n433r[0]) {
    n433[0] = 0;
    n433[1] = 0;
  }
  else if (n433e[0]) {
    n433[0] = n433d[0];
    n433[1] = n433d[1];
  }
  if (n438r[0]) {
    n438[0] = 0;
    n438[1] = 0;
  }
  else if (n438e[0]) {
    n438[0] = n438d[0];
    n438[1] = n438d[1];
  }
  if (n443r[0]) {
    n443[0] = 0;
    n443[1] = 0;
  }
  else if (n443e[0]) {
    n443[0] = n443d[0];
    n443[1] = n443d[1];
  }
  if (n448r[0]) {
    n448[0] = 0;
    n448[1] = 0;
  }
  else if (n448e[0]) {
    n448[0] = n448d[0];
    n448[1] = n448d[1];
  }
  if (n453r[0]) {
    n453[0] = 0;
    n453[1] = 0;
  }
  else if (n453e[0]) {
    n453[0] = n453d[0];
    n453[1] = n453d[1];
  }
  if (n458r[0]) {
    n458[0] = 0;
    n458[1] = 0;
  }
  else if (n458e[0]) {
    n458[0] = n458d[0];
    n458[1] = n458d[1];
  }
  if (n463r[0]) {
    n463[0] = 0;
    n463[1] = 0;
  }
  else if (n463e[0]) {
    n463[0] = n463d[0];
    n463[1] = n463d[1];
  }
  if (n468r[0]) {
    n468[0] = 0;
    n468[1] = 0;
  }
  else if (n468e[0]) {
    n468[0] = n468d[0];
    n468[1] = n468d[1];
  }
  if (n473r[0]) {
    n473[0] = 0;
    n473[1] = 0;
  }
  else if (n473e[0]) {
    n473[0] = n473d[0];
    n473[1] = n473d[1];
  }
  if (n478r[0]) {
    n478[0] = 0;
    n478[1] = 0;
  }
  else if (n478e[0]) {
    n478[0] = n478d[0];
    n478[1] = n478d[1];
  }
  if (n547r[0]) {
    n547[0] = 0;
  }
  else if (n547e[0]) {
    n547[0] = n547d[0];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_state_i[1];
static unsigned char sim_cycle_i[1];
static unsigned char sim_instr_data_i[2];
static unsigned char sim_const_data_i[2];
static unsigned char sim_load_write_i[1];
static unsigned char sim_load_addr_i[1];
static unsigned char sim_load_data_i[2];
static unsigned char sim_done_o[1];
static unsigned char sim_instr_addr_o[1];
static unsigned char sim_const_addr_o[1];
static unsigned char sim_reg_0_o[2];
static unsigned char sim_reg_1_o[2];
static unsigned char sim_reg_2_o[2];
static unsigned char sim_reg_3_o[2];
static unsigned char sim_reg_4_o[2];
static unsigned char sim_reg_5_o[2];
static unsigned char sim_reg_6_o[2];
static unsigned char sim_reg_7_o[2];
static unsigned char sim_reg_8_o[2];
static unsigned char sim_reg_9_o[2];
static unsigned char sim_reg_a_o[2];
static unsigned char sim_reg_b_o[2];
static unsigned char sim_reg_c_o[2];
static unsigned char sim_reg_d_o[2];
static unsigned char sim_reg_e_o[2];
static unsigned char sim_reg_f_o[2];

void cf_ssp_16_8_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_ssp_16_8_init();
  sim_reset_state_i[0] = reset_state_i[0];
  sim_cycle_i[0] = cycle_i[0];
  sim_instr_data_i[0] = instr_data_i[0];
  sim_instr_data_i[1] = instr_data_i[1];
  sim_const_data_i[0] = const_data_i[0];
  sim_const_data_i[1] = const_data_i[1];
  sim_load_write_i[0] = load_write_i[0];
  sim_load_addr_i[0] = load_addr_i[0];
  sim_load_data_i[0] = load_data_i[0];
  sim_load_data_i[1] = load_data_i[1];
  sim_done_o[0] = done_o[0];
  sim_instr_addr_o[0] = instr_addr_o[0];
  sim_const_addr_o[0] = const_addr_o[0];
  sim_reg_0_o[0] = reg_0_o[0];
  sim_reg_0_o[1] = reg_0_o[1];
  sim_reg_1_o[0] = reg_1_o[0];
  sim_reg_1_o[1] = reg_1_o[1];
  sim_reg_2_o[0] = reg_2_o[0];
  sim_reg_2_o[1] = reg_2_o[1];
  sim_reg_3_o[0] = reg_3_o[0];
  sim_reg_3_o[1] = reg_3_o[1];
  sim_reg_4_o[0] = reg_4_o[0];
  sim_reg_4_o[1] = reg_4_o[1];
  sim_reg_5_o[0] = reg_5_o[0];
  sim_reg_5_o[1] = reg_5_o[1];
  sim_reg_6_o[0] = reg_6_o[0];
  sim_reg_6_o[1] = reg_6_o[1];
  sim_reg_7_o[0] = reg_7_o[0];
  sim_reg_7_o[1] = reg_7_o[1];
  sim_reg_8_o[0] = reg_8_o[0];
  sim_reg_8_o[1] = reg_8_o[1];
  sim_reg_9_o[0] = reg_9_o[0];
  sim_reg_9_o[1] = reg_9_o[1];
  sim_reg_a_o[0] = reg_a_o[0];
  sim_reg_a_o[1] = reg_a_o[1];
  sim_reg_b_o[0] = reg_b_o[0];
  sim_reg_b_o[1] = reg_b_o[1];
  sim_reg_c_o[0] = reg_c_o[0];
  sim_reg_c_o[1] = reg_c_o[1];
  sim_reg_d_o[0] = reg_d_o[0];
  sim_reg_d_o[1] = reg_d_o[1];
  sim_reg_e_o[0] = reg_e_o[0];
  sim_reg_e_o[1] = reg_e_o[1];
  sim_reg_f_o[0] = reg_f_o[0];
  sim_reg_f_o[1] = reg_f_o[1];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_ssp_16_8 $end\n"
    "$var wire 1 ! reset_state_i $end\n"
    "$var wire 1 \" cycle_i $end\n"
    "$var wire 16 # instr_data_i $end\n"
    "$var wire 16 $ const_data_i $end\n"
    "$var wire 1 %% load_write_i $end\n"
    "$var wire 4 & load_addr_i $end\n"
    "$var wire 16 ' load_data_i $end\n"
    "$var wire 1 ( done_o $end\n"
    "$var wire 8 ) instr_addr_o $end\n"
    "$var wire 8 * const_addr_o $end\n"
    "$var wire 16 + reg_0_o $end\n"
    "$var wire 16 , reg_1_o $end\n"
    "$var wire 16 - reg_2_o $end\n"
    "$var wire 16 . reg_3_o $end\n"
    "$var wire 16 / reg_4_o $end\n"
    "$var wire 16 0 reg_5_o $end\n"
    "$var wire 16 1 reg_6_o $end\n"
    "$var wire 16 2 reg_7_o $end\n"
    "$var wire 16 3 reg_8_o $end\n"
    "$var wire 16 4 reg_9_o $end\n"
    "$var wire 16 5 reg_a_o $end\n"
    "$var wire 16 6 reg_b_o $end\n"
    "$var wire 16 7 reg_c_o $end\n"
    "$var wire 16 8 reg_d_o $end\n"
    "$var wire 16 9 reg_e_o $end\n"
    "$var wire 16 : reg_f_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_state_i[0] ? "1!\n" : "0!\n");
  fprintf(sim_file, cycle_i[0] ? "1\"\n" : "0\"\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & instr_data_i[byte]) ? "1" : "0");
        else if (bit & instr_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & const_data_i[byte]) ? "1" : "0");
        else if (bit & const_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  fprintf(sim_file, load_write_i[0] ? "1%%\n" : "0%%\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & load_addr_i[byte]) ? "1" : "0");
        else if (bit & load_addr_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & load_data_i[byte]) ? "1" : "0");
        else if (bit & load_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  fprintf(sim_file, done_o[0] ? "1(\n" : "0(\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & instr_addr_o[byte]) ? "1" : "0");
        else if (bit & instr_addr_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & const_addr_o[byte]) ? "1" : "0");
        else if (bit & const_addr_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_0_o[byte]) ? "1" : "0");
        else if (bit & reg_0_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_1_o[byte]) ? "1" : "0");
        else if (bit & reg_1_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ,\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_2_o[byte]) ? "1" : "0");
        else if (bit & reg_2_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " -\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_3_o[byte]) ? "1" : "0");
        else if (bit & reg_3_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " .\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_4_o[byte]) ? "1" : "0");
        else if (bit & reg_4_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " /\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_5_o[byte]) ? "1" : "0");
        else if (bit & reg_5_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 0\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_6_o[byte]) ? "1" : "0");
        else if (bit & reg_6_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 1\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_7_o[byte]) ? "1" : "0");
        else if (bit & reg_7_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 2\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_8_o[byte]) ? "1" : "0");
        else if (bit & reg_8_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 3\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_9_o[byte]) ? "1" : "0");
        else if (bit & reg_9_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 4\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_a_o[byte]) ? "1" : "0");
        else if (bit & reg_a_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 5\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_b_o[byte]) ? "1" : "0");
        else if (bit & reg_b_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 6\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_c_o[byte]) ? "1" : "0");
        else if (bit & reg_c_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 7\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_d_o[byte]) ? "1" : "0");
        else if (bit & reg_d_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 8\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_e_o[byte]) ? "1" : "0");
        else if (bit & reg_e_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 9\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_f_o[byte]) ? "1" : "0");
        else if (bit & reg_f_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " :\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_ssp_16_8_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_ssp_16_8_sim_sample() {
  int changed = 0;
  if (sim_reset_state_i[0] != reset_state_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_state_i[0] ? "1!\n" : "0!\n");
    sim_reset_state_i[0] = reset_state_i[0];
  }
  if (sim_cycle_i[0] != cycle_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, cycle_i[0] ? "1\"\n" : "0\"\n");
    sim_cycle_i[0] = cycle_i[0];
  }
  if (sim_instr_data_i[1] != instr_data_i[1] || sim_instr_data_i[0] != instr_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & instr_data_i[byte]) ? "1" : "0");
          else if (bit & instr_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_instr_data_i[0] = instr_data_i[0];
    sim_instr_data_i[1] = instr_data_i[1];
  }
  if (sim_const_data_i[1] != const_data_i[1] || sim_const_data_i[0] != const_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & const_data_i[byte]) ? "1" : "0");
          else if (bit & const_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_const_data_i[0] = const_data_i[0];
    sim_const_data_i[1] = const_data_i[1];
  }
  if (sim_load_write_i[0] != load_write_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, load_write_i[0] ? "1%%\n" : "0%%\n");
    sim_load_write_i[0] = load_write_i[0];
  }
  if (sim_load_addr_i[0] != load_addr_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & load_addr_i[byte]) ? "1" : "0");
          else if (bit & load_addr_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_load_addr_i[0] = load_addr_i[0];
  }
  if (sim_load_data_i[1] != load_data_i[1] || sim_load_data_i[0] != load_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & load_data_i[byte]) ? "1" : "0");
          else if (bit & load_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_load_data_i[0] = load_data_i[0];
    sim_load_data_i[1] = load_data_i[1];
  }
  if (sim_done_o[0] != done_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, done_o[0] ? "1(\n" : "0(\n");
    sim_done_o[0] = done_o[0];
  }
  if (sim_instr_addr_o[0] != instr_addr_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & instr_addr_o[byte]) ? "1" : "0");
          else if (bit & instr_addr_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_instr_addr_o[0] = instr_addr_o[0];
  }
  if (sim_const_addr_o[0] != const_addr_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & const_addr_o[byte]) ? "1" : "0");
          else if (bit & const_addr_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_const_addr_o[0] = const_addr_o[0];
  }
  if (sim_reg_0_o[1] != reg_0_o[1] || sim_reg_0_o[0] != reg_0_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_0_o[byte]) ? "1" : "0");
          else if (bit & reg_0_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_reg_0_o[0] = reg_0_o[0];
    sim_reg_0_o[1] = reg_0_o[1];
  }
  if (sim_reg_1_o[1] != reg_1_o[1] || sim_reg_1_o[0] != reg_1_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_1_o[byte]) ? "1" : "0");
          else if (bit & reg_1_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ,\n");
    }
    sim_reg_1_o[0] = reg_1_o[0];
    sim_reg_1_o[1] = reg_1_o[1];
  }
  if (sim_reg_2_o[1] != reg_2_o[1] || sim_reg_2_o[0] != reg_2_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_2_o[byte]) ? "1" : "0");
          else if (bit & reg_2_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " -\n");
    }
    sim_reg_2_o[0] = reg_2_o[0];
    sim_reg_2_o[1] = reg_2_o[1];
  }
  if (sim_reg_3_o[1] != reg_3_o[1] || sim_reg_3_o[0] != reg_3_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_3_o[byte]) ? "1" : "0");
          else if (bit & reg_3_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " .\n");
    }
    sim_reg_3_o[0] = reg_3_o[0];
    sim_reg_3_o[1] = reg_3_o[1];
  }
  if (sim_reg_4_o[1] != reg_4_o[1] || sim_reg_4_o[0] != reg_4_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_4_o[byte]) ? "1" : "0");
          else if (bit & reg_4_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " /\n");
    }
    sim_reg_4_o[0] = reg_4_o[0];
    sim_reg_4_o[1] = reg_4_o[1];
  }
  if (sim_reg_5_o[1] != reg_5_o[1] || sim_reg_5_o[0] != reg_5_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_5_o[byte]) ? "1" : "0");
          else if (bit & reg_5_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 0\n");
    }
    sim_reg_5_o[0] = reg_5_o[0];
    sim_reg_5_o[1] = reg_5_o[1];
  }
  if (sim_reg_6_o[1] != reg_6_o[1] || sim_reg_6_o[0] != reg_6_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_6_o[byte]) ? "1" : "0");
          else if (bit & reg_6_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 1\n");
    }
    sim_reg_6_o[0] = reg_6_o[0];
    sim_reg_6_o[1] = reg_6_o[1];
  }
  if (sim_reg_7_o[1] != reg_7_o[1] || sim_reg_7_o[0] != reg_7_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_7_o[byte]) ? "1" : "0");
          else if (bit & reg_7_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 2\n");
    }
    sim_reg_7_o[0] = reg_7_o[0];
    sim_reg_7_o[1] = reg_7_o[1];
  }
  if (sim_reg_8_o[1] != reg_8_o[1] || sim_reg_8_o[0] != reg_8_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_8_o[byte]) ? "1" : "0");
          else if (bit & reg_8_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 3\n");
    }
    sim_reg_8_o[0] = reg_8_o[0];
    sim_reg_8_o[1] = reg_8_o[1];
  }
  if (sim_reg_9_o[1] != reg_9_o[1] || sim_reg_9_o[0] != reg_9_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_9_o[byte]) ? "1" : "0");
          else if (bit & reg_9_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 4\n");
    }
    sim_reg_9_o[0] = reg_9_o[0];
    sim_reg_9_o[1] = reg_9_o[1];
  }
  if (sim_reg_a_o[1] != reg_a_o[1] || sim_reg_a_o[0] != reg_a_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_a_o[byte]) ? "1" : "0");
          else if (bit & reg_a_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 5\n");
    }
    sim_reg_a_o[0] = reg_a_o[0];
    sim_reg_a_o[1] = reg_a_o[1];
  }
  if (sim_reg_b_o[1] != reg_b_o[1] || sim_reg_b_o[0] != reg_b_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_b_o[byte]) ? "1" : "0");
          else if (bit & reg_b_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 6\n");
    }
    sim_reg_b_o[0] = reg_b_o[0];
    sim_reg_b_o[1] = reg_b_o[1];
  }
  if (sim_reg_c_o[1] != reg_c_o[1] || sim_reg_c_o[0] != reg_c_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_c_o[byte]) ? "1" : "0");
          else if (bit & reg_c_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 7\n");
    }
    sim_reg_c_o[0] = reg_c_o[0];
    sim_reg_c_o[1] = reg_c_o[1];
  }
  if (sim_reg_d_o[1] != reg_d_o[1] || sim_reg_d_o[0] != reg_d_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_d_o[byte]) ? "1" : "0");
          else if (bit & reg_d_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 8\n");
    }
    sim_reg_d_o[0] = reg_d_o[0];
    sim_reg_d_o[1] = reg_d_o[1];
  }
  if (sim_reg_e_o[1] != reg_e_o[1] || sim_reg_e_o[0] != reg_e_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_e_o[byte]) ? "1" : "0");
          else if (bit & reg_e_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 9\n");
    }
    sim_reg_e_o[0] = reg_e_o[0];
    sim_reg_e_o[1] = reg_e_o[1];
  }
  if (sim_reg_f_o[1] != reg_f_o[1] || sim_reg_f_o[0] != reg_f_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_f_o[byte]) ? "1" : "0");
          else if (bit & reg_f_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " :\n");
    }
    sim_reg_f_o[0] = reg_f_o[0];
    sim_reg_f_o[1] = reg_f_o[1];
  }
  sim_count++;
}

