//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    State Space Processor is used for implementing discrete (digital) linear systems, such as
//    finite impulse response filters, infinite impulse response filters, multiple input and output
//    systems, and general state space equations.
//  
//  Architecture:
//  
//    The State Space Processor is designed with a small logic footprint for area limited
//    applications.  The processor requires two external memories: one for program instructions
//    and the other for constants (coefficients) used in calculation.  The processor maintains a
//    register file of 16 N-bit registers used to retain state information and for processing intermediate
//    results.  The register file is also used for handling input and output; registers can be written
//    from an external source and all registers are available as outputs.  For convenience, register 0
//    is wired to ground (0) and instructions updating r0 have no effect on the register file.
//  
//    The processor runs calculations on a cycle basis:
//      1. The external environment writes inputs into the register file.
//      2. The external environment signals a "Cycle" to run the program and calculate a cycle.
//      3. The external environment waits for "Done", then reads output from the register file.
//  
//  Instruction Set:
//  
//    There are 4 instruction types and a total of 8 instructions.  Each instruction is 16-bits.
//    The types include:
//      Unary Operation  : OpCode [15:12], Operand Reg A [11:8], Not Used [7:4], Result Reg X [3:0]
//      Binary Operation : OpCode [15:12], Operand Reg A [11:8], Operand Reg B [7:4], Result Reg X [3:0]
//      Constant Load    : OpCode [15:12], Constant Memory Address [11:4], Result Reg X [3:0]
//      Halt             : OpCode [15:12], Not Used [11:0]
//  
//    Unary Operations (OpCode):
//  
//      ShiftLeft  (0000) : RegX <- lsbs RegA '++' '0'
//                          Flag <- Flag
//      ShiftRight (0001) : RegX <- msb RegA '++' msbs RegA
//                          Flag <- lsb RegA
//      ShiftClip  (0010) : RegX <- lsbs RegA '++' '0' when top 2 bits of RegA == '00' or '11' else
//                                  '0111...1'         when top 2 bits of RegA == '01'         else
//                                  '1000...0'         when top 2 bits of RegA == '10'
//                          Flag <- Flag
//                          Performs a limited/clipped multiplication by 2.
//  
//    Binary Operations (OpCode):
//  
//      Add        (0011) : RegX <- RegA '+' RegB
//                          Flag <- msb Result
//      AddCond    (0100) : RegX <- RegA '+' RegB when Flag == '1' else RegA
//                          Flag <- Flag
//      Sub        (0101) : RegX <- RegA '-' RegB
//                          Flag <- msb Result
//      Switch     (0110) : RegX <- RegA when Flag == '1' else RegB
//                          Flag <- Flag
//  
//    Constant Load Instruction (OpCode):
//  
//      Constant   (0111) : RegX <- Data from constant memory.
//                          Flag <- Flag
//  
//    Halt Instruction (OpCode):
//  
//      Halt       (1---) : Halts processor (prevents further register updates).
//  
//    Booth multiplication can be performed using ShiftRight and AddCond with an accumulation register.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_state_i : Reset all state registers (register file and ALU flag).
//  
//    Inputs:
//      cycle_i      : Input pulse to perform a cycle (sample) calculation.
//      instr_data_i : Instruction data from instruction memory.
//      const_data_i : Constant data from constant memory.
//      load_write_i : Write enable for writing to register file.
//      load_addr_i  : Address (4-bits) for writing to register file.
//      load_data_i  : Data for writing to register file.
//  
//    Outputs:
//      done_o       : Output flag signaling processor is done calculating cycle (active high).
//      instr_addr_o : Address to instruction memory.
//      const_addr_o : Address to constant memory (8-bits).
//      reg_0_o      : Register 0 value.
//      reg_1_o      : Register 1 value.
//      ...
//      reg_f_o      : Register F value.
//  
//  Built In Parameters:
//  
//    Data Width                = 32
//    Instruction Address Width = 8
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:51:10 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_ssp_32_8
//    Clock Domains : clock_c  
//    Vector Input  : reset_state_i(1)
//    Vector Input  : cycle_i(1)
//    Vector Input  : instr_data_i(16)
//    Vector Input  : const_data_i(32)
//    Vector Input  : load_write_i(1)
//    Vector Input  : load_addr_i(4)
//    Vector Input  : load_data_i(32)
//    Vector Output : done_o(1)
//    Vector Output : instr_addr_o(8)
//    Vector Output : const_addr_o(8)
//    Vector Output : reg_0_o(32)
//    Vector Output : reg_1_o(32)
//    Vector Output : reg_2_o(32)
//    Vector Output : reg_3_o(32)
//    Vector Output : reg_4_o(32)
//    Vector Output : reg_5_o(32)
//    Vector Output : reg_6_o(32)
//    Vector Output : reg_7_o(32)
//    Vector Output : reg_8_o(32)
//    Vector Output : reg_9_o(32)
//    Vector Output : reg_a_o(32)
//    Vector Output : reg_b_o(32)
//    Vector Output : reg_c_o(32)
//    Vector Output : reg_d_o(32)
//    Vector Output : reg_e_o(32)
//    Vector Output : reg_f_o(32)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_ssp_32_8.h"

static unsigned char n636[1];
static unsigned char n627[1];
static unsigned char n626[1];
static unsigned char *reg_f_o;
static unsigned char *reg_e_o;
static unsigned char *reg_d_o;
static unsigned char *reg_c_o;
static unsigned char *reg_b_o;
static unsigned char *reg_a_o;
static unsigned char *reg_9_o;
static unsigned char *reg_8_o;
static unsigned char *reg_7_o;
static unsigned char *reg_6_o;
static unsigned char *reg_5_o;
static unsigned char *reg_4_o;
static unsigned char *reg_3_o;
static unsigned char *reg_2_o;
static unsigned char *reg_1_o;
static unsigned char *instr_addr_o;
static unsigned char n526[1];
static unsigned char n525[1];
static unsigned char n524[1];
static unsigned char n523[1];
static unsigned char n522[1];
static unsigned char n521[1];
static unsigned char n513[1];
static unsigned char n512[1];
static unsigned char n511[1];
static unsigned char n510[1];
static unsigned char n509[1];
static unsigned char n508[1];
static unsigned char n507[1];
static unsigned char n506[1];
static unsigned char n505[1];
static unsigned char n504[1];
static unsigned char n503[1];
static unsigned char n502[1];
static unsigned char n501[1];
static unsigned char n500[1];
static unsigned char n499[1];
static unsigned char n498[1];
static unsigned char n497[1];
static unsigned char n399[1];
static unsigned char n398[1];
static unsigned char n391[1];
static unsigned char n388[1];
static unsigned char n385[1];
static unsigned char n375[1];
static unsigned char n310[1];
static unsigned char n309[1];
static unsigned char n280[1];
static unsigned char n279[1];
static unsigned char n226[4];
static unsigned char n193[1];
static unsigned char n191[1];
static unsigned char n189[1];
static unsigned char n187[1];
static unsigned char n185[1];
static unsigned char n183[1];
static unsigned char n181[1];
static unsigned char n179[1];
static unsigned char n177[1];
static unsigned char n175[1];
static unsigned char n173[1];
static unsigned char n171[1];
static unsigned char n169[1];
static unsigned char n167[1];
static unsigned char n165[1];
static unsigned char n163[1];
static unsigned char n161[1];
static unsigned char n159[1];
static unsigned char n157[1];
static unsigned char n155[1];
static unsigned char n153[1];
static unsigned char n151[1];
static unsigned char n149[1];
static unsigned char n147[1];
static unsigned char n145[1];
static unsigned char n143[1];
static unsigned char n141[1];
static unsigned char n139[1];
static unsigned char n137[1];
static unsigned char n135[1];
static unsigned char n133[1];
static unsigned char n132[2];
static unsigned char n131[2];
static unsigned char n130[2];
static unsigned char n129[2];
static unsigned char n128[2];
static unsigned char n127[2];
static unsigned char n126[2];
static unsigned char n125[2];
static unsigned char n124[2];
static unsigned char n123[2];
static unsigned char n122[2];
static unsigned char n121[2];
static unsigned char n120[2];
static unsigned char n119[2];
static unsigned char n118[2];
static unsigned char n117[2];
static unsigned char n116[2];
static unsigned char n61[1];
static unsigned char n60[1];
static unsigned char n59[1];
static unsigned char n58[1];
static unsigned char n57[1];
static unsigned char n56[1];
static unsigned char n55[1];
static unsigned char n54[1];
static unsigned char n49[1];
static unsigned char n48[1];
static unsigned char n47[1];
static unsigned char n46[1];
static unsigned char n45[1];
static unsigned char n44[1];
static unsigned char n43[1];
static unsigned char n42[1];
static unsigned char n41[1];
static unsigned char n40[1];
static unsigned char n39[1];
static unsigned char n38[1];
static unsigned char n37[1];
static unsigned char n36[1];
static unsigned char n35[1];
static unsigned char n10[1];
static unsigned char *load_data_i;
static unsigned char *load_addr_i;
static unsigned char *load_write_i;
static unsigned char *const_data_i;
static unsigned char *instr_data_i;
static unsigned char *reset_state_i;
static unsigned char *cycle_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char *reg_0_o;
static unsigned char n405[1];
static unsigned char n404[1];
static unsigned char n392[1];
static unsigned char n389[1];
static unsigned char n386[1];
static unsigned char n320[1];
static unsigned char n319[1];
static unsigned char n318[4];
static unsigned char n317[4];
static unsigned char n316[4];
static unsigned char n315[4];
static unsigned char n314[4];
static unsigned char n313[4];
static unsigned char n312[4];
static unsigned char n311[4];
static unsigned char n290[1];
static unsigned char n289[1];
static unsigned char n288[4];
static unsigned char n287[4];
static unsigned char n286[4];
static unsigned char n285[4];
static unsigned char n284[4];
static unsigned char n283[4];
static unsigned char n282[4];
static unsigned char n281[4];
static unsigned char n114[1];
static unsigned char n112[1];
static unsigned char n104[1];
static unsigned char n103[1];
static unsigned char n102[1];
static unsigned char n101[1];
static unsigned char n33[1];
static unsigned char n32[1];
static unsigned char n32r[1];
static unsigned char n32e[1];
static unsigned char n32d[1];
static unsigned char n25[1];
static unsigned char n25r[1];
static unsigned char n25e[1];
static unsigned char n25d[1];
static unsigned char n13[1];
static unsigned char *const_addr_o;
static unsigned char n409[1];
static unsigned char n338[1];
static unsigned char n338r[1];
static unsigned char n338e[1];
static unsigned char n338d[1];
static unsigned char n326[1];
static unsigned char n325[1];
static unsigned char n324[4];
static unsigned char n323[4];
static unsigned char n322[4];
static unsigned char n321[4];
static unsigned char n308[1];
static unsigned char n308r[1];
static unsigned char n308e[1];
static unsigned char n308d[1];
static unsigned char n296[1];
static unsigned char n295[1];
static unsigned char n294[4];
static unsigned char n293[4];
static unsigned char n292[4];
static unsigned char n291[4];
static unsigned char n278[1];
static unsigned char n278r[1];
static unsigned char n278e[1];
static unsigned char n278d[1];
static unsigned char n111[1];
static unsigned char n111r[1];
static unsigned char n111e[1];
static unsigned char n111d[1];
static unsigned char n34[1];
static unsigned char n18[1];
static unsigned char n18r[1];
static unsigned char n18e[1];
static unsigned char n18d[1];
static unsigned char n330[1];
static unsigned char n328[4];
static unsigned char n327[4];
static unsigned char n300[1];
static unsigned char n298[4];
static unsigned char n297[4];
static unsigned char n67[1];
static unsigned char n331[4];
static unsigned char n301[4];
static unsigned char n90[1];
static unsigned char n89[1];
static unsigned char n88[1];
static unsigned char n87[1];
static unsigned char n74[1];
static unsigned char n73[1];
static unsigned char n72[1];
static unsigned char n71[1];
static unsigned char n70[1];
static unsigned char n69[1];
static unsigned char n68[1];
static unsigned char n397[4];
static unsigned char n387[1];
static unsigned char n384[4];
static unsigned char n383[4];
static unsigned char n380[1];
static unsigned char n378[4];
static unsigned char n377[1];
static unsigned char n374[4];
static unsigned char n339[1];
static unsigned char n97[1];
static unsigned char n75[1];
static unsigned char n403[4];
static unsigned char n396[4];
static unsigned char n393[1];
static unsigned char n390[1];
static unsigned char n381[1];
static unsigned char n379[4];
static unsigned char n376[4];
static unsigned char n340[1];
static unsigned char n98[1];
static unsigned char n76[1];
static unsigned char n411[1];
static unsigned char n402[4];
static unsigned char n400[4];
static unsigned char n343[1];
static unsigned char n99[1];
static unsigned char n77[1];
static unsigned char n412[1];
static unsigned char n407[4];
static unsigned char n344[1];
static unsigned char n100[1];
static unsigned char n78[1];
static unsigned char n495[1];
static unsigned char n413[1];
static unsigned char n345[1];
static unsigned char n113[1];
static unsigned char n79[1];
static unsigned char n536[1];
static unsigned char n418[1];
static unsigned char n418r[1];
static unsigned char n418e[1];
static unsigned char n418d[1];
static unsigned char n346[1];
static unsigned char n115[1];
static unsigned char n80[1];
static unsigned char n567[1];
static unsigned char n566[1];
static unsigned char n565[1];
static unsigned char n564[1];
static unsigned char n546[1];
static unsigned char n545[1];
static unsigned char n544[1];
static unsigned char n543[1];
static unsigned char n542[1];
static unsigned char n541[1];
static unsigned char n540[1];
static unsigned char n539[1];
static unsigned char n538[1];
static unsigned char n537[1];
static unsigned char n347[1];
static unsigned char n194[1];
static unsigned char n192[1];
static unsigned char n190[1];
static unsigned char n188[1];
static unsigned char n186[1];
static unsigned char n184[1];
static unsigned char n182[1];
static unsigned char n180[1];
static unsigned char n178[1];
static unsigned char n176[1];
static unsigned char n174[1];
static unsigned char n172[1];
static unsigned char n170[1];
static unsigned char n168[1];
static unsigned char n166[1];
static unsigned char n164[1];
static unsigned char n162[1];
static unsigned char n160[1];
static unsigned char n158[1];
static unsigned char n156[1];
static unsigned char n154[1];
static unsigned char n152[1];
static unsigned char n150[1];
static unsigned char n148[1];
static unsigned char n146[1];
static unsigned char n144[1];
static unsigned char n142[1];
static unsigned char n140[1];
static unsigned char n138[1];
static unsigned char n136[1];
static unsigned char n134[1];
static unsigned char n81[1];
static unsigned char n582[1];
static unsigned char n549[1];
static unsigned char n348[1];
static unsigned char n195[2];
static unsigned char n86[1];
static unsigned char n86r[1];
static unsigned char n86e[1];
static unsigned char n86d[1];
static unsigned char n583[1];
static unsigned char n550[1];
static unsigned char n349[1];
static unsigned char n196[2];
static unsigned char n584[1];
static unsigned char n551[1];
static unsigned char n350[2];
static unsigned char n197[2];
static unsigned char n585[1];
static unsigned char n552[1];
static unsigned char n351[2];
static unsigned char n198[2];
static unsigned char *done_o;
static unsigned char n553[1];
static unsigned char n352[2];
static unsigned char n199[2];
static unsigned char n554[1];
static unsigned char n353[2];
static unsigned char n200[2];
static unsigned char n555[1];
static unsigned char n354[2];
static unsigned char n201[2];
static unsigned char n556[1];
static unsigned char n355[2];
static unsigned char n202[2];
static unsigned char n557[1];
static unsigned char n356[2];
static unsigned char n203[2];
static unsigned char n558[1];
static unsigned char n357[2];
static unsigned char n204[2];
static unsigned char n563[1];
static unsigned char n563r[1];
static unsigned char n563e[1];
static unsigned char n563d[1];
static unsigned char n358[3];
static unsigned char n205[2];
static unsigned char n359[3];
static unsigned char n206[2];
static unsigned char n360[3];
static unsigned char n207[2];
static unsigned char n361[3];
static unsigned char n208[2];
static unsigned char n362[3];
static unsigned char n209[2];
static unsigned char n363[3];
static unsigned char n210[2];
static unsigned char n364[3];
static unsigned char n211[2];
static unsigned char n365[3];
static unsigned char n212[2];
static unsigned char n366[4];
static unsigned char n213[2];
static unsigned char n367[4];
static unsigned char n214[2];
static unsigned char n368[4];
static unsigned char n215[2];
static unsigned char n369[4];
static unsigned char n216[2];
static unsigned char n370[4];
static unsigned char n217[2];
static unsigned char n371[4];
static unsigned char n218[2];
static unsigned char n372[4];
static unsigned char n219[2];
static unsigned char n373[4];
static unsigned char n220[2];
static unsigned char n382[4];
static unsigned char n221[2];
static unsigned char n401[4];
static unsigned char n222[2];
static unsigned char n406[4];
static unsigned char n223[2];
static unsigned char n410[4];
static unsigned char n224[2];
static unsigned char n419[4];
static unsigned char n225[2];
static unsigned char n269[1];
static unsigned char n266[1];
static unsigned char n263[1];
static unsigned char n260[1];
static unsigned char n257[1];
static unsigned char n254[1];
static unsigned char n251[1];
static unsigned char n248[1];
static unsigned char n245[1];
static unsigned char n242[1];
static unsigned char n239[1];
static unsigned char n236[1];
static unsigned char n233[1];
static unsigned char n230[1];
static unsigned char n227[1];
static unsigned char n494[4];
static unsigned char n494r[1];
static unsigned char n494e[1];
static unsigned char n494d[4];
static unsigned char n489[4];
static unsigned char n489r[1];
static unsigned char n489e[1];
static unsigned char n489d[4];
static unsigned char n484[4];
static unsigned char n484r[1];
static unsigned char n484e[1];
static unsigned char n484d[4];
static unsigned char n479[4];
static unsigned char n479r[1];
static unsigned char n479e[1];
static unsigned char n479d[4];
static unsigned char n474[4];
static unsigned char n474r[1];
static unsigned char n474e[1];
static unsigned char n474d[4];
static unsigned char n469[4];
static unsigned char n469r[1];
static unsigned char n469e[1];
static unsigned char n469d[4];
static unsigned char n464[4];
static unsigned char n464r[1];
static unsigned char n464e[1];
static unsigned char n464d[4];
static unsigned char n459[4];
static unsigned char n459r[1];
static unsigned char n459e[1];
static unsigned char n459d[4];
static unsigned char n454[4];
static unsigned char n454r[1];
static unsigned char n454e[1];
static unsigned char n454d[4];
static unsigned char n449[4];
static unsigned char n449r[1];
static unsigned char n449e[1];
static unsigned char n449d[4];
static unsigned char n444[4];
static unsigned char n444r[1];
static unsigned char n444e[1];
static unsigned char n444d[4];
static unsigned char n439[4];
static unsigned char n439r[1];
static unsigned char n439e[1];
static unsigned char n439d[4];
static unsigned char n434[4];
static unsigned char n434r[1];
static unsigned char n434e[1];
static unsigned char n434d[4];
static unsigned char n429[4];
static unsigned char n429r[1];
static unsigned char n429e[1];
static unsigned char n429d[4];
static unsigned char n424[4];
static unsigned char n424r[1];
static unsigned char n424e[1];
static unsigned char n424d[4];

void cf_ssp_32_8_ports(unsigned char* port_reset_state_i, unsigned char* port_cycle_i, unsigned char* port_instr_data_i, unsigned char* port_const_data_i, unsigned char* port_load_write_i, unsigned char* port_load_addr_i, unsigned char* port_load_data_i, unsigned char* port_done_o, unsigned char* port_instr_addr_o, unsigned char* port_const_addr_o, unsigned char* port_reg_0_o, unsigned char* port_reg_1_o, unsigned char* port_reg_2_o, unsigned char* port_reg_3_o, unsigned char* port_reg_4_o, unsigned char* port_reg_5_o, unsigned char* port_reg_6_o, unsigned char* port_reg_7_o, unsigned char* port_reg_8_o, unsigned char* port_reg_9_o, unsigned char* port_reg_a_o, unsigned char* port_reg_b_o, unsigned char* port_reg_c_o, unsigned char* port_reg_d_o, unsigned char* port_reg_e_o, unsigned char* port_reg_f_o) {
  reset_state_i = port_reset_state_i;
  cycle_i = port_cycle_i;
  instr_data_i = port_instr_data_i;
  const_data_i = port_const_data_i;
  load_write_i = port_load_write_i;
  load_addr_i = port_load_addr_i;
  load_data_i = port_load_data_i;
  done_o = port_done_o;
  instr_addr_o = port_instr_addr_o;
  const_addr_o = port_const_addr_o;
  reg_0_o = port_reg_0_o;
  reg_1_o = port_reg_1_o;
  reg_2_o = port_reg_2_o;
  reg_3_o = port_reg_3_o;
  reg_4_o = port_reg_4_o;
  reg_5_o = port_reg_5_o;
  reg_6_o = port_reg_6_o;
  reg_7_o = port_reg_7_o;
  reg_8_o = port_reg_8_o;
  reg_9_o = port_reg_9_o;
  reg_a_o = port_reg_a_o;
  reg_b_o = port_reg_b_o;
  reg_c_o = port_reg_c_o;
  reg_d_o = port_reg_d_o;
  reg_e_o = port_reg_e_o;
  reg_f_o = port_reg_f_o;
}

void cf_ssp_32_8_calc() {
  n636[0] = 0;
  n627[0] = 1;
  n626[0] = 1;
  reg_f_o[0] = n494[0];
  reg_f_o[1] = n494[1];
  reg_f_o[2] = n494[2];
  reg_f_o[3] = n494[3];
  reg_e_o[0] = n489[0];
  reg_e_o[1] = n489[1];
  reg_e_o[2] = n489[2];
  reg_e_o[3] = n489[3];
  reg_d_o[0] = n484[0];
  reg_d_o[1] = n484[1];
  reg_d_o[2] = n484[2];
  reg_d_o[3] = n484[3];
  reg_c_o[0] = n479[0];
  reg_c_o[1] = n479[1];
  reg_c_o[2] = n479[2];
  reg_c_o[3] = n479[3];
  reg_b_o[0] = n474[0];
  reg_b_o[1] = n474[1];
  reg_b_o[2] = n474[2];
  reg_b_o[3] = n474[3];
  reg_a_o[0] = n469[0];
  reg_a_o[1] = n469[1];
  reg_a_o[2] = n469[2];
  reg_a_o[3] = n469[3];
  reg_9_o[0] = n464[0];
  reg_9_o[1] = n464[1];
  reg_9_o[2] = n464[2];
  reg_9_o[3] = n464[3];
  reg_8_o[0] = n459[0];
  reg_8_o[1] = n459[1];
  reg_8_o[2] = n459[2];
  reg_8_o[3] = n459[3];
  reg_7_o[0] = n454[0];
  reg_7_o[1] = n454[1];
  reg_7_o[2] = n454[2];
  reg_7_o[3] = n454[3];
  reg_6_o[0] = n449[0];
  reg_6_o[1] = n449[1];
  reg_6_o[2] = n449[2];
  reg_6_o[3] = n449[3];
  reg_5_o[0] = n444[0];
  reg_5_o[1] = n444[1];
  reg_5_o[2] = n444[2];
  reg_5_o[3] = n444[3];
  reg_4_o[0] = n439[0];
  reg_4_o[1] = n439[1];
  reg_4_o[2] = n439[2];
  reg_4_o[3] = n439[3];
  reg_3_o[0] = n434[0];
  reg_3_o[1] = n434[1];
  reg_3_o[2] = n434[2];
  reg_3_o[3] = n434[3];
  reg_2_o[0] = n429[0];
  reg_2_o[1] = n429[1];
  reg_2_o[2] = n429[2];
  reg_2_o[3] = n429[3];
  reg_1_o[0] = n424[0];
  reg_1_o[1] = n424[1];
  reg_1_o[2] = n424[2];
  reg_1_o[3] = n424[3];
  instr_addr_o[0] = n18[0];
  n526[0] = 12;
  n525[0] = 8;
  n524[0] = 4;
  n523[0] = 0;
  n522[0] = 1;
  n521[0] = 1;
  n513[0] = 6;
  n512[0] = 2;
  n511[0] = 13;
  n510[0] = 9;
  n509[0] = 5;
  n508[0] = 1;
  n507[0] = 12;
  n506[0] = 8;
  n505[0] = 4;
  n504[0] = 0;
  n503[0] = 0;
  n502[0] = 1;
  n501[0] = 1;
  n500[0] = 2;
  n499[0] = 1;
  n498[0] = 0;
  n497[0] = 2;
  n399[0] = (1 & (n338[0]));
  n398[0] = (1 & (n338[0] >> 1)) | (2 & (n338[0] >> 1));
  n391[0] = 5;
  n388[0] = 3;
  n385[0] = 1;
  n375[0] = 0;
  n310[0] = (1 & (n308[0]));
  n309[0] = (1 & (n308[0] >> 1)) | (2 & (n308[0] >> 1)) | (4 & (n308[0] >> 1));
  n280[0] = (1 & (n278[0]));
  n279[0] = (1 & (n278[0] >> 1)) | (2 & (n278[0] >> 1)) | (4 & (n278[0] >> 1));
  n226[0] = 0;
  n226[1] = 0;
  n226[2] = 0;
  n226[3] = 0;
  n193[0] = 30;
  n191[0] = 29;
  n189[0] = 28;
  n187[0] = 27;
  n185[0] = 26;
  n183[0] = 25;
  n181[0] = 24;
  n179[0] = 23;
  n177[0] = 22;
  n175[0] = 21;
  n173[0] = 20;
  n171[0] = 19;
  n169[0] = 18;
  n167[0] = 17;
  n165[0] = 16;
  n163[0] = 15;
  n161[0] = 14;
  n159[0] = 13;
  n157[0] = 12;
  n155[0] = 11;
  n153[0] = 10;
  n151[0] = 9;
  n149[0] = 8;
  n147[0] = 7;
  n145[0] = 6;
  n143[0] = 5;
  n141[0] = 4;
  n139[0] = 3;
  n137[0] = 2;
  n135[0] = 1;
  n133[0] = 0;
  n132[0] = 0;
  n132[1] = 0;
  n131[0] = 1;
  n131[1] = 0;
  n130[0] = 2;
  n130[1] = 0;
  n129[0] = 4;
  n129[1] = 0;
  n128[0] = 8;
  n128[1] = 0;
  n127[0] = 16;
  n127[1] = 0;
  n126[0] = 32;
  n126[1] = 0;
  n125[0] = 64;
  n125[1] = 0;
  n124[0] = 128;
  n124[1] = 0;
  n123[0] = 0;
  n123[1] = 1;
  n122[0] = 0;
  n122[1] = 2;
  n121[0] = 0;
  n121[1] = 4;
  n120[0] = 0;
  n120[1] = 8;
  n119[0] = 0;
  n119[1] = 16;
  n118[0] = 0;
  n118[1] = 32;
  n117[0] = 0;
  n117[1] = 64;
  n116[0] = 0;
  n116[1] = 128;
  n61[0] = 6;
  n60[0] = 4;
  n59[0] = 2;
  n58[0] = 0;
  n57[0] = 0;
  n56[0] = 0;
  n55[0] = 0;
  n54[0] = 0;
  n49[0] = 5;
  n48[0] = 3;
  n47[0] = 1;
  n46[0] = 6;
  n45[0] = 4;
  n44[0] = 2;
  n43[0] = 0;
  n42[0] = 0;
  n41[0] = 0;
  n40[0] = 1;
  n39[0] = 0;
  n38[0] = 1;
  n37[0] = 0;
  n36[0] = 1;
  n35[0] = 0;
  n10[0] = 1;
  n2[0] = 0;
  n1[0] = 1;
  reg_0_o[0] = n226[0];
  reg_0_o[1] = n226[1];
  reg_0_o[2] = n226[2];
  reg_0_o[3] = n226[3];
  n405[0] = (1 & (n398[0]));
  n404[0] = (1 & (n398[0] >> 1));
  n392[0] = n338[0] == n391[0] ? 1 : 0;
  n389[0] = n338[0] == n388[0] ? 1 : 0;
  n386[0] = n338[0] == n385[0] ? 1 : 0;
  n320[0] = (1 & (n309[0]));
  n319[0] = (1 & (n309[0] >> 1)) | (2 & (n309[0] >> 1));
  if (n310[0]) {
    n318[0] = n494[0];
    n318[1] = n494[1];
    n318[2] = n494[2];
    n318[3] = n494[3];
  }
  else {
    n318[0] = n489[0];
    n318[1] = n489[1];
    n318[2] = n489[2];
    n318[3] = n489[3];
  }
  if (n310[0]) {
    n317[0] = n484[0];
    n317[1] = n484[1];
    n317[2] = n484[2];
    n317[3] = n484[3];
  }
  else {
    n317[0] = n479[0];
    n317[1] = n479[1];
    n317[2] = n479[2];
    n317[3] = n479[3];
  }
  if (n310[0]) {
    n316[0] = n474[0];
    n316[1] = n474[1];
    n316[2] = n474[2];
    n316[3] = n474[3];
  }
  else {
    n316[0] = n469[0];
    n316[1] = n469[1];
    n316[2] = n469[2];
    n316[3] = n469[3];
  }
  if (n310[0]) {
    n315[0] = n464[0];
    n315[1] = n464[1];
    n315[2] = n464[2];
    n315[3] = n464[3];
  }
  else {
    n315[0] = n459[0];
    n315[1] = n459[1];
    n315[2] = n459[2];
    n315[3] = n459[3];
  }
  if (n310[0]) {
    n314[0] = n454[0];
    n314[1] = n454[1];
    n314[2] = n454[2];
    n314[3] = n454[3];
  }
  else {
    n314[0] = n449[0];
    n314[1] = n449[1];
    n314[2] = n449[2];
    n314[3] = n449[3];
  }
  if (n310[0]) {
    n313[0] = n444[0];
    n313[1] = n444[1];
    n313[2] = n444[2];
    n313[3] = n444[3];
  }
  else {
    n313[0] = n439[0];
    n313[1] = n439[1];
    n313[2] = n439[2];
    n313[3] = n439[3];
  }
  if (n310[0]) {
    n312[0] = n434[0];
    n312[1] = n434[1];
    n312[2] = n434[2];
    n312[3] = n434[3];
  }
  else {
    n312[0] = n429[0];
    n312[1] = n429[1];
    n312[2] = n429[2];
    n312[3] = n429[3];
  }
  if (n310[0]) {
    n311[0] = n424[0];
    n311[1] = n424[1];
    n311[2] = n424[2];
    n311[3] = n424[3];
  }
  else {
    n311[0] = n226[0];
    n311[1] = n226[1];
    n311[2] = n226[2];
    n311[3] = n226[3];
  }
  n290[0] = (1 & (n279[0]));
  n289[0] = (1 & (n279[0] >> 1)) | (2 & (n279[0] >> 1));
  if (n280[0]) {
    n288[0] = n494[0];
    n288[1] = n494[1];
    n288[2] = n494[2];
    n288[3] = n494[3];
  }
  else {
    n288[0] = n489[0];
    n288[1] = n489[1];
    n288[2] = n489[2];
    n288[3] = n489[3];
  }
  if (n280[0]) {
    n287[0] = n484[0];
    n287[1] = n484[1];
    n287[2] = n484[2];
    n287[3] = n484[3];
  }
  else {
    n287[0] = n479[0];
    n287[1] = n479[1];
    n287[2] = n479[2];
    n287[3] = n479[3];
  }
  if (n280[0]) {
    n286[0] = n474[0];
    n286[1] = n474[1];
    n286[2] = n474[2];
    n286[3] = n474[3];
  }
  else {
    n286[0] = n469[0];
    n286[1] = n469[1];
    n286[2] = n469[2];
    n286[3] = n469[3];
  }
  if (n280[0]) {
    n285[0] = n464[0];
    n285[1] = n464[1];
    n285[2] = n464[2];
    n285[3] = n464[3];
  }
  else {
    n285[0] = n459[0];
    n285[1] = n459[1];
    n285[2] = n459[2];
    n285[3] = n459[3];
  }
  if (n280[0]) {
    n284[0] = n454[0];
    n284[1] = n454[1];
    n284[2] = n454[2];
    n284[3] = n454[3];
  }
  else {
    n284[0] = n449[0];
    n284[1] = n449[1];
    n284[2] = n449[2];
    n284[3] = n449[3];
  }
  if (n280[0]) {
    n283[0] = n444[0];
    n283[1] = n444[1];
    n283[2] = n444[2];
    n283[3] = n444[3];
  }
  else {
    n283[0] = n439[0];
    n283[1] = n439[1];
    n283[2] = n439[2];
    n283[3] = n439[3];
  }
  if (n280[0]) {
    n282[0] = n434[0];
    n282[1] = n434[1];
    n282[2] = n434[2];
    n282[3] = n434[3];
  }
  else {
    n282[0] = n429[0];
    n282[1] = n429[1];
    n282[2] = n429[2];
    n282[3] = n429[3];
  }
  if (n280[0]) {
    n281[0] = n424[0];
    n281[1] = n424[1];
    n281[2] = n424[2];
    n281[3] = n424[3];
  }
  else {
    n281[0] = n226[0];
    n281[1] = n226[1];
    n281[2] = n226[2];
    n281[3] = n226[3];
  }
  if (load_write_i[0]) {
    n114[0] = load_addr_i[0];
  }
  else {
    n114[0] = n111[0];
  }
  n112[0] = (1 & (instr_data_i[0] >> 4)) | (2 & (instr_data_i[0] >> 4)) | (4 & (instr_data_i[0] >> 4)) | (8 & (instr_data_i[0] >> 4)) | (16 & (instr_data_i[1] << 4)) | (32 & (instr_data_i[1] << 4)) | (64 & (instr_data_i[1] << 4)) | (128 & (instr_data_i[1] << 4));
  n104[0] = (1 & (instr_data_i[0])) | (2 & (instr_data_i[0])) | (4 & (instr_data_i[0])) | (8 & (instr_data_i[0]));
  n103[0] = (1 & (instr_data_i[0] >> 4)) | (2 & (instr_data_i[0] >> 4)) | (4 & (instr_data_i[0] >> 4)) | (8 & (instr_data_i[0] >> 4));
  n102[0] = (1 & (instr_data_i[1])) | (2 & (instr_data_i[1])) | (4 & (instr_data_i[1])) | (8 & (instr_data_i[1]));
  n101[0] = (1 & (instr_data_i[1] >> 4)) | (2 & (instr_data_i[1] >> 4)) | (4 & (instr_data_i[1] >> 4));
  n33[0] = (1 & (instr_data_i[1] >> 7));
  n32r[0] = n2[0];
  n32e[0] = n1[0];
  n32d[0] = n25[0];
  n25r[0] = n2[0];
  n25e[0] = n1[0];
  n25d[0] = cycle_i[0];
  { unsigned int tmp; (tmp = (unsigned int) n18[0] + (unsigned int) n10[0], n13[0] = 255 & (unsigned char) tmp); }
  const_addr_o[0] = n112[0];
  n409[0] = (1 & (n404[0]));
  n338r[0] = n2[0];
  n338e[0] = n1[0];
  n338d[0] = n101[0];
  n326[0] = (1 & (n319[0]));
  n325[0] = (1 & (n319[0] >> 1));
  if (n320[0]) {
    n324[0] = n318[0];
    n324[1] = n318[1];
    n324[2] = n318[2];
    n324[3] = n318[3];
  }
  else {
    n324[0] = n317[0];
    n324[1] = n317[1];
    n324[2] = n317[2];
    n324[3] = n317[3];
  }
  if (n320[0]) {
    n323[0] = n316[0];
    n323[1] = n316[1];
    n323[2] = n316[2];
    n323[3] = n316[3];
  }
  else {
    n323[0] = n315[0];
    n323[1] = n315[1];
    n323[2] = n315[2];
    n323[3] = n315[3];
  }
  if (n320[0]) {
    n322[0] = n314[0];
    n322[1] = n314[1];
    n322[2] = n314[2];
    n322[3] = n314[3];
  }
  else {
    n322[0] = n313[0];
    n322[1] = n313[1];
    n322[2] = n313[2];
    n322[3] = n313[3];
  }
  if (n320[0]) {
    n321[0] = n312[0];
    n321[1] = n312[1];
    n321[2] = n312[2];
    n321[3] = n312[3];
  }
  else {
    n321[0] = n311[0];
    n321[1] = n311[1];
    n321[2] = n311[2];
    n321[3] = n311[3];
  }
  n308r[0] = reset_state_i[0];
  n308e[0] = n1[0];
  n308d[0] = n103[0];
  n296[0] = (1 & (n289[0]));
  n295[0] = (1 & (n289[0] >> 1));
  if (n290[0]) {
    n294[0] = n288[0];
    n294[1] = n288[1];
    n294[2] = n288[2];
    n294[3] = n288[3];
  }
  else {
    n294[0] = n287[0];
    n294[1] = n287[1];
    n294[2] = n287[2];
    n294[3] = n287[3];
  }
  if (n290[0]) {
    n293[0] = n286[0];
    n293[1] = n286[1];
    n293[2] = n286[2];
    n293[3] = n286[3];
  }
  else {
    n293[0] = n285[0];
    n293[1] = n285[1];
    n293[2] = n285[2];
    n293[3] = n285[3];
  }
  if (n290[0]) {
    n292[0] = n284[0];
    n292[1] = n284[1];
    n292[2] = n284[2];
    n292[3] = n284[3];
  }
  else {
    n292[0] = n283[0];
    n292[1] = n283[1];
    n292[2] = n283[2];
    n292[3] = n283[3];
  }
  if (n290[0]) {
    n291[0] = n282[0];
    n291[1] = n282[1];
    n291[2] = n282[2];
    n291[3] = n282[3];
  }
  else {
    n291[0] = n281[0];
    n291[1] = n281[1];
    n291[2] = n281[2];
    n291[3] = n281[3];
  }
  n278r[0] = reset_state_i[0];
  n278e[0] = n1[0];
  n278d[0] = n102[0];
  n111r[0] = n2[0];
  n111e[0] = n1[0];
  n111d[0] = n104[0];
  n34[0] = 255 & (n32[0] << 1 | n33[0]);
  n18r[0] = cycle_i[0];
  n18e[0] = n1[0];
  n18d[0] = n13[0];
  n330[0] = (1 & (n325[0]));
  if (n326[0]) {
    n328[0] = n324[0];
    n328[1] = n324[1];
    n328[2] = n324[2];
    n328[3] = n324[3];
  }
  else {
    n328[0] = n323[0];
    n328[1] = n323[1];
    n328[2] = n323[2];
    n328[3] = n323[3];
  }
  if (n326[0]) {
    n327[0] = n322[0];
    n327[1] = n322[1];
    n327[2] = n322[2];
    n327[3] = n322[3];
  }
  else {
    n327[0] = n321[0];
    n327[1] = n321[1];
    n327[2] = n321[2];
    n327[3] = n321[3];
  }
  n300[0] = (1 & (n295[0]));
  if (n296[0]) {
    n298[0] = n294[0];
    n298[1] = n294[1];
    n298[2] = n294[2];
    n298[3] = n294[3];
  }
  else {
    n298[0] = n293[0];
    n298[1] = n293[1];
    n298[2] = n293[2];
    n298[3] = n293[3];
  }
  if (n296[0]) {
    n297[0] = n292[0];
    n297[1] = n292[1];
    n297[2] = n292[2];
    n297[3] = n292[3];
  }
  else {
    n297[0] = n291[0];
    n297[1] = n291[1];
    n297[2] = n291[2];
    n297[3] = n291[3];
  }
  n67[0] = 255 & (n34[0] << 1 | n86[0]);
  if (n330[0]) {
    n331[0] = n328[0];
    n331[1] = n328[1];
    n331[2] = n328[2];
    n331[3] = n328[3];
  }
  else {
    n331[0] = n327[0];
    n331[1] = n327[1];
    n331[2] = n327[2];
    n331[3] = n327[3];
  }
  if (n300[0]) {
    n301[0] = n298[0];
    n301[1] = n298[1];
    n301[2] = n298[2];
    n301[3] = n298[3];
  }
  else {
    n301[0] = n297[0];
    n301[1] = n297[1];
    n301[2] = n297[2];
    n301[3] = n297[3];
  }
  n90[0] = n67[0] == n61[0] ? 1 : 0;
  n89[0] = n67[0] == n60[0] ? 1 : 0;
  n88[0] = n67[0] == n59[0] ? 1 : 0;
  n87[0] = n67[0] == n58[0] ? 1 : 0;
  n74[0] = n67[0] == n49[0] ? 1 : 0;
  n73[0] = n67[0] == n48[0] ? 1 : 0;
  n72[0] = n67[0] == n47[0] ? 1 : 0;
  n71[0] = n67[0] == n46[0] ? 1 : 0;
  n70[0] = n67[0] == n45[0] ? 1 : 0;
  n69[0] = n67[0] == n44[0] ? 1 : 0;
  n68[0] = n67[0] == n43[0] ? 1 : 0;
  if (n418[0]) {
    n397[0] = n301[0];
    n397[1] = n301[1];
    n397[2] = n301[2];
    n397[3] = n301[3];
  }
  else {
    n397[0] = n331[0];
    n397[1] = n331[1];
    n397[2] = n331[2];
    n397[3] = n331[3];
  }
  n387[0] = (1 & (n301[0]));
  { unsigned int tmp; (tmp = (unsigned int) n301[3] - (unsigned int) n331[3] - (tmp = (unsigned int) n301[2] - (unsigned int) n331[2] - (tmp = (unsigned int) n301[1] - (unsigned int) n331[1] - (tmp = (unsigned int) n301[0] - (unsigned int) n331[0], n384[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n384[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n384[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n384[3] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n301[3] + (unsigned int) n331[3] + (tmp = (unsigned int) n301[2] + (unsigned int) n331[2] + (tmp = (unsigned int) n301[1] + (unsigned int) n331[1] + (tmp = (unsigned int) n301[0] + (unsigned int) n331[0], n383[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n383[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n383[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n383[3] = 255 & (unsigned char) tmp); }
  n380[0] = (1 & (n301[3] >> 6));
  n378[0] = (1 & (n301[0] >> 1)) | (2 & (n301[0] >> 1)) | (4 & (n301[0] >> 1)) | (8 & (n301[0] >> 1)) | (16 & (n301[0] >> 1)) | (32 & (n301[0] >> 1)) | (64 & (n301[0] >> 1)) | (128 & (n301[1] << 7));
  n378[1] = (1 & (n301[1] >> 1)) | (2 & (n301[1] >> 1)) | (4 & (n301[1] >> 1)) | (8 & (n301[1] >> 1)) | (16 & (n301[1] >> 1)) | (32 & (n301[1] >> 1)) | (64 & (n301[1] >> 1)) | (128 & (n301[2] << 7));
  n378[2] = (1 & (n301[2] >> 1)) | (2 & (n301[2] >> 1)) | (4 & (n301[2] >> 1)) | (8 & (n301[2] >> 1)) | (16 & (n301[2] >> 1)) | (32 & (n301[2] >> 1)) | (64 & (n301[2] >> 1)) | (128 & (n301[3] << 7));
  n378[3] = (1 & (n301[3] >> 1)) | (2 & (n301[3] >> 1)) | (4 & (n301[3] >> 1)) | (8 & (n301[3] >> 1)) | (16 & (n301[3] >> 1)) | (32 & (n301[3] >> 1)) | (64 & (n301[3] >> 1));
  n377[0] = (1 & (n301[3] >> 7));
  n374[0] = (1 & (n301[0])) | (2 & (n301[0])) | (4 & (n301[0])) | (8 & (n301[0])) | (16 & (n301[0])) | (32 & (n301[0])) | (64 & (n301[0])) | (128 & (n301[0]));
  n374[1] = (1 & (n301[1])) | (2 & (n301[1])) | (4 & (n301[1])) | (8 & (n301[1])) | (16 & (n301[1])) | (32 & (n301[1])) | (64 & (n301[1])) | (128 & (n301[1]));
  n374[2] = (1 & (n301[2])) | (2 & (n301[2])) | (4 & (n301[2])) | (8 & (n301[2])) | (16 & (n301[2])) | (32 & (n301[2])) | (64 & (n301[2])) | (128 & (n301[2]));
  n374[3] = (1 & (n301[3])) | (2 & (n301[3])) | (4 & (n301[3])) | (8 & (n301[3])) | (16 & (n301[3])) | (32 & (n301[3])) | (64 & (n301[3]));
  n339[0] = (1 & (n301[3] >> 7));
  if (n90[0]) {
    n97[0] = n54[0];
  }
  else {
    n97[0] = n626[0];
  }
  if (n74[0]) {
    n75[0] = n36[0];
  }
  else {
    n75[0] = n35[0];
  }
  if (n399[0]) {
    n403[0] = const_data_i[0];
    n403[1] = const_data_i[1];
    n403[2] = const_data_i[2];
    n403[3] = const_data_i[3];
  }
  else {
    n403[0] = n397[0];
    n403[1] = n397[1];
    n403[2] = n397[2];
    n403[3] = n397[3];
  }
  if (n418[0]) {
    n396[0] = n383[0];
    n396[1] = n383[1];
    n396[2] = n383[2];
    n396[3] = n383[3];
  }
  else {
    n396[0] = n301[0];
    n396[1] = n301[1];
    n396[2] = n301[2];
    n396[3] = n301[3];
  }
  n393[0] = (1 & (n384[3] >> 7));
  n390[0] = (1 & (n383[3] >> 7));
  n381[0] = n339[0] ^ n380[0];
  n379[0] = n378[0];
  n379[1] = n378[1];
  n379[2] = n378[2];
  n379[3] = 255 & (n377[0] << 7 | n378[3]);
  n376[0] = 255 & (n374[0] << 1 | n375[0]);
  n376[1] = 255 & (n374[1] << 1 | n374[0] >> 7);
  n376[2] = 255 & (n374[2] << 1 | n374[1] >> 7);
  n376[3] = 255 & (n374[3] << 1 | n374[2] >> 7);
  n340[0] = 1 & ~n339[0];
  if (n89[0]) {
    n98[0] = n55[0];
  }
  else {
    n98[0] = n97[0];
  }
  if (n73[0]) {
    n76[0] = n37[0];
  }
  else {
    n76[0] = n75[0];
  }
  if (n392[0]) {
    n411[0] = n393[0];
  }
  else {
    n411[0] = n418[0];
  }
  if (n399[0]) {
    n402[0] = n384[0];
    n402[1] = n384[1];
    n402[2] = n384[2];
    n402[3] = n384[3];
  }
  else {
    n402[0] = n396[0];
    n402[1] = n396[1];
    n402[2] = n396[2];
    n402[3] = n396[3];
  }
  if (n399[0]) {
    n400[0] = n379[0];
    n400[1] = n379[1];
    n400[2] = n379[2];
    n400[3] = n379[3];
  }
  else {
    n400[0] = n376[0];
    n400[1] = n376[1];
    n400[2] = n376[2];
    n400[3] = n376[3];
  }
  n343[0] = 255 & (n340[0] << 1 | n340[0]);
  if (n88[0]) {
    n99[0] = n56[0];
  }
  else {
    n99[0] = n98[0];
  }
  if (n72[0]) {
    n77[0] = n38[0];
  }
  else {
    n77[0] = n76[0];
  }
  if (n389[0]) {
    n412[0] = n390[0];
  }
  else {
    n412[0] = n411[0];
  }
  if (n405[0]) {
    n407[0] = n403[0];
    n407[1] = n403[1];
    n407[2] = n403[2];
    n407[3] = n403[3];
  }
  else {
    n407[0] = n402[0];
    n407[1] = n402[1];
    n407[2] = n402[2];
    n407[3] = n402[3];
  }
  n344[0] = 255 & (n340[0] << 2 | n343[0]);
  if (n87[0]) {
    n100[0] = n57[0];
  }
  else {
    n100[0] = n99[0];
  }
  if (n71[0]) {
    n78[0] = n39[0];
  }
  else {
    n78[0] = n77[0];
  }
  n495[0] = 255 & (cycle_i[0] << 1 | n100[0]);
  if (n386[0]) {
    n413[0] = n387[0];
  }
  else {
    n413[0] = n412[0];
  }
  n345[0] = 255 & (n340[0] << 3 | n344[0]);
  n113[0] = load_write_i[0] | n100[0];
  if (n70[0]) {
    n79[0] = n40[0];
  }
  else {
    n79[0] = n78[0];
  }
  n536[0] = 255 & (n495[0] << 2 | n563[0]);
  n418r[0] = reset_state_i[0];
  n418e[0] = n1[0];
  n418d[0] = n413[0];
  n346[0] = 255 & (n340[0] << 4 | n345[0]);
  n115[0] = 255 & (n113[0] << 4 | n114[0]);
  if (n69[0]) {
    n80[0] = n41[0];
  }
  else {
    n80[0] = n79[0];
  }
  n567[0] = n536[0] == n526[0] ? 1 : 0;
  n566[0] = n536[0] == n525[0] ? 1 : 0;
  n565[0] = n536[0] == n524[0] ? 1 : 0;
  n564[0] = n536[0] == n523[0] ? 1 : 0;
  n546[0] = n536[0] == n513[0] ? 1 : 0;
  n545[0] = n536[0] == n512[0] ? 1 : 0;
  n544[0] = n536[0] == n511[0] ? 1 : 0;
  n543[0] = n536[0] == n510[0] ? 1 : 0;
  n542[0] = n536[0] == n509[0] ? 1 : 0;
  n541[0] = n536[0] == n508[0] ? 1 : 0;
  n540[0] = n536[0] == n507[0] ? 1 : 0;
  n539[0] = n536[0] == n506[0] ? 1 : 0;
  n538[0] = n536[0] == n505[0] ? 1 : 0;
  n537[0] = n536[0] == n504[0] ? 1 : 0;
  n347[0] = 255 & (n340[0] << 5 | n346[0]);
  n194[0] = n115[0] == n193[0] ? 1 : 0;
  n192[0] = n115[0] == n191[0] ? 1 : 0;
  n190[0] = n115[0] == n189[0] ? 1 : 0;
  n188[0] = n115[0] == n187[0] ? 1 : 0;
  n186[0] = n115[0] == n185[0] ? 1 : 0;
  n184[0] = n115[0] == n183[0] ? 1 : 0;
  n182[0] = n115[0] == n181[0] ? 1 : 0;
  n180[0] = n115[0] == n179[0] ? 1 : 0;
  n178[0] = n115[0] == n177[0] ? 1 : 0;
  n176[0] = n115[0] == n175[0] ? 1 : 0;
  n174[0] = n115[0] == n173[0] ? 1 : 0;
  n172[0] = n115[0] == n171[0] ? 1 : 0;
  n170[0] = n115[0] == n169[0] ? 1 : 0;
  n168[0] = n115[0] == n167[0] ? 1 : 0;
  n166[0] = n115[0] == n165[0] ? 1 : 0;
  n164[0] = n115[0] == n163[0] ? 1 : 0;
  n162[0] = n115[0] == n161[0] ? 1 : 0;
  n160[0] = n115[0] == n159[0] ? 1 : 0;
  n158[0] = n115[0] == n157[0] ? 1 : 0;
  n156[0] = n115[0] == n155[0] ? 1 : 0;
  n154[0] = n115[0] == n153[0] ? 1 : 0;
  n152[0] = n115[0] == n151[0] ? 1 : 0;
  n150[0] = n115[0] == n149[0] ? 1 : 0;
  n148[0] = n115[0] == n147[0] ? 1 : 0;
  n146[0] = n115[0] == n145[0] ? 1 : 0;
  n144[0] = n115[0] == n143[0] ? 1 : 0;
  n142[0] = n115[0] == n141[0] ? 1 : 0;
  n140[0] = n115[0] == n139[0] ? 1 : 0;
  n138[0] = n115[0] == n137[0] ? 1 : 0;
  n136[0] = n115[0] == n135[0] ? 1 : 0;
  n134[0] = n115[0] == n133[0] ? 1 : 0;
  if (n68[0]) {
    n81[0] = n42[0];
  }
  else {
    n81[0] = n80[0];
  }
  if (n567[0]) {
    n582[0] = n521[0];
  }
  else {
    n582[0] = n636[0];
  }
  if (n546[0]) {
    n549[0] = n497[0];
  }
  else {
    n549[0] = n627[0];
  }
  n348[0] = 255 & (n340[0] << 6 | n347[0]);
  if (n194[0]) {
    n195[0] = n117[0];
    n195[1] = n117[1];
  }
  else {
    n195[0] = n116[0];
    n195[1] = n116[1];
  }
  n86r[0] = n2[0];
  n86e[0] = n1[0];
  n86d[0] = n81[0];
  if (n566[0]) {
    n583[0] = n521[0];
  }
  else {
    n583[0] = n582[0];
  }
  if (n545[0]) {
    n550[0] = n498[0];
  }
  else {
    n550[0] = n549[0];
  }
  n349[0] = 255 & (n340[0] << 7 | n348[0]);
  if (n192[0]) {
    n196[0] = n118[0];
    n196[1] = n118[1];
  }
  else {
    n196[0] = n195[0];
    n196[1] = n195[1];
  }
  if (n565[0]) {
    n584[0] = n522[0];
  }
  else {
    n584[0] = n583[0];
  }
  if (n544[0]) {
    n551[0] = n499[0];
  }
  else {
    n551[0] = n550[0];
  }
  n350[0] = n349[0];
  n350[1] = n340[0];
  if (n190[0]) {
    n197[0] = n119[0];
    n197[1] = n119[1];
  }
  else {
    n197[0] = n196[0];
    n197[1] = n196[1];
  }
  if (n564[0]) {
    n585[0] = n522[0];
  }
  else {
    n585[0] = n584[0];
  }
  if (n543[0]) {
    n552[0] = n499[0];
  }
  else {
    n552[0] = n551[0];
  }
  n351[0] = n350[0];
  n351[1] = 255 & (n340[0] << 1 | n350[1]);
  if (n188[0]) {
    n198[0] = n120[0];
    n198[1] = n120[1];
  }
  else {
    n198[0] = n197[0];
    n198[1] = n197[1];
  }
  done_o[0] = n585[0];
  if (n542[0]) {
    n553[0] = n500[0];
  }
  else {
    n553[0] = n552[0];
  }
  n352[0] = n351[0];
  n352[1] = 255 & (n340[0] << 2 | n351[1]);
  if (n186[0]) {
    n199[0] = n121[0];
    n199[1] = n121[1];
  }
  else {
    n199[0] = n198[0];
    n199[1] = n198[1];
  }
  if (n541[0]) {
    n554[0] = n501[0];
  }
  else {
    n554[0] = n553[0];
  }
  n353[0] = n352[0];
  n353[1] = 255 & (n340[0] << 3 | n352[1]);
  if (n184[0]) {
    n200[0] = n122[0];
    n200[1] = n122[1];
  }
  else {
    n200[0] = n199[0];
    n200[1] = n199[1];
  }
  if (n540[0]) {
    n555[0] = n502[0];
  }
  else {
    n555[0] = n554[0];
  }
  n354[0] = n353[0];
  n354[1] = 255 & (n340[0] << 4 | n353[1]);
  if (n182[0]) {
    n201[0] = n123[0];
    n201[1] = n123[1];
  }
  else {
    n201[0] = n200[0];
    n201[1] = n200[1];
  }
  if (n539[0]) {
    n556[0] = n502[0];
  }
  else {
    n556[0] = n555[0];
  }
  n355[0] = n354[0];
  n355[1] = 255 & (n340[0] << 5 | n354[1]);
  if (n180[0]) {
    n202[0] = n124[0];
    n202[1] = n124[1];
  }
  else {
    n202[0] = n201[0];
    n202[1] = n201[1];
  }
  if (n538[0]) {
    n557[0] = n503[0];
  }
  else {
    n557[0] = n556[0];
  }
  n356[0] = n355[0];
  n356[1] = 255 & (n340[0] << 6 | n355[1]);
  if (n178[0]) {
    n203[0] = n125[0];
    n203[1] = n125[1];
  }
  else {
    n203[0] = n202[0];
    n203[1] = n202[1];
  }
  if (n537[0]) {
    n558[0] = n503[0];
  }
  else {
    n558[0] = n557[0];
  }
  n357[0] = n356[0];
  n357[1] = 255 & (n340[0] << 7 | n356[1]);
  if (n176[0]) {
    n204[0] = n126[0];
    n204[1] = n126[1];
  }
  else {
    n204[0] = n203[0];
    n204[1] = n203[1];
  }
  n563r[0] = n2[0];
  n563e[0] = n1[0];
  n563d[0] = n558[0];
  n358[0] = n357[0];
  n358[1] = n357[1];
  n358[2] = n340[0];
  if (n174[0]) {
    n205[0] = n127[0];
    n205[1] = n127[1];
  }
  else {
    n205[0] = n204[0];
    n205[1] = n204[1];
  }
  n359[0] = n358[0];
  n359[1] = n358[1];
  n359[2] = 255 & (n340[0] << 1 | n358[2]);
  if (n172[0]) {
    n206[0] = n128[0];
    n206[1] = n128[1];
  }
  else {
    n206[0] = n205[0];
    n206[1] = n205[1];
  }
  n360[0] = n359[0];
  n360[1] = n359[1];
  n360[2] = 255 & (n340[0] << 2 | n359[2]);
  if (n170[0]) {
    n207[0] = n129[0];
    n207[1] = n129[1];
  }
  else {
    n207[0] = n206[0];
    n207[1] = n206[1];
  }
  n361[0] = n360[0];
  n361[1] = n360[1];
  n361[2] = 255 & (n340[0] << 3 | n360[2]);
  if (n168[0]) {
    n208[0] = n130[0];
    n208[1] = n130[1];
  }
  else {
    n208[0] = n207[0];
    n208[1] = n207[1];
  }
  n362[0] = n361[0];
  n362[1] = n361[1];
  n362[2] = 255 & (n340[0] << 4 | n361[2]);
  if (n166[0]) {
    n209[0] = n131[0];
    n209[1] = n131[1];
  }
  else {
    n209[0] = n208[0];
    n209[1] = n208[1];
  }
  n363[0] = n362[0];
  n363[1] = n362[1];
  n363[2] = 255 & (n340[0] << 5 | n362[2]);
  if (n164[0]) {
    n210[0] = n132[0];
    n210[1] = n132[1];
  }
  else {
    n210[0] = n209[0];
    n210[1] = n209[1];
  }
  n364[0] = n363[0];
  n364[1] = n363[1];
  n364[2] = 255 & (n340[0] << 6 | n363[2]);
  if (n162[0]) {
    n211[0] = n132[0];
    n211[1] = n132[1];
  }
  else {
    n211[0] = n210[0];
    n211[1] = n210[1];
  }
  n365[0] = n364[0];
  n365[1] = n364[1];
  n365[2] = 255 & (n340[0] << 7 | n364[2]);
  if (n160[0]) {
    n212[0] = n132[0];
    n212[1] = n132[1];
  }
  else {
    n212[0] = n211[0];
    n212[1] = n211[1];
  }
  n366[0] = n365[0];
  n366[1] = n365[1];
  n366[2] = n365[2];
  n366[3] = n340[0];
  if (n158[0]) {
    n213[0] = n132[0];
    n213[1] = n132[1];
  }
  else {
    n213[0] = n212[0];
    n213[1] = n212[1];
  }
  n367[0] = n366[0];
  n367[1] = n366[1];
  n367[2] = n366[2];
  n367[3] = 255 & (n340[0] << 1 | n366[3]);
  if (n156[0]) {
    n214[0] = n132[0];
    n214[1] = n132[1];
  }
  else {
    n214[0] = n213[0];
    n214[1] = n213[1];
  }
  n368[0] = n367[0];
  n368[1] = n367[1];
  n368[2] = n367[2];
  n368[3] = 255 & (n340[0] << 2 | n367[3]);
  if (n154[0]) {
    n215[0] = n132[0];
    n215[1] = n132[1];
  }
  else {
    n215[0] = n214[0];
    n215[1] = n214[1];
  }
  n369[0] = n368[0];
  n369[1] = n368[1];
  n369[2] = n368[2];
  n369[3] = 255 & (n340[0] << 3 | n368[3]);
  if (n152[0]) {
    n216[0] = n132[0];
    n216[1] = n132[1];
  }
  else {
    n216[0] = n215[0];
    n216[1] = n215[1];
  }
  n370[0] = n369[0];
  n370[1] = n369[1];
  n370[2] = n369[2];
  n370[3] = 255 & (n340[0] << 4 | n369[3]);
  if (n150[0]) {
    n217[0] = n132[0];
    n217[1] = n132[1];
  }
  else {
    n217[0] = n216[0];
    n217[1] = n216[1];
  }
  n371[0] = n370[0];
  n371[1] = n370[1];
  n371[2] = n370[2];
  n371[3] = 255 & (n340[0] << 5 | n370[3]);
  if (n148[0]) {
    n218[0] = n132[0];
    n218[1] = n132[1];
  }
  else {
    n218[0] = n217[0];
    n218[1] = n217[1];
  }
  n372[0] = n371[0];
  n372[1] = n371[1];
  n372[2] = n371[2];
  n372[3] = 255 & (n340[0] << 6 | n371[3]);
  if (n146[0]) {
    n219[0] = n132[0];
    n219[1] = n132[1];
  }
  else {
    n219[0] = n218[0];
    n219[1] = n218[1];
  }
  n373[0] = n372[0];
  n373[1] = n372[1];
  n373[2] = n372[2];
  n373[3] = 255 & (n339[0] << 7 | n372[3]);
  if (n144[0]) {
    n220[0] = n132[0];
    n220[1] = n132[1];
  }
  else {
    n220[0] = n219[0];
    n220[1] = n219[1];
  }
  if (n381[0]) {
    n382[0] = n373[0];
    n382[1] = n373[1];
    n382[2] = n373[2];
    n382[3] = n373[3];
  }
  else {
    n382[0] = n376[0];
    n382[1] = n376[1];
    n382[2] = n376[2];
    n382[3] = n376[3];
  }
  if (n142[0]) {
    n221[0] = n132[0];
    n221[1] = n132[1];
  }
  else {
    n221[0] = n220[0];
    n221[1] = n220[1];
  }
  if (n399[0]) {
    n401[0] = n383[0];
    n401[1] = n383[1];
    n401[2] = n383[2];
    n401[3] = n383[3];
  }
  else {
    n401[0] = n382[0];
    n401[1] = n382[1];
    n401[2] = n382[2];
    n401[3] = n382[3];
  }
  if (n140[0]) {
    n222[0] = n132[0];
    n222[1] = n132[1];
  }
  else {
    n222[0] = n221[0];
    n222[1] = n221[1];
  }
  if (n405[0]) {
    n406[0] = n401[0];
    n406[1] = n401[1];
    n406[2] = n401[2];
    n406[3] = n401[3];
  }
  else {
    n406[0] = n400[0];
    n406[1] = n400[1];
    n406[2] = n400[2];
    n406[3] = n400[3];
  }
  if (n138[0]) {
    n223[0] = n132[0];
    n223[1] = n132[1];
  }
  else {
    n223[0] = n222[0];
    n223[1] = n222[1];
  }
  if (n409[0]) {
    n410[0] = n407[0];
    n410[1] = n407[1];
    n410[2] = n407[2];
    n410[3] = n407[3];
  }
  else {
    n410[0] = n406[0];
    n410[1] = n406[1];
    n410[2] = n406[2];
    n410[3] = n406[3];
  }
  if (n136[0]) {
    n224[0] = n132[0];
    n224[1] = n132[1];
  }
  else {
    n224[0] = n223[0];
    n224[1] = n223[1];
  }
  if (load_write_i[0]) {
    n419[0] = load_data_i[0];
    n419[1] = load_data_i[1];
    n419[2] = load_data_i[2];
    n419[3] = load_data_i[3];
  }
  else {
    n419[0] = n410[0];
    n419[1] = n410[1];
    n419[2] = n410[2];
    n419[3] = n410[3];
  }
  if (n134[0]) {
    n225[0] = n132[0];
    n225[1] = n132[1];
  }
  else {
    n225[0] = n224[0];
    n225[1] = n224[1];
  }
  n269[0] = (1 & (n225[1] >> 7));
  n266[0] = (1 & (n225[1] >> 6));
  n263[0] = (1 & (n225[1] >> 5));
  n260[0] = (1 & (n225[1] >> 4));
  n257[0] = (1 & (n225[1] >> 3));
  n254[0] = (1 & (n225[1] >> 2));
  n251[0] = (1 & (n225[1] >> 1));
  n248[0] = (1 & (n225[1]));
  n245[0] = (1 & (n225[0] >> 7));
  n242[0] = (1 & (n225[0] >> 6));
  n239[0] = (1 & (n225[0] >> 5));
  n236[0] = (1 & (n225[0] >> 4));
  n233[0] = (1 & (n225[0] >> 3));
  n230[0] = (1 & (n225[0] >> 2));
  n227[0] = (1 & (n225[0] >> 1));
  n494r[0] = reset_state_i[0];
  n494e[0] = n269[0];
  n494d[0] = n419[0];
  n494d[1] = n419[1];
  n494d[2] = n419[2];
  n494d[3] = n419[3];
  n489r[0] = reset_state_i[0];
  n489e[0] = n266[0];
  n489d[0] = n419[0];
  n489d[1] = n419[1];
  n489d[2] = n419[2];
  n489d[3] = n419[3];
  n484r[0] = reset_state_i[0];
  n484e[0] = n263[0];
  n484d[0] = n419[0];
  n484d[1] = n419[1];
  n484d[2] = n419[2];
  n484d[3] = n419[3];
  n479r[0] = reset_state_i[0];
  n479e[0] = n260[0];
  n479d[0] = n419[0];
  n479d[1] = n419[1];
  n479d[2] = n419[2];
  n479d[3] = n419[3];
  n474r[0] = reset_state_i[0];
  n474e[0] = n257[0];
  n474d[0] = n419[0];
  n474d[1] = n419[1];
  n474d[2] = n419[2];
  n474d[3] = n419[3];
  n469r[0] = reset_state_i[0];
  n469e[0] = n254[0];
  n469d[0] = n419[0];
  n469d[1] = n419[1];
  n469d[2] = n419[2];
  n469d[3] = n419[3];
  n464r[0] = reset_state_i[0];
  n464e[0] = n251[0];
  n464d[0] = n419[0];
  n464d[1] = n419[1];
  n464d[2] = n419[2];
  n464d[3] = n419[3];
  n459r[0] = reset_state_i[0];
  n459e[0] = n248[0];
  n459d[0] = n419[0];
  n459d[1] = n419[1];
  n459d[2] = n419[2];
  n459d[3] = n419[3];
  n454r[0] = reset_state_i[0];
  n454e[0] = n245[0];
  n454d[0] = n419[0];
  n454d[1] = n419[1];
  n454d[2] = n419[2];
  n454d[3] = n419[3];
  n449r[0] = reset_state_i[0];
  n449e[0] = n242[0];
  n449d[0] = n419[0];
  n449d[1] = n419[1];
  n449d[2] = n419[2];
  n449d[3] = n419[3];
  n444r[0] = reset_state_i[0];
  n444e[0] = n239[0];
  n444d[0] = n419[0];
  n444d[1] = n419[1];
  n444d[2] = n419[2];
  n444d[3] = n419[3];
  n439r[0] = reset_state_i[0];
  n439e[0] = n236[0];
  n439d[0] = n419[0];
  n439d[1] = n419[1];
  n439d[2] = n419[2];
  n439d[3] = n419[3];
  n434r[0] = reset_state_i[0];
  n434e[0] = n233[0];
  n434d[0] = n419[0];
  n434d[1] = n419[1];
  n434d[2] = n419[2];
  n434d[3] = n419[3];
  n429r[0] = reset_state_i[0];
  n429e[0] = n230[0];
  n429d[0] = n419[0];
  n429d[1] = n419[1];
  n429d[2] = n419[2];
  n429d[3] = n419[3];
  n424r[0] = reset_state_i[0];
  n424e[0] = n227[0];
  n424d[0] = n419[0];
  n424d[1] = n419[1];
  n424d[2] = n419[2];
  n424d[3] = n419[3];
}

void cf_ssp_32_8_init() {
  n636[0] = 0;
  n627[0] = 0;
  n626[0] = 0;
  n526[0] = 0;
  n525[0] = 0;
  n524[0] = 0;
  n523[0] = 0;
  n522[0] = 0;
  n521[0] = 0;
  n513[0] = 0;
  n512[0] = 0;
  n511[0] = 0;
  n510[0] = 0;
  n509[0] = 0;
  n508[0] = 0;
  n507[0] = 0;
  n506[0] = 0;
  n505[0] = 0;
  n504[0] = 0;
  n503[0] = 0;
  n502[0] = 0;
  n501[0] = 0;
  n500[0] = 0;
  n499[0] = 0;
  n498[0] = 0;
  n497[0] = 0;
  n399[0] = 0;
  n398[0] = 0;
  n391[0] = 0;
  n388[0] = 0;
  n385[0] = 0;
  n375[0] = 0;
  n310[0] = 0;
  n309[0] = 0;
  n280[0] = 0;
  n279[0] = 0;
  { int index; for (index = 4; index > 0;) n226[--index] = 0; }
  n193[0] = 0;
  n191[0] = 0;
  n189[0] = 0;
  n187[0] = 0;
  n185[0] = 0;
  n183[0] = 0;
  n181[0] = 0;
  n179[0] = 0;
  n177[0] = 0;
  n175[0] = 0;
  n173[0] = 0;
  n171[0] = 0;
  n169[0] = 0;
  n167[0] = 0;
  n165[0] = 0;
  n163[0] = 0;
  n161[0] = 0;
  n159[0] = 0;
  n157[0] = 0;
  n155[0] = 0;
  n153[0] = 0;
  n151[0] = 0;
  n149[0] = 0;
  n147[0] = 0;
  n145[0] = 0;
  n143[0] = 0;
  n141[0] = 0;
  n139[0] = 0;
  n137[0] = 0;
  n135[0] = 0;
  n133[0] = 0;
  { int index; for (index = 2; index > 0;) n132[--index] = 0; }
  { int index; for (index = 2; index > 0;) n131[--index] = 0; }
  { int index; for (index = 2; index > 0;) n130[--index] = 0; }
  { int index; for (index = 2; index > 0;) n129[--index] = 0; }
  { int index; for (index = 2; index > 0;) n128[--index] = 0; }
  { int index; for (index = 2; index > 0;) n127[--index] = 0; }
  { int index; for (index = 2; index > 0;) n126[--index] = 0; }
  { int index; for (index = 2; index > 0;) n125[--index] = 0; }
  { int index; for (index = 2; index > 0;) n124[--index] = 0; }
  { int index; for (index = 2; index > 0;) n123[--index] = 0; }
  { int index; for (index = 2; index > 0;) n122[--index] = 0; }
  { int index; for (index = 2; index > 0;) n121[--index] = 0; }
  { int index; for (index = 2; index > 0;) n120[--index] = 0; }
  { int index; for (index = 2; index > 0;) n119[--index] = 0; }
  { int index; for (index = 2; index > 0;) n118[--index] = 0; }
  { int index; for (index = 2; index > 0;) n117[--index] = 0; }
  { int index; for (index = 2; index > 0;) n116[--index] = 0; }
  n61[0] = 0;
  n60[0] = 0;
  n59[0] = 0;
  n58[0] = 0;
  n57[0] = 0;
  n56[0] = 0;
  n55[0] = 0;
  n54[0] = 0;
  n49[0] = 0;
  n48[0] = 0;
  n47[0] = 0;
  n46[0] = 0;
  n45[0] = 0;
  n44[0] = 0;
  n43[0] = 0;
  n42[0] = 0;
  n41[0] = 0;
  n40[0] = 0;
  n39[0] = 0;
  n38[0] = 0;
  n37[0] = 0;
  n36[0] = 0;
  n35[0] = 0;
  n10[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  n405[0] = 0;
  n404[0] = 0;
  n392[0] = 0;
  n389[0] = 0;
  n386[0] = 0;
  n320[0] = 0;
  n319[0] = 0;
  { int index; for (index = 4; index > 0;) n318[--index] = 0; }
  { int index; for (index = 4; index > 0;) n317[--index] = 0; }
  { int index; for (index = 4; index > 0;) n316[--index] = 0; }
  { int index; for (index = 4; index > 0;) n315[--index] = 0; }
  { int index; for (index = 4; index > 0;) n314[--index] = 0; }
  { int index; for (index = 4; index > 0;) n313[--index] = 0; }
  { int index; for (index = 4; index > 0;) n312[--index] = 0; }
  { int index; for (index = 4; index > 0;) n311[--index] = 0; }
  n290[0] = 0;
  n289[0] = 0;
  { int index; for (index = 4; index > 0;) n288[--index] = 0; }
  { int index; for (index = 4; index > 0;) n287[--index] = 0; }
  { int index; for (index = 4; index > 0;) n286[--index] = 0; }
  { int index; for (index = 4; index > 0;) n285[--index] = 0; }
  { int index; for (index = 4; index > 0;) n284[--index] = 0; }
  { int index; for (index = 4; index > 0;) n283[--index] = 0; }
  { int index; for (index = 4; index > 0;) n282[--index] = 0; }
  { int index; for (index = 4; index > 0;) n281[--index] = 0; }
  n114[0] = 0;
  n112[0] = 0;
  n104[0] = 0;
  n103[0] = 0;
  n102[0] = 0;
  n101[0] = 0;
  n33[0] = 0;
  n32[0] = 0;
  n32r[0] = 0;
  n32e[0] = 0;
  n32d[0] = 0;
  n25[0] = 0;
  n25r[0] = 0;
  n25e[0] = 0;
  n25d[0] = 0;
  n13[0] = 0;
  n409[0] = 0;
  n338[0] = 0;
  n338r[0] = 0;
  n338e[0] = 0;
  n338d[0] = 0;
  n326[0] = 0;
  n325[0] = 0;
  { int index; for (index = 4; index > 0;) n324[--index] = 0; }
  { int index; for (index = 4; index > 0;) n323[--index] = 0; }
  { int index; for (index = 4; index > 0;) n322[--index] = 0; }
  { int index; for (index = 4; index > 0;) n321[--index] = 0; }
  n308[0] = 0;
  n308r[0] = 0;
  n308e[0] = 0;
  n308d[0] = 0;
  n296[0] = 0;
  n295[0] = 0;
  { int index; for (index = 4; index > 0;) n294[--index] = 0; }
  { int index; for (index = 4; index > 0;) n293[--index] = 0; }
  { int index; for (index = 4; index > 0;) n292[--index] = 0; }
  { int index; for (index = 4; index > 0;) n291[--index] = 0; }
  n278[0] = 0;
  n278r[0] = 0;
  n278e[0] = 0;
  n278d[0] = 0;
  n111[0] = 0;
  n111r[0] = 0;
  n111e[0] = 0;
  n111d[0] = 0;
  n34[0] = 0;
  n18[0] = 0;
  n18r[0] = 0;
  n18e[0] = 0;
  n18d[0] = 0;
  n330[0] = 0;
  { int index; for (index = 4; index > 0;) n328[--index] = 0; }
  { int index; for (index = 4; index > 0;) n327[--index] = 0; }
  n300[0] = 0;
  { int index; for (index = 4; index > 0;) n298[--index] = 0; }
  { int index; for (index = 4; index > 0;) n297[--index] = 0; }
  n67[0] = 0;
  { int index; for (index = 4; index > 0;) n331[--index] = 0; }
  { int index; for (index = 4; index > 0;) n301[--index] = 0; }
  n90[0] = 0;
  n89[0] = 0;
  n88[0] = 0;
  n87[0] = 0;
  n74[0] = 0;
  n73[0] = 0;
  n72[0] = 0;
  n71[0] = 0;
  n70[0] = 0;
  n69[0] = 0;
  n68[0] = 0;
  { int index; for (index = 4; index > 0;) n397[--index] = 0; }
  n387[0] = 0;
  { int index; for (index = 4; index > 0;) n384[--index] = 0; }
  { int index; for (index = 4; index > 0;) n383[--index] = 0; }
  n380[0] = 0;
  { int index; for (index = 4; index > 0;) n378[--index] = 0; }
  n377[0] = 0;
  { int index; for (index = 4; index > 0;) n374[--index] = 0; }
  n339[0] = 0;
  n97[0] = 0;
  n75[0] = 0;
  { int index; for (index = 4; index > 0;) n403[--index] = 0; }
  { int index; for (index = 4; index > 0;) n396[--index] = 0; }
  n393[0] = 0;
  n390[0] = 0;
  n381[0] = 0;
  { int index; for (index = 4; index > 0;) n379[--index] = 0; }
  { int index; for (index = 4; index > 0;) n376[--index] = 0; }
  n340[0] = 0;
  n98[0] = 0;
  n76[0] = 0;
  n411[0] = 0;
  { int index; for (index = 4; index > 0;) n402[--index] = 0; }
  { int index; for (index = 4; index > 0;) n400[--index] = 0; }
  n343[0] = 0;
  n99[0] = 0;
  n77[0] = 0;
  n412[0] = 0;
  { int index; for (index = 4; index > 0;) n407[--index] = 0; }
  n344[0] = 0;
  n100[0] = 0;
  n78[0] = 0;
  n495[0] = 0;
  n413[0] = 0;
  n345[0] = 0;
  n113[0] = 0;
  n79[0] = 0;
  n536[0] = 0;
  n418[0] = 0;
  n418r[0] = 0;
  n418e[0] = 0;
  n418d[0] = 0;
  n346[0] = 0;
  n115[0] = 0;
  n80[0] = 0;
  n567[0] = 0;
  n566[0] = 0;
  n565[0] = 0;
  n564[0] = 0;
  n546[0] = 0;
  n545[0] = 0;
  n544[0] = 0;
  n543[0] = 0;
  n542[0] = 0;
  n541[0] = 0;
  n540[0] = 0;
  n539[0] = 0;
  n538[0] = 0;
  n537[0] = 0;
  n347[0] = 0;
  n194[0] = 0;
  n192[0] = 0;
  n190[0] = 0;
  n188[0] = 0;
  n186[0] = 0;
  n184[0] = 0;
  n182[0] = 0;
  n180[0] = 0;
  n178[0] = 0;
  n176[0] = 0;
  n174[0] = 0;
  n172[0] = 0;
  n170[0] = 0;
  n168[0] = 0;
  n166[0] = 0;
  n164[0] = 0;
  n162[0] = 0;
  n160[0] = 0;
  n158[0] = 0;
  n156[0] = 0;
  n154[0] = 0;
  n152[0] = 0;
  n150[0] = 0;
  n148[0] = 0;
  n146[0] = 0;
  n144[0] = 0;
  n142[0] = 0;
  n140[0] = 0;
  n138[0] = 0;
  n136[0] = 0;
  n134[0] = 0;
  n81[0] = 0;
  n582[0] = 0;
  n549[0] = 0;
  n348[0] = 0;
  { int index; for (index = 2; index > 0;) n195[--index] = 0; }
  n86[0] = 0;
  n86r[0] = 0;
  n86e[0] = 0;
  n86d[0] = 0;
  n583[0] = 0;
  n550[0] = 0;
  n349[0] = 0;
  { int index; for (index = 2; index > 0;) n196[--index] = 0; }
  n584[0] = 0;
  n551[0] = 0;
  { int index; for (index = 2; index > 0;) n350[--index] = 0; }
  { int index; for (index = 2; index > 0;) n197[--index] = 0; }
  n585[0] = 0;
  n552[0] = 0;
  { int index; for (index = 2; index > 0;) n351[--index] = 0; }
  { int index; for (index = 2; index > 0;) n198[--index] = 0; }
  n553[0] = 0;
  { int index; for (index = 2; index > 0;) n352[--index] = 0; }
  { int index; for (index = 2; index > 0;) n199[--index] = 0; }
  n554[0] = 0;
  { int index; for (index = 2; index > 0;) n353[--index] = 0; }
  { int index; for (index = 2; index > 0;) n200[--index] = 0; }
  n555[0] = 0;
  { int index; for (index = 2; index > 0;) n354[--index] = 0; }
  { int index; for (index = 2; index > 0;) n201[--index] = 0; }
  n556[0] = 0;
  { int index; for (index = 2; index > 0;) n355[--index] = 0; }
  { int index; for (index = 2; index > 0;) n202[--index] = 0; }
  n557[0] = 0;
  { int index; for (index = 2; index > 0;) n356[--index] = 0; }
  { int index; for (index = 2; index > 0;) n203[--index] = 0; }
  n558[0] = 0;
  { int index; for (index = 2; index > 0;) n357[--index] = 0; }
  { int index; for (index = 2; index > 0;) n204[--index] = 0; }
  n563[0] = 0;
  n563r[0] = 0;
  n563e[0] = 0;
  n563d[0] = 0;
  { int index; for (index = 3; index > 0;) n358[--index] = 0; }
  { int index; for (index = 2; index > 0;) n205[--index] = 0; }
  { int index; for (index = 3; index > 0;) n359[--index] = 0; }
  { int index; for (index = 2; index > 0;) n206[--index] = 0; }
  { int index; for (index = 3; index > 0;) n360[--index] = 0; }
  { int index; for (index = 2; index > 0;) n207[--index] = 0; }
  { int index; for (index = 3; index > 0;) n361[--index] = 0; }
  { int index; for (index = 2; index > 0;) n208[--index] = 0; }
  { int index; for (index = 3; index > 0;) n362[--index] = 0; }
  { int index; for (index = 2; index > 0;) n209[--index] = 0; }
  { int index; for (index = 3; index > 0;) n363[--index] = 0; }
  { int index; for (index = 2; index > 0;) n210[--index] = 0; }
  { int index; for (index = 3; index > 0;) n364[--index] = 0; }
  { int index; for (index = 2; index > 0;) n211[--index] = 0; }
  { int index; for (index = 3; index > 0;) n365[--index] = 0; }
  { int index; for (index = 2; index > 0;) n212[--index] = 0; }
  { int index; for (index = 4; index > 0;) n366[--index] = 0; }
  { int index; for (index = 2; index > 0;) n213[--index] = 0; }
  { int index; for (index = 4; index > 0;) n367[--index] = 0; }
  { int index; for (index = 2; index > 0;) n214[--index] = 0; }
  { int index; for (index = 4; index > 0;) n368[--index] = 0; }
  { int index; for (index = 2; index > 0;) n215[--index] = 0; }
  { int index; for (index = 4; index > 0;) n369[--index] = 0; }
  { int index; for (index = 2; index > 0;) n216[--index] = 0; }
  { int index; for (index = 4; index > 0;) n370[--index] = 0; }
  { int index; for (index = 2; index > 0;) n217[--index] = 0; }
  { int index; for (index = 4; index > 0;) n371[--index] = 0; }
  { int index; for (index = 2; index > 0;) n218[--index] = 0; }
  { int index; for (index = 4; index > 0;) n372[--index] = 0; }
  { int index; for (index = 2; index > 0;) n219[--index] = 0; }
  { int index; for (index = 4; index > 0;) n373[--index] = 0; }
  { int index; for (index = 2; index > 0;) n220[--index] = 0; }
  { int index; for (index = 4; index > 0;) n382[--index] = 0; }
  { int index; for (index = 2; index > 0;) n221[--index] = 0; }
  { int index; for (index = 4; index > 0;) n401[--index] = 0; }
  { int index; for (index = 2; index > 0;) n222[--index] = 0; }
  { int index; for (index = 4; index > 0;) n406[--index] = 0; }
  { int index; for (index = 2; index > 0;) n223[--index] = 0; }
  { int index; for (index = 4; index > 0;) n410[--index] = 0; }
  { int index; for (index = 2; index > 0;) n224[--index] = 0; }
  { int index; for (index = 4; index > 0;) n419[--index] = 0; }
  { int index; for (index = 2; index > 0;) n225[--index] = 0; }
  n269[0] = 0;
  n266[0] = 0;
  n263[0] = 0;
  n260[0] = 0;
  n257[0] = 0;
  n254[0] = 0;
  n251[0] = 0;
  n248[0] = 0;
  n245[0] = 0;
  n242[0] = 0;
  n239[0] = 0;
  n236[0] = 0;
  n233[0] = 0;
  n230[0] = 0;
  n227[0] = 0;
  { int index; for (index = 4; index > 0;) n494[--index] = 0; }
  n494r[0] = 0;
  n494e[0] = 0;
  { int index; for (index = 4; index > 0;) n494d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n489[--index] = 0; }
  n489r[0] = 0;
  n489e[0] = 0;
  { int index; for (index = 4; index > 0;) n489d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n484[--index] = 0; }
  n484r[0] = 0;
  n484e[0] = 0;
  { int index; for (index = 4; index > 0;) n484d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n479[--index] = 0; }
  n479r[0] = 0;
  n479e[0] = 0;
  { int index; for (index = 4; index > 0;) n479d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n474[--index] = 0; }
  n474r[0] = 0;
  n474e[0] = 0;
  { int index; for (index = 4; index > 0;) n474d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n469[--index] = 0; }
  n469r[0] = 0;
  n469e[0] = 0;
  { int index; for (index = 4; index > 0;) n469d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n464[--index] = 0; }
  n464r[0] = 0;
  n464e[0] = 0;
  { int index; for (index = 4; index > 0;) n464d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n459[--index] = 0; }
  n459r[0] = 0;
  n459e[0] = 0;
  { int index; for (index = 4; index > 0;) n459d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n454[--index] = 0; }
  n454r[0] = 0;
  n454e[0] = 0;
  { int index; for (index = 4; index > 0;) n454d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n449[--index] = 0; }
  n449r[0] = 0;
  n449e[0] = 0;
  { int index; for (index = 4; index > 0;) n449d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n444[--index] = 0; }
  n444r[0] = 0;
  n444e[0] = 0;
  { int index; for (index = 4; index > 0;) n444d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n439[--index] = 0; }
  n439r[0] = 0;
  n439e[0] = 0;
  { int index; for (index = 4; index > 0;) n439d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n434[--index] = 0; }
  n434r[0] = 0;
  n434e[0] = 0;
  { int index; for (index = 4; index > 0;) n434d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n429[--index] = 0; }
  n429r[0] = 0;
  n429e[0] = 0;
  { int index; for (index = 4; index > 0;) n429d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n424[--index] = 0; }
  n424r[0] = 0;
  n424e[0] = 0;
  { int index; for (index = 4; index > 0;) n424d[--index] = 0; }
  cf_ssp_32_8_calc();
}

void cf_ssp_32_8_cycle_clock()
{
  if (n18r[0]) {
    n18[0] = 0;
  }
  else if (n18e[0]) {
    n18[0] = n18d[0];
  }
  if (n25r[0]) {
    n25[0] = 0;
  }
  else if (n25e[0]) {
    n25[0] = n25d[0];
  }
  if (n32r[0]) {
    n32[0] = 0;
  }
  else if (n32e[0]) {
    n32[0] = n32d[0];
  }
  if (n86r[0]) {
    n86[0] = 0;
  }
  else if (n86e[0]) {
    n86[0] = n86d[0];
  }
  if (n111r[0]) {
    n111[0] = 0;
  }
  else if (n111e[0]) {
    n111[0] = n111d[0];
  }
  if (n278r[0]) {
    n278[0] = 0;
  }
  else if (n278e[0]) {
    n278[0] = n278d[0];
  }
  if (n308r[0]) {
    n308[0] = 0;
  }
  else if (n308e[0]) {
    n308[0] = n308d[0];
  }
  if (n338r[0]) {
    n338[0] = 0;
  }
  else if (n338e[0]) {
    n338[0] = n338d[0];
  }
  if (n418r[0]) {
    n418[0] = 0;
  }
  else if (n418e[0]) {
    n418[0] = n418d[0];
  }
  if (n424r[0]) {
    n424[0] = 0;
    n424[1] = 0;
    n424[2] = 0;
    n424[3] = 0;
  }
  else if (n424e[0]) {
    n424[0] = n424d[0];
    n424[1] = n424d[1];
    n424[2] = n424d[2];
    n424[3] = n424d[3];
  }
  if (n429r[0]) {
    n429[0] = 0;
    n429[1] = 0;
    n429[2] = 0;
    n429[3] = 0;
  }
  else if (n429e[0]) {
    n429[0] = n429d[0];
    n429[1] = n429d[1];
    n429[2] = n429d[2];
    n429[3] = n429d[3];
  }
  if (n434r[0]) {
    n434[0] = 0;
    n434[1] = 0;
    n434[2] = 0;
    n434[3] = 0;
  }
  else if (n434e[0]) {
    n434[0] = n434d[0];
    n434[1] = n434d[1];
    n434[2] = n434d[2];
    n434[3] = n434d[3];
  }
  if (n439r[0]) {
    n439[0] = 0;
    n439[1] = 0;
    n439[2] = 0;
    n439[3] = 0;
  }
  else if (n439e[0]) {
    n439[0] = n439d[0];
    n439[1] = n439d[1];
    n439[2] = n439d[2];
    n439[3] = n439d[3];
  }
  if (n444r[0]) {
    n444[0] = 0;
    n444[1] = 0;
    n444[2] = 0;
    n444[3] = 0;
  }
  else if (n444e[0]) {
    n444[0] = n444d[0];
    n444[1] = n444d[1];
    n444[2] = n444d[2];
    n444[3] = n444d[3];
  }
  if (n449r[0]) {
    n449[0] = 0;
    n449[1] = 0;
    n449[2] = 0;
    n449[3] = 0;
  }
  else if (n449e[0]) {
    n449[0] = n449d[0];
    n449[1] = n449d[1];
    n449[2] = n449d[2];
    n449[3] = n449d[3];
  }
  if (n454r[0]) {
    n454[0] = 0;
    n454[1] = 0;
    n454[2] = 0;
    n454[3] = 0;
  }
  else if (n454e[0]) {
    n454[0] = n454d[0];
    n454[1] = n454d[1];
    n454[2] = n454d[2];
    n454[3] = n454d[3];
  }
  if (n459r[0]) {
    n459[0] = 0;
    n459[1] = 0;
    n459[2] = 0;
    n459[3] = 0;
  }
  else if (n459e[0]) {
    n459[0] = n459d[0];
    n459[1] = n459d[1];
    n459[2] = n459d[2];
    n459[3] = n459d[3];
  }
  if (n464r[0]) {
    n464[0] = 0;
    n464[1] = 0;
    n464[2] = 0;
    n464[3] = 0;
  }
  else if (n464e[0]) {
    n464[0] = n464d[0];
    n464[1] = n464d[1];
    n464[2] = n464d[2];
    n464[3] = n464d[3];
  }
  if (n469r[0]) {
    n469[0] = 0;
    n469[1] = 0;
    n469[2] = 0;
    n469[3] = 0;
  }
  else if (n469e[0]) {
    n469[0] = n469d[0];
    n469[1] = n469d[1];
    n469[2] = n469d[2];
    n469[3] = n469d[3];
  }
  if (n474r[0]) {
    n474[0] = 0;
    n474[1] = 0;
    n474[2] = 0;
    n474[3] = 0;
  }
  else if (n474e[0]) {
    n474[0] = n474d[0];
    n474[1] = n474d[1];
    n474[2] = n474d[2];
    n474[3] = n474d[3];
  }
  if (n479r[0]) {
    n479[0] = 0;
    n479[1] = 0;
    n479[2] = 0;
    n479[3] = 0;
  }
  else if (n479e[0]) {
    n479[0] = n479d[0];
    n479[1] = n479d[1];
    n479[2] = n479d[2];
    n479[3] = n479d[3];
  }
  if (n484r[0]) {
    n484[0] = 0;
    n484[1] = 0;
    n484[2] = 0;
    n484[3] = 0;
  }
  else if (n484e[0]) {
    n484[0] = n484d[0];
    n484[1] = n484d[1];
    n484[2] = n484d[2];
    n484[3] = n484d[3];
  }
  if (n489r[0]) {
    n489[0] = 0;
    n489[1] = 0;
    n489[2] = 0;
    n489[3] = 0;
  }
  else if (n489e[0]) {
    n489[0] = n489d[0];
    n489[1] = n489d[1];
    n489[2] = n489d[2];
    n489[3] = n489d[3];
  }
  if (n494r[0]) {
    n494[0] = 0;
    n494[1] = 0;
    n494[2] = 0;
    n494[3] = 0;
  }
  else if (n494e[0]) {
    n494[0] = n494d[0];
    n494[1] = n494d[1];
    n494[2] = n494d[2];
    n494[3] = n494d[3];
  }
  if (n563r[0]) {
    n563[0] = 0;
  }
  else if (n563e[0]) {
    n563[0] = n563d[0];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_state_i[1];
static unsigned char sim_cycle_i[1];
static unsigned char sim_instr_data_i[2];
static unsigned char sim_const_data_i[4];
static unsigned char sim_load_write_i[1];
static unsigned char sim_load_addr_i[1];
static unsigned char sim_load_data_i[4];
static unsigned char sim_done_o[1];
static unsigned char sim_instr_addr_o[1];
static unsigned char sim_const_addr_o[1];
static unsigned char sim_reg_0_o[4];
static unsigned char sim_reg_1_o[4];
static unsigned char sim_reg_2_o[4];
static unsigned char sim_reg_3_o[4];
static unsigned char sim_reg_4_o[4];
static unsigned char sim_reg_5_o[4];
static unsigned char sim_reg_6_o[4];
static unsigned char sim_reg_7_o[4];
static unsigned char sim_reg_8_o[4];
static unsigned char sim_reg_9_o[4];
static unsigned char sim_reg_a_o[4];
static unsigned char sim_reg_b_o[4];
static unsigned char sim_reg_c_o[4];
static unsigned char sim_reg_d_o[4];
static unsigned char sim_reg_e_o[4];
static unsigned char sim_reg_f_o[4];

void cf_ssp_32_8_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_ssp_32_8_init();
  sim_reset_state_i[0] = reset_state_i[0];
  sim_cycle_i[0] = cycle_i[0];
  sim_instr_data_i[0] = instr_data_i[0];
  sim_instr_data_i[1] = instr_data_i[1];
  sim_const_data_i[0] = const_data_i[0];
  sim_const_data_i[1] = const_data_i[1];
  sim_const_data_i[2] = const_data_i[2];
  sim_const_data_i[3] = const_data_i[3];
  sim_load_write_i[0] = load_write_i[0];
  sim_load_addr_i[0] = load_addr_i[0];
  sim_load_data_i[0] = load_data_i[0];
  sim_load_data_i[1] = load_data_i[1];
  sim_load_data_i[2] = load_data_i[2];
  sim_load_data_i[3] = load_data_i[3];
  sim_done_o[0] = done_o[0];
  sim_instr_addr_o[0] = instr_addr_o[0];
  sim_const_addr_o[0] = const_addr_o[0];
  sim_reg_0_o[0] = reg_0_o[0];
  sim_reg_0_o[1] = reg_0_o[1];
  sim_reg_0_o[2] = reg_0_o[2];
  sim_reg_0_o[3] = reg_0_o[3];
  sim_reg_1_o[0] = reg_1_o[0];
  sim_reg_1_o[1] = reg_1_o[1];
  sim_reg_1_o[2] = reg_1_o[2];
  sim_reg_1_o[3] = reg_1_o[3];
  sim_reg_2_o[0] = reg_2_o[0];
  sim_reg_2_o[1] = reg_2_o[1];
  sim_reg_2_o[2] = reg_2_o[2];
  sim_reg_2_o[3] = reg_2_o[3];
  sim_reg_3_o[0] = reg_3_o[0];
  sim_reg_3_o[1] = reg_3_o[1];
  sim_reg_3_o[2] = reg_3_o[2];
  sim_reg_3_o[3] = reg_3_o[3];
  sim_reg_4_o[0] = reg_4_o[0];
  sim_reg_4_o[1] = reg_4_o[1];
  sim_reg_4_o[2] = reg_4_o[2];
  sim_reg_4_o[3] = reg_4_o[3];
  sim_reg_5_o[0] = reg_5_o[0];
  sim_reg_5_o[1] = reg_5_o[1];
  sim_reg_5_o[2] = reg_5_o[2];
  sim_reg_5_o[3] = reg_5_o[3];
  sim_reg_6_o[0] = reg_6_o[0];
  sim_reg_6_o[1] = reg_6_o[1];
  sim_reg_6_o[2] = reg_6_o[2];
  sim_reg_6_o[3] = reg_6_o[3];
  sim_reg_7_o[0] = reg_7_o[0];
  sim_reg_7_o[1] = reg_7_o[1];
  sim_reg_7_o[2] = reg_7_o[2];
  sim_reg_7_o[3] = reg_7_o[3];
  sim_reg_8_o[0] = reg_8_o[0];
  sim_reg_8_o[1] = reg_8_o[1];
  sim_reg_8_o[2] = reg_8_o[2];
  sim_reg_8_o[3] = reg_8_o[3];
  sim_reg_9_o[0] = reg_9_o[0];
  sim_reg_9_o[1] = reg_9_o[1];
  sim_reg_9_o[2] = reg_9_o[2];
  sim_reg_9_o[3] = reg_9_o[3];
  sim_reg_a_o[0] = reg_a_o[0];
  sim_reg_a_o[1] = reg_a_o[1];
  sim_reg_a_o[2] = reg_a_o[2];
  sim_reg_a_o[3] = reg_a_o[3];
  sim_reg_b_o[0] = reg_b_o[0];
  sim_reg_b_o[1] = reg_b_o[1];
  sim_reg_b_o[2] = reg_b_o[2];
  sim_reg_b_o[3] = reg_b_o[3];
  sim_reg_c_o[0] = reg_c_o[0];
  sim_reg_c_o[1] = reg_c_o[1];
  sim_reg_c_o[2] = reg_c_o[2];
  sim_reg_c_o[3] = reg_c_o[3];
  sim_reg_d_o[0] = reg_d_o[0];
  sim_reg_d_o[1] = reg_d_o[1];
  sim_reg_d_o[2] = reg_d_o[2];
  sim_reg_d_o[3] = reg_d_o[3];
  sim_reg_e_o[0] = reg_e_o[0];
  sim_reg_e_o[1] = reg_e_o[1];
  sim_reg_e_o[2] = reg_e_o[2];
  sim_reg_e_o[3] = reg_e_o[3];
  sim_reg_f_o[0] = reg_f_o[0];
  sim_reg_f_o[1] = reg_f_o[1];
  sim_reg_f_o[2] = reg_f_o[2];
  sim_reg_f_o[3] = reg_f_o[3];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_ssp_32_8 $end\n"
    "$var wire 1 ! reset_state_i $end\n"
    "$var wire 1 \" cycle_i $end\n"
    "$var wire 16 # instr_data_i $end\n"
    "$var wire 32 $ const_data_i $end\n"
    "$var wire 1 %% load_write_i $end\n"
    "$var wire 4 & load_addr_i $end\n"
    "$var wire 32 ' load_data_i $end\n"
    "$var wire 1 ( done_o $end\n"
    "$var wire 8 ) instr_addr_o $end\n"
    "$var wire 8 * const_addr_o $end\n"
    "$var wire 32 + reg_0_o $end\n"
    "$var wire 32 , reg_1_o $end\n"
    "$var wire 32 - reg_2_o $end\n"
    "$var wire 32 . reg_3_o $end\n"
    "$var wire 32 / reg_4_o $end\n"
    "$var wire 32 0 reg_5_o $end\n"
    "$var wire 32 1 reg_6_o $end\n"
    "$var wire 32 2 reg_7_o $end\n"
    "$var wire 32 3 reg_8_o $end\n"
    "$var wire 32 4 reg_9_o $end\n"
    "$var wire 32 5 reg_a_o $end\n"
    "$var wire 32 6 reg_b_o $end\n"
    "$var wire 32 7 reg_c_o $end\n"
    "$var wire 32 8 reg_d_o $end\n"
    "$var wire 32 9 reg_e_o $end\n"
    "$var wire 32 : reg_f_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_state_i[0] ? "1!\n" : "0!\n");
  fprintf(sim_file, cycle_i[0] ? "1\"\n" : "0\"\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & instr_data_i[byte]) ? "1" : "0");
        else if (bit & instr_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & const_data_i[byte]) ? "1" : "0");
        else if (bit & const_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  fprintf(sim_file, load_write_i[0] ? "1%%\n" : "0%%\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & load_addr_i[byte]) ? "1" : "0");
        else if (bit & load_addr_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & load_data_i[byte]) ? "1" : "0");
        else if (bit & load_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  fprintf(sim_file, done_o[0] ? "1(\n" : "0(\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & instr_addr_o[byte]) ? "1" : "0");
        else if (bit & instr_addr_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & const_addr_o[byte]) ? "1" : "0");
        else if (bit & const_addr_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_0_o[byte]) ? "1" : "0");
        else if (bit & reg_0_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_1_o[byte]) ? "1" : "0");
        else if (bit & reg_1_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ,\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_2_o[byte]) ? "1" : "0");
        else if (bit & reg_2_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " -\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_3_o[byte]) ? "1" : "0");
        else if (bit & reg_3_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " .\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_4_o[byte]) ? "1" : "0");
        else if (bit & reg_4_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " /\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_5_o[byte]) ? "1" : "0");
        else if (bit & reg_5_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 0\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_6_o[byte]) ? "1" : "0");
        else if (bit & reg_6_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 1\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_7_o[byte]) ? "1" : "0");
        else if (bit & reg_7_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 2\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_8_o[byte]) ? "1" : "0");
        else if (bit & reg_8_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 3\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_9_o[byte]) ? "1" : "0");
        else if (bit & reg_9_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 4\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_a_o[byte]) ? "1" : "0");
        else if (bit & reg_a_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 5\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_b_o[byte]) ? "1" : "0");
        else if (bit & reg_b_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 6\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_c_o[byte]) ? "1" : "0");
        else if (bit & reg_c_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 7\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_d_o[byte]) ? "1" : "0");
        else if (bit & reg_d_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 8\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_e_o[byte]) ? "1" : "0");
        else if (bit & reg_e_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 9\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_f_o[byte]) ? "1" : "0");
        else if (bit & reg_f_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " :\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_ssp_32_8_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_ssp_32_8_sim_sample() {
  int changed = 0;
  if (sim_reset_state_i[0] != reset_state_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_state_i[0] ? "1!\n" : "0!\n");
    sim_reset_state_i[0] = reset_state_i[0];
  }
  if (sim_cycle_i[0] != cycle_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, cycle_i[0] ? "1\"\n" : "0\"\n");
    sim_cycle_i[0] = cycle_i[0];
  }
  if (sim_instr_data_i[1] != instr_data_i[1] || sim_instr_data_i[0] != instr_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & instr_data_i[byte]) ? "1" : "0");
          else if (bit & instr_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_instr_data_i[0] = instr_data_i[0];
    sim_instr_data_i[1] = instr_data_i[1];
  }
  if (sim_const_data_i[3] != const_data_i[3] || sim_const_data_i[2] != const_data_i[2] || sim_const_data_i[1] != const_data_i[1] || sim_const_data_i[0] != const_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & const_data_i[byte]) ? "1" : "0");
          else if (bit & const_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_const_data_i[0] = const_data_i[0];
    sim_const_data_i[1] = const_data_i[1];
    sim_const_data_i[2] = const_data_i[2];
    sim_const_data_i[3] = const_data_i[3];
  }
  if (sim_load_write_i[0] != load_write_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, load_write_i[0] ? "1%%\n" : "0%%\n");
    sim_load_write_i[0] = load_write_i[0];
  }
  if (sim_load_addr_i[0] != load_addr_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & load_addr_i[byte]) ? "1" : "0");
          else if (bit & load_addr_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_load_addr_i[0] = load_addr_i[0];
  }
  if (sim_load_data_i[3] != load_data_i[3] || sim_load_data_i[2] != load_data_i[2] || sim_load_data_i[1] != load_data_i[1] || sim_load_data_i[0] != load_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & load_data_i[byte]) ? "1" : "0");
          else if (bit & load_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_load_data_i[0] = load_data_i[0];
    sim_load_data_i[1] = load_data_i[1];
    sim_load_data_i[2] = load_data_i[2];
    sim_load_data_i[3] = load_data_i[3];
  }
  if (sim_done_o[0] != done_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, done_o[0] ? "1(\n" : "0(\n");
    sim_done_o[0] = done_o[0];
  }
  if (sim_instr_addr_o[0] != instr_addr_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & instr_addr_o[byte]) ? "1" : "0");
          else if (bit & instr_addr_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_instr_addr_o[0] = instr_addr_o[0];
  }
  if (sim_const_addr_o[0] != const_addr_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & const_addr_o[byte]) ? "1" : "0");
          else if (bit & const_addr_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_const_addr_o[0] = const_addr_o[0];
  }
  if (sim_reg_0_o[3] != reg_0_o[3] || sim_reg_0_o[2] != reg_0_o[2] || sim_reg_0_o[1] != reg_0_o[1] || sim_reg_0_o[0] != reg_0_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_0_o[byte]) ? "1" : "0");
          else if (bit & reg_0_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_reg_0_o[0] = reg_0_o[0];
    sim_reg_0_o[1] = reg_0_o[1];
    sim_reg_0_o[2] = reg_0_o[2];
    sim_reg_0_o[3] = reg_0_o[3];
  }
  if (sim_reg_1_o[3] != reg_1_o[3] || sim_reg_1_o[2] != reg_1_o[2] || sim_reg_1_o[1] != reg_1_o[1] || sim_reg_1_o[0] != reg_1_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_1_o[byte]) ? "1" : "0");
          else if (bit & reg_1_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ,\n");
    }
    sim_reg_1_o[0] = reg_1_o[0];
    sim_reg_1_o[1] = reg_1_o[1];
    sim_reg_1_o[2] = reg_1_o[2];
    sim_reg_1_o[3] = reg_1_o[3];
  }
  if (sim_reg_2_o[3] != reg_2_o[3] || sim_reg_2_o[2] != reg_2_o[2] || sim_reg_2_o[1] != reg_2_o[1] || sim_reg_2_o[0] != reg_2_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_2_o[byte]) ? "1" : "0");
          else if (bit & reg_2_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " -\n");
    }
    sim_reg_2_o[0] = reg_2_o[0];
    sim_reg_2_o[1] = reg_2_o[1];
    sim_reg_2_o[2] = reg_2_o[2];
    sim_reg_2_o[3] = reg_2_o[3];
  }
  if (sim_reg_3_o[3] != reg_3_o[3] || sim_reg_3_o[2] != reg_3_o[2] || sim_reg_3_o[1] != reg_3_o[1] || sim_reg_3_o[0] != reg_3_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_3_o[byte]) ? "1" : "0");
          else if (bit & reg_3_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " .\n");
    }
    sim_reg_3_o[0] = reg_3_o[0];
    sim_reg_3_o[1] = reg_3_o[1];
    sim_reg_3_o[2] = reg_3_o[2];
    sim_reg_3_o[3] = reg_3_o[3];
  }
  if (sim_reg_4_o[3] != reg_4_o[3] || sim_reg_4_o[2] != reg_4_o[2] || sim_reg_4_o[1] != reg_4_o[1] || sim_reg_4_o[0] != reg_4_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_4_o[byte]) ? "1" : "0");
          else if (bit & reg_4_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " /\n");
    }
    sim_reg_4_o[0] = reg_4_o[0];
    sim_reg_4_o[1] = reg_4_o[1];
    sim_reg_4_o[2] = reg_4_o[2];
    sim_reg_4_o[3] = reg_4_o[3];
  }
  if (sim_reg_5_o[3] != reg_5_o[3] || sim_reg_5_o[2] != reg_5_o[2] || sim_reg_5_o[1] != reg_5_o[1] || sim_reg_5_o[0] != reg_5_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_5_o[byte]) ? "1" : "0");
          else if (bit & reg_5_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 0\n");
    }
    sim_reg_5_o[0] = reg_5_o[0];
    sim_reg_5_o[1] = reg_5_o[1];
    sim_reg_5_o[2] = reg_5_o[2];
    sim_reg_5_o[3] = reg_5_o[3];
  }
  if (sim_reg_6_o[3] != reg_6_o[3] || sim_reg_6_o[2] != reg_6_o[2] || sim_reg_6_o[1] != reg_6_o[1] || sim_reg_6_o[0] != reg_6_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_6_o[byte]) ? "1" : "0");
          else if (bit & reg_6_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 1\n");
    }
    sim_reg_6_o[0] = reg_6_o[0];
    sim_reg_6_o[1] = reg_6_o[1];
    sim_reg_6_o[2] = reg_6_o[2];
    sim_reg_6_o[3] = reg_6_o[3];
  }
  if (sim_reg_7_o[3] != reg_7_o[3] || sim_reg_7_o[2] != reg_7_o[2] || sim_reg_7_o[1] != reg_7_o[1] || sim_reg_7_o[0] != reg_7_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_7_o[byte]) ? "1" : "0");
          else if (bit & reg_7_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 2\n");
    }
    sim_reg_7_o[0] = reg_7_o[0];
    sim_reg_7_o[1] = reg_7_o[1];
    sim_reg_7_o[2] = reg_7_o[2];
    sim_reg_7_o[3] = reg_7_o[3];
  }
  if (sim_reg_8_o[3] != reg_8_o[3] || sim_reg_8_o[2] != reg_8_o[2] || sim_reg_8_o[1] != reg_8_o[1] || sim_reg_8_o[0] != reg_8_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_8_o[byte]) ? "1" : "0");
          else if (bit & reg_8_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 3\n");
    }
    sim_reg_8_o[0] = reg_8_o[0];
    sim_reg_8_o[1] = reg_8_o[1];
    sim_reg_8_o[2] = reg_8_o[2];
    sim_reg_8_o[3] = reg_8_o[3];
  }
  if (sim_reg_9_o[3] != reg_9_o[3] || sim_reg_9_o[2] != reg_9_o[2] || sim_reg_9_o[1] != reg_9_o[1] || sim_reg_9_o[0] != reg_9_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_9_o[byte]) ? "1" : "0");
          else if (bit & reg_9_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 4\n");
    }
    sim_reg_9_o[0] = reg_9_o[0];
    sim_reg_9_o[1] = reg_9_o[1];
    sim_reg_9_o[2] = reg_9_o[2];
    sim_reg_9_o[3] = reg_9_o[3];
  }
  if (sim_reg_a_o[3] != reg_a_o[3] || sim_reg_a_o[2] != reg_a_o[2] || sim_reg_a_o[1] != reg_a_o[1] || sim_reg_a_o[0] != reg_a_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_a_o[byte]) ? "1" : "0");
          else if (bit & reg_a_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 5\n");
    }
    sim_reg_a_o[0] = reg_a_o[0];
    sim_reg_a_o[1] = reg_a_o[1];
    sim_reg_a_o[2] = reg_a_o[2];
    sim_reg_a_o[3] = reg_a_o[3];
  }
  if (sim_reg_b_o[3] != reg_b_o[3] || sim_reg_b_o[2] != reg_b_o[2] || sim_reg_b_o[1] != reg_b_o[1] || sim_reg_b_o[0] != reg_b_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_b_o[byte]) ? "1" : "0");
          else if (bit & reg_b_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 6\n");
    }
    sim_reg_b_o[0] = reg_b_o[0];
    sim_reg_b_o[1] = reg_b_o[1];
    sim_reg_b_o[2] = reg_b_o[2];
    sim_reg_b_o[3] = reg_b_o[3];
  }
  if (sim_reg_c_o[3] != reg_c_o[3] || sim_reg_c_o[2] != reg_c_o[2] || sim_reg_c_o[1] != reg_c_o[1] || sim_reg_c_o[0] != reg_c_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_c_o[byte]) ? "1" : "0");
          else if (bit & reg_c_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 7\n");
    }
    sim_reg_c_o[0] = reg_c_o[0];
    sim_reg_c_o[1] = reg_c_o[1];
    sim_reg_c_o[2] = reg_c_o[2];
    sim_reg_c_o[3] = reg_c_o[3];
  }
  if (sim_reg_d_o[3] != reg_d_o[3] || sim_reg_d_o[2] != reg_d_o[2] || sim_reg_d_o[1] != reg_d_o[1] || sim_reg_d_o[0] != reg_d_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_d_o[byte]) ? "1" : "0");
          else if (bit & reg_d_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 8\n");
    }
    sim_reg_d_o[0] = reg_d_o[0];
    sim_reg_d_o[1] = reg_d_o[1];
    sim_reg_d_o[2] = reg_d_o[2];
    sim_reg_d_o[3] = reg_d_o[3];
  }
  if (sim_reg_e_o[3] != reg_e_o[3] || sim_reg_e_o[2] != reg_e_o[2] || sim_reg_e_o[1] != reg_e_o[1] || sim_reg_e_o[0] != reg_e_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_e_o[byte]) ? "1" : "0");
          else if (bit & reg_e_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 9\n");
    }
    sim_reg_e_o[0] = reg_e_o[0];
    sim_reg_e_o[1] = reg_e_o[1];
    sim_reg_e_o[2] = reg_e_o[2];
    sim_reg_e_o[3] = reg_e_o[3];
  }
  if (sim_reg_f_o[3] != reg_f_o[3] || sim_reg_f_o[2] != reg_f_o[2] || sim_reg_f_o[1] != reg_f_o[1] || sim_reg_f_o[0] != reg_f_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_f_o[byte]) ? "1" : "0");
          else if (bit & reg_f_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " :\n");
    }
    sim_reg_f_o[0] = reg_f_o[0];
    sim_reg_f_o[1] = reg_f_o[1];
    sim_reg_f_o[2] = reg_f_o[2];
    sim_reg_f_o[3] = reg_f_o[3];
  }
  sim_count++;
}

