//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    State Space Processor is used for implementing discrete (digital) linear systems, such as
//    finite impulse response filters, infinite impulse response filters, multiple input and output
//    systems, and general state space equations.
//  
//  Architecture:
//  
//    The State Space Processor is designed with a small logic footprint for area limited
//    applications.  The processor requires two external memories: one for program instructions
//    and the other for constants (coefficients) used in calculation.  The processor maintains a
//    register file of 16 N-bit registers used to retain state information and for processing intermediate
//    results.  The register file is also used for handling input and output; registers can be written
//    from an external source and all registers are available as outputs.  For convenience, register 0
//    is wired to ground (0) and instructions updating r0 have no effect on the register file.
//  
//    The processor runs calculations on a cycle basis:
//      1. The external environment writes inputs into the register file.
//      2. The external environment signals a "Cycle" to run the program and calculate a cycle.
//      3. The external environment waits for "Done", then reads output from the register file.
//  
//  Instruction Set:
//  
//    There are 4 instruction types and a total of 8 instructions.  Each instruction is 16-bits.
//    The types include:
//      Unary Operation  : OpCode [15:12], Operand Reg A [11:8], Not Used [7:4], Result Reg X [3:0]
//      Binary Operation : OpCode [15:12], Operand Reg A [11:8], Operand Reg B [7:4], Result Reg X [3:0]
//      Constant Load    : OpCode [15:12], Constant Memory Address [11:4], Result Reg X [3:0]
//      Halt             : OpCode [15:12], Not Used [11:0]
//  
//    Unary Operations (OpCode):
//  
//      ShiftLeft  (0000) : RegX <- lsbs RegA '++' '0'
//                          Flag <- Flag
//      ShiftRight (0001) : RegX <- msb RegA '++' msbs RegA
//                          Flag <- lsb RegA
//      ShiftClip  (0010) : RegX <- lsbs RegA '++' '0' when top 2 bits of RegA == '00' or '11' else
//                                  '0111...1'         when top 2 bits of RegA == '01'         else
//                                  '1000...0'         when top 2 bits of RegA == '10'
//                          Flag <- Flag
//                          Performs a limited/clipped multiplication by 2.
//  
//    Binary Operations (OpCode):
//  
//      Add        (0011) : RegX <- RegA '+' RegB
//                          Flag <- msb Result
//      AddCond    (0100) : RegX <- RegA '+' RegB when Flag == '1' else RegA
//                          Flag <- Flag
//      Sub        (0101) : RegX <- RegA '-' RegB
//                          Flag <- msb Result
//      Switch     (0110) : RegX <- RegA when Flag == '1' else RegB
//                          Flag <- Flag
//  
//    Constant Load Instruction (OpCode):
//  
//      Constant   (0111) : RegX <- Data from constant memory.
//                          Flag <- Flag
//  
//    Halt Instruction (OpCode):
//  
//      Halt       (1---) : Halts processor (prevents further register updates).
//  
//    Booth multiplication can be performed using ShiftRight and AddCond with an accumulation register.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_state_i : Reset all state registers (register file and ALU flag).
//  
//    Inputs:
//      cycle_i      : Input pulse to perform a cycle (sample) calculation.
//      instr_data_i : Instruction data from instruction memory.
//      const_data_i : Constant data from constant memory.
//      load_write_i : Write enable for writing to register file.
//      load_addr_i  : Address (4-bits) for writing to register file.
//      load_data_i  : Data for writing to register file.
//  
//    Outputs:
//      done_o       : Output flag signaling processor is done calculating cycle (active high).
//      instr_addr_o : Address to instruction memory.
//      const_addr_o : Address to constant memory (8-bits).
//      reg_0_o      : Register 0 value.
//      reg_1_o      : Register 1 value.
//      ...
//      reg_f_o      : Register F value.
//  
//  Built In Parameters:
//  
//    Data Width                = 32
//    Instruction Address Width = 9
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:51:25 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_ssp_32_9
//    Clock Domains : clock_c  
//    Vector Input  : reset_state_i(1)
//    Vector Input  : cycle_i(1)
//    Vector Input  : instr_data_i(16)
//    Vector Input  : const_data_i(32)
//    Vector Input  : load_write_i(1)
//    Vector Input  : load_addr_i(4)
//    Vector Input  : load_data_i(32)
//    Vector Output : done_o(1)
//    Vector Output : instr_addr_o(9)
//    Vector Output : const_addr_o(8)
//    Vector Output : reg_0_o(32)
//    Vector Output : reg_1_o(32)
//    Vector Output : reg_2_o(32)
//    Vector Output : reg_3_o(32)
//    Vector Output : reg_4_o(32)
//    Vector Output : reg_5_o(32)
//    Vector Output : reg_6_o(32)
//    Vector Output : reg_7_o(32)
//    Vector Output : reg_8_o(32)
//    Vector Output : reg_9_o(32)
//    Vector Output : reg_a_o(32)
//    Vector Output : reg_b_o(32)
//    Vector Output : reg_c_o(32)
//    Vector Output : reg_d_o(32)
//    Vector Output : reg_e_o(32)
//    Vector Output : reg_f_o(32)
//  
//  
//  

#ifdef __cplusplus
extern "C" {
#endif

void cf_ssp_32_9_ports(unsigned char* port_reset_state_i, unsigned char* port_cycle_i, unsigned char* port_instr_data_i, unsigned char* port_const_data_i, unsigned char* port_load_write_i, unsigned char* port_load_addr_i, unsigned char* port_load_data_i, unsigned char* port_done_o, unsigned char* port_instr_addr_o, unsigned char* port_const_addr_o, unsigned char* port_reg_0_o, unsigned char* port_reg_1_o, unsigned char* port_reg_2_o, unsigned char* port_reg_3_o, unsigned char* port_reg_4_o, unsigned char* port_reg_5_o, unsigned char* port_reg_6_o, unsigned char* port_reg_7_o, unsigned char* port_reg_8_o, unsigned char* port_reg_9_o, unsigned char* port_reg_a_o, unsigned char* port_reg_b_o, unsigned char* port_reg_c_o, unsigned char* port_reg_d_o, unsigned char* port_reg_e_o, unsigned char* port_reg_f_o);
void cf_ssp_32_9_init();
void cf_ssp_32_9_calc();
void cf_ssp_32_9_cycle_clock();
void cf_ssp_32_9_sim_init(const char* file);
void cf_ssp_32_9_sim_end();
void cf_ssp_32_9_sim_sample();

#ifdef __cplusplus
}
#endif

