--
--  Copyright (c) 2003 Launchbird Design Systems, Inc.
--  All rights reserved.
--  
--  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
--    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
--    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
--  
--  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
--  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
--  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
--  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
--  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
--  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--  
--  
--  Overview:
--  
--    State Space Processor is used for implementing discrete (digital) linear systems, such as
--    finite impulse response filters, infinite impulse response filters, multiple input and output
--    systems, and general state space equations.
--  
--  Architecture:
--  
--    The State Space Processor is designed with a small logic footprint for area limited
--    applications.  The processor requires two external memories: one for program instructions
--    and the other for constants (coefficients) used in calculation.  The processor maintains a
--    register file of 16 N-bit registers used to retain state information and for processing intermediate
--    results.  The register file is also used for handling input and output; registers can be written
--    from an external source and all registers are available as outputs.  For convenience, register 0
--    is wired to ground (0) and instructions updating r0 have no effect on the register file.
--  
--    The processor runs calculations on a cycle basis:
--      1. The external environment writes inputs into the register file.
--      2. The external environment signals a "Cycle" to run the program and calculate a cycle.
--      3. The external environment waits for "Done", then reads output from the register file.
--  
--  Instruction Set:
--  
--    There are 4 instruction types and a total of 8 instructions.  Each instruction is 16-bits.
--    The types include:
--      Unary Operation  : OpCode [15:12], Operand Reg A [11:8], Not Used [7:4], Result Reg X [3:0]
--      Binary Operation : OpCode [15:12], Operand Reg A [11:8], Operand Reg B [7:4], Result Reg X [3:0]
--      Constant Load    : OpCode [15:12], Constant Memory Address [11:4], Result Reg X [3:0]
--      Halt             : OpCode [15:12], Not Used [11:0]
--  
--    Unary Operations (OpCode):
--  
--      ShiftLeft  (0000) : RegX <- lsbs RegA '++' '0'
--                          Flag <- Flag
--      ShiftRight (0001) : RegX <- msb RegA '++' msbs RegA
--                          Flag <- lsb RegA
--      ShiftClip  (0010) : RegX <- lsbs RegA '++' '0' when top 2 bits of RegA == '00' or '11' else
--                                  '0111...1'         when top 2 bits of RegA == '01'         else
--                                  '1000...0'         when top 2 bits of RegA == '10'
--                          Flag <- Flag
--                          Performs a limited/clipped multiplication by 2.
--  
--    Binary Operations (OpCode):
--  
--      Add        (0011) : RegX <- RegA '+' RegB
--                          Flag <- msb Result
--      AddCond    (0100) : RegX <- RegA '+' RegB when Flag == '1' else RegA
--                          Flag <- Flag
--      Sub        (0101) : RegX <- RegA '-' RegB
--                          Flag <- msb Result
--      Switch     (0110) : RegX <- RegA when Flag == '1' else RegB
--                          Flag <- Flag
--  
--    Constant Load Instruction (OpCode):
--  
--      Constant   (0111) : RegX <- Data from constant memory.
--                          Flag <- Flag
--  
--    Halt Instruction (OpCode):
--  
--      Halt       (1---) : Halts processor (prevents further register updates).
--  
--    Booth multiplication can be performed using ShiftRight and AddCond with an accumulation register.
--  
--  Interface:
--  
--    Synchronization:
--      clock_c  : Clock input.
--      reset_state_i : Reset all state registers (register file and ALU flag).
--  
--    Inputs:
--      cycle_i      : Input pulse to perform a cycle (sample) calculation.
--      instr_data_i : Instruction data from instruction memory.
--      const_data_i : Constant data from constant memory.
--      load_write_i : Write enable for writing to register file.
--      load_addr_i  : Address (4-bits) for writing to register file.
--      load_data_i  : Data for writing to register file.
--  
--    Outputs:
--      done_o       : Output flag signaling processor is done calculating cycle (active high).
--      instr_addr_o : Address to instruction memory.
--      const_addr_o : Address to constant memory (8-bits).
--      reg_0_o      : Register 0 value.
--      reg_1_o      : Register 1 value.
--      ...
--      reg_f_o      : Register F value.
--  
--  Built In Parameters:
--  
--    Data Width                = 64
--    Instruction Address Width = 6
--  
--  
--  
--  
--  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
--  
--  Build Date : Fri Aug 22 09:50:45 CDT 2003
--  
--  Interface
--  
--    Build Name    : cf_ssp_64_6
--    Clock Domains : clock_c  
--    Vector Input  : reset_state_i(1)
--    Vector Input  : cycle_i(1)
--    Vector Input  : instr_data_i(16)
--    Vector Input  : const_data_i(64)
--    Vector Input  : load_write_i(1)
--    Vector Input  : load_addr_i(4)
--    Vector Input  : load_data_i(64)
--    Vector Output : done_o(1)
--    Vector Output : instr_addr_o(6)
--    Vector Output : const_addr_o(8)
--    Vector Output : reg_0_o(64)
--    Vector Output : reg_1_o(64)
--    Vector Output : reg_2_o(64)
--    Vector Output : reg_3_o(64)
--    Vector Output : reg_4_o(64)
--    Vector Output : reg_5_o(64)
--    Vector Output : reg_6_o(64)
--    Vector Output : reg_7_o(64)
--    Vector Output : reg_8_o(64)
--    Vector Output : reg_9_o(64)
--    Vector Output : reg_a_o(64)
--    Vector Output : reg_b_o(64)
--    Vector Output : reg_c_o(64)
--    Vector Output : reg_d_o(64)
--    Vector Output : reg_e_o(64)
--    Vector Output : reg_f_o(64)
--  
--  
--  

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_ssp_64_6_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(63 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(3 downto 0);
i7 : in  unsigned(63 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(63 downto 0);
o4 : out unsigned(63 downto 0);
o5 : out unsigned(63 downto 0);
o6 : out unsigned(63 downto 0);
o7 : out unsigned(63 downto 0);
o8 : out unsigned(63 downto 0);
o9 : out unsigned(63 downto 0);
o10 : out unsigned(63 downto 0);
o11 : out unsigned(63 downto 0);
o12 : out unsigned(63 downto 0);
o13 : out unsigned(63 downto 0);
o14 : out unsigned(63 downto 0);
o15 : out unsigned(63 downto 0);
o16 : out unsigned(63 downto 0);
o17 : out unsigned(63 downto 0);
o18 : out unsigned(63 downto 0);
o19 : out unsigned(0 downto 0));
end entity cf_ssp_64_6_1;
architecture rtl of cf_ssp_64_6_1 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(5 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0) := "000000";
signal n6 : unsigned(0 downto 0) := "0";
signal n7 : unsigned(0 downto 0) := "0";
signal n8 : unsigned(0 downto 0);
signal n9 : unsigned(1 downto 0);
signal n10 : unsigned(0 downto 0);
signal n11 : unsigned(0 downto 0);
signal n12 : unsigned(0 downto 0);
signal n13 : unsigned(0 downto 0);
signal n14 : unsigned(0 downto 0);
signal n15 : unsigned(0 downto 0);
signal n16 : unsigned(0 downto 0);
signal n17 : unsigned(0 downto 0);
signal n18 : unsigned(2 downto 0);
signal n19 : unsigned(2 downto 0);
signal n20 : unsigned(2 downto 0);
signal n21 : unsigned(2 downto 0);
signal n22 : unsigned(2 downto 0);
signal n23 : unsigned(2 downto 0);
signal n24 : unsigned(2 downto 0);
signal n25 : unsigned(0 downto 0);
signal n26 : unsigned(0 downto 0);
signal n27 : unsigned(0 downto 0);
signal n28 : unsigned(0 downto 0);
signal n29 : unsigned(2 downto 0);
signal n30 : unsigned(2 downto 0);
signal n31 : unsigned(2 downto 0);
signal n32 : unsigned(2 downto 0);
signal n33 : unsigned(2 downto 0);
signal n34 : unsigned(0 downto 0);
signal n35 : unsigned(0 downto 0);
signal n36 : unsigned(0 downto 0);
signal n37 : unsigned(0 downto 0);
signal n38 : unsigned(0 downto 0);
signal n39 : unsigned(0 downto 0);
signal n40 : unsigned(0 downto 0);
signal n41 : unsigned(0 downto 0);
signal n42 : unsigned(0 downto 0);
signal n43 : unsigned(0 downto 0);
signal n44 : unsigned(0 downto 0);
signal n45 : unsigned(0 downto 0);
signal n46 : unsigned(0 downto 0);
signal n47 : unsigned(0 downto 0);
signal n48 : unsigned(0 downto 0) := "0";
signal n49 : unsigned(0 downto 0);
signal n50 : unsigned(0 downto 0);
signal n51 : unsigned(0 downto 0);
signal n52 : unsigned(0 downto 0);
signal n53 : unsigned(0 downto 0);
signal n54 : unsigned(0 downto 0);
signal n55 : unsigned(0 downto 0);
signal n56 : unsigned(0 downto 0);
signal n57 : unsigned(2 downto 0);
signal n58 : unsigned(3 downto 0);
signal n59 : unsigned(3 downto 0);
signal n60 : unsigned(3 downto 0);
signal n61 : unsigned(3 downto 0) := "0000";
signal n62 : unsigned(7 downto 0);
signal n63 : unsigned(0 downto 0);
signal n64 : unsigned(3 downto 0);
signal n65 : unsigned(4 downto 0);
signal n66 : unsigned(15 downto 0);
signal n67 : unsigned(15 downto 0);
signal n68 : unsigned(15 downto 0);
signal n69 : unsigned(15 downto 0);
signal n70 : unsigned(15 downto 0);
signal n71 : unsigned(15 downto 0);
signal n72 : unsigned(15 downto 0);
signal n73 : unsigned(15 downto 0);
signal n74 : unsigned(15 downto 0);
signal n75 : unsigned(15 downto 0);
signal n76 : unsigned(15 downto 0);
signal n77 : unsigned(15 downto 0);
signal n78 : unsigned(15 downto 0);
signal n79 : unsigned(15 downto 0);
signal n80 : unsigned(15 downto 0);
signal n81 : unsigned(15 downto 0);
signal n82 : unsigned(15 downto 0);
signal n83 : unsigned(4 downto 0);
signal n84 : unsigned(0 downto 0);
signal n85 : unsigned(4 downto 0);
signal n86 : unsigned(0 downto 0);
signal n87 : unsigned(4 downto 0);
signal n88 : unsigned(0 downto 0);
signal n89 : unsigned(4 downto 0);
signal n90 : unsigned(0 downto 0);
signal n91 : unsigned(4 downto 0);
signal n92 : unsigned(0 downto 0);
signal n93 : unsigned(4 downto 0);
signal n94 : unsigned(0 downto 0);
signal n95 : unsigned(4 downto 0);
signal n96 : unsigned(0 downto 0);
signal n97 : unsigned(4 downto 0);
signal n98 : unsigned(0 downto 0);
signal n99 : unsigned(4 downto 0);
signal n100 : unsigned(0 downto 0);
signal n101 : unsigned(4 downto 0);
signal n102 : unsigned(0 downto 0);
signal n103 : unsigned(4 downto 0);
signal n104 : unsigned(0 downto 0);
signal n105 : unsigned(4 downto 0);
signal n106 : unsigned(0 downto 0);
signal n107 : unsigned(4 downto 0);
signal n108 : unsigned(0 downto 0);
signal n109 : unsigned(4 downto 0);
signal n110 : unsigned(0 downto 0);
signal n111 : unsigned(4 downto 0);
signal n112 : unsigned(0 downto 0);
signal n113 : unsigned(4 downto 0);
signal n114 : unsigned(0 downto 0);
signal n115 : unsigned(4 downto 0);
signal n116 : unsigned(0 downto 0);
signal n117 : unsigned(4 downto 0);
signal n118 : unsigned(0 downto 0);
signal n119 : unsigned(4 downto 0);
signal n120 : unsigned(0 downto 0);
signal n121 : unsigned(4 downto 0);
signal n122 : unsigned(0 downto 0);
signal n123 : unsigned(4 downto 0);
signal n124 : unsigned(0 downto 0);
signal n125 : unsigned(4 downto 0);
signal n126 : unsigned(0 downto 0);
signal n127 : unsigned(4 downto 0);
signal n128 : unsigned(0 downto 0);
signal n129 : unsigned(4 downto 0);
signal n130 : unsigned(0 downto 0);
signal n131 : unsigned(4 downto 0);
signal n132 : unsigned(0 downto 0);
signal n133 : unsigned(4 downto 0);
signal n134 : unsigned(0 downto 0);
signal n135 : unsigned(4 downto 0);
signal n136 : unsigned(0 downto 0);
signal n137 : unsigned(4 downto 0);
signal n138 : unsigned(0 downto 0);
signal n139 : unsigned(4 downto 0);
signal n140 : unsigned(0 downto 0);
signal n141 : unsigned(4 downto 0);
signal n142 : unsigned(0 downto 0);
signal n143 : unsigned(4 downto 0);
signal n144 : unsigned(0 downto 0);
signal n145 : unsigned(15 downto 0);
signal n146 : unsigned(15 downto 0);
signal n147 : unsigned(15 downto 0);
signal n148 : unsigned(15 downto 0);
signal n149 : unsigned(15 downto 0);
signal n150 : unsigned(15 downto 0);
signal n151 : unsigned(15 downto 0);
signal n152 : unsigned(15 downto 0);
signal n153 : unsigned(15 downto 0);
signal n154 : unsigned(15 downto 0);
signal n155 : unsigned(15 downto 0);
signal n156 : unsigned(15 downto 0);
signal n157 : unsigned(15 downto 0);
signal n158 : unsigned(15 downto 0);
signal n159 : unsigned(15 downto 0);
signal n160 : unsigned(15 downto 0);
signal n161 : unsigned(15 downto 0);
signal n162 : unsigned(15 downto 0);
signal n163 : unsigned(15 downto 0);
signal n164 : unsigned(15 downto 0);
signal n165 : unsigned(15 downto 0);
signal n166 : unsigned(15 downto 0);
signal n167 : unsigned(15 downto 0);
signal n168 : unsigned(15 downto 0);
signal n169 : unsigned(15 downto 0);
signal n170 : unsigned(15 downto 0);
signal n171 : unsigned(15 downto 0);
signal n172 : unsigned(15 downto 0);
signal n173 : unsigned(15 downto 0);
signal n174 : unsigned(15 downto 0);
signal n175 : unsigned(15 downto 0);
signal n176 : unsigned(63 downto 0);
signal n177 : unsigned(0 downto 0);
signal n178 : unsigned(0 downto 0);
signal n179 : unsigned(0 downto 0);
signal n180 : unsigned(0 downto 0);
signal n181 : unsigned(0 downto 0);
signal n182 : unsigned(0 downto 0);
signal n183 : unsigned(0 downto 0);
signal n184 : unsigned(0 downto 0);
signal n185 : unsigned(0 downto 0);
signal n186 : unsigned(0 downto 0);
signal n187 : unsigned(0 downto 0);
signal n188 : unsigned(0 downto 0);
signal n189 : unsigned(0 downto 0);
signal n190 : unsigned(0 downto 0);
signal n191 : unsigned(0 downto 0);
signal n192 : unsigned(3 downto 0) := "0000";
signal n193 : unsigned(2 downto 0);
signal n194 : unsigned(0 downto 0);
signal n195 : unsigned(63 downto 0);
signal n196 : unsigned(63 downto 0);
signal n197 : unsigned(63 downto 0);
signal n198 : unsigned(63 downto 0);
signal n199 : unsigned(63 downto 0);
signal n200 : unsigned(63 downto 0);
signal n201 : unsigned(63 downto 0);
signal n202 : unsigned(63 downto 0);
signal n203 : unsigned(1 downto 0);
signal n204 : unsigned(0 downto 0);
signal n205 : unsigned(63 downto 0);
signal n206 : unsigned(63 downto 0);
signal n207 : unsigned(63 downto 0);
signal n208 : unsigned(63 downto 0);
signal n209 : unsigned(0 downto 0);
signal n210 : unsigned(0 downto 0);
signal n211 : unsigned(63 downto 0);
signal n212 : unsigned(63 downto 0);
signal n213 : unsigned(0 downto 0);
signal n214 : unsigned(63 downto 0);
signal n215 : unsigned(3 downto 0) := "0000";
signal n216 : unsigned(2 downto 0);
signal n217 : unsigned(0 downto 0);
signal n218 : unsigned(63 downto 0);
signal n219 : unsigned(63 downto 0);
signal n220 : unsigned(63 downto 0);
signal n221 : unsigned(63 downto 0);
signal n222 : unsigned(63 downto 0);
signal n223 : unsigned(63 downto 0);
signal n224 : unsigned(63 downto 0);
signal n225 : unsigned(63 downto 0);
signal n226 : unsigned(1 downto 0);
signal n227 : unsigned(0 downto 0);
signal n228 : unsigned(63 downto 0);
signal n229 : unsigned(63 downto 0);
signal n230 : unsigned(63 downto 0);
signal n231 : unsigned(63 downto 0);
signal n232 : unsigned(0 downto 0);
signal n233 : unsigned(0 downto 0);
signal n234 : unsigned(63 downto 0);
signal n235 : unsigned(63 downto 0);
signal n236 : unsigned(0 downto 0);
signal n237 : unsigned(63 downto 0);
signal n238 : unsigned(2 downto 0) := "000";
signal n239 : unsigned(0 downto 0);
signal n240 : unsigned(0 downto 0);
signal n241 : unsigned(1 downto 0);
signal n242 : unsigned(2 downto 0);
signal n243 : unsigned(3 downto 0);
signal n244 : unsigned(4 downto 0);
signal n245 : unsigned(5 downto 0);
signal n246 : unsigned(6 downto 0);
signal n247 : unsigned(7 downto 0);
signal n248 : unsigned(8 downto 0);
signal n249 : unsigned(9 downto 0);
signal n250 : unsigned(10 downto 0);
signal n251 : unsigned(11 downto 0);
signal n252 : unsigned(12 downto 0);
signal n253 : unsigned(13 downto 0);
signal n254 : unsigned(14 downto 0);
signal n255 : unsigned(15 downto 0);
signal n256 : unsigned(16 downto 0);
signal n257 : unsigned(17 downto 0);
signal n258 : unsigned(18 downto 0);
signal n259 : unsigned(19 downto 0);
signal n260 : unsigned(20 downto 0);
signal n261 : unsigned(21 downto 0);
signal n262 : unsigned(22 downto 0);
signal n263 : unsigned(23 downto 0);
signal n264 : unsigned(24 downto 0);
signal n265 : unsigned(25 downto 0);
signal n266 : unsigned(26 downto 0);
signal n267 : unsigned(27 downto 0);
signal n268 : unsigned(28 downto 0);
signal n269 : unsigned(29 downto 0);
signal n270 : unsigned(30 downto 0);
signal n271 : unsigned(31 downto 0);
signal n272 : unsigned(32 downto 0);
signal n273 : unsigned(33 downto 0);
signal n274 : unsigned(34 downto 0);
signal n275 : unsigned(35 downto 0);
signal n276 : unsigned(36 downto 0);
signal n277 : unsigned(37 downto 0);
signal n278 : unsigned(38 downto 0);
signal n279 : unsigned(39 downto 0);
signal n280 : unsigned(40 downto 0);
signal n281 : unsigned(41 downto 0);
signal n282 : unsigned(42 downto 0);
signal n283 : unsigned(43 downto 0);
signal n284 : unsigned(44 downto 0);
signal n285 : unsigned(45 downto 0);
signal n286 : unsigned(46 downto 0);
signal n287 : unsigned(47 downto 0);
signal n288 : unsigned(48 downto 0);
signal n289 : unsigned(49 downto 0);
signal n290 : unsigned(50 downto 0);
signal n291 : unsigned(51 downto 0);
signal n292 : unsigned(52 downto 0);
signal n293 : unsigned(53 downto 0);
signal n294 : unsigned(54 downto 0);
signal n295 : unsigned(55 downto 0);
signal n296 : unsigned(56 downto 0);
signal n297 : unsigned(57 downto 0);
signal n298 : unsigned(58 downto 0);
signal n299 : unsigned(59 downto 0);
signal n300 : unsigned(60 downto 0);
signal n301 : unsigned(61 downto 0);
signal n302 : unsigned(62 downto 0);
signal n303 : unsigned(63 downto 0);
signal n304 : unsigned(62 downto 0);
signal n305 : unsigned(0 downto 0);
signal n306 : unsigned(63 downto 0);
signal n307 : unsigned(0 downto 0);
signal n308 : unsigned(62 downto 0);
signal n309 : unsigned(63 downto 0);
signal n310 : unsigned(0 downto 0);
signal n311 : unsigned(0 downto 0);
signal n312 : unsigned(63 downto 0);
signal n313 : unsigned(63 downto 0);
signal n314 : unsigned(63 downto 0);
signal n315 : unsigned(2 downto 0);
signal n316 : unsigned(0 downto 0);
signal n317 : unsigned(0 downto 0);
signal n318 : unsigned(2 downto 0);
signal n319 : unsigned(0 downto 0);
signal n320 : unsigned(0 downto 0);
signal n321 : unsigned(2 downto 0);
signal n322 : unsigned(0 downto 0);
signal n323 : unsigned(0 downto 0);
signal n324 : unsigned(63 downto 0);
signal n325 : unsigned(63 downto 0);
signal n326 : unsigned(1 downto 0);
signal n327 : unsigned(0 downto 0);
signal n328 : unsigned(63 downto 0);
signal n329 : unsigned(63 downto 0);
signal n330 : unsigned(63 downto 0);
signal n331 : unsigned(63 downto 0);
signal n332 : unsigned(0 downto 0);
signal n333 : unsigned(0 downto 0);
signal n334 : unsigned(63 downto 0);
signal n335 : unsigned(63 downto 0);
signal n336 : unsigned(0 downto 0);
signal n337 : unsigned(63 downto 0);
signal n338 : unsigned(0 downto 0);
signal n339 : unsigned(0 downto 0);
signal n340 : unsigned(0 downto 0);
signal n341 : unsigned(0 downto 0) := "0";
signal n342 : unsigned(63 downto 0);
signal n343 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n344 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n345 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n346 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n347 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n348 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n349 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n350 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n351 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n352 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n353 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n354 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n355 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n356 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n357 : unsigned(63 downto 0) := "0000000000000000000000000000000000000000000000000000000000000000";
signal n358 : unsigned(1 downto 0);
signal n359 : unsigned(1 downto 0);
signal n360 : unsigned(1 downto 0);
signal n361 : unsigned(1 downto 0);
signal n362 : unsigned(1 downto 0);
signal n363 : unsigned(1 downto 0);
signal n364 : unsigned(1 downto 0);
signal n365 : unsigned(1 downto 0);
signal n366 : unsigned(3 downto 0);
signal n367 : unsigned(3 downto 0);
signal n368 : unsigned(3 downto 0);
signal n369 : unsigned(3 downto 0);
signal n370 : unsigned(3 downto 0);
signal n371 : unsigned(3 downto 0);
signal n372 : unsigned(3 downto 0);
signal n373 : unsigned(3 downto 0);
signal n374 : unsigned(3 downto 0);
signal n375 : unsigned(3 downto 0);
signal n376 : unsigned(0 downto 0);
signal n377 : unsigned(0 downto 0);
signal n378 : unsigned(3 downto 0);
signal n379 : unsigned(3 downto 0);
signal n380 : unsigned(3 downto 0);
signal n381 : unsigned(3 downto 0);
signal n382 : unsigned(3 downto 0);
signal n383 : unsigned(0 downto 0);
signal n384 : unsigned(0 downto 0);
signal n385 : unsigned(0 downto 0);
signal n386 : unsigned(0 downto 0);
signal n387 : unsigned(0 downto 0);
signal n388 : unsigned(0 downto 0);
signal n389 : unsigned(0 downto 0);
signal n390 : unsigned(0 downto 0);
signal n391 : unsigned(0 downto 0);
signal n392 : unsigned(0 downto 0);
signal n393 : unsigned(1 downto 0);
signal n394 : unsigned(1 downto 0);
signal n395 : unsigned(1 downto 0);
signal n396 : unsigned(1 downto 0);
signal n397 : unsigned(1 downto 0);
signal n398 : unsigned(1 downto 0);
signal n399 : unsigned(1 downto 0);
signal n400 : unsigned(1 downto 0);
signal n401 : unsigned(1 downto 0);
signal n402 : unsigned(1 downto 0);
signal n403 : unsigned(1 downto 0) := "00";
signal n404 : unsigned(0 downto 0);
signal n405 : unsigned(0 downto 0);
signal n406 : unsigned(0 downto 0);
signal n407 : unsigned(0 downto 0);
signal n408 : unsigned(0 downto 0);
signal n409 : unsigned(0 downto 0);
signal n410 : unsigned(0 downto 0);
signal n411 : unsigned(0 downto 0);
signal n412 : unsigned(0 downto 0);
signal n413 : unsigned(1 downto 0);
signal n414 : unsigned(0 downto 0);
begin
n1 <= "1";
n2 <= "0";
n3 <= "000001";
n4 <= n5 + n3;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i1 = "1" then
      n5 <= "000000";
    elsif n1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if n2 = "1" then
      n6 <= "0";
    elsif n1 = "1" then
      n6 <= i1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if n2 = "1" then
      n7 <= "0";
    elsif n1 = "1" then
      n7 <= n6;
    end if;
  end if;
end process;
n8 <= i3(15 downto 15);
n9 <= n7 & n8;
n10 <= "0";
n11 <= "1";
n12 <= "0";
n13 <= "1";
n14 <= "0";
n15 <= "1";
n16 <= "0";
n17 <= "0";
n18 <= "000";
n19 <= "010";
n20 <= "100";
n21 <= "110";
n22 <= "001";
n23 <= "011";
n24 <= "101";
n25 <= "0";
n26 <= "0";
n27 <= "0";
n28 <= "0";
n29 <= "000";
n30 <= "010";
n31 <= "100";
n32 <= "110";
n33 <= n9 & n48;
n34 <= "1" when n33 = n18 else "0";
n35 <= "1" when n33 = n19 else "0";
n36 <= "1" when n33 = n20 else "0";
n37 <= "1" when n33 = n21 else "0";
n38 <= "1" when n33 = n22 else "0";
n39 <= "1" when n33 = n23 else "0";
n40 <= "1" when n33 = n24 else "0";
n41 <= n11 when n40 = "1" else n10;
n42 <= n12 when n39 = "1" else n41;
n43 <= n13 when n38 = "1" else n42;
n44 <= n14 when n37 = "1" else n43;
n45 <= n15 when n36 = "1" else n44;
n46 <= n16 when n35 = "1" else n45;
n47 <= n17 when n34 = "1" else n46;
process (clock_c) begin
  if rising_edge(clock_c) then
    if n2 = "1" then
      n48 <= "0";
    elsif n1 = "1" then
      n48 <= n47;
    end if;
  end if;
end process;
n49 <= "1" when n33 = n29 else "0";
n50 <= "1" when n33 = n30 else "0";
n51 <= "1" when n33 = n31 else "0";
n52 <= "1" when n33 = n32 else "0";
n53 <= n25 when n52 = "1" else n412;
n54 <= n26 when n51 = "1" else n53;
n55 <= n27 when n50 = "1" else n54;
n56 <= n28 when n49 = "1" else n55;
n57 <= i3(14 downto 14) &
  i3(13 downto 13) &
  i3(12 downto 12);
n58 <= i3(11 downto 11) &
  i3(10 downto 10) &
  i3(9 downto 9) &
  i3(8 downto 8);
n59 <= i3(7 downto 7) &
  i3(6 downto 6) &
  i3(5 downto 5) &
  i3(4 downto 4);
n60 <= i3(3 downto 3) &
  i3(2 downto 2) &
  i3(1 downto 1) &
  i3(0 downto 0);
process (clock_c) begin
  if rising_edge(clock_c) then
    if n2 = "1" then
      n61 <= "0000";
    elsif n1 = "1" then
      n61 <= n60;
    end if;
  end if;
end process;
n62 <= i3(11 downto 11) &
  i3(10 downto 10) &
  i3(9 downto 9) &
  i3(8 downto 8) &
  i3(7 downto 7) &
  i3(6 downto 6) &
  i3(5 downto 5) &
  i3(4 downto 4);
n63 <= i5 or n56;
n64 <= i6 when i5 = "1" else n61;
n65 <= n63 & n64;
n66 <= "1000000000000000";
n67 <= "0100000000000000";
n68 <= "0010000000000000";
n69 <= "0001000000000000";
n70 <= "0000100000000000";
n71 <= "0000010000000000";
n72 <= "0000001000000000";
n73 <= "0000000100000000";
n74 <= "0000000010000000";
n75 <= "0000000001000000";
n76 <= "0000000000100000";
n77 <= "0000000000010000";
n78 <= "0000000000001000";
n79 <= "0000000000000100";
n80 <= "0000000000000010";
n81 <= "0000000000000001";
n82 <= "0000000000000000";
n83 <= "00000";
n84 <= "1" when n65 = n83 else "0";
n85 <= "00001";
n86 <= "1" when n65 = n85 else "0";
n87 <= "00010";
n88 <= "1" when n65 = n87 else "0";
n89 <= "00011";
n90 <= "1" when n65 = n89 else "0";
n91 <= "00100";
n92 <= "1" when n65 = n91 else "0";
n93 <= "00101";
n94 <= "1" when n65 = n93 else "0";
n95 <= "00110";
n96 <= "1" when n65 = n95 else "0";
n97 <= "00111";
n98 <= "1" when n65 = n97 else "0";
n99 <= "01000";
n100 <= "1" when n65 = n99 else "0";
n101 <= "01001";
n102 <= "1" when n65 = n101 else "0";
n103 <= "01010";
n104 <= "1" when n65 = n103 else "0";
n105 <= "01011";
n106 <= "1" when n65 = n105 else "0";
n107 <= "01100";
n108 <= "1" when n65 = n107 else "0";
n109 <= "01101";
n110 <= "1" when n65 = n109 else "0";
n111 <= "01110";
n112 <= "1" when n65 = n111 else "0";
n113 <= "01111";
n114 <= "1" when n65 = n113 else "0";
n115 <= "10000";
n116 <= "1" when n65 = n115 else "0";
n117 <= "10001";
n118 <= "1" when n65 = n117 else "0";
n119 <= "10010";
n120 <= "1" when n65 = n119 else "0";
n121 <= "10011";
n122 <= "1" when n65 = n121 else "0";
n123 <= "10100";
n124 <= "1" when n65 = n123 else "0";
n125 <= "10101";
n126 <= "1" when n65 = n125 else "0";
n127 <= "10110";
n128 <= "1" when n65 = n127 else "0";
n129 <= "10111";
n130 <= "1" when n65 = n129 else "0";
n131 <= "11000";
n132 <= "1" when n65 = n131 else "0";
n133 <= "11001";
n134 <= "1" when n65 = n133 else "0";
n135 <= "11010";
n136 <= "1" when n65 = n135 else "0";
n137 <= "11011";
n138 <= "1" when n65 = n137 else "0";
n139 <= "11100";
n140 <= "1" when n65 = n139 else "0";
n141 <= "11101";
n142 <= "1" when n65 = n141 else "0";
n143 <= "11110";
n144 <= "1" when n65 = n143 else "0";
n145 <= n67 when n144 = "1" else n66;
n146 <= n68 when n142 = "1" else n145;
n147 <= n69 when n140 = "1" else n146;
n148 <= n70 when n138 = "1" else n147;
n149 <= n71 when n136 = "1" else n148;
n150 <= n72 when n134 = "1" else n149;
n151 <= n73 when n132 = "1" else n150;
n152 <= n74 when n130 = "1" else n151;
n153 <= n75 when n128 = "1" else n152;
n154 <= n76 when n126 = "1" else n153;
n155 <= n77 when n124 = "1" else n154;
n156 <= n78 when n122 = "1" else n155;
n157 <= n79 when n120 = "1" else n156;
n158 <= n80 when n118 = "1" else n157;
n159 <= n81 when n116 = "1" else n158;
n160 <= n82 when n114 = "1" else n159;
n161 <= n82 when n112 = "1" else n160;
n162 <= n82 when n110 = "1" else n161;
n163 <= n82 when n108 = "1" else n162;
n164 <= n82 when n106 = "1" else n163;
n165 <= n82 when n104 = "1" else n164;
n166 <= n82 when n102 = "1" else n165;
n167 <= n82 when n100 = "1" else n166;
n168 <= n82 when n98 = "1" else n167;
n169 <= n82 when n96 = "1" else n168;
n170 <= n82 when n94 = "1" else n169;
n171 <= n82 when n92 = "1" else n170;
n172 <= n82 when n90 = "1" else n171;
n173 <= n82 when n88 = "1" else n172;
n174 <= n82 when n86 = "1" else n173;
n175 <= n82 when n84 = "1" else n174;
n176 <= "0000000000000000000000000000000000000000000000000000000000000000";
n177 <= n175(1 downto 1);
n178 <= n175(2 downto 2);
n179 <= n175(3 downto 3);
n180 <= n175(4 downto 4);
n181 <= n175(5 downto 5);
n182 <= n175(6 downto 6);
n183 <= n175(7 downto 7);
n184 <= n175(8 downto 8);
n185 <= n175(9 downto 9);
n186 <= n175(10 downto 10);
n187 <= n175(11 downto 11);
n188 <= n175(12 downto 12);
n189 <= n175(13 downto 13);
n190 <= n175(14 downto 14);
n191 <= n175(15 downto 15);
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n192 <= "0000";
    elsif n1 = "1" then
      n192 <= n58;
    end if;
  end if;
end process;
n193 <= n192(3 downto 3) &
  n192(2 downto 2) &
  n192(1 downto 1);
n194 <= n192(0 downto 0);
n195 <= n343 when n194 = "1" else n176;
n196 <= n345 when n194 = "1" else n344;
n197 <= n347 when n194 = "1" else n346;
n198 <= n349 when n194 = "1" else n348;
n199 <= n351 when n194 = "1" else n350;
n200 <= n353 when n194 = "1" else n352;
n201 <= n355 when n194 = "1" else n354;
n202 <= n357 when n194 = "1" else n356;
n203 <= n193(2 downto 2) &
  n193(1 downto 1);
n204 <= n193(0 downto 0);
n205 <= n196 when n204 = "1" else n195;
n206 <= n198 when n204 = "1" else n197;
n207 <= n200 when n204 = "1" else n199;
n208 <= n202 when n204 = "1" else n201;
n209 <= n203(1 downto 1);
n210 <= n203(0 downto 0);
n211 <= n206 when n210 = "1" else n205;
n212 <= n208 when n210 = "1" else n207;
n213 <= n209(0 downto 0);
n214 <= n212 when n213 = "1" else n211;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n215 <= "0000";
    elsif n1 = "1" then
      n215 <= n59;
    end if;
  end if;
end process;
n216 <= n215(3 downto 3) &
  n215(2 downto 2) &
  n215(1 downto 1);
n217 <= n215(0 downto 0);
n218 <= n343 when n217 = "1" else n176;
n219 <= n345 when n217 = "1" else n344;
n220 <= n347 when n217 = "1" else n346;
n221 <= n349 when n217 = "1" else n348;
n222 <= n351 when n217 = "1" else n350;
n223 <= n353 when n217 = "1" else n352;
n224 <= n355 when n217 = "1" else n354;
n225 <= n357 when n217 = "1" else n356;
n226 <= n216(2 downto 2) &
  n216(1 downto 1);
n227 <= n216(0 downto 0);
n228 <= n219 when n227 = "1" else n218;
n229 <= n221 when n227 = "1" else n220;
n230 <= n223 when n227 = "1" else n222;
n231 <= n225 when n227 = "1" else n224;
n232 <= n226(1 downto 1);
n233 <= n226(0 downto 0);
n234 <= n229 when n233 = "1" else n228;
n235 <= n231 when n233 = "1" else n230;
n236 <= n232(0 downto 0);
n237 <= n235 when n236 = "1" else n234;
process (clock_c) begin
  if rising_edge(clock_c) then
    if n2 = "1" then
      n238 <= "000";
    elsif n1 = "1" then
      n238 <= n57;
    end if;
  end if;
end process;
n239 <= n214(63 downto 63);
n240 <= not n239;
n241 <= n240 & n240;
n242 <= n240 & n241;
n243 <= n240 & n242;
n244 <= n240 & n243;
n245 <= n240 & n244;
n246 <= n240 & n245;
n247 <= n240 & n246;
n248 <= n240 & n247;
n249 <= n240 & n248;
n250 <= n240 & n249;
n251 <= n240 & n250;
n252 <= n240 & n251;
n253 <= n240 & n252;
n254 <= n240 & n253;
n255 <= n240 & n254;
n256 <= n240 & n255;
n257 <= n240 & n256;
n258 <= n240 & n257;
n259 <= n240 & n258;
n260 <= n240 & n259;
n261 <= n240 & n260;
n262 <= n240 & n261;
n263 <= n240 & n262;
n264 <= n240 & n263;
n265 <= n240 & n264;
n266 <= n240 & n265;
n267 <= n240 & n266;
n268 <= n240 & n267;
n269 <= n240 & n268;
n270 <= n240 & n269;
n271 <= n240 & n270;
n272 <= n240 & n271;
n273 <= n240 & n272;
n274 <= n240 & n273;
n275 <= n240 & n274;
n276 <= n240 & n275;
n277 <= n240 & n276;
n278 <= n240 & n277;
n279 <= n240 & n278;
n280 <= n240 & n279;
n281 <= n240 & n280;
n282 <= n240 & n281;
n283 <= n240 & n282;
n284 <= n240 & n283;
n285 <= n240 & n284;
n286 <= n240 & n285;
n287 <= n240 & n286;
n288 <= n240 & n287;
n289 <= n240 & n288;
n290 <= n240 & n289;
n291 <= n240 & n290;
n292 <= n240 & n291;
n293 <= n240 & n292;
n294 <= n240 & n293;
n295 <= n240 & n294;
n296 <= n240 & n295;
n297 <= n240 & n296;
n298 <= n240 & n297;
n299 <= n240 & n298;
n300 <= n240 & n299;
n301 <= n240 & n300;
n302 <= n240 & n301;
n303 <= n239 & n302;
n304 <= n214(62 downto 62) &
  n214(61 downto 61) &
  n214(60 downto 60) &
  n214(59 downto 59) &
  n214(58 downto 58) &
  n214(57 downto 57) &
  n214(56 downto 56) &
  n214(55 downto 55) &
  n214(54 downto 54) &
  n214(53 downto 53) &
  n214(52 downto 52) &
  n214(51 downto 51) &
  n214(50 downto 50) &
  n214(49 downto 49) &
  n214(48 downto 48) &
  n214(47 downto 47) &
  n214(46 downto 46) &
  n214(45 downto 45) &
  n214(44 downto 44) &
  n214(43 downto 43) &
  n214(42 downto 42) &
  n214(41 downto 41) &
  n214(40 downto 40) &
  n214(39 downto 39) &
  n214(38 downto 38) &
  n214(37 downto 37) &
  n214(36 downto 36) &
  n214(35 downto 35) &
  n214(34 downto 34) &
  n214(33 downto 33) &
  n214(32 downto 32) &
  n214(31 downto 31) &
  n214(30 downto 30) &
  n214(29 downto 29) &
  n214(28 downto 28) &
  n214(27 downto 27) &
  n214(26 downto 26) &
  n214(25 downto 25) &
  n214(24 downto 24) &
  n214(23 downto 23) &
  n214(22 downto 22) &
  n214(21 downto 21) &
  n214(20 downto 20) &
  n214(19 downto 19) &
  n214(18 downto 18) &
  n214(17 downto 17) &
  n214(16 downto 16) &
  n214(15 downto 15) &
  n214(14 downto 14) &
  n214(13 downto 13) &
  n214(12 downto 12) &
  n214(11 downto 11) &
  n214(10 downto 10) &
  n214(9 downto 9) &
  n214(8 downto 8) &
  n214(7 downto 7) &
  n214(6 downto 6) &
  n214(5 downto 5) &
  n214(4 downto 4) &
  n214(3 downto 3) &
  n214(2 downto 2) &
  n214(1 downto 1) &
  n214(0 downto 0);
n305 <= "0";
n306 <= n304 & n305;
n307 <= n214(63 downto 63);
n308 <= n214(63 downto 63) &
  n214(62 downto 62) &
  n214(61 downto 61) &
  n214(60 downto 60) &
  n214(59 downto 59) &
  n214(58 downto 58) &
  n214(57 downto 57) &
  n214(56 downto 56) &
  n214(55 downto 55) &
  n214(54 downto 54) &
  n214(53 downto 53) &
  n214(52 downto 52) &
  n214(51 downto 51) &
  n214(50 downto 50) &
  n214(49 downto 49) &
  n214(48 downto 48) &
  n214(47 downto 47) &
  n214(46 downto 46) &
  n214(45 downto 45) &
  n214(44 downto 44) &
  n214(43 downto 43) &
  n214(42 downto 42) &
  n214(41 downto 41) &
  n214(40 downto 40) &
  n214(39 downto 39) &
  n214(38 downto 38) &
  n214(37 downto 37) &
  n214(36 downto 36) &
  n214(35 downto 35) &
  n214(34 downto 34) &
  n214(33 downto 33) &
  n214(32 downto 32) &
  n214(31 downto 31) &
  n214(30 downto 30) &
  n214(29 downto 29) &
  n214(28 downto 28) &
  n214(27 downto 27) &
  n214(26 downto 26) &
  n214(25 downto 25) &
  n214(24 downto 24) &
  n214(23 downto 23) &
  n214(22 downto 22) &
  n214(21 downto 21) &
  n214(20 downto 20) &
  n214(19 downto 19) &
  n214(18 downto 18) &
  n214(17 downto 17) &
  n214(16 downto 16) &
  n214(15 downto 15) &
  n214(14 downto 14) &
  n214(13 downto 13) &
  n214(12 downto 12) &
  n214(11 downto 11) &
  n214(10 downto 10) &
  n214(9 downto 9) &
  n214(8 downto 8) &
  n214(7 downto 7) &
  n214(6 downto 6) &
  n214(5 downto 5) &
  n214(4 downto 4) &
  n214(3 downto 3) &
  n214(2 downto 2) &
  n214(1 downto 1);
n309 <= n307 & n308;
n310 <= n214(62 downto 62);
n311 <= n239 xor n310;
n312 <= n303 when n311 = "1" else n306;
n313 <= n214 + n237;
n314 <= n214 - n237;
n315 <= "001";
n316 <= "1" when n238 = n315 else "0";
n317 <= n214(0 downto 0);
n318 <= "011";
n319 <= "1" when n238 = n318 else "0";
n320 <= n313(63 downto 63);
n321 <= "101";
n322 <= "1" when n238 = n321 else "0";
n323 <= n314(63 downto 63);
n324 <= n313 when n341 = "1" else n214;
n325 <= n214 when n341 = "1" else n237;
n326 <= n238(2 downto 2) &
  n238(1 downto 1);
n327 <= n238(0 downto 0);
n328 <= n309 when n327 = "1" else n306;
n329 <= n313 when n327 = "1" else n312;
n330 <= n314 when n327 = "1" else n324;
n331 <= i4 when n327 = "1" else n325;
n332 <= n326(1 downto 1);
n333 <= n326(0 downto 0);
n334 <= n329 when n333 = "1" else n328;
n335 <= n331 when n333 = "1" else n330;
n336 <= n332(0 downto 0);
n337 <= n335 when n336 = "1" else n334;
n338 <= n323 when n322 = "1" else n341;
n339 <= n320 when n319 = "1" else n338;
n340 <= n317 when n316 = "1" else n339;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n341 <= "0";
    elsif n1 = "1" then
      n341 <= n340;
    end if;
  end if;
end process;
n342 <= i7 when i5 = "1" else n337;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n343 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n177 = "1" then
      n343 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n344 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n178 = "1" then
      n344 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n345 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n179 = "1" then
      n345 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n346 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n180 = "1" then
      n346 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n347 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n181 = "1" then
      n347 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n348 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n182 = "1" then
      n348 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n349 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n183 = "1" then
      n349 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n350 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n184 = "1" then
      n350 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n351 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n185 = "1" then
      n351 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n352 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n186 = "1" then
      n352 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n353 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n187 = "1" then
      n353 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n354 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n188 = "1" then
      n354 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n355 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n189 = "1" then
      n355 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n356 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n190 = "1" then
      n356 <= n342;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n357 <= "0000000000000000000000000000000000000000000000000000000000000000";
    elsif n191 = "1" then
      n357 <= n342;
    end if;
  end if;
end process;
n358 <= i1 & n56;
n359 <= "10";
n360 <= "00";
n361 <= "01";
n362 <= "10";
n363 <= "01";
n364 <= "01";
n365 <= "00";
n366 <= "0000";
n367 <= "0100";
n368 <= "1000";
n369 <= "1100";
n370 <= "0001";
n371 <= "0101";
n372 <= "1001";
n373 <= "1101";
n374 <= "0010";
n375 <= "0110";
n376 <= "1";
n377 <= "1";
n378 <= "0000";
n379 <= "0100";
n380 <= "1000";
n381 <= "1100";
n382 <= n358 & n403;
n383 <= "1" when n382 = n366 else "0";
n384 <= "1" when n382 = n367 else "0";
n385 <= "1" when n382 = n368 else "0";
n386 <= "1" when n382 = n369 else "0";
n387 <= "1" when n382 = n370 else "0";
n388 <= "1" when n382 = n371 else "0";
n389 <= "1" when n382 = n372 else "0";
n390 <= "1" when n382 = n373 else "0";
n391 <= "1" when n382 = n374 else "0";
n392 <= "1" when n382 = n375 else "0";
n393 <= n359 when n392 = "1" else n413;
n394 <= n360 when n391 = "1" else n393;
n395 <= n361 when n390 = "1" else n394;
n396 <= n361 when n389 = "1" else n395;
n397 <= n362 when n388 = "1" else n396;
n398 <= n363 when n387 = "1" else n397;
n399 <= n364 when n386 = "1" else n398;
n400 <= n364 when n385 = "1" else n399;
n401 <= n365 when n384 = "1" else n400;
n402 <= n365 when n383 = "1" else n401;
process (clock_c) begin
  if rising_edge(clock_c) then
    if n2 = "1" then
      n403 <= "00";
    elsif n1 = "1" then
      n403 <= n402;
    end if;
  end if;
end process;
n404 <= "1" when n382 = n378 else "0";
n405 <= "1" when n382 = n379 else "0";
n406 <= "1" when n382 = n380 else "0";
n407 <= "1" when n382 = n381 else "0";
n408 <= n376 when n407 = "1" else n414;
n409 <= n376 when n406 = "1" else n408;
n410 <= n377 when n405 = "1" else n409;
n411 <= n377 when n404 = "1" else n410;
n412 <= "1";
n413 <= "01";
n414 <= "0";
o19 <= n411;
o18 <= n357;
o17 <= n356;
o16 <= n355;
o15 <= n354;
o14 <= n353;
o13 <= n352;
o12 <= n351;
o11 <= n350;
o10 <= n349;
o9 <= n348;
o8 <= n347;
o7 <= n346;
o6 <= n345;
o5 <= n344;
o4 <= n343;
o3 <= n176;
o2 <= n62;
o1 <= n5;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_ssp_64_6 is
port(
signal clock_c : in std_logic;
signal reset_state_i : in unsigned(0 downto 0);
signal cycle_i : in unsigned(0 downto 0);
signal instr_data_i : in unsigned(15 downto 0);
signal const_data_i : in unsigned(63 downto 0);
signal load_write_i : in unsigned(0 downto 0);
signal load_addr_i : in unsigned(3 downto 0);
signal load_data_i : in unsigned(63 downto 0);
signal done_o : out unsigned(0 downto 0);
signal instr_addr_o : out unsigned(5 downto 0);
signal const_addr_o : out unsigned(7 downto 0);
signal reg_0_o : out unsigned(63 downto 0);
signal reg_1_o : out unsigned(63 downto 0);
signal reg_2_o : out unsigned(63 downto 0);
signal reg_3_o : out unsigned(63 downto 0);
signal reg_4_o : out unsigned(63 downto 0);
signal reg_5_o : out unsigned(63 downto 0);
signal reg_6_o : out unsigned(63 downto 0);
signal reg_7_o : out unsigned(63 downto 0);
signal reg_8_o : out unsigned(63 downto 0);
signal reg_9_o : out unsigned(63 downto 0);
signal reg_a_o : out unsigned(63 downto 0);
signal reg_b_o : out unsigned(63 downto 0);
signal reg_c_o : out unsigned(63 downto 0);
signal reg_d_o : out unsigned(63 downto 0);
signal reg_e_o : out unsigned(63 downto 0);
signal reg_f_o : out unsigned(63 downto 0));
end entity cf_ssp_64_6;
architecture rtl of cf_ssp_64_6 is
component cf_ssp_64_6_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(63 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(3 downto 0);
i7 : in  unsigned(63 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(63 downto 0);
o4 : out unsigned(63 downto 0);
o5 : out unsigned(63 downto 0);
o6 : out unsigned(63 downto 0);
o7 : out unsigned(63 downto 0);
o8 : out unsigned(63 downto 0);
o9 : out unsigned(63 downto 0);
o10 : out unsigned(63 downto 0);
o11 : out unsigned(63 downto 0);
o12 : out unsigned(63 downto 0);
o13 : out unsigned(63 downto 0);
o14 : out unsigned(63 downto 0);
o15 : out unsigned(63 downto 0);
o16 : out unsigned(63 downto 0);
o17 : out unsigned(63 downto 0);
o18 : out unsigned(63 downto 0);
o19 : out unsigned(0 downto 0));
end component cf_ssp_64_6_1;
signal n1 : unsigned(5 downto 0);
signal n2 : unsigned(7 downto 0);
signal n3 : unsigned(63 downto 0);
signal n4 : unsigned(63 downto 0);
signal n5 : unsigned(63 downto 0);
signal n6 : unsigned(63 downto 0);
signal n7 : unsigned(63 downto 0);
signal n8 : unsigned(63 downto 0);
signal n9 : unsigned(63 downto 0);
signal n10 : unsigned(63 downto 0);
signal n11 : unsigned(63 downto 0);
signal n12 : unsigned(63 downto 0);
signal n13 : unsigned(63 downto 0);
signal n14 : unsigned(63 downto 0);
signal n15 : unsigned(63 downto 0);
signal n16 : unsigned(63 downto 0);
signal n17 : unsigned(63 downto 0);
signal n18 : unsigned(63 downto 0);
signal n19 : unsigned(0 downto 0);
begin
s1 : cf_ssp_64_6_1 port map (clock_c, cycle_i, reset_state_i, instr_data_i, const_data_i, load_write_i, load_addr_i, load_data_i, n1, n2, n3, n4, n5, n6, n7, n8, n9, n10, n11, n12, n13, n14, n15, n16, n17, n18, n19);
done_o <= n19;
instr_addr_o <= n1;
const_addr_o <= n2;
reg_0_o <= n3;
reg_1_o <= n4;
reg_2_o <= n5;
reg_3_o <= n6;
reg_4_o <= n7;
reg_5_o <= n8;
reg_6_o <= n9;
reg_7_o <= n10;
reg_8_o <= n11;
reg_9_o <= n12;
reg_a_o <= n13;
reg_b_o <= n14;
reg_c_o <= n15;
reg_d_o <= n16;
reg_e_o <= n17;
reg_f_o <= n18;
end architecture rtl;


