#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    State Space Processor is used for implementing discrete (digital) linear systems, such as
#    finite impulse response filters, infinite impulse response filters, multiple input and output
#    systems, and general state space equations.
#  
#  Architecture:
#  
#    The State Space Processor is designed with a small logic footprint for area limited
#    applications.  The processor requires two external memories: one for program instructions
#    and the other for constants (coefficients) used in calculation.  The processor maintains a
#    register file of 16 N-bit registers used to retain state information and for processing intermediate
#    results.  The register file is also used for handling input and output; registers can be written
#    from an external source and all registers are available as outputs.  For convenience, register 0
#    is wired to ground (0) and instructions updating r0 have no effect on the register file.
#  
#    The processor runs calculations on a cycle basis:
#      1. The external environment writes inputs into the register file.
#      2. The external environment signals a "Cycle" to run the program and calculate a cycle.
#      3. The external environment waits for "Done", then reads output from the register file.
#  
#  Instruction Set:
#  
#    There are 4 instruction types and a total of 8 instructions.  Each instruction is 16-bits.
#    The types include:
#      Unary Operation  : OpCode [15:12], Operand Reg A [11:8], Not Used [7:4], Result Reg X [3:0]
#      Binary Operation : OpCode [15:12], Operand Reg A [11:8], Operand Reg B [7:4], Result Reg X [3:0]
#      Constant Load    : OpCode [15:12], Constant Memory Address [11:4], Result Reg X [3:0]
#      Halt             : OpCode [15:12], Not Used [11:0]
#  
#    Unary Operations (OpCode):
#  
#      ShiftLeft  (0000) : RegX <- lsbs RegA '++' '0'
#                          Flag <- Flag
#      ShiftRight (0001) : RegX <- msb RegA '++' msbs RegA
#                          Flag <- lsb RegA
#      ShiftClip  (0010) : RegX <- lsbs RegA '++' '0' when top 2 bits of RegA == '00' or '11' else
#                                  '0111...1'         when top 2 bits of RegA == '01'         else
#                                  '1000...0'         when top 2 bits of RegA == '10'
#                          Flag <- Flag
#                          Performs a limited/clipped multiplication by 2.
#  
#    Binary Operations (OpCode):
#  
#      Add        (0011) : RegX <- RegA '+' RegB
#                          Flag <- msb Result
#      AddCond    (0100) : RegX <- RegA '+' RegB when Flag == '1' else RegA
#                          Flag <- Flag
#      Sub        (0101) : RegX <- RegA '-' RegB
#                          Flag <- msb Result
#      Switch     (0110) : RegX <- RegA when Flag == '1' else RegB
#                          Flag <- Flag
#  
#    Constant Load Instruction (OpCode):
#  
#      Constant   (0111) : RegX <- Data from constant memory.
#                          Flag <- Flag
#  
#    Halt Instruction (OpCode):
#  
#      Halt       (1---) : Halts processor (prevents further register updates).
#  
#    Booth multiplication can be performed using ShiftRight and AddCond with an accumulation register.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      reset_state_i : Reset all state registers (register file and ALU flag).
#  
#    Inputs:
#      cycle_i      : Input pulse to perform a cycle (sample) calculation.
#      instr_data_i : Instruction data from instruction memory.
#      const_data_i : Constant data from constant memory.
#      load_write_i : Write enable for writing to register file.
#      load_addr_i  : Address (4-bits) for writing to register file.
#      load_data_i  : Data for writing to register file.
#  
#    Outputs:
#      done_o       : Output flag signaling processor is done calculating cycle (active high).
#      instr_addr_o : Address to instruction memory.
#      const_addr_o : Address to constant memory (8-bits).
#      reg_0_o      : Register 0 value.
#      reg_1_o      : Register 1 value.
#      ...
#      reg_f_o      : Register F value.
#  
#  Built In Parameters:
#  
#    Data Width                = 8
#    Instruction Address Width = 10
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:51:33 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_ssp_8_10
#    Clock Domains : clock_c  
#    Vector Input  : reset_state_i(1)
#    Vector Input  : cycle_i(1)
#    Vector Input  : instr_data_i(16)
#    Vector Input  : const_data_i(8)
#    Vector Input  : load_write_i(1)
#    Vector Input  : load_addr_i(4)
#    Vector Input  : load_data_i(8)
#    Vector Output : done_o(1)
#    Vector Output : instr_addr_o(10)
#    Vector Output : const_addr_o(8)
#    Vector Output : reg_0_o(8)
#    Vector Output : reg_1_o(8)
#    Vector Output : reg_2_o(8)
#    Vector Output : reg_3_o(8)
#    Vector Output : reg_4_o(8)
#    Vector Output : reg_5_o(8)
#    Vector Output : reg_6_o(8)
#    Vector Output : reg_7_o(8)
#    Vector Output : reg_8_o(8)
#    Vector Output : reg_9_o(8)
#    Vector Output : reg_a_o(8)
#    Vector Output : reg_b_o(8)
#    Vector Output : reg_c_o(8)
#    Vector Output : reg_d_o(8)
#    Vector Output : reg_e_o(8)
#    Vector Output : reg_f_o(8)
#  
#  
#  

import sys
import time

class cf_ssp_8_10:

  def init(self):
    self.n612 = 0L
    self.n603 = 0L
    self.n602 = 0L
    self.n580 = 0L
    self.n579 = 0L
    self.n578 = 0L
    self.n577 = 0L
    self.n576 = 0L
    self.n575 = 0L
    self.n574 = 0L
    self.n573 = 0L
    self.n572 = 0L
    self.n571 = 0L
    self.n570 = 0L
    self.n569 = 0L
    self.n568 = 0L
    self.n567 = 0L
    self.n566 = 0L
    self.n563 = 0L
    self.n502 = 0L
    self.n501 = 0L
    self.n500 = 0L
    self.n499 = 0L
    self.n498 = 0L
    self.n497 = 0L
    self.n489 = 0L
    self.n488 = 0L
    self.n487 = 0L
    self.n486 = 0L
    self.n485 = 0L
    self.n484 = 0L
    self.n483 = 0L
    self.n482 = 0L
    self.n481 = 0L
    self.n480 = 0L
    self.n479 = 0L
    self.n478 = 0L
    self.n477 = 0L
    self.n476 = 0L
    self.n475 = 0L
    self.n474 = 0L
    self.n473 = 0L
    self.n375 = 0L
    self.n374 = 0L
    self.n367 = 0L
    self.n364 = 0L
    self.n361 = 0L
    self.n351 = 0L
    self.n310 = 0L
    self.n309 = 0L
    self.n280 = 0L
    self.n279 = 0L
    self.n226 = 0L
    self.n193 = 0L
    self.n191 = 0L
    self.n189 = 0L
    self.n187 = 0L
    self.n185 = 0L
    self.n183 = 0L
    self.n181 = 0L
    self.n179 = 0L
    self.n177 = 0L
    self.n175 = 0L
    self.n173 = 0L
    self.n171 = 0L
    self.n169 = 0L
    self.n167 = 0L
    self.n165 = 0L
    self.n163 = 0L
    self.n161 = 0L
    self.n159 = 0L
    self.n157 = 0L
    self.n155 = 0L
    self.n153 = 0L
    self.n151 = 0L
    self.n149 = 0L
    self.n147 = 0L
    self.n145 = 0L
    self.n143 = 0L
    self.n141 = 0L
    self.n139 = 0L
    self.n137 = 0L
    self.n135 = 0L
    self.n133 = 0L
    self.n132 = 0L
    self.n131 = 0L
    self.n130 = 0L
    self.n129 = 0L
    self.n128 = 0L
    self.n127 = 0L
    self.n126 = 0L
    self.n125 = 0L
    self.n124 = 0L
    self.n123 = 0L
    self.n122 = 0L
    self.n121 = 0L
    self.n120 = 0L
    self.n119 = 0L
    self.n118 = 0L
    self.n117 = 0L
    self.n116 = 0L
    self.n61 = 0L
    self.n60 = 0L
    self.n59 = 0L
    self.n58 = 0L
    self.n57 = 0L
    self.n56 = 0L
    self.n55 = 0L
    self.n54 = 0L
    self.n49 = 0L
    self.n48 = 0L
    self.n47 = 0L
    self.n46 = 0L
    self.n45 = 0L
    self.n44 = 0L
    self.n43 = 0L
    self.n42 = 0L
    self.n41 = 0L
    self.n40 = 0L
    self.n39 = 0L
    self.n38 = 0L
    self.n37 = 0L
    self.n36 = 0L
    self.n35 = 0L
    self.n10 = 0L
    self.n9 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n2 = 0L
    self.n1 = 0L
    self.n565 = 0L
    self.n381 = 0L
    self.n380 = 0L
    self.n368 = 0L
    self.n365 = 0L
    self.n362 = 0L
    self.n320 = 0L
    self.n319 = 0L
    self.n318 = 0L
    self.n317 = 0L
    self.n316 = 0L
    self.n315 = 0L
    self.n314 = 0L
    self.n313 = 0L
    self.n312 = 0L
    self.n311 = 0L
    self.n290 = 0L
    self.n289 = 0L
    self.n288 = 0L
    self.n287 = 0L
    self.n286 = 0L
    self.n285 = 0L
    self.n284 = 0L
    self.n283 = 0L
    self.n282 = 0L
    self.n281 = 0L
    self.n114 = 0L
    self.n112 = 0L
    self.n104 = 0L
    self.n103 = 0L
    self.n102 = 0L
    self.n101 = 0L
    self.n33 = 0L
    self.n32 = 0L
    self.n32r = 0L
    self.n32e = 0L
    self.n32d = 0L
    self.n25 = 0L
    self.n25r = 0L
    self.n25e = 0L
    self.n25d = 0L
    self.n13 = 0L
    self.n564 = 0L
    self.n385 = 0L
    self.n338 = 0L
    self.n338r = 0L
    self.n338e = 0L
    self.n338d = 0L
    self.n326 = 0L
    self.n325 = 0L
    self.n324 = 0L
    self.n323 = 0L
    self.n322 = 0L
    self.n321 = 0L
    self.n308 = 0L
    self.n308r = 0L
    self.n308e = 0L
    self.n308d = 0L
    self.n296 = 0L
    self.n295 = 0L
    self.n294 = 0L
    self.n293 = 0L
    self.n292 = 0L
    self.n291 = 0L
    self.n278 = 0L
    self.n278r = 0L
    self.n278e = 0L
    self.n278d = 0L
    self.n111 = 0L
    self.n111r = 0L
    self.n111e = 0L
    self.n111d = 0L
    self.n34 = 0L
    self.n18 = 0L
    self.n18r = 0L
    self.n18e = 0L
    self.n18d = 0L
    self.n330 = 0L
    self.n328 = 0L
    self.n327 = 0L
    self.n300 = 0L
    self.n298 = 0L
    self.n297 = 0L
    self.n67 = 0L
    self.n331 = 0L
    self.n301 = 0L
    self.n90 = 0L
    self.n89 = 0L
    self.n88 = 0L
    self.n87 = 0L
    self.n74 = 0L
    self.n73 = 0L
    self.n72 = 0L
    self.n71 = 0L
    self.n70 = 0L
    self.n69 = 0L
    self.n68 = 0L
    self.n373 = 0L
    self.n363 = 0L
    self.n360 = 0L
    self.n359 = 0L
    self.n356 = 0L
    self.n354 = 0L
    self.n353 = 0L
    self.n350 = 0L
    self.n339 = 0L
    self.n97 = 0L
    self.n75 = 0L
    self.n379 = 0L
    self.n372 = 0L
    self.n369 = 0L
    self.n366 = 0L
    self.n357 = 0L
    self.n355 = 0L
    self.n352 = 0L
    self.n340 = 0L
    self.n98 = 0L
    self.n76 = 0L
    self.n387 = 0L
    self.n378 = 0L
    self.n376 = 0L
    self.n343 = 0L
    self.n99 = 0L
    self.n77 = 0L
    self.n388 = 0L
    self.n383 = 0L
    self.n344 = 0L
    self.n100 = 0L
    self.n78 = 0L
    self.n471 = 0L
    self.n389 = 0L
    self.n345 = 0L
    self.n113 = 0L
    self.n79 = 0L
    self.n512 = 0L
    self.n394 = 0L
    self.n394r = 0L
    self.n394e = 0L
    self.n394d = 0L
    self.n346 = 0L
    self.n115 = 0L
    self.n80 = 0L
    self.n543 = 0L
    self.n542 = 0L
    self.n541 = 0L
    self.n540 = 0L
    self.n522 = 0L
    self.n521 = 0L
    self.n520 = 0L
    self.n519 = 0L
    self.n518 = 0L
    self.n517 = 0L
    self.n516 = 0L
    self.n515 = 0L
    self.n514 = 0L
    self.n513 = 0L
    self.n347 = 0L
    self.n194 = 0L
    self.n192 = 0L
    self.n190 = 0L
    self.n188 = 0L
    self.n186 = 0L
    self.n184 = 0L
    self.n182 = 0L
    self.n180 = 0L
    self.n178 = 0L
    self.n176 = 0L
    self.n174 = 0L
    self.n172 = 0L
    self.n170 = 0L
    self.n168 = 0L
    self.n166 = 0L
    self.n164 = 0L
    self.n162 = 0L
    self.n160 = 0L
    self.n158 = 0L
    self.n156 = 0L
    self.n154 = 0L
    self.n152 = 0L
    self.n150 = 0L
    self.n148 = 0L
    self.n146 = 0L
    self.n144 = 0L
    self.n142 = 0L
    self.n140 = 0L
    self.n138 = 0L
    self.n136 = 0L
    self.n134 = 0L
    self.n81 = 0L
    self.n558 = 0L
    self.n525 = 0L
    self.n348 = 0L
    self.n195 = 0L
    self.n86 = 0L
    self.n86r = 0L
    self.n86e = 0L
    self.n86d = 0L
    self.n559 = 0L
    self.n526 = 0L
    self.n349 = 0L
    self.n196 = 0L
    self.n560 = 0L
    self.n527 = 0L
    self.n358 = 0L
    self.n197 = 0L
    self.n561 = 0L
    self.n528 = 0L
    self.n377 = 0L
    self.n198 = 0L
    self.n562 = 0L
    self.n529 = 0L
    self.n382 = 0L
    self.n199 = 0L
    self.n530 = 0L
    self.n386 = 0L
    self.n200 = 0L
    self.n531 = 0L
    self.n395 = 0L
    self.n201 = 0L
    self.n532 = 0L
    self.n202 = 0L
    self.n533 = 0L
    self.n203 = 0L
    self.n534 = 0L
    self.n204 = 0L
    self.n539 = 0L
    self.n539r = 0L
    self.n539e = 0L
    self.n539d = 0L
    self.n205 = 0L
    self.n206 = 0L
    self.n207 = 0L
    self.n208 = 0L
    self.n209 = 0L
    self.n210 = 0L
    self.n211 = 0L
    self.n212 = 0L
    self.n213 = 0L
    self.n214 = 0L
    self.n215 = 0L
    self.n216 = 0L
    self.n217 = 0L
    self.n218 = 0L
    self.n219 = 0L
    self.n220 = 0L
    self.n221 = 0L
    self.n222 = 0L
    self.n223 = 0L
    self.n224 = 0L
    self.n225 = 0L
    self.n269 = 0L
    self.n266 = 0L
    self.n263 = 0L
    self.n260 = 0L
    self.n257 = 0L
    self.n254 = 0L
    self.n251 = 0L
    self.n248 = 0L
    self.n245 = 0L
    self.n242 = 0L
    self.n239 = 0L
    self.n236 = 0L
    self.n233 = 0L
    self.n230 = 0L
    self.n227 = 0L
    self.n470 = 0L
    self.n470r = 0L
    self.n470e = 0L
    self.n470d = 0L
    self.n465 = 0L
    self.n465r = 0L
    self.n465e = 0L
    self.n465d = 0L
    self.n460 = 0L
    self.n460r = 0L
    self.n460e = 0L
    self.n460d = 0L
    self.n455 = 0L
    self.n455r = 0L
    self.n455e = 0L
    self.n455d = 0L
    self.n450 = 0L
    self.n450r = 0L
    self.n450e = 0L
    self.n450d = 0L
    self.n445 = 0L
    self.n445r = 0L
    self.n445e = 0L
    self.n445d = 0L
    self.n440 = 0L
    self.n440r = 0L
    self.n440e = 0L
    self.n440d = 0L
    self.n435 = 0L
    self.n435r = 0L
    self.n435e = 0L
    self.n435d = 0L
    self.n430 = 0L
    self.n430r = 0L
    self.n430e = 0L
    self.n430d = 0L
    self.n425 = 0L
    self.n425r = 0L
    self.n425e = 0L
    self.n425d = 0L
    self.n420 = 0L
    self.n420r = 0L
    self.n420e = 0L
    self.n420d = 0L
    self.n415 = 0L
    self.n415r = 0L
    self.n415e = 0L
    self.n415d = 0L
    self.n410 = 0L
    self.n410r = 0L
    self.n410e = 0L
    self.n410d = 0L
    self.n405 = 0L
    self.n405r = 0L
    self.n405e = 0L
    self.n405d = 0L
    self.n400 = 0L
    self.n400r = 0L
    self.n400e = 0L
    self.n400d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, reset_state_i, cycle_i, instr_data_i, const_data_i, load_write_i, load_addr_i, load_data_i, ):
    self.n612 = 0x0L
    self.n603 = 0x1L
    self.n602 = 0x1L
    reg_f_o = self.n470
    self.n580 = self.n470
    reg_e_o = self.n465
    self.n579 = self.n465
    reg_d_o = self.n460
    self.n578 = self.n460
    reg_c_o = self.n455
    self.n577 = self.n455
    reg_b_o = self.n450
    self.n576 = self.n450
    reg_a_o = self.n445
    self.n575 = self.n445
    reg_9_o = self.n440
    self.n574 = self.n440
    reg_8_o = self.n435
    self.n573 = self.n435
    reg_7_o = self.n430
    self.n572 = self.n430
    reg_6_o = self.n425
    self.n571 = self.n425
    reg_5_o = self.n420
    self.n570 = self.n420
    reg_4_o = self.n415
    self.n569 = self.n415
    reg_3_o = self.n410
    self.n568 = self.n410
    reg_2_o = self.n405
    self.n567 = self.n405
    reg_1_o = self.n400
    self.n566 = self.n400
    instr_addr_o = self.n18
    self.n563 = self.n18
    self.n502 = 0xCL
    self.n501 = 0x8L
    self.n500 = 0x4L
    self.n499 = 0x0L
    self.n498 = 0x1L
    self.n497 = 0x1L
    self.n489 = 0x6L
    self.n488 = 0x2L
    self.n487 = 0xDL
    self.n486 = 0x9L
    self.n485 = 0x5L
    self.n484 = 0x1L
    self.n483 = 0xCL
    self.n482 = 0x8L
    self.n481 = 0x4L
    self.n480 = 0x0L
    self.n479 = 0x0L
    self.n478 = 0x1L
    self.n477 = 0x1L
    self.n476 = 0x2L
    self.n475 = 0x1L
    self.n474 = 0x0L
    self.n473 = 0x2L
    self.n375 = (self.n338 & 0x1L)
    self.n374 = ((self.n338 & 0x4L) >> 1) | ((self.n338 & 0x2L) >> 1)
    self.n367 = 0x5L
    self.n364 = 0x3L
    self.n361 = 0x1L
    self.n351 = 0x0L
    self.n310 = (self.n308 & 0x1L)
    self.n309 = ((self.n308 & 0x8L) >> 1) | ((self.n308 & 0x4L) >> 1) | ((self.n308 & 0x2L) >> 1)
    self.n280 = (self.n278 & 0x1L)
    self.n279 = ((self.n278 & 0x8L) >> 1) | ((self.n278 & 0x4L) >> 1) | ((self.n278 & 0x2L) >> 1)
    self.n226 = 0x00L
    self.n193 = 0x1EL
    self.n191 = 0x1DL
    self.n189 = 0x1CL
    self.n187 = 0x1BL
    self.n185 = 0x1AL
    self.n183 = 0x19L
    self.n181 = 0x18L
    self.n179 = 0x17L
    self.n177 = 0x16L
    self.n175 = 0x15L
    self.n173 = 0x14L
    self.n171 = 0x13L
    self.n169 = 0x12L
    self.n167 = 0x11L
    self.n165 = 0x10L
    self.n163 = 0x0FL
    self.n161 = 0x0EL
    self.n159 = 0x0DL
    self.n157 = 0x0CL
    self.n155 = 0x0BL
    self.n153 = 0x0AL
    self.n151 = 0x09L
    self.n149 = 0x08L
    self.n147 = 0x07L
    self.n145 = 0x06L
    self.n143 = 0x05L
    self.n141 = 0x04L
    self.n139 = 0x03L
    self.n137 = 0x02L
    self.n135 = 0x01L
    self.n133 = 0x00L
    self.n132 = 0x0000L
    self.n131 = 0x0001L
    self.n130 = 0x0002L
    self.n129 = 0x0004L
    self.n128 = 0x0008L
    self.n127 = 0x0010L
    self.n126 = 0x0020L
    self.n125 = 0x0040L
    self.n124 = 0x0080L
    self.n123 = 0x0100L
    self.n122 = 0x0200L
    self.n121 = 0x0400L
    self.n120 = 0x0800L
    self.n119 = 0x1000L
    self.n118 = 0x2000L
    self.n117 = 0x4000L
    self.n116 = 0x8000L
    self.n61 = 0x6L
    self.n60 = 0x4L
    self.n59 = 0x2L
    self.n58 = 0x0L
    self.n57 = 0x0L
    self.n56 = 0x0L
    self.n55 = 0x0L
    self.n54 = 0x0L
    self.n49 = 0x5L
    self.n48 = 0x3L
    self.n47 = 0x1L
    self.n46 = 0x6L
    self.n45 = 0x4L
    self.n44 = 0x2L
    self.n43 = 0x0L
    self.n42 = 0x0L
    self.n41 = 0x0L
    self.n40 = 0x1L
    self.n39 = 0x0L
    self.n38 = 0x1L
    self.n37 = 0x0L
    self.n36 = 0x1L
    self.n35 = 0x0L
    self.n10 = 0x001L
    self.n9 = load_data_i
    self.n8 = load_addr_i
    self.n7 = load_write_i
    self.n6 = const_data_i
    self.n5 = instr_data_i
    self.n4 = reset_state_i
    self.n3 = cycle_i
    self.n2 = 0x0L
    self.n1 = 0x1L
    reg_0_o = self.n226
    self.n565 = self.n226
    self.n381 = (self.n374 & 0x1L)
    self.n380 = ((self.n374 & 0x2L) >> 1)
    if self.n338 == self.n367:
      self.n368 = 1L
    else:
      self.n368 = 0L
    if self.n338 == self.n364:
      self.n365 = 1L
    else:
      self.n365 = 0L
    if self.n338 == self.n361:
      self.n362 = 1L
    else:
      self.n362 = 0L
    self.n320 = (self.n309 & 0x1L)
    self.n319 = ((self.n309 & 0x4L) >> 1) | ((self.n309 & 0x2L) >> 1)
    if self.n310:
      self.n318 = self.n470
    else:
      self.n318 = self.n465
    if self.n310:
      self.n317 = self.n460
    else:
      self.n317 = self.n455
    if self.n310:
      self.n316 = self.n450
    else:
      self.n316 = self.n445
    if self.n310:
      self.n315 = self.n440
    else:
      self.n315 = self.n435
    if self.n310:
      self.n314 = self.n430
    else:
      self.n314 = self.n425
    if self.n310:
      self.n313 = self.n420
    else:
      self.n313 = self.n415
    if self.n310:
      self.n312 = self.n410
    else:
      self.n312 = self.n405
    if self.n310:
      self.n311 = self.n400
    else:
      self.n311 = self.n226
    self.n290 = (self.n279 & 0x1L)
    self.n289 = ((self.n279 & 0x4L) >> 1) | ((self.n279 & 0x2L) >> 1)
    if self.n280:
      self.n288 = self.n470
    else:
      self.n288 = self.n465
    if self.n280:
      self.n287 = self.n460
    else:
      self.n287 = self.n455
    if self.n280:
      self.n286 = self.n450
    else:
      self.n286 = self.n445
    if self.n280:
      self.n285 = self.n440
    else:
      self.n285 = self.n435
    if self.n280:
      self.n284 = self.n430
    else:
      self.n284 = self.n425
    if self.n280:
      self.n283 = self.n420
    else:
      self.n283 = self.n415
    if self.n280:
      self.n282 = self.n410
    else:
      self.n282 = self.n405
    if self.n280:
      self.n281 = self.n400
    else:
      self.n281 = self.n226
    if self.n7:
      self.n114 = self.n8
    else:
      self.n114 = self.n111
    self.n112 = ((self.n5 & 0x800L) >> 4) | ((self.n5 & 0x400L) >> 4) | ((self.n5 & 0x200L) >> 4) | ((self.n5 & 0x100L) >> 4) | ((self.n5 & 0x80L) >> 4) | ((self.n5 & 0x40L) >> 4) | ((self.n5 & 0x20L) >> 4) | ((self.n5 & 0x10L) >> 4)
    self.n104 = (self.n5 & 0x8L) | (self.n5 & 0x4L) | (self.n5 & 0x2L) | (self.n5 & 0x1L)
    self.n103 = ((self.n5 & 0x80L) >> 4) | ((self.n5 & 0x40L) >> 4) | ((self.n5 & 0x20L) >> 4) | ((self.n5 & 0x10L) >> 4)
    self.n102 = ((self.n5 & 0x800L) >> 8) | ((self.n5 & 0x400L) >> 8) | ((self.n5 & 0x200L) >> 8) | ((self.n5 & 0x100L) >> 8)
    self.n101 = ((self.n5 & 0x4000L) >> 12) | ((self.n5 & 0x2000L) >> 12) | ((self.n5 & 0x1000L) >> 12)
    self.n33 = ((self.n5 & 0x8000L) >> 15)
    self.n32r = self.n2
    self.n32e = self.n1
    self.n32d = self.n25
    self.n25r = self.n2
    self.n25e = self.n1
    self.n25d = self.n3
    self.n13 = (self.n18 + self.n10) & 0x3FFL
    const_addr_o = self.n112
    self.n564 = self.n112
    self.n385 = (self.n380 & 0x1L)
    self.n338r = self.n2
    self.n338e = self.n1
    self.n338d = self.n101
    self.n326 = (self.n319 & 0x1L)
    self.n325 = ((self.n319 & 0x2L) >> 1)
    if self.n320:
      self.n324 = self.n318
    else:
      self.n324 = self.n317
    if self.n320:
      self.n323 = self.n316
    else:
      self.n323 = self.n315
    if self.n320:
      self.n322 = self.n314
    else:
      self.n322 = self.n313
    if self.n320:
      self.n321 = self.n312
    else:
      self.n321 = self.n311
    self.n308r = self.n4
    self.n308e = self.n1
    self.n308d = self.n103
    self.n296 = (self.n289 & 0x1L)
    self.n295 = ((self.n289 & 0x2L) >> 1)
    if self.n290:
      self.n294 = self.n288
    else:
      self.n294 = self.n287
    if self.n290:
      self.n293 = self.n286
    else:
      self.n293 = self.n285
    if self.n290:
      self.n292 = self.n284
    else:
      self.n292 = self.n283
    if self.n290:
      self.n291 = self.n282
    else:
      self.n291 = self.n281
    self.n278r = self.n4
    self.n278e = self.n1
    self.n278d = self.n102
    self.n111r = self.n2
    self.n111e = self.n1
    self.n111d = self.n104
    self.n34 = self.n32 << 1 | self.n33
    self.n18r = self.n3
    self.n18e = self.n1
    self.n18d = self.n13
    self.n330 = (self.n325 & 0x1L)
    if self.n326:
      self.n328 = self.n324
    else:
      self.n328 = self.n323
    if self.n326:
      self.n327 = self.n322
    else:
      self.n327 = self.n321
    self.n300 = (self.n295 & 0x1L)
    if self.n296:
      self.n298 = self.n294
    else:
      self.n298 = self.n293
    if self.n296:
      self.n297 = self.n292
    else:
      self.n297 = self.n291
    self.n67 = self.n34 << 1 | self.n86
    if self.n330:
      self.n331 = self.n328
    else:
      self.n331 = self.n327
    if self.n300:
      self.n301 = self.n298
    else:
      self.n301 = self.n297
    if self.n67 == self.n61:
      self.n90 = 1L
    else:
      self.n90 = 0L
    if self.n67 == self.n60:
      self.n89 = 1L
    else:
      self.n89 = 0L
    if self.n67 == self.n59:
      self.n88 = 1L
    else:
      self.n88 = 0L
    if self.n67 == self.n58:
      self.n87 = 1L
    else:
      self.n87 = 0L
    if self.n67 == self.n49:
      self.n74 = 1L
    else:
      self.n74 = 0L
    if self.n67 == self.n48:
      self.n73 = 1L
    else:
      self.n73 = 0L
    if self.n67 == self.n47:
      self.n72 = 1L
    else:
      self.n72 = 0L
    if self.n67 == self.n46:
      self.n71 = 1L
    else:
      self.n71 = 0L
    if self.n67 == self.n45:
      self.n70 = 1L
    else:
      self.n70 = 0L
    if self.n67 == self.n44:
      self.n69 = 1L
    else:
      self.n69 = 0L
    if self.n67 == self.n43:
      self.n68 = 1L
    else:
      self.n68 = 0L
    if self.n394:
      self.n373 = self.n301
    else:
      self.n373 = self.n331
    self.n363 = (self.n301 & 0x1L)
    self.n360 = (self.n301 - self.n331) & 0xFFL
    self.n359 = (self.n301 + self.n331) & 0xFFL
    self.n356 = ((self.n301 & 0x40L) >> 6)
    self.n354 = ((self.n301 & 0x80L) >> 1) | ((self.n301 & 0x40L) >> 1) | ((self.n301 & 0x20L) >> 1) | ((self.n301 & 0x10L) >> 1) | ((self.n301 & 0x8L) >> 1) | ((self.n301 & 0x4L) >> 1) | ((self.n301 & 0x2L) >> 1)
    self.n353 = ((self.n301 & 0x80L) >> 7)
    self.n350 = (self.n301 & 0x40L) | (self.n301 & 0x20L) | (self.n301 & 0x10L) | (self.n301 & 0x8L) | (self.n301 & 0x4L) | (self.n301 & 0x2L) | (self.n301 & 0x1L)
    self.n339 = ((self.n301 & 0x80L) >> 7)
    if self.n90:
      self.n97 = self.n54
    else:
      self.n97 = self.n602
    if self.n74:
      self.n75 = self.n36
    else:
      self.n75 = self.n35
    if self.n375:
      self.n379 = self.n6
    else:
      self.n379 = self.n373
    if self.n394:
      self.n372 = self.n359
    else:
      self.n372 = self.n301
    self.n369 = ((self.n360 & 0x80L) >> 7)
    self.n366 = ((self.n359 & 0x80L) >> 7)
    self.n357 = self.n339 ^ self.n356
    self.n355 = self.n353 << 7 | self.n354
    self.n352 = self.n350 << 1 | self.n351
    self.n340 = ~self.n339 & 0x1L
    if self.n89:
      self.n98 = self.n55
    else:
      self.n98 = self.n97
    if self.n73:
      self.n76 = self.n37
    else:
      self.n76 = self.n75
    if self.n368:
      self.n387 = self.n369
    else:
      self.n387 = self.n394
    if self.n375:
      self.n378 = self.n360
    else:
      self.n378 = self.n372
    if self.n375:
      self.n376 = self.n355
    else:
      self.n376 = self.n352
    self.n343 = self.n340 << 1 | self.n340
    if self.n88:
      self.n99 = self.n56
    else:
      self.n99 = self.n98
    if self.n72:
      self.n77 = self.n38
    else:
      self.n77 = self.n76
    if self.n365:
      self.n388 = self.n366
    else:
      self.n388 = self.n387
    if self.n381:
      self.n383 = self.n379
    else:
      self.n383 = self.n378
    self.n344 = self.n340 << 2 | self.n343
    if self.n87:
      self.n100 = self.n57
    else:
      self.n100 = self.n99
    if self.n71:
      self.n78 = self.n39
    else:
      self.n78 = self.n77
    self.n471 = self.n3 << 1 | self.n100
    if self.n362:
      self.n389 = self.n363
    else:
      self.n389 = self.n388
    self.n345 = self.n340 << 3 | self.n344
    self.n113 = self.n7 | self.n100
    if self.n70:
      self.n79 = self.n40
    else:
      self.n79 = self.n78
    self.n512 = self.n471 << 2 | self.n539
    self.n394r = self.n4
    self.n394e = self.n1
    self.n394d = self.n389
    self.n346 = self.n340 << 4 | self.n345
    self.n115 = self.n113 << 4 | self.n114
    if self.n69:
      self.n80 = self.n41
    else:
      self.n80 = self.n79
    if self.n512 == self.n502:
      self.n543 = 1L
    else:
      self.n543 = 0L
    if self.n512 == self.n501:
      self.n542 = 1L
    else:
      self.n542 = 0L
    if self.n512 == self.n500:
      self.n541 = 1L
    else:
      self.n541 = 0L
    if self.n512 == self.n499:
      self.n540 = 1L
    else:
      self.n540 = 0L
    if self.n512 == self.n489:
      self.n522 = 1L
    else:
      self.n522 = 0L
    if self.n512 == self.n488:
      self.n521 = 1L
    else:
      self.n521 = 0L
    if self.n512 == self.n487:
      self.n520 = 1L
    else:
      self.n520 = 0L
    if self.n512 == self.n486:
      self.n519 = 1L
    else:
      self.n519 = 0L
    if self.n512 == self.n485:
      self.n518 = 1L
    else:
      self.n518 = 0L
    if self.n512 == self.n484:
      self.n517 = 1L
    else:
      self.n517 = 0L
    if self.n512 == self.n483:
      self.n516 = 1L
    else:
      self.n516 = 0L
    if self.n512 == self.n482:
      self.n515 = 1L
    else:
      self.n515 = 0L
    if self.n512 == self.n481:
      self.n514 = 1L
    else:
      self.n514 = 0L
    if self.n512 == self.n480:
      self.n513 = 1L
    else:
      self.n513 = 0L
    self.n347 = self.n340 << 5 | self.n346
    if self.n115 == self.n193:
      self.n194 = 1L
    else:
      self.n194 = 0L
    if self.n115 == self.n191:
      self.n192 = 1L
    else:
      self.n192 = 0L
    if self.n115 == self.n189:
      self.n190 = 1L
    else:
      self.n190 = 0L
    if self.n115 == self.n187:
      self.n188 = 1L
    else:
      self.n188 = 0L
    if self.n115 == self.n185:
      self.n186 = 1L
    else:
      self.n186 = 0L
    if self.n115 == self.n183:
      self.n184 = 1L
    else:
      self.n184 = 0L
    if self.n115 == self.n181:
      self.n182 = 1L
    else:
      self.n182 = 0L
    if self.n115 == self.n179:
      self.n180 = 1L
    else:
      self.n180 = 0L
    if self.n115 == self.n177:
      self.n178 = 1L
    else:
      self.n178 = 0L
    if self.n115 == self.n175:
      self.n176 = 1L
    else:
      self.n176 = 0L
    if self.n115 == self.n173:
      self.n174 = 1L
    else:
      self.n174 = 0L
    if self.n115 == self.n171:
      self.n172 = 1L
    else:
      self.n172 = 0L
    if self.n115 == self.n169:
      self.n170 = 1L
    else:
      self.n170 = 0L
    if self.n115 == self.n167:
      self.n168 = 1L
    else:
      self.n168 = 0L
    if self.n115 == self.n165:
      self.n166 = 1L
    else:
      self.n166 = 0L
    if self.n115 == self.n163:
      self.n164 = 1L
    else:
      self.n164 = 0L
    if self.n115 == self.n161:
      self.n162 = 1L
    else:
      self.n162 = 0L
    if self.n115 == self.n159:
      self.n160 = 1L
    else:
      self.n160 = 0L
    if self.n115 == self.n157:
      self.n158 = 1L
    else:
      self.n158 = 0L
    if self.n115 == self.n155:
      self.n156 = 1L
    else:
      self.n156 = 0L
    if self.n115 == self.n153:
      self.n154 = 1L
    else:
      self.n154 = 0L
    if self.n115 == self.n151:
      self.n152 = 1L
    else:
      self.n152 = 0L
    if self.n115 == self.n149:
      self.n150 = 1L
    else:
      self.n150 = 0L
    if self.n115 == self.n147:
      self.n148 = 1L
    else:
      self.n148 = 0L
    if self.n115 == self.n145:
      self.n146 = 1L
    else:
      self.n146 = 0L
    if self.n115 == self.n143:
      self.n144 = 1L
    else:
      self.n144 = 0L
    if self.n115 == self.n141:
      self.n142 = 1L
    else:
      self.n142 = 0L
    if self.n115 == self.n139:
      self.n140 = 1L
    else:
      self.n140 = 0L
    if self.n115 == self.n137:
      self.n138 = 1L
    else:
      self.n138 = 0L
    if self.n115 == self.n135:
      self.n136 = 1L
    else:
      self.n136 = 0L
    if self.n115 == self.n133:
      self.n134 = 1L
    else:
      self.n134 = 0L
    if self.n68:
      self.n81 = self.n42
    else:
      self.n81 = self.n80
    if self.n543:
      self.n558 = self.n497
    else:
      self.n558 = self.n612
    if self.n522:
      self.n525 = self.n473
    else:
      self.n525 = self.n603
    self.n348 = self.n340 << 6 | self.n347
    if self.n194:
      self.n195 = self.n117
    else:
      self.n195 = self.n116
    self.n86r = self.n2
    self.n86e = self.n1
    self.n86d = self.n81
    if self.n542:
      self.n559 = self.n497
    else:
      self.n559 = self.n558
    if self.n521:
      self.n526 = self.n474
    else:
      self.n526 = self.n525
    self.n349 = self.n339 << 7 | self.n348
    if self.n192:
      self.n196 = self.n118
    else:
      self.n196 = self.n195
    if self.n541:
      self.n560 = self.n498
    else:
      self.n560 = self.n559
    if self.n520:
      self.n527 = self.n475
    else:
      self.n527 = self.n526
    if self.n357:
      self.n358 = self.n349
    else:
      self.n358 = self.n352
    if self.n190:
      self.n197 = self.n119
    else:
      self.n197 = self.n196
    if self.n540:
      self.n561 = self.n498
    else:
      self.n561 = self.n560
    if self.n519:
      self.n528 = self.n475
    else:
      self.n528 = self.n527
    if self.n375:
      self.n377 = self.n359
    else:
      self.n377 = self.n358
    if self.n188:
      self.n198 = self.n120
    else:
      self.n198 = self.n197
    done_o = self.n561
    self.n562 = self.n561
    if self.n518:
      self.n529 = self.n476
    else:
      self.n529 = self.n528
    if self.n381:
      self.n382 = self.n377
    else:
      self.n382 = self.n376
    if self.n186:
      self.n199 = self.n121
    else:
      self.n199 = self.n198
    if self.n517:
      self.n530 = self.n477
    else:
      self.n530 = self.n529
    if self.n385:
      self.n386 = self.n383
    else:
      self.n386 = self.n382
    if self.n184:
      self.n200 = self.n122
    else:
      self.n200 = self.n199
    if self.n516:
      self.n531 = self.n478
    else:
      self.n531 = self.n530
    if self.n7:
      self.n395 = self.n9
    else:
      self.n395 = self.n386
    if self.n182:
      self.n201 = self.n123
    else:
      self.n201 = self.n200
    if self.n515:
      self.n532 = self.n478
    else:
      self.n532 = self.n531
    if self.n180:
      self.n202 = self.n124
    else:
      self.n202 = self.n201
    if self.n514:
      self.n533 = self.n479
    else:
      self.n533 = self.n532
    if self.n178:
      self.n203 = self.n125
    else:
      self.n203 = self.n202
    if self.n513:
      self.n534 = self.n479
    else:
      self.n534 = self.n533
    if self.n176:
      self.n204 = self.n126
    else:
      self.n204 = self.n203
    self.n539r = self.n2
    self.n539e = self.n1
    self.n539d = self.n534
    if self.n174:
      self.n205 = self.n127
    else:
      self.n205 = self.n204
    if self.n172:
      self.n206 = self.n128
    else:
      self.n206 = self.n205
    if self.n170:
      self.n207 = self.n129
    else:
      self.n207 = self.n206
    if self.n168:
      self.n208 = self.n130
    else:
      self.n208 = self.n207
    if self.n166:
      self.n209 = self.n131
    else:
      self.n209 = self.n208
    if self.n164:
      self.n210 = self.n132
    else:
      self.n210 = self.n209
    if self.n162:
      self.n211 = self.n132
    else:
      self.n211 = self.n210
    if self.n160:
      self.n212 = self.n132
    else:
      self.n212 = self.n211
    if self.n158:
      self.n213 = self.n132
    else:
      self.n213 = self.n212
    if self.n156:
      self.n214 = self.n132
    else:
      self.n214 = self.n213
    if self.n154:
      self.n215 = self.n132
    else:
      self.n215 = self.n214
    if self.n152:
      self.n216 = self.n132
    else:
      self.n216 = self.n215
    if self.n150:
      self.n217 = self.n132
    else:
      self.n217 = self.n216
    if self.n148:
      self.n218 = self.n132
    else:
      self.n218 = self.n217
    if self.n146:
      self.n219 = self.n132
    else:
      self.n219 = self.n218
    if self.n144:
      self.n220 = self.n132
    else:
      self.n220 = self.n219
    if self.n142:
      self.n221 = self.n132
    else:
      self.n221 = self.n220
    if self.n140:
      self.n222 = self.n132
    else:
      self.n222 = self.n221
    if self.n138:
      self.n223 = self.n132
    else:
      self.n223 = self.n222
    if self.n136:
      self.n224 = self.n132
    else:
      self.n224 = self.n223
    if self.n134:
      self.n225 = self.n132
    else:
      self.n225 = self.n224
    self.n269 = ((self.n225 & 0x8000L) >> 15)
    self.n266 = ((self.n225 & 0x4000L) >> 14)
    self.n263 = ((self.n225 & 0x2000L) >> 13)
    self.n260 = ((self.n225 & 0x1000L) >> 12)
    self.n257 = ((self.n225 & 0x800L) >> 11)
    self.n254 = ((self.n225 & 0x400L) >> 10)
    self.n251 = ((self.n225 & 0x200L) >> 9)
    self.n248 = ((self.n225 & 0x100L) >> 8)
    self.n245 = ((self.n225 & 0x80L) >> 7)
    self.n242 = ((self.n225 & 0x40L) >> 6)
    self.n239 = ((self.n225 & 0x20L) >> 5)
    self.n236 = ((self.n225 & 0x10L) >> 4)
    self.n233 = ((self.n225 & 0x8L) >> 3)
    self.n230 = ((self.n225 & 0x4L) >> 2)
    self.n227 = ((self.n225 & 0x2L) >> 1)
    self.n470r = self.n4
    self.n470e = self.n269
    self.n470d = self.n395
    self.n465r = self.n4
    self.n465e = self.n266
    self.n465d = self.n395
    self.n460r = self.n4
    self.n460e = self.n263
    self.n460d = self.n395
    self.n455r = self.n4
    self.n455e = self.n260
    self.n455d = self.n395
    self.n450r = self.n4
    self.n450e = self.n257
    self.n450d = self.n395
    self.n445r = self.n4
    self.n445e = self.n254
    self.n445d = self.n395
    self.n440r = self.n4
    self.n440e = self.n251
    self.n440d = self.n395
    self.n435r = self.n4
    self.n435e = self.n248
    self.n435d = self.n395
    self.n430r = self.n4
    self.n430e = self.n245
    self.n430d = self.n395
    self.n425r = self.n4
    self.n425e = self.n242
    self.n425d = self.n395
    self.n420r = self.n4
    self.n420e = self.n239
    self.n420d = self.n395
    self.n415r = self.n4
    self.n415e = self.n236
    self.n415d = self.n395
    self.n410r = self.n4
    self.n410e = self.n233
    self.n410d = self.n395
    self.n405r = self.n4
    self.n405e = self.n230
    self.n405d = self.n395
    self.n400r = self.n4
    self.n400e = self.n227
    self.n400d = self.n395
    return (done_o, instr_addr_o, const_addr_o, reg_0_o, reg_1_o, reg_2_o, reg_3_o, reg_4_o, reg_5_o, reg_6_o, reg_7_o, reg_8_o, reg_9_o, reg_a_o, reg_b_o, reg_c_o, reg_d_o, reg_e_o, reg_f_o, )

  def cycle_clock(self):
    if self.n18r:
      self.n18 = 0L
    elif self.n18e:
        self.n18 = self.n18d
    if self.n25r:
      self.n25 = 0L
    elif self.n25e:
        self.n25 = self.n25d
    if self.n32r:
      self.n32 = 0L
    elif self.n32e:
        self.n32 = self.n32d
    if self.n86r:
      self.n86 = 0L
    elif self.n86e:
        self.n86 = self.n86d
    if self.n111r:
      self.n111 = 0L
    elif self.n111e:
        self.n111 = self.n111d
    if self.n278r:
      self.n278 = 0L
    elif self.n278e:
        self.n278 = self.n278d
    if self.n308r:
      self.n308 = 0L
    elif self.n308e:
        self.n308 = self.n308d
    if self.n338r:
      self.n338 = 0L
    elif self.n338e:
        self.n338 = self.n338d
    if self.n394r:
      self.n394 = 0L
    elif self.n394e:
        self.n394 = self.n394d
    if self.n400r:
      self.n400 = 0L
    elif self.n400e:
        self.n400 = self.n400d
    if self.n405r:
      self.n405 = 0L
    elif self.n405e:
        self.n405 = self.n405d
    if self.n410r:
      self.n410 = 0L
    elif self.n410e:
        self.n410 = self.n410d
    if self.n415r:
      self.n415 = 0L
    elif self.n415e:
        self.n415 = self.n415d
    if self.n420r:
      self.n420 = 0L
    elif self.n420e:
        self.n420 = self.n420d
    if self.n425r:
      self.n425 = 0L
    elif self.n425e:
        self.n425 = self.n425d
    if self.n430r:
      self.n430 = 0L
    elif self.n430e:
        self.n430 = self.n430d
    if self.n435r:
      self.n435 = 0L
    elif self.n435e:
        self.n435 = self.n435d
    if self.n440r:
      self.n440 = 0L
    elif self.n440e:
        self.n440 = self.n440d
    if self.n445r:
      self.n445 = 0L
    elif self.n445e:
        self.n445 = self.n445d
    if self.n450r:
      self.n450 = 0L
    elif self.n450e:
        self.n450 = self.n450d
    if self.n455r:
      self.n455 = 0L
    elif self.n455e:
        self.n455 = self.n455d
    if self.n460r:
      self.n460 = 0L
    elif self.n460e:
        self.n460 = self.n460d
    if self.n465r:
      self.n465 = 0L
    elif self.n465e:
        self.n465 = self.n465d
    if self.n470r:
      self.n470 = 0L
    elif self.n470e:
        self.n470 = self.n470d
    if self.n539r:
      self.n539 = 0L
    elif self.n539e:
        self.n539 = self.n539d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n4 = self.n4
    self.sim_n3 = self.n3
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n8 = self.n8
    self.sim_n9 = self.n9
    self.sim_n562 = self.n562
    self.sim_n563 = self.n563
    self.sim_n564 = self.n564
    self.sim_n565 = self.n565
    self.sim_n566 = self.n566
    self.sim_n567 = self.n567
    self.sim_n568 = self.n568
    self.sim_n569 = self.n569
    self.sim_n570 = self.n570
    self.sim_n571 = self.n571
    self.sim_n572 = self.n572
    self.sim_n573 = self.n573
    self.sim_n574 = self.n574
    self.sim_n575 = self.n575
    self.sim_n576 = self.n576
    self.sim_n577 = self.n577
    self.sim_n578 = self.n578
    self.sim_n579 = self.n579
    self.sim_n580 = self.n580
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_ssp_8_10 $end\n")
    self.sim_file.write("$var wire 1 ! reset_state_i $end\n")
    self.sim_file.write("$var wire 1 \" cycle_i $end\n")
    self.sim_file.write("$var wire 16 # instr_data_i $end\n")
    self.sim_file.write("$var wire 8 $ const_data_i $end\n")
    self.sim_file.write("$var wire 1 % load_write_i $end\n")
    self.sim_file.write("$var wire 4 & load_addr_i $end\n")
    self.sim_file.write("$var wire 8 ' load_data_i $end\n")
    self.sim_file.write("$var wire 1 ( done_o $end\n")
    self.sim_file.write("$var wire 10 ) instr_addr_o $end\n")
    self.sim_file.write("$var wire 8 * const_addr_o $end\n")
    self.sim_file.write("$var wire 8 + reg_0_o $end\n")
    self.sim_file.write("$var wire 8 , reg_1_o $end\n")
    self.sim_file.write("$var wire 8 - reg_2_o $end\n")
    self.sim_file.write("$var wire 8 . reg_3_o $end\n")
    self.sim_file.write("$var wire 8 / reg_4_o $end\n")
    self.sim_file.write("$var wire 8 0 reg_5_o $end\n")
    self.sim_file.write("$var wire 8 1 reg_6_o $end\n")
    self.sim_file.write("$var wire 8 2 reg_7_o $end\n")
    self.sim_file.write("$var wire 8 3 reg_8_o $end\n")
    self.sim_file.write("$var wire 8 4 reg_9_o $end\n")
    self.sim_file.write("$var wire 8 5 reg_a_o $end\n")
    self.sim_file.write("$var wire 8 6 reg_b_o $end\n")
    self.sim_file.write("$var wire 8 7 reg_c_o $end\n")
    self.sim_file.write("$var wire 8 8 reg_d_o $end\n")
    self.sim_file.write("$var wire 8 9 reg_e_o $end\n")
    self.sim_file.write("$var wire 8 : reg_f_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n4:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    if self.n3:
      self.sim_file.write("1\"\n")
    else:
      self.sim_file.write("0\"\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    if self.n7:
      self.sim_file.write("1%\n")
    else:
      self.sim_file.write("0%\n")
    found = 0
    for bit in range(3, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n9 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n9 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    if self.n562:
      self.sim_file.write("1(\n")
    else:
      self.sim_file.write("0(\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n563 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n563 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" )\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n564 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n564 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" *\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n565 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n565 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" +\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n566 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n566 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ,\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n567 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n567 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" -\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n568 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n568 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" .\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n569 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n569 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" /\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n570 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n570 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 0\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n571 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n571 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 1\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n572 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n572 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 2\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n573 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n573 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 3\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n574 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n574 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 4\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n575 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n575 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 5\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n576 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n576 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 6\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n577 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n577 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 7\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n578 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n578 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 8\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n579 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n579 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 9\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n580 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n580 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" :\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n4:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n4 = self.n4
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1\"\n")
      else:
        self.sim_file.write("0\"\n")
      self.sim_n3 = self.n3
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n7:
        self.sim_file.write("1%\n")
      else:
        self.sim_file.write("0%\n")
      self.sim_n7 = self.n7
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(3, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n8 = self.n8
    if self.sim_n9 != self.n9:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n9 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n9 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n9 = self.n9
    if self.sim_n562 != self.n562:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n562:
        self.sim_file.write("1(\n")
      else:
        self.sim_file.write("0(\n")
      self.sim_n562 = self.n562
    if self.sim_n563 != self.n563:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n563 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n563 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" )\n")
      self.sim_n563 = self.n563
    if self.sim_n564 != self.n564:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n564 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n564 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" *\n")
      self.sim_n564 = self.n564
    if self.sim_n565 != self.n565:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n565 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n565 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" +\n")
      self.sim_n565 = self.n565
    if self.sim_n566 != self.n566:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n566 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n566 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ,\n")
      self.sim_n566 = self.n566
    if self.sim_n567 != self.n567:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n567 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n567 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" -\n")
      self.sim_n567 = self.n567
    if self.sim_n568 != self.n568:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n568 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n568 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" .\n")
      self.sim_n568 = self.n568
    if self.sim_n569 != self.n569:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n569 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n569 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" /\n")
      self.sim_n569 = self.n569
    if self.sim_n570 != self.n570:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n570 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n570 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 0\n")
      self.sim_n570 = self.n570
    if self.sim_n571 != self.n571:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n571 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n571 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 1\n")
      self.sim_n571 = self.n571
    if self.sim_n572 != self.n572:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n572 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n572 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 2\n")
      self.sim_n572 = self.n572
    if self.sim_n573 != self.n573:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n573 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n573 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 3\n")
      self.sim_n573 = self.n573
    if self.sim_n574 != self.n574:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n574 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n574 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 4\n")
      self.sim_n574 = self.n574
    if self.sim_n575 != self.n575:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n575 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n575 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 5\n")
      self.sim_n575 = self.n575
    if self.sim_n576 != self.n576:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n576 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n576 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 6\n")
      self.sim_n576 = self.n576
    if self.sim_n577 != self.n577:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n577 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n577 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 7\n")
      self.sim_n577 = self.n577
    if self.sim_n578 != self.n578:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n578 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n578 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 8\n")
      self.sim_n578 = self.n578
    if self.sim_n579 != self.n579:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n579 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n579 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 9\n")
      self.sim_n579 = self.n579
    if self.sim_n580 != self.n580:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n580 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n580 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" :\n")
      self.sim_n580 = self.n580
    self.sim_count = self.sim_count + 1

