//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    State Space Processor is used for implementing discrete (digital) linear systems, such as
//    finite impulse response filters, infinite impulse response filters, multiple input and output
//    systems, and general state space equations.
//  
//  Architecture:
//  
//    The State Space Processor is designed with a small logic footprint for area limited
//    applications.  The processor requires two external memories: one for program instructions
//    and the other for constants (coefficients) used in calculation.  The processor maintains a
//    register file of 16 N-bit registers used to retain state information and for processing intermediate
//    results.  The register file is also used for handling input and output; registers can be written
//    from an external source and all registers are available as outputs.  For convenience, register 0
//    is wired to ground (0) and instructions updating r0 have no effect on the register file.
//  
//    The processor runs calculations on a cycle basis:
//      1. The external environment writes inputs into the register file.
//      2. The external environment signals a "Cycle" to run the program and calculate a cycle.
//      3. The external environment waits for "Done", then reads output from the register file.
//  
//  Instruction Set:
//  
//    There are 4 instruction types and a total of 8 instructions.  Each instruction is 16-bits.
//    The types include:
//      Unary Operation  : OpCode [15:12], Operand Reg A [11:8], Not Used [7:4], Result Reg X [3:0]
//      Binary Operation : OpCode [15:12], Operand Reg A [11:8], Operand Reg B [7:4], Result Reg X [3:0]
//      Constant Load    : OpCode [15:12], Constant Memory Address [11:4], Result Reg X [3:0]
//      Halt             : OpCode [15:12], Not Used [11:0]
//  
//    Unary Operations (OpCode):
//  
//      ShiftLeft  (0000) : RegX <- lsbs RegA '++' '0'
//                          Flag <- Flag
//      ShiftRight (0001) : RegX <- msb RegA '++' msbs RegA
//                          Flag <- lsb RegA
//      ShiftClip  (0010) : RegX <- lsbs RegA '++' '0' when top 2 bits of RegA == '00' or '11' else
//                                  '0111...1'         when top 2 bits of RegA == '01'         else
//                                  '1000...0'         when top 2 bits of RegA == '10'
//                          Flag <- Flag
//                          Performs a limited/clipped multiplication by 2.
//  
//    Binary Operations (OpCode):
//  
//      Add        (0011) : RegX <- RegA '+' RegB
//                          Flag <- msb Result
//      AddCond    (0100) : RegX <- RegA '+' RegB when Flag == '1' else RegA
//                          Flag <- Flag
//      Sub        (0101) : RegX <- RegA '-' RegB
//                          Flag <- msb Result
//      Switch     (0110) : RegX <- RegA when Flag == '1' else RegB
//                          Flag <- Flag
//  
//    Constant Load Instruction (OpCode):
//  
//      Constant   (0111) : RegX <- Data from constant memory.
//                          Flag <- Flag
//  
//    Halt Instruction (OpCode):
//  
//      Halt       (1---) : Halts processor (prevents further register updates).
//  
//    Booth multiplication can be performed using ShiftRight and AddCond with an accumulation register.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_state_i : Reset all state registers (register file and ALU flag).
//  
//    Inputs:
//      cycle_i      : Input pulse to perform a cycle (sample) calculation.
//      instr_data_i : Instruction data from instruction memory.
//      const_data_i : Constant data from constant memory.
//      load_write_i : Write enable for writing to register file.
//      load_addr_i  : Address (4-bits) for writing to register file.
//      load_data_i  : Data for writing to register file.
//  
//    Outputs:
//      done_o       : Output flag signaling processor is done calculating cycle (active high).
//      instr_addr_o : Address to instruction memory.
//      const_addr_o : Address to constant memory (8-bits).
//      reg_0_o      : Register 0 value.
//      reg_1_o      : Register 1 value.
//      ...
//      reg_f_o      : Register F value.
//  
//  Built In Parameters:
//  
//    Data Width                = 64
//    Instruction Address Width = 6
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:50:45 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_ssp_64_6
//    Clock Domains : clock_c  
//    Vector Input  : reset_state_i(1)
//    Vector Input  : cycle_i(1)
//    Vector Input  : instr_data_i(16)
//    Vector Input  : const_data_i(64)
//    Vector Input  : load_write_i(1)
//    Vector Input  : load_addr_i(4)
//    Vector Input  : load_data_i(64)
//    Vector Output : done_o(1)
//    Vector Output : instr_addr_o(6)
//    Vector Output : const_addr_o(8)
//    Vector Output : reg_0_o(64)
//    Vector Output : reg_1_o(64)
//    Vector Output : reg_2_o(64)
//    Vector Output : reg_3_o(64)
//    Vector Output : reg_4_o(64)
//    Vector Output : reg_5_o(64)
//    Vector Output : reg_6_o(64)
//    Vector Output : reg_7_o(64)
//    Vector Output : reg_8_o(64)
//    Vector Output : reg_9_o(64)
//    Vector Output : reg_a_o(64)
//    Vector Output : reg_b_o(64)
//    Vector Output : reg_c_o(64)
//    Vector Output : reg_d_o(64)
//    Vector Output : reg_e_o(64)
//    Vector Output : reg_f_o(64)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_ssp_64_6.h"

static unsigned char n668[1];
static unsigned char n659[1];
static unsigned char n658[1];
static unsigned char *reg_f_o;
static unsigned char *reg_e_o;
static unsigned char *reg_d_o;
static unsigned char *reg_c_o;
static unsigned char *reg_b_o;
static unsigned char *reg_a_o;
static unsigned char *reg_9_o;
static unsigned char *reg_8_o;
static unsigned char *reg_7_o;
static unsigned char *reg_6_o;
static unsigned char *reg_5_o;
static unsigned char *reg_4_o;
static unsigned char *reg_3_o;
static unsigned char *reg_2_o;
static unsigned char *reg_1_o;
static unsigned char *instr_addr_o;
static unsigned char n558[1];
static unsigned char n557[1];
static unsigned char n556[1];
static unsigned char n555[1];
static unsigned char n554[1];
static unsigned char n553[1];
static unsigned char n545[1];
static unsigned char n544[1];
static unsigned char n543[1];
static unsigned char n542[1];
static unsigned char n541[1];
static unsigned char n540[1];
static unsigned char n539[1];
static unsigned char n538[1];
static unsigned char n537[1];
static unsigned char n536[1];
static unsigned char n535[1];
static unsigned char n534[1];
static unsigned char n533[1];
static unsigned char n532[1];
static unsigned char n531[1];
static unsigned char n530[1];
static unsigned char n529[1];
static unsigned char n431[1];
static unsigned char n430[1];
static unsigned char n423[1];
static unsigned char n420[1];
static unsigned char n417[1];
static unsigned char n407[1];
static unsigned char n310[1];
static unsigned char n309[1];
static unsigned char n280[1];
static unsigned char n279[1];
static unsigned char n226[8];
static unsigned char n193[1];
static unsigned char n191[1];
static unsigned char n189[1];
static unsigned char n187[1];
static unsigned char n185[1];
static unsigned char n183[1];
static unsigned char n181[1];
static unsigned char n179[1];
static unsigned char n177[1];
static unsigned char n175[1];
static unsigned char n173[1];
static unsigned char n171[1];
static unsigned char n169[1];
static unsigned char n167[1];
static unsigned char n165[1];
static unsigned char n163[1];
static unsigned char n161[1];
static unsigned char n159[1];
static unsigned char n157[1];
static unsigned char n155[1];
static unsigned char n153[1];
static unsigned char n151[1];
static unsigned char n149[1];
static unsigned char n147[1];
static unsigned char n145[1];
static unsigned char n143[1];
static unsigned char n141[1];
static unsigned char n139[1];
static unsigned char n137[1];
static unsigned char n135[1];
static unsigned char n133[1];
static unsigned char n132[2];
static unsigned char n131[2];
static unsigned char n130[2];
static unsigned char n129[2];
static unsigned char n128[2];
static unsigned char n127[2];
static unsigned char n126[2];
static unsigned char n125[2];
static unsigned char n124[2];
static unsigned char n123[2];
static unsigned char n122[2];
static unsigned char n121[2];
static unsigned char n120[2];
static unsigned char n119[2];
static unsigned char n118[2];
static unsigned char n117[2];
static unsigned char n116[2];
static unsigned char n61[1];
static unsigned char n60[1];
static unsigned char n59[1];
static unsigned char n58[1];
static unsigned char n57[1];
static unsigned char n56[1];
static unsigned char n55[1];
static unsigned char n54[1];
static unsigned char n49[1];
static unsigned char n48[1];
static unsigned char n47[1];
static unsigned char n46[1];
static unsigned char n45[1];
static unsigned char n44[1];
static unsigned char n43[1];
static unsigned char n42[1];
static unsigned char n41[1];
static unsigned char n40[1];
static unsigned char n39[1];
static unsigned char n38[1];
static unsigned char n37[1];
static unsigned char n36[1];
static unsigned char n35[1];
static unsigned char n10[1];
static unsigned char *load_data_i;
static unsigned char *load_addr_i;
static unsigned char *load_write_i;
static unsigned char *const_data_i;
static unsigned char *instr_data_i;
static unsigned char *reset_state_i;
static unsigned char *cycle_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char *reg_0_o;
static unsigned char n437[1];
static unsigned char n436[1];
static unsigned char n424[1];
static unsigned char n421[1];
static unsigned char n418[1];
static unsigned char n320[1];
static unsigned char n319[1];
static unsigned char n318[8];
static unsigned char n317[8];
static unsigned char n316[8];
static unsigned char n315[8];
static unsigned char n314[8];
static unsigned char n313[8];
static unsigned char n312[8];
static unsigned char n311[8];
static unsigned char n290[1];
static unsigned char n289[1];
static unsigned char n288[8];
static unsigned char n287[8];
static unsigned char n286[8];
static unsigned char n285[8];
static unsigned char n284[8];
static unsigned char n283[8];
static unsigned char n282[8];
static unsigned char n281[8];
static unsigned char n114[1];
static unsigned char n112[1];
static unsigned char n104[1];
static unsigned char n103[1];
static unsigned char n102[1];
static unsigned char n101[1];
static unsigned char n33[1];
static unsigned char n32[1];
static unsigned char n32r[1];
static unsigned char n32e[1];
static unsigned char n32d[1];
static unsigned char n25[1];
static unsigned char n25r[1];
static unsigned char n25e[1];
static unsigned char n25d[1];
static unsigned char n13[1];
static unsigned char *const_addr_o;
static unsigned char n441[1];
static unsigned char n338[1];
static unsigned char n338r[1];
static unsigned char n338e[1];
static unsigned char n338d[1];
static unsigned char n326[1];
static unsigned char n325[1];
static unsigned char n324[8];
static unsigned char n323[8];
static unsigned char n322[8];
static unsigned char n321[8];
static unsigned char n308[1];
static unsigned char n308r[1];
static unsigned char n308e[1];
static unsigned char n308d[1];
static unsigned char n296[1];
static unsigned char n295[1];
static unsigned char n294[8];
static unsigned char n293[8];
static unsigned char n292[8];
static unsigned char n291[8];
static unsigned char n278[1];
static unsigned char n278r[1];
static unsigned char n278e[1];
static unsigned char n278d[1];
static unsigned char n111[1];
static unsigned char n111r[1];
static unsigned char n111e[1];
static unsigned char n111d[1];
static unsigned char n34[1];
static unsigned char n18[1];
static unsigned char n18r[1];
static unsigned char n18e[1];
static unsigned char n18d[1];
static unsigned char n330[1];
static unsigned char n328[8];
static unsigned char n327[8];
static unsigned char n300[1];
static unsigned char n298[8];
static unsigned char n297[8];
static unsigned char n67[1];
static unsigned char n331[8];
static unsigned char n301[8];
static unsigned char n90[1];
static unsigned char n89[1];
static unsigned char n88[1];
static unsigned char n87[1];
static unsigned char n74[1];
static unsigned char n73[1];
static unsigned char n72[1];
static unsigned char n71[1];
static unsigned char n70[1];
static unsigned char n69[1];
static unsigned char n68[1];
static unsigned char n429[8];
static unsigned char n419[1];
static unsigned char n416[8];
static unsigned char n415[8];
static unsigned char n412[1];
static unsigned char n410[8];
static unsigned char n409[1];
static unsigned char n406[8];
static unsigned char n339[1];
static unsigned char n97[1];
static unsigned char n75[1];
static unsigned char n435[8];
static unsigned char n428[8];
static unsigned char n425[1];
static unsigned char n422[1];
static unsigned char n413[1];
static unsigned char n411[8];
static unsigned char n408[8];
static unsigned char n340[1];
static unsigned char n98[1];
static unsigned char n76[1];
static unsigned char n443[1];
static unsigned char n434[8];
static unsigned char n432[8];
static unsigned char n343[1];
static unsigned char n99[1];
static unsigned char n77[1];
static unsigned char n444[1];
static unsigned char n439[8];
static unsigned char n344[1];
static unsigned char n100[1];
static unsigned char n78[1];
static unsigned char n527[1];
static unsigned char n445[1];
static unsigned char n345[1];
static unsigned char n113[1];
static unsigned char n79[1];
static unsigned char n568[1];
static unsigned char n450[1];
static unsigned char n450r[1];
static unsigned char n450e[1];
static unsigned char n450d[1];
static unsigned char n346[1];
static unsigned char n115[1];
static unsigned char n80[1];
static unsigned char n599[1];
static unsigned char n598[1];
static unsigned char n597[1];
static unsigned char n596[1];
static unsigned char n578[1];
static unsigned char n577[1];
static unsigned char n576[1];
static unsigned char n575[1];
static unsigned char n574[1];
static unsigned char n573[1];
static unsigned char n572[1];
static unsigned char n571[1];
static unsigned char n570[1];
static unsigned char n569[1];
static unsigned char n347[1];
static unsigned char n194[1];
static unsigned char n192[1];
static unsigned char n190[1];
static unsigned char n188[1];
static unsigned char n186[1];
static unsigned char n184[1];
static unsigned char n182[1];
static unsigned char n180[1];
static unsigned char n178[1];
static unsigned char n176[1];
static unsigned char n174[1];
static unsigned char n172[1];
static unsigned char n170[1];
static unsigned char n168[1];
static unsigned char n166[1];
static unsigned char n164[1];
static unsigned char n162[1];
static unsigned char n160[1];
static unsigned char n158[1];
static unsigned char n156[1];
static unsigned char n154[1];
static unsigned char n152[1];
static unsigned char n150[1];
static unsigned char n148[1];
static unsigned char n146[1];
static unsigned char n144[1];
static unsigned char n142[1];
static unsigned char n140[1];
static unsigned char n138[1];
static unsigned char n136[1];
static unsigned char n134[1];
static unsigned char n81[1];
static unsigned char n614[1];
static unsigned char n581[1];
static unsigned char n348[1];
static unsigned char n195[2];
static unsigned char n86[1];
static unsigned char n86r[1];
static unsigned char n86e[1];
static unsigned char n86d[1];
static unsigned char n615[1];
static unsigned char n582[1];
static unsigned char n349[1];
static unsigned char n196[2];
static unsigned char n616[1];
static unsigned char n583[1];
static unsigned char n350[2];
static unsigned char n197[2];
static unsigned char n617[1];
static unsigned char n584[1];
static unsigned char n351[2];
static unsigned char n198[2];
static unsigned char *done_o;
static unsigned char n585[1];
static unsigned char n352[2];
static unsigned char n199[2];
static unsigned char n586[1];
static unsigned char n353[2];
static unsigned char n200[2];
static unsigned char n587[1];
static unsigned char n354[2];
static unsigned char n201[2];
static unsigned char n588[1];
static unsigned char n355[2];
static unsigned char n202[2];
static unsigned char n589[1];
static unsigned char n356[2];
static unsigned char n203[2];
static unsigned char n590[1];
static unsigned char n357[2];
static unsigned char n204[2];
static unsigned char n595[1];
static unsigned char n595r[1];
static unsigned char n595e[1];
static unsigned char n595d[1];
static unsigned char n358[3];
static unsigned char n205[2];
static unsigned char n359[3];
static unsigned char n206[2];
static unsigned char n360[3];
static unsigned char n207[2];
static unsigned char n361[3];
static unsigned char n208[2];
static unsigned char n362[3];
static unsigned char n209[2];
static unsigned char n363[3];
static unsigned char n210[2];
static unsigned char n364[3];
static unsigned char n211[2];
static unsigned char n365[3];
static unsigned char n212[2];
static unsigned char n366[4];
static unsigned char n213[2];
static unsigned char n367[4];
static unsigned char n214[2];
static unsigned char n368[4];
static unsigned char n215[2];
static unsigned char n369[4];
static unsigned char n216[2];
static unsigned char n370[4];
static unsigned char n217[2];
static unsigned char n371[4];
static unsigned char n218[2];
static unsigned char n372[4];
static unsigned char n219[2];
static unsigned char n373[4];
static unsigned char n220[2];
static unsigned char n374[5];
static unsigned char n221[2];
static unsigned char n375[5];
static unsigned char n222[2];
static unsigned char n376[5];
static unsigned char n223[2];
static unsigned char n377[5];
static unsigned char n224[2];
static unsigned char n378[5];
static unsigned char n225[2];
static unsigned char n379[5];
static unsigned char n269[1];
static unsigned char n266[1];
static unsigned char n263[1];
static unsigned char n260[1];
static unsigned char n257[1];
static unsigned char n254[1];
static unsigned char n251[1];
static unsigned char n248[1];
static unsigned char n245[1];
static unsigned char n242[1];
static unsigned char n239[1];
static unsigned char n236[1];
static unsigned char n233[1];
static unsigned char n230[1];
static unsigned char n227[1];
static unsigned char n380[5];
static unsigned char n381[5];
static unsigned char n382[6];
static unsigned char n383[6];
static unsigned char n384[6];
static unsigned char n385[6];
static unsigned char n386[6];
static unsigned char n387[6];
static unsigned char n388[6];
static unsigned char n389[6];
static unsigned char n390[7];
static unsigned char n391[7];
static unsigned char n392[7];
static unsigned char n393[7];
static unsigned char n394[7];
static unsigned char n395[7];
static unsigned char n396[7];
static unsigned char n397[7];
static unsigned char n398[8];
static unsigned char n399[8];
static unsigned char n400[8];
static unsigned char n401[8];
static unsigned char n402[8];
static unsigned char n403[8];
static unsigned char n404[8];
static unsigned char n405[8];
static unsigned char n414[8];
static unsigned char n433[8];
static unsigned char n438[8];
static unsigned char n442[8];
static unsigned char n451[8];
static unsigned char n526[8];
static unsigned char n526r[1];
static unsigned char n526e[1];
static unsigned char n526d[8];
static unsigned char n521[8];
static unsigned char n521r[1];
static unsigned char n521e[1];
static unsigned char n521d[8];
static unsigned char n516[8];
static unsigned char n516r[1];
static unsigned char n516e[1];
static unsigned char n516d[8];
static unsigned char n511[8];
static unsigned char n511r[1];
static unsigned char n511e[1];
static unsigned char n511d[8];
static unsigned char n506[8];
static unsigned char n506r[1];
static unsigned char n506e[1];
static unsigned char n506d[8];
static unsigned char n501[8];
static unsigned char n501r[1];
static unsigned char n501e[1];
static unsigned char n501d[8];
static unsigned char n496[8];
static unsigned char n496r[1];
static unsigned char n496e[1];
static unsigned char n496d[8];
static unsigned char n491[8];
static unsigned char n491r[1];
static unsigned char n491e[1];
static unsigned char n491d[8];
static unsigned char n486[8];
static unsigned char n486r[1];
static unsigned char n486e[1];
static unsigned char n486d[8];
static unsigned char n481[8];
static unsigned char n481r[1];
static unsigned char n481e[1];
static unsigned char n481d[8];
static unsigned char n476[8];
static unsigned char n476r[1];
static unsigned char n476e[1];
static unsigned char n476d[8];
static unsigned char n471[8];
static unsigned char n471r[1];
static unsigned char n471e[1];
static unsigned char n471d[8];
static unsigned char n466[8];
static unsigned char n466r[1];
static unsigned char n466e[1];
static unsigned char n466d[8];
static unsigned char n461[8];
static unsigned char n461r[1];
static unsigned char n461e[1];
static unsigned char n461d[8];
static unsigned char n456[8];
static unsigned char n456r[1];
static unsigned char n456e[1];
static unsigned char n456d[8];

void cf_ssp_64_6_ports(unsigned char* port_reset_state_i, unsigned char* port_cycle_i, unsigned char* port_instr_data_i, unsigned char* port_const_data_i, unsigned char* port_load_write_i, unsigned char* port_load_addr_i, unsigned char* port_load_data_i, unsigned char* port_done_o, unsigned char* port_instr_addr_o, unsigned char* port_const_addr_o, unsigned char* port_reg_0_o, unsigned char* port_reg_1_o, unsigned char* port_reg_2_o, unsigned char* port_reg_3_o, unsigned char* port_reg_4_o, unsigned char* port_reg_5_o, unsigned char* port_reg_6_o, unsigned char* port_reg_7_o, unsigned char* port_reg_8_o, unsigned char* port_reg_9_o, unsigned char* port_reg_a_o, unsigned char* port_reg_b_o, unsigned char* port_reg_c_o, unsigned char* port_reg_d_o, unsigned char* port_reg_e_o, unsigned char* port_reg_f_o) {
  reset_state_i = port_reset_state_i;
  cycle_i = port_cycle_i;
  instr_data_i = port_instr_data_i;
  const_data_i = port_const_data_i;
  load_write_i = port_load_write_i;
  load_addr_i = port_load_addr_i;
  load_data_i = port_load_data_i;
  done_o = port_done_o;
  instr_addr_o = port_instr_addr_o;
  const_addr_o = port_const_addr_o;
  reg_0_o = port_reg_0_o;
  reg_1_o = port_reg_1_o;
  reg_2_o = port_reg_2_o;
  reg_3_o = port_reg_3_o;
  reg_4_o = port_reg_4_o;
  reg_5_o = port_reg_5_o;
  reg_6_o = port_reg_6_o;
  reg_7_o = port_reg_7_o;
  reg_8_o = port_reg_8_o;
  reg_9_o = port_reg_9_o;
  reg_a_o = port_reg_a_o;
  reg_b_o = port_reg_b_o;
  reg_c_o = port_reg_c_o;
  reg_d_o = port_reg_d_o;
  reg_e_o = port_reg_e_o;
  reg_f_o = port_reg_f_o;
}

void cf_ssp_64_6_calc() {
  n668[0] = 0;
  n659[0] = 1;
  n658[0] = 1;
  reg_f_o[0] = n526[0];
  reg_f_o[1] = n526[1];
  reg_f_o[2] = n526[2];
  reg_f_o[3] = n526[3];
  reg_f_o[4] = n526[4];
  reg_f_o[5] = n526[5];
  reg_f_o[6] = n526[6];
  reg_f_o[7] = n526[7];
  reg_e_o[0] = n521[0];
  reg_e_o[1] = n521[1];
  reg_e_o[2] = n521[2];
  reg_e_o[3] = n521[3];
  reg_e_o[4] = n521[4];
  reg_e_o[5] = n521[5];
  reg_e_o[6] = n521[6];
  reg_e_o[7] = n521[7];
  reg_d_o[0] = n516[0];
  reg_d_o[1] = n516[1];
  reg_d_o[2] = n516[2];
  reg_d_o[3] = n516[3];
  reg_d_o[4] = n516[4];
  reg_d_o[5] = n516[5];
  reg_d_o[6] = n516[6];
  reg_d_o[7] = n516[7];
  reg_c_o[0] = n511[0];
  reg_c_o[1] = n511[1];
  reg_c_o[2] = n511[2];
  reg_c_o[3] = n511[3];
  reg_c_o[4] = n511[4];
  reg_c_o[5] = n511[5];
  reg_c_o[6] = n511[6];
  reg_c_o[7] = n511[7];
  reg_b_o[0] = n506[0];
  reg_b_o[1] = n506[1];
  reg_b_o[2] = n506[2];
  reg_b_o[3] = n506[3];
  reg_b_o[4] = n506[4];
  reg_b_o[5] = n506[5];
  reg_b_o[6] = n506[6];
  reg_b_o[7] = n506[7];
  reg_a_o[0] = n501[0];
  reg_a_o[1] = n501[1];
  reg_a_o[2] = n501[2];
  reg_a_o[3] = n501[3];
  reg_a_o[4] = n501[4];
  reg_a_o[5] = n501[5];
  reg_a_o[6] = n501[6];
  reg_a_o[7] = n501[7];
  reg_9_o[0] = n496[0];
  reg_9_o[1] = n496[1];
  reg_9_o[2] = n496[2];
  reg_9_o[3] = n496[3];
  reg_9_o[4] = n496[4];
  reg_9_o[5] = n496[5];
  reg_9_o[6] = n496[6];
  reg_9_o[7] = n496[7];
  reg_8_o[0] = n491[0];
  reg_8_o[1] = n491[1];
  reg_8_o[2] = n491[2];
  reg_8_o[3] = n491[3];
  reg_8_o[4] = n491[4];
  reg_8_o[5] = n491[5];
  reg_8_o[6] = n491[6];
  reg_8_o[7] = n491[7];
  reg_7_o[0] = n486[0];
  reg_7_o[1] = n486[1];
  reg_7_o[2] = n486[2];
  reg_7_o[3] = n486[3];
  reg_7_o[4] = n486[4];
  reg_7_o[5] = n486[5];
  reg_7_o[6] = n486[6];
  reg_7_o[7] = n486[7];
  reg_6_o[0] = n481[0];
  reg_6_o[1] = n481[1];
  reg_6_o[2] = n481[2];
  reg_6_o[3] = n481[3];
  reg_6_o[4] = n481[4];
  reg_6_o[5] = n481[5];
  reg_6_o[6] = n481[6];
  reg_6_o[7] = n481[7];
  reg_5_o[0] = n476[0];
  reg_5_o[1] = n476[1];
  reg_5_o[2] = n476[2];
  reg_5_o[3] = n476[3];
  reg_5_o[4] = n476[4];
  reg_5_o[5] = n476[5];
  reg_5_o[6] = n476[6];
  reg_5_o[7] = n476[7];
  reg_4_o[0] = n471[0];
  reg_4_o[1] = n471[1];
  reg_4_o[2] = n471[2];
  reg_4_o[3] = n471[3];
  reg_4_o[4] = n471[4];
  reg_4_o[5] = n471[5];
  reg_4_o[6] = n471[6];
  reg_4_o[7] = n471[7];
  reg_3_o[0] = n466[0];
  reg_3_o[1] = n466[1];
  reg_3_o[2] = n466[2];
  reg_3_o[3] = n466[3];
  reg_3_o[4] = n466[4];
  reg_3_o[5] = n466[5];
  reg_3_o[6] = n466[6];
  reg_3_o[7] = n466[7];
  reg_2_o[0] = n461[0];
  reg_2_o[1] = n461[1];
  reg_2_o[2] = n461[2];
  reg_2_o[3] = n461[3];
  reg_2_o[4] = n461[4];
  reg_2_o[5] = n461[5];
  reg_2_o[6] = n461[6];
  reg_2_o[7] = n461[7];
  reg_1_o[0] = n456[0];
  reg_1_o[1] = n456[1];
  reg_1_o[2] = n456[2];
  reg_1_o[3] = n456[3];
  reg_1_o[4] = n456[4];
  reg_1_o[5] = n456[5];
  reg_1_o[6] = n456[6];
  reg_1_o[7] = n456[7];
  instr_addr_o[0] = n18[0];
  n558[0] = 12;
  n557[0] = 8;
  n556[0] = 4;
  n555[0] = 0;
  n554[0] = 1;
  n553[0] = 1;
  n545[0] = 6;
  n544[0] = 2;
  n543[0] = 13;
  n542[0] = 9;
  n541[0] = 5;
  n540[0] = 1;
  n539[0] = 12;
  n538[0] = 8;
  n537[0] = 4;
  n536[0] = 0;
  n535[0] = 0;
  n534[0] = 1;
  n533[0] = 1;
  n532[0] = 2;
  n531[0] = 1;
  n530[0] = 0;
  n529[0] = 2;
  n431[0] = (1 & (n338[0]));
  n430[0] = (1 & (n338[0] >> 1)) | (2 & (n338[0] >> 1));
  n423[0] = 5;
  n420[0] = 3;
  n417[0] = 1;
  n407[0] = 0;
  n310[0] = (1 & (n308[0]));
  n309[0] = (1 & (n308[0] >> 1)) | (2 & (n308[0] >> 1)) | (4 & (n308[0] >> 1));
  n280[0] = (1 & (n278[0]));
  n279[0] = (1 & (n278[0] >> 1)) | (2 & (n278[0] >> 1)) | (4 & (n278[0] >> 1));
  n226[0] = 0;
  n226[1] = 0;
  n226[2] = 0;
  n226[3] = 0;
  n226[4] = 0;
  n226[5] = 0;
  n226[6] = 0;
  n226[7] = 0;
  n193[0] = 30;
  n191[0] = 29;
  n189[0] = 28;
  n187[0] = 27;
  n185[0] = 26;
  n183[0] = 25;
  n181[0] = 24;
  n179[0] = 23;
  n177[0] = 22;
  n175[0] = 21;
  n173[0] = 20;
  n171[0] = 19;
  n169[0] = 18;
  n167[0] = 17;
  n165[0] = 16;
  n163[0] = 15;
  n161[0] = 14;
  n159[0] = 13;
  n157[0] = 12;
  n155[0] = 11;
  n153[0] = 10;
  n151[0] = 9;
  n149[0] = 8;
  n147[0] = 7;
  n145[0] = 6;
  n143[0] = 5;
  n141[0] = 4;
  n139[0] = 3;
  n137[0] = 2;
  n135[0] = 1;
  n133[0] = 0;
  n132[0] = 0;
  n132[1] = 0;
  n131[0] = 1;
  n131[1] = 0;
  n130[0] = 2;
  n130[1] = 0;
  n129[0] = 4;
  n129[1] = 0;
  n128[0] = 8;
  n128[1] = 0;
  n127[0] = 16;
  n127[1] = 0;
  n126[0] = 32;
  n126[1] = 0;
  n125[0] = 64;
  n125[1] = 0;
  n124[0] = 128;
  n124[1] = 0;
  n123[0] = 0;
  n123[1] = 1;
  n122[0] = 0;
  n122[1] = 2;
  n121[0] = 0;
  n121[1] = 4;
  n120[0] = 0;
  n120[1] = 8;
  n119[0] = 0;
  n119[1] = 16;
  n118[0] = 0;
  n118[1] = 32;
  n117[0] = 0;
  n117[1] = 64;
  n116[0] = 0;
  n116[1] = 128;
  n61[0] = 6;
  n60[0] = 4;
  n59[0] = 2;
  n58[0] = 0;
  n57[0] = 0;
  n56[0] = 0;
  n55[0] = 0;
  n54[0] = 0;
  n49[0] = 5;
  n48[0] = 3;
  n47[0] = 1;
  n46[0] = 6;
  n45[0] = 4;
  n44[0] = 2;
  n43[0] = 0;
  n42[0] = 0;
  n41[0] = 0;
  n40[0] = 1;
  n39[0] = 0;
  n38[0] = 1;
  n37[0] = 0;
  n36[0] = 1;
  n35[0] = 0;
  n10[0] = 1;
  n2[0] = 0;
  n1[0] = 1;
  reg_0_o[0] = n226[0];
  reg_0_o[1] = n226[1];
  reg_0_o[2] = n226[2];
  reg_0_o[3] = n226[3];
  reg_0_o[4] = n226[4];
  reg_0_o[5] = n226[5];
  reg_0_o[6] = n226[6];
  reg_0_o[7] = n226[7];
  n437[0] = (1 & (n430[0]));
  n436[0] = (1 & (n430[0] >> 1));
  n424[0] = n338[0] == n423[0] ? 1 : 0;
  n421[0] = n338[0] == n420[0] ? 1 : 0;
  n418[0] = n338[0] == n417[0] ? 1 : 0;
  n320[0] = (1 & (n309[0]));
  n319[0] = (1 & (n309[0] >> 1)) | (2 & (n309[0] >> 1));
  if (n310[0]) {
    n318[0] = n526[0];
    n318[1] = n526[1];
    n318[2] = n526[2];
    n318[3] = n526[3];
    n318[4] = n526[4];
    n318[5] = n526[5];
    n318[6] = n526[6];
    n318[7] = n526[7];
  }
  else {
    n318[0] = n521[0];
    n318[1] = n521[1];
    n318[2] = n521[2];
    n318[3] = n521[3];
    n318[4] = n521[4];
    n318[5] = n521[5];
    n318[6] = n521[6];
    n318[7] = n521[7];
  }
  if (n310[0]) {
    n317[0] = n516[0];
    n317[1] = n516[1];
    n317[2] = n516[2];
    n317[3] = n516[3];
    n317[4] = n516[4];
    n317[5] = n516[5];
    n317[6] = n516[6];
    n317[7] = n516[7];
  }
  else {
    n317[0] = n511[0];
    n317[1] = n511[1];
    n317[2] = n511[2];
    n317[3] = n511[3];
    n317[4] = n511[4];
    n317[5] = n511[5];
    n317[6] = n511[6];
    n317[7] = n511[7];
  }
  if (n310[0]) {
    n316[0] = n506[0];
    n316[1] = n506[1];
    n316[2] = n506[2];
    n316[3] = n506[3];
    n316[4] = n506[4];
    n316[5] = n506[5];
    n316[6] = n506[6];
    n316[7] = n506[7];
  }
  else {
    n316[0] = n501[0];
    n316[1] = n501[1];
    n316[2] = n501[2];
    n316[3] = n501[3];
    n316[4] = n501[4];
    n316[5] = n501[5];
    n316[6] = n501[6];
    n316[7] = n501[7];
  }
  if (n310[0]) {
    n315[0] = n496[0];
    n315[1] = n496[1];
    n315[2] = n496[2];
    n315[3] = n496[3];
    n315[4] = n496[4];
    n315[5] = n496[5];
    n315[6] = n496[6];
    n315[7] = n496[7];
  }
  else {
    n315[0] = n491[0];
    n315[1] = n491[1];
    n315[2] = n491[2];
    n315[3] = n491[3];
    n315[4] = n491[4];
    n315[5] = n491[5];
    n315[6] = n491[6];
    n315[7] = n491[7];
  }
  if (n310[0]) {
    n314[0] = n486[0];
    n314[1] = n486[1];
    n314[2] = n486[2];
    n314[3] = n486[3];
    n314[4] = n486[4];
    n314[5] = n486[5];
    n314[6] = n486[6];
    n314[7] = n486[7];
  }
  else {
    n314[0] = n481[0];
    n314[1] = n481[1];
    n314[2] = n481[2];
    n314[3] = n481[3];
    n314[4] = n481[4];
    n314[5] = n481[5];
    n314[6] = n481[6];
    n314[7] = n481[7];
  }
  if (n310[0]) {
    n313[0] = n476[0];
    n313[1] = n476[1];
    n313[2] = n476[2];
    n313[3] = n476[3];
    n313[4] = n476[4];
    n313[5] = n476[5];
    n313[6] = n476[6];
    n313[7] = n476[7];
  }
  else {
    n313[0] = n471[0];
    n313[1] = n471[1];
    n313[2] = n471[2];
    n313[3] = n471[3];
    n313[4] = n471[4];
    n313[5] = n471[5];
    n313[6] = n471[6];
    n313[7] = n471[7];
  }
  if (n310[0]) {
    n312[0] = n466[0];
    n312[1] = n466[1];
    n312[2] = n466[2];
    n312[3] = n466[3];
    n312[4] = n466[4];
    n312[5] = n466[5];
    n312[6] = n466[6];
    n312[7] = n466[7];
  }
  else {
    n312[0] = n461[0];
    n312[1] = n461[1];
    n312[2] = n461[2];
    n312[3] = n461[3];
    n312[4] = n461[4];
    n312[5] = n461[5];
    n312[6] = n461[6];
    n312[7] = n461[7];
  }
  if (n310[0]) {
    n311[0] = n456[0];
    n311[1] = n456[1];
    n311[2] = n456[2];
    n311[3] = n456[3];
    n311[4] = n456[4];
    n311[5] = n456[5];
    n311[6] = n456[6];
    n311[7] = n456[7];
  }
  else {
    n311[0] = n226[0];
    n311[1] = n226[1];
    n311[2] = n226[2];
    n311[3] = n226[3];
    n311[4] = n226[4];
    n311[5] = n226[5];
    n311[6] = n226[6];
    n311[7] = n226[7];
  }
  n290[0] = (1 & (n279[0]));
  n289[0] = (1 & (n279[0] >> 1)) | (2 & (n279[0] >> 1));
  if (n280[0]) {
    n288[0] = n526[0];
    n288[1] = n526[1];
    n288[2] = n526[2];
    n288[3] = n526[3];
    n288[4] = n526[4];
    n288[5] = n526[5];
    n288[6] = n526[6];
    n288[7] = n526[7];
  }
  else {
    n288[0] = n521[0];
    n288[1] = n521[1];
    n288[2] = n521[2];
    n288[3] = n521[3];
    n288[4] = n521[4];
    n288[5] = n521[5];
    n288[6] = n521[6];
    n288[7] = n521[7];
  }
  if (n280[0]) {
    n287[0] = n516[0];
    n287[1] = n516[1];
    n287[2] = n516[2];
    n287[3] = n516[3];
    n287[4] = n516[4];
    n287[5] = n516[5];
    n287[6] = n516[6];
    n287[7] = n516[7];
  }
  else {
    n287[0] = n511[0];
    n287[1] = n511[1];
    n287[2] = n511[2];
    n287[3] = n511[3];
    n287[4] = n511[4];
    n287[5] = n511[5];
    n287[6] = n511[6];
    n287[7] = n511[7];
  }
  if (n280[0]) {
    n286[0] = n506[0];
    n286[1] = n506[1];
    n286[2] = n506[2];
    n286[3] = n506[3];
    n286[4] = n506[4];
    n286[5] = n506[5];
    n286[6] = n506[6];
    n286[7] = n506[7];
  }
  else {
    n286[0] = n501[0];
    n286[1] = n501[1];
    n286[2] = n501[2];
    n286[3] = n501[3];
    n286[4] = n501[4];
    n286[5] = n501[5];
    n286[6] = n501[6];
    n286[7] = n501[7];
  }
  if (n280[0]) {
    n285[0] = n496[0];
    n285[1] = n496[1];
    n285[2] = n496[2];
    n285[3] = n496[3];
    n285[4] = n496[4];
    n285[5] = n496[5];
    n285[6] = n496[6];
    n285[7] = n496[7];
  }
  else {
    n285[0] = n491[0];
    n285[1] = n491[1];
    n285[2] = n491[2];
    n285[3] = n491[3];
    n285[4] = n491[4];
    n285[5] = n491[5];
    n285[6] = n491[6];
    n285[7] = n491[7];
  }
  if (n280[0]) {
    n284[0] = n486[0];
    n284[1] = n486[1];
    n284[2] = n486[2];
    n284[3] = n486[3];
    n284[4] = n486[4];
    n284[5] = n486[5];
    n284[6] = n486[6];
    n284[7] = n486[7];
  }
  else {
    n284[0] = n481[0];
    n284[1] = n481[1];
    n284[2] = n481[2];
    n284[3] = n481[3];
    n284[4] = n481[4];
    n284[5] = n481[5];
    n284[6] = n481[6];
    n284[7] = n481[7];
  }
  if (n280[0]) {
    n283[0] = n476[0];
    n283[1] = n476[1];
    n283[2] = n476[2];
    n283[3] = n476[3];
    n283[4] = n476[4];
    n283[5] = n476[5];
    n283[6] = n476[6];
    n283[7] = n476[7];
  }
  else {
    n283[0] = n471[0];
    n283[1] = n471[1];
    n283[2] = n471[2];
    n283[3] = n471[3];
    n283[4] = n471[4];
    n283[5] = n471[5];
    n283[6] = n471[6];
    n283[7] = n471[7];
  }
  if (n280[0]) {
    n282[0] = n466[0];
    n282[1] = n466[1];
    n282[2] = n466[2];
    n282[3] = n466[3];
    n282[4] = n466[4];
    n282[5] = n466[5];
    n282[6] = n466[6];
    n282[7] = n466[7];
  }
  else {
    n282[0] = n461[0];
    n282[1] = n461[1];
    n282[2] = n461[2];
    n282[3] = n461[3];
    n282[4] = n461[4];
    n282[5] = n461[5];
    n282[6] = n461[6];
    n282[7] = n461[7];
  }
  if (n280[0]) {
    n281[0] = n456[0];
    n281[1] = n456[1];
    n281[2] = n456[2];
    n281[3] = n456[3];
    n281[4] = n456[4];
    n281[5] = n456[5];
    n281[6] = n456[6];
    n281[7] = n456[7];
  }
  else {
    n281[0] = n226[0];
    n281[1] = n226[1];
    n281[2] = n226[2];
    n281[3] = n226[3];
    n281[4] = n226[4];
    n281[5] = n226[5];
    n281[6] = n226[6];
    n281[7] = n226[7];
  }
  if (load_write_i[0]) {
    n114[0] = load_addr_i[0];
  }
  else {
    n114[0] = n111[0];
  }
  n112[0] = (1 & (instr_data_i[0] >> 4)) | (2 & (instr_data_i[0] >> 4)) | (4 & (instr_data_i[0] >> 4)) | (8 & (instr_data_i[0] >> 4)) | (16 & (instr_data_i[1] << 4)) | (32 & (instr_data_i[1] << 4)) | (64 & (instr_data_i[1] << 4)) | (128 & (instr_data_i[1] << 4));
  n104[0] = (1 & (instr_data_i[0])) | (2 & (instr_data_i[0])) | (4 & (instr_data_i[0])) | (8 & (instr_data_i[0]));
  n103[0] = (1 & (instr_data_i[0] >> 4)) | (2 & (instr_data_i[0] >> 4)) | (4 & (instr_data_i[0] >> 4)) | (8 & (instr_data_i[0] >> 4));
  n102[0] = (1 & (instr_data_i[1])) | (2 & (instr_data_i[1])) | (4 & (instr_data_i[1])) | (8 & (instr_data_i[1]));
  n101[0] = (1 & (instr_data_i[1] >> 4)) | (2 & (instr_data_i[1] >> 4)) | (4 & (instr_data_i[1] >> 4));
  n33[0] = (1 & (instr_data_i[1] >> 7));
  n32r[0] = n2[0];
  n32e[0] = n1[0];
  n32d[0] = n25[0];
  n25r[0] = n2[0];
  n25e[0] = n1[0];
  n25d[0] = cycle_i[0];
  { unsigned int tmp; (tmp = (unsigned int) n18[0] + (unsigned int) n10[0], n13[0] = 63 & (unsigned char) tmp); }
  const_addr_o[0] = n112[0];
  n441[0] = (1 & (n436[0]));
  n338r[0] = n2[0];
  n338e[0] = n1[0];
  n338d[0] = n101[0];
  n326[0] = (1 & (n319[0]));
  n325[0] = (1 & (n319[0] >> 1));
  if (n320[0]) {
    n324[0] = n318[0];
    n324[1] = n318[1];
    n324[2] = n318[2];
    n324[3] = n318[3];
    n324[4] = n318[4];
    n324[5] = n318[5];
    n324[6] = n318[6];
    n324[7] = n318[7];
  }
  else {
    n324[0] = n317[0];
    n324[1] = n317[1];
    n324[2] = n317[2];
    n324[3] = n317[3];
    n324[4] = n317[4];
    n324[5] = n317[5];
    n324[6] = n317[6];
    n324[7] = n317[7];
  }
  if (n320[0]) {
    n323[0] = n316[0];
    n323[1] = n316[1];
    n323[2] = n316[2];
    n323[3] = n316[3];
    n323[4] = n316[4];
    n323[5] = n316[5];
    n323[6] = n316[6];
    n323[7] = n316[7];
  }
  else {
    n323[0] = n315[0];
    n323[1] = n315[1];
    n323[2] = n315[2];
    n323[3] = n315[3];
    n323[4] = n315[4];
    n323[5] = n315[5];
    n323[6] = n315[6];
    n323[7] = n315[7];
  }
  if (n320[0]) {
    n322[0] = n314[0];
    n322[1] = n314[1];
    n322[2] = n314[2];
    n322[3] = n314[3];
    n322[4] = n314[4];
    n322[5] = n314[5];
    n322[6] = n314[6];
    n322[7] = n314[7];
  }
  else {
    n322[0] = n313[0];
    n322[1] = n313[1];
    n322[2] = n313[2];
    n322[3] = n313[3];
    n322[4] = n313[4];
    n322[5] = n313[5];
    n322[6] = n313[6];
    n322[7] = n313[7];
  }
  if (n320[0]) {
    n321[0] = n312[0];
    n321[1] = n312[1];
    n321[2] = n312[2];
    n321[3] = n312[3];
    n321[4] = n312[4];
    n321[5] = n312[5];
    n321[6] = n312[6];
    n321[7] = n312[7];
  }
  else {
    n321[0] = n311[0];
    n321[1] = n311[1];
    n321[2] = n311[2];
    n321[3] = n311[3];
    n321[4] = n311[4];
    n321[5] = n311[5];
    n321[6] = n311[6];
    n321[7] = n311[7];
  }
  n308r[0] = reset_state_i[0];
  n308e[0] = n1[0];
  n308d[0] = n103[0];
  n296[0] = (1 & (n289[0]));
  n295[0] = (1 & (n289[0] >> 1));
  if (n290[0]) {
    n294[0] = n288[0];
    n294[1] = n288[1];
    n294[2] = n288[2];
    n294[3] = n288[3];
    n294[4] = n288[4];
    n294[5] = n288[5];
    n294[6] = n288[6];
    n294[7] = n288[7];
  }
  else {
    n294[0] = n287[0];
    n294[1] = n287[1];
    n294[2] = n287[2];
    n294[3] = n287[3];
    n294[4] = n287[4];
    n294[5] = n287[5];
    n294[6] = n287[6];
    n294[7] = n287[7];
  }
  if (n290[0]) {
    n293[0] = n286[0];
    n293[1] = n286[1];
    n293[2] = n286[2];
    n293[3] = n286[3];
    n293[4] = n286[4];
    n293[5] = n286[5];
    n293[6] = n286[6];
    n293[7] = n286[7];
  }
  else {
    n293[0] = n285[0];
    n293[1] = n285[1];
    n293[2] = n285[2];
    n293[3] = n285[3];
    n293[4] = n285[4];
    n293[5] = n285[5];
    n293[6] = n285[6];
    n293[7] = n285[7];
  }
  if (n290[0]) {
    n292[0] = n284[0];
    n292[1] = n284[1];
    n292[2] = n284[2];
    n292[3] = n284[3];
    n292[4] = n284[4];
    n292[5] = n284[5];
    n292[6] = n284[6];
    n292[7] = n284[7];
  }
  else {
    n292[0] = n283[0];
    n292[1] = n283[1];
    n292[2] = n283[2];
    n292[3] = n283[3];
    n292[4] = n283[4];
    n292[5] = n283[5];
    n292[6] = n283[6];
    n292[7] = n283[7];
  }
  if (n290[0]) {
    n291[0] = n282[0];
    n291[1] = n282[1];
    n291[2] = n282[2];
    n291[3] = n282[3];
    n291[4] = n282[4];
    n291[5] = n282[5];
    n291[6] = n282[6];
    n291[7] = n282[7];
  }
  else {
    n291[0] = n281[0];
    n291[1] = n281[1];
    n291[2] = n281[2];
    n291[3] = n281[3];
    n291[4] = n281[4];
    n291[5] = n281[5];
    n291[6] = n281[6];
    n291[7] = n281[7];
  }
  n278r[0] = reset_state_i[0];
  n278e[0] = n1[0];
  n278d[0] = n102[0];
  n111r[0] = n2[0];
  n111e[0] = n1[0];
  n111d[0] = n104[0];
  n34[0] = 255 & (n32[0] << 1 | n33[0]);
  n18r[0] = cycle_i[0];
  n18e[0] = n1[0];
  n18d[0] = n13[0];
  n330[0] = (1 & (n325[0]));
  if (n326[0]) {
    n328[0] = n324[0];
    n328[1] = n324[1];
    n328[2] = n324[2];
    n328[3] = n324[3];
    n328[4] = n324[4];
    n328[5] = n324[5];
    n328[6] = n324[6];
    n328[7] = n324[7];
  }
  else {
    n328[0] = n323[0];
    n328[1] = n323[1];
    n328[2] = n323[2];
    n328[3] = n323[3];
    n328[4] = n323[4];
    n328[5] = n323[5];
    n328[6] = n323[6];
    n328[7] = n323[7];
  }
  if (n326[0]) {
    n327[0] = n322[0];
    n327[1] = n322[1];
    n327[2] = n322[2];
    n327[3] = n322[3];
    n327[4] = n322[4];
    n327[5] = n322[5];
    n327[6] = n322[6];
    n327[7] = n322[7];
  }
  else {
    n327[0] = n321[0];
    n327[1] = n321[1];
    n327[2] = n321[2];
    n327[3] = n321[3];
    n327[4] = n321[4];
    n327[5] = n321[5];
    n327[6] = n321[6];
    n327[7] = n321[7];
  }
  n300[0] = (1 & (n295[0]));
  if (n296[0]) {
    n298[0] = n294[0];
    n298[1] = n294[1];
    n298[2] = n294[2];
    n298[3] = n294[3];
    n298[4] = n294[4];
    n298[5] = n294[5];
    n298[6] = n294[6];
    n298[7] = n294[7];
  }
  else {
    n298[0] = n293[0];
    n298[1] = n293[1];
    n298[2] = n293[2];
    n298[3] = n293[3];
    n298[4] = n293[4];
    n298[5] = n293[5];
    n298[6] = n293[6];
    n298[7] = n293[7];
  }
  if (n296[0]) {
    n297[0] = n292[0];
    n297[1] = n292[1];
    n297[2] = n292[2];
    n297[3] = n292[3];
    n297[4] = n292[4];
    n297[5] = n292[5];
    n297[6] = n292[6];
    n297[7] = n292[7];
  }
  else {
    n297[0] = n291[0];
    n297[1] = n291[1];
    n297[2] = n291[2];
    n297[3] = n291[3];
    n297[4] = n291[4];
    n297[5] = n291[5];
    n297[6] = n291[6];
    n297[7] = n291[7];
  }
  n67[0] = 255 & (n34[0] << 1 | n86[0]);
  if (n330[0]) {
    n331[0] = n328[0];
    n331[1] = n328[1];
    n331[2] = n328[2];
    n331[3] = n328[3];
    n331[4] = n328[4];
    n331[5] = n328[5];
    n331[6] = n328[6];
    n331[7] = n328[7];
  }
  else {
    n331[0] = n327[0];
    n331[1] = n327[1];
    n331[2] = n327[2];
    n331[3] = n327[3];
    n331[4] = n327[4];
    n331[5] = n327[5];
    n331[6] = n327[6];
    n331[7] = n327[7];
  }
  if (n300[0]) {
    n301[0] = n298[0];
    n301[1] = n298[1];
    n301[2] = n298[2];
    n301[3] = n298[3];
    n301[4] = n298[4];
    n301[5] = n298[5];
    n301[6] = n298[6];
    n301[7] = n298[7];
  }
  else {
    n301[0] = n297[0];
    n301[1] = n297[1];
    n301[2] = n297[2];
    n301[3] = n297[3];
    n301[4] = n297[4];
    n301[5] = n297[5];
    n301[6] = n297[6];
    n301[7] = n297[7];
  }
  n90[0] = n67[0] == n61[0] ? 1 : 0;
  n89[0] = n67[0] == n60[0] ? 1 : 0;
  n88[0] = n67[0] == n59[0] ? 1 : 0;
  n87[0] = n67[0] == n58[0] ? 1 : 0;
  n74[0] = n67[0] == n49[0] ? 1 : 0;
  n73[0] = n67[0] == n48[0] ? 1 : 0;
  n72[0] = n67[0] == n47[0] ? 1 : 0;
  n71[0] = n67[0] == n46[0] ? 1 : 0;
  n70[0] = n67[0] == n45[0] ? 1 : 0;
  n69[0] = n67[0] == n44[0] ? 1 : 0;
  n68[0] = n67[0] == n43[0] ? 1 : 0;
  if (n450[0]) {
    n429[0] = n301[0];
    n429[1] = n301[1];
    n429[2] = n301[2];
    n429[3] = n301[3];
    n429[4] = n301[4];
    n429[5] = n301[5];
    n429[6] = n301[6];
    n429[7] = n301[7];
  }
  else {
    n429[0] = n331[0];
    n429[1] = n331[1];
    n429[2] = n331[2];
    n429[3] = n331[3];
    n429[4] = n331[4];
    n429[5] = n331[5];
    n429[6] = n331[6];
    n429[7] = n331[7];
  }
  n419[0] = (1 & (n301[0]));
  { unsigned int tmp; (tmp = (unsigned int) n301[7] - (unsigned int) n331[7] - (tmp = (unsigned int) n301[6] - (unsigned int) n331[6] - (tmp = (unsigned int) n301[5] - (unsigned int) n331[5] - (tmp = (unsigned int) n301[4] - (unsigned int) n331[4] - (tmp = (unsigned int) n301[3] - (unsigned int) n331[3] - (tmp = (unsigned int) n301[2] - (unsigned int) n331[2] - (tmp = (unsigned int) n301[1] - (unsigned int) n331[1] - (tmp = (unsigned int) n301[0] - (unsigned int) n331[0], n416[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[4] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[5] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[6] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[7] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n301[7] + (unsigned int) n331[7] + (tmp = (unsigned int) n301[6] + (unsigned int) n331[6] + (tmp = (unsigned int) n301[5] + (unsigned int) n331[5] + (tmp = (unsigned int) n301[4] + (unsigned int) n331[4] + (tmp = (unsigned int) n301[3] + (unsigned int) n331[3] + (tmp = (unsigned int) n301[2] + (unsigned int) n331[2] + (tmp = (unsigned int) n301[1] + (unsigned int) n331[1] + (tmp = (unsigned int) n301[0] + (unsigned int) n331[0], n415[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[4] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[5] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[6] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[7] = 255 & (unsigned char) tmp); }
  n412[0] = (1 & (n301[7] >> 6));
  n410[0] = (1 & (n301[0] >> 1)) | (2 & (n301[0] >> 1)) | (4 & (n301[0] >> 1)) | (8 & (n301[0] >> 1)) | (16 & (n301[0] >> 1)) | (32 & (n301[0] >> 1)) | (64 & (n301[0] >> 1)) | (128 & (n301[1] << 7));
  n410[1] = (1 & (n301[1] >> 1)) | (2 & (n301[1] >> 1)) | (4 & (n301[1] >> 1)) | (8 & (n301[1] >> 1)) | (16 & (n301[1] >> 1)) | (32 & (n301[1] >> 1)) | (64 & (n301[1] >> 1)) | (128 & (n301[2] << 7));
  n410[2] = (1 & (n301[2] >> 1)) | (2 & (n301[2] >> 1)) | (4 & (n301[2] >> 1)) | (8 & (n301[2] >> 1)) | (16 & (n301[2] >> 1)) | (32 & (n301[2] >> 1)) | (64 & (n301[2] >> 1)) | (128 & (n301[3] << 7));
  n410[3] = (1 & (n301[3] >> 1)) | (2 & (n301[3] >> 1)) | (4 & (n301[3] >> 1)) | (8 & (n301[3] >> 1)) | (16 & (n301[3] >> 1)) | (32 & (n301[3] >> 1)) | (64 & (n301[3] >> 1)) | (128 & (n301[4] << 7));
  n410[4] = (1 & (n301[4] >> 1)) | (2 & (n301[4] >> 1)) | (4 & (n301[4] >> 1)) | (8 & (n301[4] >> 1)) | (16 & (n301[4] >> 1)) | (32 & (n301[4] >> 1)) | (64 & (n301[4] >> 1)) | (128 & (n301[5] << 7));
  n410[5] = (1 & (n301[5] >> 1)) | (2 & (n301[5] >> 1)) | (4 & (n301[5] >> 1)) | (8 & (n301[5] >> 1)) | (16 & (n301[5] >> 1)) | (32 & (n301[5] >> 1)) | (64 & (n301[5] >> 1)) | (128 & (n301[6] << 7));
  n410[6] = (1 & (n301[6] >> 1)) | (2 & (n301[6] >> 1)) | (4 & (n301[6] >> 1)) | (8 & (n301[6] >> 1)) | (16 & (n301[6] >> 1)) | (32 & (n301[6] >> 1)) | (64 & (n301[6] >> 1)) | (128 & (n301[7] << 7));
  n410[7] = (1 & (n301[7] >> 1)) | (2 & (n301[7] >> 1)) | (4 & (n301[7] >> 1)) | (8 & (n301[7] >> 1)) | (16 & (n301[7] >> 1)) | (32 & (n301[7] >> 1)) | (64 & (n301[7] >> 1));
  n409[0] = (1 & (n301[7] >> 7));
  n406[0] = (1 & (n301[0])) | (2 & (n301[0])) | (4 & (n301[0])) | (8 & (n301[0])) | (16 & (n301[0])) | (32 & (n301[0])) | (64 & (n301[0])) | (128 & (n301[0]));
  n406[1] = (1 & (n301[1])) | (2 & (n301[1])) | (4 & (n301[1])) | (8 & (n301[1])) | (16 & (n301[1])) | (32 & (n301[1])) | (64 & (n301[1])) | (128 & (n301[1]));
  n406[2] = (1 & (n301[2])) | (2 & (n301[2])) | (4 & (n301[2])) | (8 & (n301[2])) | (16 & (n301[2])) | (32 & (n301[2])) | (64 & (n301[2])) | (128 & (n301[2]));
  n406[3] = (1 & (n301[3])) | (2 & (n301[3])) | (4 & (n301[3])) | (8 & (n301[3])) | (16 & (n301[3])) | (32 & (n301[3])) | (64 & (n301[3])) | (128 & (n301[3]));
  n406[4] = (1 & (n301[4])) | (2 & (n301[4])) | (4 & (n301[4])) | (8 & (n301[4])) | (16 & (n301[4])) | (32 & (n301[4])) | (64 & (n301[4])) | (128 & (n301[4]));
  n406[5] = (1 & (n301[5])) | (2 & (n301[5])) | (4 & (n301[5])) | (8 & (n301[5])) | (16 & (n301[5])) | (32 & (n301[5])) | (64 & (n301[5])) | (128 & (n301[5]));
  n406[6] = (1 & (n301[6])) | (2 & (n301[6])) | (4 & (n301[6])) | (8 & (n301[6])) | (16 & (n301[6])) | (32 & (n301[6])) | (64 & (n301[6])) | (128 & (n301[6]));
  n406[7] = (1 & (n301[7])) | (2 & (n301[7])) | (4 & (n301[7])) | (8 & (n301[7])) | (16 & (n301[7])) | (32 & (n301[7])) | (64 & (n301[7]));
  n339[0] = (1 & (n301[7] >> 7));
  if (n90[0]) {
    n97[0] = n54[0];
  }
  else {
    n97[0] = n658[0];
  }
  if (n74[0]) {
    n75[0] = n36[0];
  }
  else {
    n75[0] = n35[0];
  }
  if (n431[0]) {
    n435[0] = const_data_i[0];
    n435[1] = const_data_i[1];
    n435[2] = const_data_i[2];
    n435[3] = const_data_i[3];
    n435[4] = const_data_i[4];
    n435[5] = const_data_i[5];
    n435[6] = const_data_i[6];
    n435[7] = const_data_i[7];
  }
  else {
    n435[0] = n429[0];
    n435[1] = n429[1];
    n435[2] = n429[2];
    n435[3] = n429[3];
    n435[4] = n429[4];
    n435[5] = n429[5];
    n435[6] = n429[6];
    n435[7] = n429[7];
  }
  if (n450[0]) {
    n428[0] = n415[0];
    n428[1] = n415[1];
    n428[2] = n415[2];
    n428[3] = n415[3];
    n428[4] = n415[4];
    n428[5] = n415[5];
    n428[6] = n415[6];
    n428[7] = n415[7];
  }
  else {
    n428[0] = n301[0];
    n428[1] = n301[1];
    n428[2] = n301[2];
    n428[3] = n301[3];
    n428[4] = n301[4];
    n428[5] = n301[5];
    n428[6] = n301[6];
    n428[7] = n301[7];
  }
  n425[0] = (1 & (n416[7] >> 7));
  n422[0] = (1 & (n415[7] >> 7));
  n413[0] = n339[0] ^ n412[0];
  n411[0] = n410[0];
  n411[1] = n410[1];
  n411[2] = n410[2];
  n411[3] = n410[3];
  n411[4] = n410[4];
  n411[5] = n410[5];
  n411[6] = n410[6];
  n411[7] = 255 & (n409[0] << 7 | n410[7]);
  n408[0] = 255 & (n406[0] << 1 | n407[0]);
  n408[1] = 255 & (n406[1] << 1 | n406[0] >> 7);
  n408[2] = 255 & (n406[2] << 1 | n406[1] >> 7);
  n408[3] = 255 & (n406[3] << 1 | n406[2] >> 7);
  n408[4] = 255 & (n406[4] << 1 | n406[3] >> 7);
  n408[5] = 255 & (n406[5] << 1 | n406[4] >> 7);
  n408[6] = 255 & (n406[6] << 1 | n406[5] >> 7);
  n408[7] = 255 & (n406[7] << 1 | n406[6] >> 7);
  n340[0] = 1 & ~n339[0];
  if (n89[0]) {
    n98[0] = n55[0];
  }
  else {
    n98[0] = n97[0];
  }
  if (n73[0]) {
    n76[0] = n37[0];
  }
  else {
    n76[0] = n75[0];
  }
  if (n424[0]) {
    n443[0] = n425[0];
  }
  else {
    n443[0] = n450[0];
  }
  if (n431[0]) {
    n434[0] = n416[0];
    n434[1] = n416[1];
    n434[2] = n416[2];
    n434[3] = n416[3];
    n434[4] = n416[4];
    n434[5] = n416[5];
    n434[6] = n416[6];
    n434[7] = n416[7];
  }
  else {
    n434[0] = n428[0];
    n434[1] = n428[1];
    n434[2] = n428[2];
    n434[3] = n428[3];
    n434[4] = n428[4];
    n434[5] = n428[5];
    n434[6] = n428[6];
    n434[7] = n428[7];
  }
  if (n431[0]) {
    n432[0] = n411[0];
    n432[1] = n411[1];
    n432[2] = n411[2];
    n432[3] = n411[3];
    n432[4] = n411[4];
    n432[5] = n411[5];
    n432[6] = n411[6];
    n432[7] = n411[7];
  }
  else {
    n432[0] = n408[0];
    n432[1] = n408[1];
    n432[2] = n408[2];
    n432[3] = n408[3];
    n432[4] = n408[4];
    n432[5] = n408[5];
    n432[6] = n408[6];
    n432[7] = n408[7];
  }
  n343[0] = 255 & (n340[0] << 1 | n340[0]);
  if (n88[0]) {
    n99[0] = n56[0];
  }
  else {
    n99[0] = n98[0];
  }
  if (n72[0]) {
    n77[0] = n38[0];
  }
  else {
    n77[0] = n76[0];
  }
  if (n421[0]) {
    n444[0] = n422[0];
  }
  else {
    n444[0] = n443[0];
  }
  if (n437[0]) {
    n439[0] = n435[0];
    n439[1] = n435[1];
    n439[2] = n435[2];
    n439[3] = n435[3];
    n439[4] = n435[4];
    n439[5] = n435[5];
    n439[6] = n435[6];
    n439[7] = n435[7];
  }
  else {
    n439[0] = n434[0];
    n439[1] = n434[1];
    n439[2] = n434[2];
    n439[3] = n434[3];
    n439[4] = n434[4];
    n439[5] = n434[5];
    n439[6] = n434[6];
    n439[7] = n434[7];
  }
  n344[0] = 255 & (n340[0] << 2 | n343[0]);
  if (n87[0]) {
    n100[0] = n57[0];
  }
  else {
    n100[0] = n99[0];
  }
  if (n71[0]) {
    n78[0] = n39[0];
  }
  else {
    n78[0] = n77[0];
  }
  n527[0] = 255 & (cycle_i[0] << 1 | n100[0]);
  if (n418[0]) {
    n445[0] = n419[0];
  }
  else {
    n445[0] = n444[0];
  }
  n345[0] = 255 & (n340[0] << 3 | n344[0]);
  n113[0] = load_write_i[0] | n100[0];
  if (n70[0]) {
    n79[0] = n40[0];
  }
  else {
    n79[0] = n78[0];
  }
  n568[0] = 255 & (n527[0] << 2 | n595[0]);
  n450r[0] = reset_state_i[0];
  n450e[0] = n1[0];
  n450d[0] = n445[0];
  n346[0] = 255 & (n340[0] << 4 | n345[0]);
  n115[0] = 255 & (n113[0] << 4 | n114[0]);
  if (n69[0]) {
    n80[0] = n41[0];
  }
  else {
    n80[0] = n79[0];
  }
  n599[0] = n568[0] == n558[0] ? 1 : 0;
  n598[0] = n568[0] == n557[0] ? 1 : 0;
  n597[0] = n568[0] == n556[0] ? 1 : 0;
  n596[0] = n568[0] == n555[0] ? 1 : 0;
  n578[0] = n568[0] == n545[0] ? 1 : 0;
  n577[0] = n568[0] == n544[0] ? 1 : 0;
  n576[0] = n568[0] == n543[0] ? 1 : 0;
  n575[0] = n568[0] == n542[0] ? 1 : 0;
  n574[0] = n568[0] == n541[0] ? 1 : 0;
  n573[0] = n568[0] == n540[0] ? 1 : 0;
  n572[0] = n568[0] == n539[0] ? 1 : 0;
  n571[0] = n568[0] == n538[0] ? 1 : 0;
  n570[0] = n568[0] == n537[0] ? 1 : 0;
  n569[0] = n568[0] == n536[0] ? 1 : 0;
  n347[0] = 255 & (n340[0] << 5 | n346[0]);
  n194[0] = n115[0] == n193[0] ? 1 : 0;
  n192[0] = n115[0] == n191[0] ? 1 : 0;
  n190[0] = n115[0] == n189[0] ? 1 : 0;
  n188[0] = n115[0] == n187[0] ? 1 : 0;
  n186[0] = n115[0] == n185[0] ? 1 : 0;
  n184[0] = n115[0] == n183[0] ? 1 : 0;
  n182[0] = n115[0] == n181[0] ? 1 : 0;
  n180[0] = n115[0] == n179[0] ? 1 : 0;
  n178[0] = n115[0] == n177[0] ? 1 : 0;
  n176[0] = n115[0] == n175[0] ? 1 : 0;
  n174[0] = n115[0] == n173[0] ? 1 : 0;
  n172[0] = n115[0] == n171[0] ? 1 : 0;
  n170[0] = n115[0] == n169[0] ? 1 : 0;
  n168[0] = n115[0] == n167[0] ? 1 : 0;
  n166[0] = n115[0] == n165[0] ? 1 : 0;
  n164[0] = n115[0] == n163[0] ? 1 : 0;
  n162[0] = n115[0] == n161[0] ? 1 : 0;
  n160[0] = n115[0] == n159[0] ? 1 : 0;
  n158[0] = n115[0] == n157[0] ? 1 : 0;
  n156[0] = n115[0] == n155[0] ? 1 : 0;
  n154[0] = n115[0] == n153[0] ? 1 : 0;
  n152[0] = n115[0] == n151[0] ? 1 : 0;
  n150[0] = n115[0] == n149[0] ? 1 : 0;
  n148[0] = n115[0] == n147[0] ? 1 : 0;
  n146[0] = n115[0] == n145[0] ? 1 : 0;
  n144[0] = n115[0] == n143[0] ? 1 : 0;
  n142[0] = n115[0] == n141[0] ? 1 : 0;
  n140[0] = n115[0] == n139[0] ? 1 : 0;
  n138[0] = n115[0] == n137[0] ? 1 : 0;
  n136[0] = n115[0] == n135[0] ? 1 : 0;
  n134[0] = n115[0] == n133[0] ? 1 : 0;
  if (n68[0]) {
    n81[0] = n42[0];
  }
  else {
    n81[0] = n80[0];
  }
  if (n599[0]) {
    n614[0] = n553[0];
  }
  else {
    n614[0] = n668[0];
  }
  if (n578[0]) {
    n581[0] = n529[0];
  }
  else {
    n581[0] = n659[0];
  }
  n348[0] = 255 & (n340[0] << 6 | n347[0]);
  if (n194[0]) {
    n195[0] = n117[0];
    n195[1] = n117[1];
  }
  else {
    n195[0] = n116[0];
    n195[1] = n116[1];
  }
  n86r[0] = n2[0];
  n86e[0] = n1[0];
  n86d[0] = n81[0];
  if (n598[0]) {
    n615[0] = n553[0];
  }
  else {
    n615[0] = n614[0];
  }
  if (n577[0]) {
    n582[0] = n530[0];
  }
  else {
    n582[0] = n581[0];
  }
  n349[0] = 255 & (n340[0] << 7 | n348[0]);
  if (n192[0]) {
    n196[0] = n118[0];
    n196[1] = n118[1];
  }
  else {
    n196[0] = n195[0];
    n196[1] = n195[1];
  }
  if (n597[0]) {
    n616[0] = n554[0];
  }
  else {
    n616[0] = n615[0];
  }
  if (n576[0]) {
    n583[0] = n531[0];
  }
  else {
    n583[0] = n582[0];
  }
  n350[0] = n349[0];
  n350[1] = n340[0];
  if (n190[0]) {
    n197[0] = n119[0];
    n197[1] = n119[1];
  }
  else {
    n197[0] = n196[0];
    n197[1] = n196[1];
  }
  if (n596[0]) {
    n617[0] = n554[0];
  }
  else {
    n617[0] = n616[0];
  }
  if (n575[0]) {
    n584[0] = n531[0];
  }
  else {
    n584[0] = n583[0];
  }
  n351[0] = n350[0];
  n351[1] = 255 & (n340[0] << 1 | n350[1]);
  if (n188[0]) {
    n198[0] = n120[0];
    n198[1] = n120[1];
  }
  else {
    n198[0] = n197[0];
    n198[1] = n197[1];
  }
  done_o[0] = n617[0];
  if (n574[0]) {
    n585[0] = n532[0];
  }
  else {
    n585[0] = n584[0];
  }
  n352[0] = n351[0];
  n352[1] = 255 & (n340[0] << 2 | n351[1]);
  if (n186[0]) {
    n199[0] = n121[0];
    n199[1] = n121[1];
  }
  else {
    n199[0] = n198[0];
    n199[1] = n198[1];
  }
  if (n573[0]) {
    n586[0] = n533[0];
  }
  else {
    n586[0] = n585[0];
  }
  n353[0] = n352[0];
  n353[1] = 255 & (n340[0] << 3 | n352[1]);
  if (n184[0]) {
    n200[0] = n122[0];
    n200[1] = n122[1];
  }
  else {
    n200[0] = n199[0];
    n200[1] = n199[1];
  }
  if (n572[0]) {
    n587[0] = n534[0];
  }
  else {
    n587[0] = n586[0];
  }
  n354[0] = n353[0];
  n354[1] = 255 & (n340[0] << 4 | n353[1]);
  if (n182[0]) {
    n201[0] = n123[0];
    n201[1] = n123[1];
  }
  else {
    n201[0] = n200[0];
    n201[1] = n200[1];
  }
  if (n571[0]) {
    n588[0] = n534[0];
  }
  else {
    n588[0] = n587[0];
  }
  n355[0] = n354[0];
  n355[1] = 255 & (n340[0] << 5 | n354[1]);
  if (n180[0]) {
    n202[0] = n124[0];
    n202[1] = n124[1];
  }
  else {
    n202[0] = n201[0];
    n202[1] = n201[1];
  }
  if (n570[0]) {
    n589[0] = n535[0];
  }
  else {
    n589[0] = n588[0];
  }
  n356[0] = n355[0];
  n356[1] = 255 & (n340[0] << 6 | n355[1]);
  if (n178[0]) {
    n203[0] = n125[0];
    n203[1] = n125[1];
  }
  else {
    n203[0] = n202[0];
    n203[1] = n202[1];
  }
  if (n569[0]) {
    n590[0] = n535[0];
  }
  else {
    n590[0] = n589[0];
  }
  n357[0] = n356[0];
  n357[1] = 255 & (n340[0] << 7 | n356[1]);
  if (n176[0]) {
    n204[0] = n126[0];
    n204[1] = n126[1];
  }
  else {
    n204[0] = n203[0];
    n204[1] = n203[1];
  }
  n595r[0] = n2[0];
  n595e[0] = n1[0];
  n595d[0] = n590[0];
  n358[0] = n357[0];
  n358[1] = n357[1];
  n358[2] = n340[0];
  if (n174[0]) {
    n205[0] = n127[0];
    n205[1] = n127[1];
  }
  else {
    n205[0] = n204[0];
    n205[1] = n204[1];
  }
  n359[0] = n358[0];
  n359[1] = n358[1];
  n359[2] = 255 & (n340[0] << 1 | n358[2]);
  if (n172[0]) {
    n206[0] = n128[0];
    n206[1] = n128[1];
  }
  else {
    n206[0] = n205[0];
    n206[1] = n205[1];
  }
  n360[0] = n359[0];
  n360[1] = n359[1];
  n360[2] = 255 & (n340[0] << 2 | n359[2]);
  if (n170[0]) {
    n207[0] = n129[0];
    n207[1] = n129[1];
  }
  else {
    n207[0] = n206[0];
    n207[1] = n206[1];
  }
  n361[0] = n360[0];
  n361[1] = n360[1];
  n361[2] = 255 & (n340[0] << 3 | n360[2]);
  if (n168[0]) {
    n208[0] = n130[0];
    n208[1] = n130[1];
  }
  else {
    n208[0] = n207[0];
    n208[1] = n207[1];
  }
  n362[0] = n361[0];
  n362[1] = n361[1];
  n362[2] = 255 & (n340[0] << 4 | n361[2]);
  if (n166[0]) {
    n209[0] = n131[0];
    n209[1] = n131[1];
  }
  else {
    n209[0] = n208[0];
    n209[1] = n208[1];
  }
  n363[0] = n362[0];
  n363[1] = n362[1];
  n363[2] = 255 & (n340[0] << 5 | n362[2]);
  if (n164[0]) {
    n210[0] = n132[0];
    n210[1] = n132[1];
  }
  else {
    n210[0] = n209[0];
    n210[1] = n209[1];
  }
  n364[0] = n363[0];
  n364[1] = n363[1];
  n364[2] = 255 & (n340[0] << 6 | n363[2]);
  if (n162[0]) {
    n211[0] = n132[0];
    n211[1] = n132[1];
  }
  else {
    n211[0] = n210[0];
    n211[1] = n210[1];
  }
  n365[0] = n364[0];
  n365[1] = n364[1];
  n365[2] = 255 & (n340[0] << 7 | n364[2]);
  if (n160[0]) {
    n212[0] = n132[0];
    n212[1] = n132[1];
  }
  else {
    n212[0] = n211[0];
    n212[1] = n211[1];
  }
  n366[0] = n365[0];
  n366[1] = n365[1];
  n366[2] = n365[2];
  n366[3] = n340[0];
  if (n158[0]) {
    n213[0] = n132[0];
    n213[1] = n132[1];
  }
  else {
    n213[0] = n212[0];
    n213[1] = n212[1];
  }
  n367[0] = n366[0];
  n367[1] = n366[1];
  n367[2] = n366[2];
  n367[3] = 255 & (n340[0] << 1 | n366[3]);
  if (n156[0]) {
    n214[0] = n132[0];
    n214[1] = n132[1];
  }
  else {
    n214[0] = n213[0];
    n214[1] = n213[1];
  }
  n368[0] = n367[0];
  n368[1] = n367[1];
  n368[2] = n367[2];
  n368[3] = 255 & (n340[0] << 2 | n367[3]);
  if (n154[0]) {
    n215[0] = n132[0];
    n215[1] = n132[1];
  }
  else {
    n215[0] = n214[0];
    n215[1] = n214[1];
  }
  n369[0] = n368[0];
  n369[1] = n368[1];
  n369[2] = n368[2];
  n369[3] = 255 & (n340[0] << 3 | n368[3]);
  if (n152[0]) {
    n216[0] = n132[0];
    n216[1] = n132[1];
  }
  else {
    n216[0] = n215[0];
    n216[1] = n215[1];
  }
  n370[0] = n369[0];
  n370[1] = n369[1];
  n370[2] = n369[2];
  n370[3] = 255 & (n340[0] << 4 | n369[3]);
  if (n150[0]) {
    n217[0] = n132[0];
    n217[1] = n132[1];
  }
  else {
    n217[0] = n216[0];
    n217[1] = n216[1];
  }
  n371[0] = n370[0];
  n371[1] = n370[1];
  n371[2] = n370[2];
  n371[3] = 255 & (n340[0] << 5 | n370[3]);
  if (n148[0]) {
    n218[0] = n132[0];
    n218[1] = n132[1];
  }
  else {
    n218[0] = n217[0];
    n218[1] = n217[1];
  }
  n372[0] = n371[0];
  n372[1] = n371[1];
  n372[2] = n371[2];
  n372[3] = 255 & (n340[0] << 6 | n371[3]);
  if (n146[0]) {
    n219[0] = n132[0];
    n219[1] = n132[1];
  }
  else {
    n219[0] = n218[0];
    n219[1] = n218[1];
  }
  n373[0] = n372[0];
  n373[1] = n372[1];
  n373[2] = n372[2];
  n373[3] = 255 & (n340[0] << 7 | n372[3]);
  if (n144[0]) {
    n220[0] = n132[0];
    n220[1] = n132[1];
  }
  else {
    n220[0] = n219[0];
    n220[1] = n219[1];
  }
  n374[0] = n373[0];
  n374[1] = n373[1];
  n374[2] = n373[2];
  n374[3] = n373[3];
  n374[4] = n340[0];
  if (n142[0]) {
    n221[0] = n132[0];
    n221[1] = n132[1];
  }
  else {
    n221[0] = n220[0];
    n221[1] = n220[1];
  }
  n375[0] = n374[0];
  n375[1] = n374[1];
  n375[2] = n374[2];
  n375[3] = n374[3];
  n375[4] = 255 & (n340[0] << 1 | n374[4]);
  if (n140[0]) {
    n222[0] = n132[0];
    n222[1] = n132[1];
  }
  else {
    n222[0] = n221[0];
    n222[1] = n221[1];
  }
  n376[0] = n375[0];
  n376[1] = n375[1];
  n376[2] = n375[2];
  n376[3] = n375[3];
  n376[4] = 255 & (n340[0] << 2 | n375[4]);
  if (n138[0]) {
    n223[0] = n132[0];
    n223[1] = n132[1];
  }
  else {
    n223[0] = n222[0];
    n223[1] = n222[1];
  }
  n377[0] = n376[0];
  n377[1] = n376[1];
  n377[2] = n376[2];
  n377[3] = n376[3];
  n377[4] = 255 & (n340[0] << 3 | n376[4]);
  if (n136[0]) {
    n224[0] = n132[0];
    n224[1] = n132[1];
  }
  else {
    n224[0] = n223[0];
    n224[1] = n223[1];
  }
  n378[0] = n377[0];
  n378[1] = n377[1];
  n378[2] = n377[2];
  n378[3] = n377[3];
  n378[4] = 255 & (n340[0] << 4 | n377[4]);
  if (n134[0]) {
    n225[0] = n132[0];
    n225[1] = n132[1];
  }
  else {
    n225[0] = n224[0];
    n225[1] = n224[1];
  }
  n379[0] = n378[0];
  n379[1] = n378[1];
  n379[2] = n378[2];
  n379[3] = n378[3];
  n379[4] = 255 & (n340[0] << 5 | n378[4]);
  n269[0] = (1 & (n225[1] >> 7));
  n266[0] = (1 & (n225[1] >> 6));
  n263[0] = (1 & (n225[1] >> 5));
  n260[0] = (1 & (n225[1] >> 4));
  n257[0] = (1 & (n225[1] >> 3));
  n254[0] = (1 & (n225[1] >> 2));
  n251[0] = (1 & (n225[1] >> 1));
  n248[0] = (1 & (n225[1]));
  n245[0] = (1 & (n225[0] >> 7));
  n242[0] = (1 & (n225[0] >> 6));
  n239[0] = (1 & (n225[0] >> 5));
  n236[0] = (1 & (n225[0] >> 4));
  n233[0] = (1 & (n225[0] >> 3));
  n230[0] = (1 & (n225[0] >> 2));
  n227[0] = (1 & (n225[0] >> 1));
  n380[0] = n379[0];
  n380[1] = n379[1];
  n380[2] = n379[2];
  n380[3] = n379[3];
  n380[4] = 255 & (n340[0] << 6 | n379[4]);
  n381[0] = n380[0];
  n381[1] = n380[1];
  n381[2] = n380[2];
  n381[3] = n380[3];
  n381[4] = 255 & (n340[0] << 7 | n380[4]);
  n382[0] = n381[0];
  n382[1] = n381[1];
  n382[2] = n381[2];
  n382[3] = n381[3];
  n382[4] = n381[4];
  n382[5] = n340[0];
  n383[0] = n382[0];
  n383[1] = n382[1];
  n383[2] = n382[2];
  n383[3] = n382[3];
  n383[4] = n382[4];
  n383[5] = 255 & (n340[0] << 1 | n382[5]);
  n384[0] = n383[0];
  n384[1] = n383[1];
  n384[2] = n383[2];
  n384[3] = n383[3];
  n384[4] = n383[4];
  n384[5] = 255 & (n340[0] << 2 | n383[5]);
  n385[0] = n384[0];
  n385[1] = n384[1];
  n385[2] = n384[2];
  n385[3] = n384[3];
  n385[4] = n384[4];
  n385[5] = 255 & (n340[0] << 3 | n384[5]);
  n386[0] = n385[0];
  n386[1] = n385[1];
  n386[2] = n385[2];
  n386[3] = n385[3];
  n386[4] = n385[4];
  n386[5] = 255 & (n340[0] << 4 | n385[5]);
  n387[0] = n386[0];
  n387[1] = n386[1];
  n387[2] = n386[2];
  n387[3] = n386[3];
  n387[4] = n386[4];
  n387[5] = 255 & (n340[0] << 5 | n386[5]);
  n388[0] = n387[0];
  n388[1] = n387[1];
  n388[2] = n387[2];
  n388[3] = n387[3];
  n388[4] = n387[4];
  n388[5] = 255 & (n340[0] << 6 | n387[5]);
  n389[0] = n388[0];
  n389[1] = n388[1];
  n389[2] = n388[2];
  n389[3] = n388[3];
  n389[4] = n388[4];
  n389[5] = 255 & (n340[0] << 7 | n388[5]);
  n390[0] = n389[0];
  n390[1] = n389[1];
  n390[2] = n389[2];
  n390[3] = n389[3];
  n390[4] = n389[4];
  n390[5] = n389[5];
  n390[6] = n340[0];
  n391[0] = n390[0];
  n391[1] = n390[1];
  n391[2] = n390[2];
  n391[3] = n390[3];
  n391[4] = n390[4];
  n391[5] = n390[5];
  n391[6] = 255 & (n340[0] << 1 | n390[6]);
  n392[0] = n391[0];
  n392[1] = n391[1];
  n392[2] = n391[2];
  n392[3] = n391[3];
  n392[4] = n391[4];
  n392[5] = n391[5];
  n392[6] = 255 & (n340[0] << 2 | n391[6]);
  n393[0] = n392[0];
  n393[1] = n392[1];
  n393[2] = n392[2];
  n393[3] = n392[3];
  n393[4] = n392[4];
  n393[5] = n392[5];
  n393[6] = 255 & (n340[0] << 3 | n392[6]);
  n394[0] = n393[0];
  n394[1] = n393[1];
  n394[2] = n393[2];
  n394[3] = n393[3];
  n394[4] = n393[4];
  n394[5] = n393[5];
  n394[6] = 255 & (n340[0] << 4 | n393[6]);
  n395[0] = n394[0];
  n395[1] = n394[1];
  n395[2] = n394[2];
  n395[3] = n394[3];
  n395[4] = n394[4];
  n395[5] = n394[5];
  n395[6] = 255 & (n340[0] << 5 | n394[6]);
  n396[0] = n395[0];
  n396[1] = n395[1];
  n396[2] = n395[2];
  n396[3] = n395[3];
  n396[4] = n395[4];
  n396[5] = n395[5];
  n396[6] = 255 & (n340[0] << 6 | n395[6]);
  n397[0] = n396[0];
  n397[1] = n396[1];
  n397[2] = n396[2];
  n397[3] = n396[3];
  n397[4] = n396[4];
  n397[5] = n396[5];
  n397[6] = 255 & (n340[0] << 7 | n396[6]);
  n398[0] = n397[0];
  n398[1] = n397[1];
  n398[2] = n397[2];
  n398[3] = n397[3];
  n398[4] = n397[4];
  n398[5] = n397[5];
  n398[6] = n397[6];
  n398[7] = n340[0];
  n399[0] = n398[0];
  n399[1] = n398[1];
  n399[2] = n398[2];
  n399[3] = n398[3];
  n399[4] = n398[4];
  n399[5] = n398[5];
  n399[6] = n398[6];
  n399[7] = 255 & (n340[0] << 1 | n398[7]);
  n400[0] = n399[0];
  n400[1] = n399[1];
  n400[2] = n399[2];
  n400[3] = n399[3];
  n400[4] = n399[4];
  n400[5] = n399[5];
  n400[6] = n399[6];
  n400[7] = 255 & (n340[0] << 2 | n399[7]);
  n401[0] = n400[0];
  n401[1] = n400[1];
  n401[2] = n400[2];
  n401[3] = n400[3];
  n401[4] = n400[4];
  n401[5] = n400[5];
  n401[6] = n400[6];
  n401[7] = 255 & (n340[0] << 3 | n400[7]);
  n402[0] = n401[0];
  n402[1] = n401[1];
  n402[2] = n401[2];
  n402[3] = n401[3];
  n402[4] = n401[4];
  n402[5] = n401[5];
  n402[6] = n401[6];
  n402[7] = 255 & (n340[0] << 4 | n401[7]);
  n403[0] = n402[0];
  n403[1] = n402[1];
  n403[2] = n402[2];
  n403[3] = n402[3];
  n403[4] = n402[4];
  n403[5] = n402[5];
  n403[6] = n402[6];
  n403[7] = 255 & (n340[0] << 5 | n402[7]);
  n404[0] = n403[0];
  n404[1] = n403[1];
  n404[2] = n403[2];
  n404[3] = n403[3];
  n404[4] = n403[4];
  n404[5] = n403[5];
  n404[6] = n403[6];
  n404[7] = 255 & (n340[0] << 6 | n403[7]);
  n405[0] = n404[0];
  n405[1] = n404[1];
  n405[2] = n404[2];
  n405[3] = n404[3];
  n405[4] = n404[4];
  n405[5] = n404[5];
  n405[6] = n404[6];
  n405[7] = 255 & (n339[0] << 7 | n404[7]);
  if (n413[0]) {
    n414[0] = n405[0];
    n414[1] = n405[1];
    n414[2] = n405[2];
    n414[3] = n405[3];
    n414[4] = n405[4];
    n414[5] = n405[5];
    n414[6] = n405[6];
    n414[7] = n405[7];
  }
  else {
    n414[0] = n408[0];
    n414[1] = n408[1];
    n414[2] = n408[2];
    n414[3] = n408[3];
    n414[4] = n408[4];
    n414[5] = n408[5];
    n414[6] = n408[6];
    n414[7] = n408[7];
  }
  if (n431[0]) {
    n433[0] = n415[0];
    n433[1] = n415[1];
    n433[2] = n415[2];
    n433[3] = n415[3];
    n433[4] = n415[4];
    n433[5] = n415[5];
    n433[6] = n415[6];
    n433[7] = n415[7];
  }
  else {
    n433[0] = n414[0];
    n433[1] = n414[1];
    n433[2] = n414[2];
    n433[3] = n414[3];
    n433[4] = n414[4];
    n433[5] = n414[5];
    n433[6] = n414[6];
    n433[7] = n414[7];
  }
  if (n437[0]) {
    n438[0] = n433[0];
    n438[1] = n433[1];
    n438[2] = n433[2];
    n438[3] = n433[3];
    n438[4] = n433[4];
    n438[5] = n433[5];
    n438[6] = n433[6];
    n438[7] = n433[7];
  }
  else {
    n438[0] = n432[0];
    n438[1] = n432[1];
    n438[2] = n432[2];
    n438[3] = n432[3];
    n438[4] = n432[4];
    n438[5] = n432[5];
    n438[6] = n432[6];
    n438[7] = n432[7];
  }
  if (n441[0]) {
    n442[0] = n439[0];
    n442[1] = n439[1];
    n442[2] = n439[2];
    n442[3] = n439[3];
    n442[4] = n439[4];
    n442[5] = n439[5];
    n442[6] = n439[6];
    n442[7] = n439[7];
  }
  else {
    n442[0] = n438[0];
    n442[1] = n438[1];
    n442[2] = n438[2];
    n442[3] = n438[3];
    n442[4] = n438[4];
    n442[5] = n438[5];
    n442[6] = n438[6];
    n442[7] = n438[7];
  }
  if (load_write_i[0]) {
    n451[0] = load_data_i[0];
    n451[1] = load_data_i[1];
    n451[2] = load_data_i[2];
    n451[3] = load_data_i[3];
    n451[4] = load_data_i[4];
    n451[5] = load_data_i[5];
    n451[6] = load_data_i[6];
    n451[7] = load_data_i[7];
  }
  else {
    n451[0] = n442[0];
    n451[1] = n442[1];
    n451[2] = n442[2];
    n451[3] = n442[3];
    n451[4] = n442[4];
    n451[5] = n442[5];
    n451[6] = n442[6];
    n451[7] = n442[7];
  }
  n526r[0] = reset_state_i[0];
  n526e[0] = n269[0];
  n526d[0] = n451[0];
  n526d[1] = n451[1];
  n526d[2] = n451[2];
  n526d[3] = n451[3];
  n526d[4] = n451[4];
  n526d[5] = n451[5];
  n526d[6] = n451[6];
  n526d[7] = n451[7];
  n521r[0] = reset_state_i[0];
  n521e[0] = n266[0];
  n521d[0] = n451[0];
  n521d[1] = n451[1];
  n521d[2] = n451[2];
  n521d[3] = n451[3];
  n521d[4] = n451[4];
  n521d[5] = n451[5];
  n521d[6] = n451[6];
  n521d[7] = n451[7];
  n516r[0] = reset_state_i[0];
  n516e[0] = n263[0];
  n516d[0] = n451[0];
  n516d[1] = n451[1];
  n516d[2] = n451[2];
  n516d[3] = n451[3];
  n516d[4] = n451[4];
  n516d[5] = n451[5];
  n516d[6] = n451[6];
  n516d[7] = n451[7];
  n511r[0] = reset_state_i[0];
  n511e[0] = n260[0];
  n511d[0] = n451[0];
  n511d[1] = n451[1];
  n511d[2] = n451[2];
  n511d[3] = n451[3];
  n511d[4] = n451[4];
  n511d[5] = n451[5];
  n511d[6] = n451[6];
  n511d[7] = n451[7];
  n506r[0] = reset_state_i[0];
  n506e[0] = n257[0];
  n506d[0] = n451[0];
  n506d[1] = n451[1];
  n506d[2] = n451[2];
  n506d[3] = n451[3];
  n506d[4] = n451[4];
  n506d[5] = n451[5];
  n506d[6] = n451[6];
  n506d[7] = n451[7];
  n501r[0] = reset_state_i[0];
  n501e[0] = n254[0];
  n501d[0] = n451[0];
  n501d[1] = n451[1];
  n501d[2] = n451[2];
  n501d[3] = n451[3];
  n501d[4] = n451[4];
  n501d[5] = n451[5];
  n501d[6] = n451[6];
  n501d[7] = n451[7];
  n496r[0] = reset_state_i[0];
  n496e[0] = n251[0];
  n496d[0] = n451[0];
  n496d[1] = n451[1];
  n496d[2] = n451[2];
  n496d[3] = n451[3];
  n496d[4] = n451[4];
  n496d[5] = n451[5];
  n496d[6] = n451[6];
  n496d[7] = n451[7];
  n491r[0] = reset_state_i[0];
  n491e[0] = n248[0];
  n491d[0] = n451[0];
  n491d[1] = n451[1];
  n491d[2] = n451[2];
  n491d[3] = n451[3];
  n491d[4] = n451[4];
  n491d[5] = n451[5];
  n491d[6] = n451[6];
  n491d[7] = n451[7];
  n486r[0] = reset_state_i[0];
  n486e[0] = n245[0];
  n486d[0] = n451[0];
  n486d[1] = n451[1];
  n486d[2] = n451[2];
  n486d[3] = n451[3];
  n486d[4] = n451[4];
  n486d[5] = n451[5];
  n486d[6] = n451[6];
  n486d[7] = n451[7];
  n481r[0] = reset_state_i[0];
  n481e[0] = n242[0];
  n481d[0] = n451[0];
  n481d[1] = n451[1];
  n481d[2] = n451[2];
  n481d[3] = n451[3];
  n481d[4] = n451[4];
  n481d[5] = n451[5];
  n481d[6] = n451[6];
  n481d[7] = n451[7];
  n476r[0] = reset_state_i[0];
  n476e[0] = n239[0];
  n476d[0] = n451[0];
  n476d[1] = n451[1];
  n476d[2] = n451[2];
  n476d[3] = n451[3];
  n476d[4] = n451[4];
  n476d[5] = n451[5];
  n476d[6] = n451[6];
  n476d[7] = n451[7];
  n471r[0] = reset_state_i[0];
  n471e[0] = n236[0];
  n471d[0] = n451[0];
  n471d[1] = n451[1];
  n471d[2] = n451[2];
  n471d[3] = n451[3];
  n471d[4] = n451[4];
  n471d[5] = n451[5];
  n471d[6] = n451[6];
  n471d[7] = n451[7];
  n466r[0] = reset_state_i[0];
  n466e[0] = n233[0];
  n466d[0] = n451[0];
  n466d[1] = n451[1];
  n466d[2] = n451[2];
  n466d[3] = n451[3];
  n466d[4] = n451[4];
  n466d[5] = n451[5];
  n466d[6] = n451[6];
  n466d[7] = n451[7];
  n461r[0] = reset_state_i[0];
  n461e[0] = n230[0];
  n461d[0] = n451[0];
  n461d[1] = n451[1];
  n461d[2] = n451[2];
  n461d[3] = n451[3];
  n461d[4] = n451[4];
  n461d[5] = n451[5];
  n461d[6] = n451[6];
  n461d[7] = n451[7];
  n456r[0] = reset_state_i[0];
  n456e[0] = n227[0];
  n456d[0] = n451[0];
  n456d[1] = n451[1];
  n456d[2] = n451[2];
  n456d[3] = n451[3];
  n456d[4] = n451[4];
  n456d[5] = n451[5];
  n456d[6] = n451[6];
  n456d[7] = n451[7];
}

void cf_ssp_64_6_init() {
  n668[0] = 0;
  n659[0] = 0;
  n658[0] = 0;
  n558[0] = 0;
  n557[0] = 0;
  n556[0] = 0;
  n555[0] = 0;
  n554[0] = 0;
  n553[0] = 0;
  n545[0] = 0;
  n544[0] = 0;
  n543[0] = 0;
  n542[0] = 0;
  n541[0] = 0;
  n540[0] = 0;
  n539[0] = 0;
  n538[0] = 0;
  n537[0] = 0;
  n536[0] = 0;
  n535[0] = 0;
  n534[0] = 0;
  n533[0] = 0;
  n532[0] = 0;
  n531[0] = 0;
  n530[0] = 0;
  n529[0] = 0;
  n431[0] = 0;
  n430[0] = 0;
  n423[0] = 0;
  n420[0] = 0;
  n417[0] = 0;
  n407[0] = 0;
  n310[0] = 0;
  n309[0] = 0;
  n280[0] = 0;
  n279[0] = 0;
  { int index; for (index = 8; index > 0;) n226[--index] = 0; }
  n193[0] = 0;
  n191[0] = 0;
  n189[0] = 0;
  n187[0] = 0;
  n185[0] = 0;
  n183[0] = 0;
  n181[0] = 0;
  n179[0] = 0;
  n177[0] = 0;
  n175[0] = 0;
  n173[0] = 0;
  n171[0] = 0;
  n169[0] = 0;
  n167[0] = 0;
  n165[0] = 0;
  n163[0] = 0;
  n161[0] = 0;
  n159[0] = 0;
  n157[0] = 0;
  n155[0] = 0;
  n153[0] = 0;
  n151[0] = 0;
  n149[0] = 0;
  n147[0] = 0;
  n145[0] = 0;
  n143[0] = 0;
  n141[0] = 0;
  n139[0] = 0;
  n137[0] = 0;
  n135[0] = 0;
  n133[0] = 0;
  { int index; for (index = 2; index > 0;) n132[--index] = 0; }
  { int index; for (index = 2; index > 0;) n131[--index] = 0; }
  { int index; for (index = 2; index > 0;) n130[--index] = 0; }
  { int index; for (index = 2; index > 0;) n129[--index] = 0; }
  { int index; for (index = 2; index > 0;) n128[--index] = 0; }
  { int index; for (index = 2; index > 0;) n127[--index] = 0; }
  { int index; for (index = 2; index > 0;) n126[--index] = 0; }
  { int index; for (index = 2; index > 0;) n125[--index] = 0; }
  { int index; for (index = 2; index > 0;) n124[--index] = 0; }
  { int index; for (index = 2; index > 0;) n123[--index] = 0; }
  { int index; for (index = 2; index > 0;) n122[--index] = 0; }
  { int index; for (index = 2; index > 0;) n121[--index] = 0; }
  { int index; for (index = 2; index > 0;) n120[--index] = 0; }
  { int index; for (index = 2; index > 0;) n119[--index] = 0; }
  { int index; for (index = 2; index > 0;) n118[--index] = 0; }
  { int index; for (index = 2; index > 0;) n117[--index] = 0; }
  { int index; for (index = 2; index > 0;) n116[--index] = 0; }
  n61[0] = 0;
  n60[0] = 0;
  n59[0] = 0;
  n58[0] = 0;
  n57[0] = 0;
  n56[0] = 0;
  n55[0] = 0;
  n54[0] = 0;
  n49[0] = 0;
  n48[0] = 0;
  n47[0] = 0;
  n46[0] = 0;
  n45[0] = 0;
  n44[0] = 0;
  n43[0] = 0;
  n42[0] = 0;
  n41[0] = 0;
  n40[0] = 0;
  n39[0] = 0;
  n38[0] = 0;
  n37[0] = 0;
  n36[0] = 0;
  n35[0] = 0;
  n10[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  n437[0] = 0;
  n436[0] = 0;
  n424[0] = 0;
  n421[0] = 0;
  n418[0] = 0;
  n320[0] = 0;
  n319[0] = 0;
  { int index; for (index = 8; index > 0;) n318[--index] = 0; }
  { int index; for (index = 8; index > 0;) n317[--index] = 0; }
  { int index; for (index = 8; index > 0;) n316[--index] = 0; }
  { int index; for (index = 8; index > 0;) n315[--index] = 0; }
  { int index; for (index = 8; index > 0;) n314[--index] = 0; }
  { int index; for (index = 8; index > 0;) n313[--index] = 0; }
  { int index; for (index = 8; index > 0;) n312[--index] = 0; }
  { int index; for (index = 8; index > 0;) n311[--index] = 0; }
  n290[0] = 0;
  n289[0] = 0;
  { int index; for (index = 8; index > 0;) n288[--index] = 0; }
  { int index; for (index = 8; index > 0;) n287[--index] = 0; }
  { int index; for (index = 8; index > 0;) n286[--index] = 0; }
  { int index; for (index = 8; index > 0;) n285[--index] = 0; }
  { int index; for (index = 8; index > 0;) n284[--index] = 0; }
  { int index; for (index = 8; index > 0;) n283[--index] = 0; }
  { int index; for (index = 8; index > 0;) n282[--index] = 0; }
  { int index; for (index = 8; index > 0;) n281[--index] = 0; }
  n114[0] = 0;
  n112[0] = 0;
  n104[0] = 0;
  n103[0] = 0;
  n102[0] = 0;
  n101[0] = 0;
  n33[0] = 0;
  n32[0] = 0;
  n32r[0] = 0;
  n32e[0] = 0;
  n32d[0] = 0;
  n25[0] = 0;
  n25r[0] = 0;
  n25e[0] = 0;
  n25d[0] = 0;
  n13[0] = 0;
  n441[0] = 0;
  n338[0] = 0;
  n338r[0] = 0;
  n338e[0] = 0;
  n338d[0] = 0;
  n326[0] = 0;
  n325[0] = 0;
  { int index; for (index = 8; index > 0;) n324[--index] = 0; }
  { int index; for (index = 8; index > 0;) n323[--index] = 0; }
  { int index; for (index = 8; index > 0;) n322[--index] = 0; }
  { int index; for (index = 8; index > 0;) n321[--index] = 0; }
  n308[0] = 0;
  n308r[0] = 0;
  n308e[0] = 0;
  n308d[0] = 0;
  n296[0] = 0;
  n295[0] = 0;
  { int index; for (index = 8; index > 0;) n294[--index] = 0; }
  { int index; for (index = 8; index > 0;) n293[--index] = 0; }
  { int index; for (index = 8; index > 0;) n292[--index] = 0; }
  { int index; for (index = 8; index > 0;) n291[--index] = 0; }
  n278[0] = 0;
  n278r[0] = 0;
  n278e[0] = 0;
  n278d[0] = 0;
  n111[0] = 0;
  n111r[0] = 0;
  n111e[0] = 0;
  n111d[0] = 0;
  n34[0] = 0;
  n18[0] = 0;
  n18r[0] = 0;
  n18e[0] = 0;
  n18d[0] = 0;
  n330[0] = 0;
  { int index; for (index = 8; index > 0;) n328[--index] = 0; }
  { int index; for (index = 8; index > 0;) n327[--index] = 0; }
  n300[0] = 0;
  { int index; for (index = 8; index > 0;) n298[--index] = 0; }
  { int index; for (index = 8; index > 0;) n297[--index] = 0; }
  n67[0] = 0;
  { int index; for (index = 8; index > 0;) n331[--index] = 0; }
  { int index; for (index = 8; index > 0;) n301[--index] = 0; }
  n90[0] = 0;
  n89[0] = 0;
  n88[0] = 0;
  n87[0] = 0;
  n74[0] = 0;
  n73[0] = 0;
  n72[0] = 0;
  n71[0] = 0;
  n70[0] = 0;
  n69[0] = 0;
  n68[0] = 0;
  { int index; for (index = 8; index > 0;) n429[--index] = 0; }
  n419[0] = 0;
  { int index; for (index = 8; index > 0;) n416[--index] = 0; }
  { int index; for (index = 8; index > 0;) n415[--index] = 0; }
  n412[0] = 0;
  { int index; for (index = 8; index > 0;) n410[--index] = 0; }
  n409[0] = 0;
  { int index; for (index = 8; index > 0;) n406[--index] = 0; }
  n339[0] = 0;
  n97[0] = 0;
  n75[0] = 0;
  { int index; for (index = 8; index > 0;) n435[--index] = 0; }
  { int index; for (index = 8; index > 0;) n428[--index] = 0; }
  n425[0] = 0;
  n422[0] = 0;
  n413[0] = 0;
  { int index; for (index = 8; index > 0;) n411[--index] = 0; }
  { int index; for (index = 8; index > 0;) n408[--index] = 0; }
  n340[0] = 0;
  n98[0] = 0;
  n76[0] = 0;
  n443[0] = 0;
  { int index; for (index = 8; index > 0;) n434[--index] = 0; }
  { int index; for (index = 8; index > 0;) n432[--index] = 0; }
  n343[0] = 0;
  n99[0] = 0;
  n77[0] = 0;
  n444[0] = 0;
  { int index; for (index = 8; index > 0;) n439[--index] = 0; }
  n344[0] = 0;
  n100[0] = 0;
  n78[0] = 0;
  n527[0] = 0;
  n445[0] = 0;
  n345[0] = 0;
  n113[0] = 0;
  n79[0] = 0;
  n568[0] = 0;
  n450[0] = 0;
  n450r[0] = 0;
  n450e[0] = 0;
  n450d[0] = 0;
  n346[0] = 0;
  n115[0] = 0;
  n80[0] = 0;
  n599[0] = 0;
  n598[0] = 0;
  n597[0] = 0;
  n596[0] = 0;
  n578[0] = 0;
  n577[0] = 0;
  n576[0] = 0;
  n575[0] = 0;
  n574[0] = 0;
  n573[0] = 0;
  n572[0] = 0;
  n571[0] = 0;
  n570[0] = 0;
  n569[0] = 0;
  n347[0] = 0;
  n194[0] = 0;
  n192[0] = 0;
  n190[0] = 0;
  n188[0] = 0;
  n186[0] = 0;
  n184[0] = 0;
  n182[0] = 0;
  n180[0] = 0;
  n178[0] = 0;
  n176[0] = 0;
  n174[0] = 0;
  n172[0] = 0;
  n170[0] = 0;
  n168[0] = 0;
  n166[0] = 0;
  n164[0] = 0;
  n162[0] = 0;
  n160[0] = 0;
  n158[0] = 0;
  n156[0] = 0;
  n154[0] = 0;
  n152[0] = 0;
  n150[0] = 0;
  n148[0] = 0;
  n146[0] = 0;
  n144[0] = 0;
  n142[0] = 0;
  n140[0] = 0;
  n138[0] = 0;
  n136[0] = 0;
  n134[0] = 0;
  n81[0] = 0;
  n614[0] = 0;
  n581[0] = 0;
  n348[0] = 0;
  { int index; for (index = 2; index > 0;) n195[--index] = 0; }
  n86[0] = 0;
  n86r[0] = 0;
  n86e[0] = 0;
  n86d[0] = 0;
  n615[0] = 0;
  n582[0] = 0;
  n349[0] = 0;
  { int index; for (index = 2; index > 0;) n196[--index] = 0; }
  n616[0] = 0;
  n583[0] = 0;
  { int index; for (index = 2; index > 0;) n350[--index] = 0; }
  { int index; for (index = 2; index > 0;) n197[--index] = 0; }
  n617[0] = 0;
  n584[0] = 0;
  { int index; for (index = 2; index > 0;) n351[--index] = 0; }
  { int index; for (index = 2; index > 0;) n198[--index] = 0; }
  n585[0] = 0;
  { int index; for (index = 2; index > 0;) n352[--index] = 0; }
  { int index; for (index = 2; index > 0;) n199[--index] = 0; }
  n586[0] = 0;
  { int index; for (index = 2; index > 0;) n353[--index] = 0; }
  { int index; for (index = 2; index > 0;) n200[--index] = 0; }
  n587[0] = 0;
  { int index; for (index = 2; index > 0;) n354[--index] = 0; }
  { int index; for (index = 2; index > 0;) n201[--index] = 0; }
  n588[0] = 0;
  { int index; for (index = 2; index > 0;) n355[--index] = 0; }
  { int index; for (index = 2; index > 0;) n202[--index] = 0; }
  n589[0] = 0;
  { int index; for (index = 2; index > 0;) n356[--index] = 0; }
  { int index; for (index = 2; index > 0;) n203[--index] = 0; }
  n590[0] = 0;
  { int index; for (index = 2; index > 0;) n357[--index] = 0; }
  { int index; for (index = 2; index > 0;) n204[--index] = 0; }
  n595[0] = 0;
  n595r[0] = 0;
  n595e[0] = 0;
  n595d[0] = 0;
  { int index; for (index = 3; index > 0;) n358[--index] = 0; }
  { int index; for (index = 2; index > 0;) n205[--index] = 0; }
  { int index; for (index = 3; index > 0;) n359[--index] = 0; }
  { int index; for (index = 2; index > 0;) n206[--index] = 0; }
  { int index; for (index = 3; index > 0;) n360[--index] = 0; }
  { int index; for (index = 2; index > 0;) n207[--index] = 0; }
  { int index; for (index = 3; index > 0;) n361[--index] = 0; }
  { int index; for (index = 2; index > 0;) n208[--index] = 0; }
  { int index; for (index = 3; index > 0;) n362[--index] = 0; }
  { int index; for (index = 2; index > 0;) n209[--index] = 0; }
  { int index; for (index = 3; index > 0;) n363[--index] = 0; }
  { int index; for (index = 2; index > 0;) n210[--index] = 0; }
  { int index; for (index = 3; index > 0;) n364[--index] = 0; }
  { int index; for (index = 2; index > 0;) n211[--index] = 0; }
  { int index; for (index = 3; index > 0;) n365[--index] = 0; }
  { int index; for (index = 2; index > 0;) n212[--index] = 0; }
  { int index; for (index = 4; index > 0;) n366[--index] = 0; }
  { int index; for (index = 2; index > 0;) n213[--index] = 0; }
  { int index; for (index = 4; index > 0;) n367[--index] = 0; }
  { int index; for (index = 2; index > 0;) n214[--index] = 0; }
  { int index; for (index = 4; index > 0;) n368[--index] = 0; }
  { int index; for (index = 2; index > 0;) n215[--index] = 0; }
  { int index; for (index = 4; index > 0;) n369[--index] = 0; }
  { int index; for (index = 2; index > 0;) n216[--index] = 0; }
  { int index; for (index = 4; index > 0;) n370[--index] = 0; }
  { int index; for (index = 2; index > 0;) n217[--index] = 0; }
  { int index; for (index = 4; index > 0;) n371[--index] = 0; }
  { int index; for (index = 2; index > 0;) n218[--index] = 0; }
  { int index; for (index = 4; index > 0;) n372[--index] = 0; }
  { int index; for (index = 2; index > 0;) n219[--index] = 0; }
  { int index; for (index = 4; index > 0;) n373[--index] = 0; }
  { int index; for (index = 2; index > 0;) n220[--index] = 0; }
  { int index; for (index = 5; index > 0;) n374[--index] = 0; }
  { int index; for (index = 2; index > 0;) n221[--index] = 0; }
  { int index; for (index = 5; index > 0;) n375[--index] = 0; }
  { int index; for (index = 2; index > 0;) n222[--index] = 0; }
  { int index; for (index = 5; index > 0;) n376[--index] = 0; }
  { int index; for (index = 2; index > 0;) n223[--index] = 0; }
  { int index; for (index = 5; index > 0;) n377[--index] = 0; }
  { int index; for (index = 2; index > 0;) n224[--index] = 0; }
  { int index; for (index = 5; index > 0;) n378[--index] = 0; }
  { int index; for (index = 2; index > 0;) n225[--index] = 0; }
  { int index; for (index = 5; index > 0;) n379[--index] = 0; }
  n269[0] = 0;
  n266[0] = 0;
  n263[0] = 0;
  n260[0] = 0;
  n257[0] = 0;
  n254[0] = 0;
  n251[0] = 0;
  n248[0] = 0;
  n245[0] = 0;
  n242[0] = 0;
  n239[0] = 0;
  n236[0] = 0;
  n233[0] = 0;
  n230[0] = 0;
  n227[0] = 0;
  { int index; for (index = 5; index > 0;) n380[--index] = 0; }
  { int index; for (index = 5; index > 0;) n381[--index] = 0; }
  { int index; for (index = 6; index > 0;) n382[--index] = 0; }
  { int index; for (index = 6; index > 0;) n383[--index] = 0; }
  { int index; for (index = 6; index > 0;) n384[--index] = 0; }
  { int index; for (index = 6; index > 0;) n385[--index] = 0; }
  { int index; for (index = 6; index > 0;) n386[--index] = 0; }
  { int index; for (index = 6; index > 0;) n387[--index] = 0; }
  { int index; for (index = 6; index > 0;) n388[--index] = 0; }
  { int index; for (index = 6; index > 0;) n389[--index] = 0; }
  { int index; for (index = 7; index > 0;) n390[--index] = 0; }
  { int index; for (index = 7; index > 0;) n391[--index] = 0; }
  { int index; for (index = 7; index > 0;) n392[--index] = 0; }
  { int index; for (index = 7; index > 0;) n393[--index] = 0; }
  { int index; for (index = 7; index > 0;) n394[--index] = 0; }
  { int index; for (index = 7; index > 0;) n395[--index] = 0; }
  { int index; for (index = 7; index > 0;) n396[--index] = 0; }
  { int index; for (index = 7; index > 0;) n397[--index] = 0; }
  { int index; for (index = 8; index > 0;) n398[--index] = 0; }
  { int index; for (index = 8; index > 0;) n399[--index] = 0; }
  { int index; for (index = 8; index > 0;) n400[--index] = 0; }
  { int index; for (index = 8; index > 0;) n401[--index] = 0; }
  { int index; for (index = 8; index > 0;) n402[--index] = 0; }
  { int index; for (index = 8; index > 0;) n403[--index] = 0; }
  { int index; for (index = 8; index > 0;) n404[--index] = 0; }
  { int index; for (index = 8; index > 0;) n405[--index] = 0; }
  { int index; for (index = 8; index > 0;) n414[--index] = 0; }
  { int index; for (index = 8; index > 0;) n433[--index] = 0; }
  { int index; for (index = 8; index > 0;) n438[--index] = 0; }
  { int index; for (index = 8; index > 0;) n442[--index] = 0; }
  { int index; for (index = 8; index > 0;) n451[--index] = 0; }
  { int index; for (index = 8; index > 0;) n526[--index] = 0; }
  n526r[0] = 0;
  n526e[0] = 0;
  { int index; for (index = 8; index > 0;) n526d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n521[--index] = 0; }
  n521r[0] = 0;
  n521e[0] = 0;
  { int index; for (index = 8; index > 0;) n521d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n516[--index] = 0; }
  n516r[0] = 0;
  n516e[0] = 0;
  { int index; for (index = 8; index > 0;) n516d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n511[--index] = 0; }
  n511r[0] = 0;
  n511e[0] = 0;
  { int index; for (index = 8; index > 0;) n511d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n506[--index] = 0; }
  n506r[0] = 0;
  n506e[0] = 0;
  { int index; for (index = 8; index > 0;) n506d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n501[--index] = 0; }
  n501r[0] = 0;
  n501e[0] = 0;
  { int index; for (index = 8; index > 0;) n501d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n496[--index] = 0; }
  n496r[0] = 0;
  n496e[0] = 0;
  { int index; for (index = 8; index > 0;) n496d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n491[--index] = 0; }
  n491r[0] = 0;
  n491e[0] = 0;
  { int index; for (index = 8; index > 0;) n491d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n486[--index] = 0; }
  n486r[0] = 0;
  n486e[0] = 0;
  { int index; for (index = 8; index > 0;) n486d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n481[--index] = 0; }
  n481r[0] = 0;
  n481e[0] = 0;
  { int index; for (index = 8; index > 0;) n481d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n476[--index] = 0; }
  n476r[0] = 0;
  n476e[0] = 0;
  { int index; for (index = 8; index > 0;) n476d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n471[--index] = 0; }
  n471r[0] = 0;
  n471e[0] = 0;
  { int index; for (index = 8; index > 0;) n471d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n466[--index] = 0; }
  n466r[0] = 0;
  n466e[0] = 0;
  { int index; for (index = 8; index > 0;) n466d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n461[--index] = 0; }
  n461r[0] = 0;
  n461e[0] = 0;
  { int index; for (index = 8; index > 0;) n461d[--index] = 0; }
  { int index; for (index = 8; index > 0;) n456[--index] = 0; }
  n456r[0] = 0;
  n456e[0] = 0;
  { int index; for (index = 8; index > 0;) n456d[--index] = 0; }
  cf_ssp_64_6_calc();
}

void cf_ssp_64_6_cycle_clock()
{
  if (n18r[0]) {
    n18[0] = 0;
  }
  else if (n18e[0]) {
    n18[0] = n18d[0];
  }
  if (n25r[0]) {
    n25[0] = 0;
  }
  else if (n25e[0]) {
    n25[0] = n25d[0];
  }
  if (n32r[0]) {
    n32[0] = 0;
  }
  else if (n32e[0]) {
    n32[0] = n32d[0];
  }
  if (n86r[0]) {
    n86[0] = 0;
  }
  else if (n86e[0]) {
    n86[0] = n86d[0];
  }
  if (n111r[0]) {
    n111[0] = 0;
  }
  else if (n111e[0]) {
    n111[0] = n111d[0];
  }
  if (n278r[0]) {
    n278[0] = 0;
  }
  else if (n278e[0]) {
    n278[0] = n278d[0];
  }
  if (n308r[0]) {
    n308[0] = 0;
  }
  else if (n308e[0]) {
    n308[0] = n308d[0];
  }
  if (n338r[0]) {
    n338[0] = 0;
  }
  else if (n338e[0]) {
    n338[0] = n338d[0];
  }
  if (n450r[0]) {
    n450[0] = 0;
  }
  else if (n450e[0]) {
    n450[0] = n450d[0];
  }
  if (n456r[0]) {
    n456[0] = 0;
    n456[1] = 0;
    n456[2] = 0;
    n456[3] = 0;
    n456[4] = 0;
    n456[5] = 0;
    n456[6] = 0;
    n456[7] = 0;
  }
  else if (n456e[0]) {
    n456[0] = n456d[0];
    n456[1] = n456d[1];
    n456[2] = n456d[2];
    n456[3] = n456d[3];
    n456[4] = n456d[4];
    n456[5] = n456d[5];
    n456[6] = n456d[6];
    n456[7] = n456d[7];
  }
  if (n461r[0]) {
    n461[0] = 0;
    n461[1] = 0;
    n461[2] = 0;
    n461[3] = 0;
    n461[4] = 0;
    n461[5] = 0;
    n461[6] = 0;
    n461[7] = 0;
  }
  else if (n461e[0]) {
    n461[0] = n461d[0];
    n461[1] = n461d[1];
    n461[2] = n461d[2];
    n461[3] = n461d[3];
    n461[4] = n461d[4];
    n461[5] = n461d[5];
    n461[6] = n461d[6];
    n461[7] = n461d[7];
  }
  if (n466r[0]) {
    n466[0] = 0;
    n466[1] = 0;
    n466[2] = 0;
    n466[3] = 0;
    n466[4] = 0;
    n466[5] = 0;
    n466[6] = 0;
    n466[7] = 0;
  }
  else if (n466e[0]) {
    n466[0] = n466d[0];
    n466[1] = n466d[1];
    n466[2] = n466d[2];
    n466[3] = n466d[3];
    n466[4] = n466d[4];
    n466[5] = n466d[5];
    n466[6] = n466d[6];
    n466[7] = n466d[7];
  }
  if (n471r[0]) {
    n471[0] = 0;
    n471[1] = 0;
    n471[2] = 0;
    n471[3] = 0;
    n471[4] = 0;
    n471[5] = 0;
    n471[6] = 0;
    n471[7] = 0;
  }
  else if (n471e[0]) {
    n471[0] = n471d[0];
    n471[1] = n471d[1];
    n471[2] = n471d[2];
    n471[3] = n471d[3];
    n471[4] = n471d[4];
    n471[5] = n471d[5];
    n471[6] = n471d[6];
    n471[7] = n471d[7];
  }
  if (n476r[0]) {
    n476[0] = 0;
    n476[1] = 0;
    n476[2] = 0;
    n476[3] = 0;
    n476[4] = 0;
    n476[5] = 0;
    n476[6] = 0;
    n476[7] = 0;
  }
  else if (n476e[0]) {
    n476[0] = n476d[0];
    n476[1] = n476d[1];
    n476[2] = n476d[2];
    n476[3] = n476d[3];
    n476[4] = n476d[4];
    n476[5] = n476d[5];
    n476[6] = n476d[6];
    n476[7] = n476d[7];
  }
  if (n481r[0]) {
    n481[0] = 0;
    n481[1] = 0;
    n481[2] = 0;
    n481[3] = 0;
    n481[4] = 0;
    n481[5] = 0;
    n481[6] = 0;
    n481[7] = 0;
  }
  else if (n481e[0]) {
    n481[0] = n481d[0];
    n481[1] = n481d[1];
    n481[2] = n481d[2];
    n481[3] = n481d[3];
    n481[4] = n481d[4];
    n481[5] = n481d[5];
    n481[6] = n481d[6];
    n481[7] = n481d[7];
  }
  if (n486r[0]) {
    n486[0] = 0;
    n486[1] = 0;
    n486[2] = 0;
    n486[3] = 0;
    n486[4] = 0;
    n486[5] = 0;
    n486[6] = 0;
    n486[7] = 0;
  }
  else if (n486e[0]) {
    n486[0] = n486d[0];
    n486[1] = n486d[1];
    n486[2] = n486d[2];
    n486[3] = n486d[3];
    n486[4] = n486d[4];
    n486[5] = n486d[5];
    n486[6] = n486d[6];
    n486[7] = n486d[7];
  }
  if (n491r[0]) {
    n491[0] = 0;
    n491[1] = 0;
    n491[2] = 0;
    n491[3] = 0;
    n491[4] = 0;
    n491[5] = 0;
    n491[6] = 0;
    n491[7] = 0;
  }
  else if (n491e[0]) {
    n491[0] = n491d[0];
    n491[1] = n491d[1];
    n491[2] = n491d[2];
    n491[3] = n491d[3];
    n491[4] = n491d[4];
    n491[5] = n491d[5];
    n491[6] = n491d[6];
    n491[7] = n491d[7];
  }
  if (n496r[0]) {
    n496[0] = 0;
    n496[1] = 0;
    n496[2] = 0;
    n496[3] = 0;
    n496[4] = 0;
    n496[5] = 0;
    n496[6] = 0;
    n496[7] = 0;
  }
  else if (n496e[0]) {
    n496[0] = n496d[0];
    n496[1] = n496d[1];
    n496[2] = n496d[2];
    n496[3] = n496d[3];
    n496[4] = n496d[4];
    n496[5] = n496d[5];
    n496[6] = n496d[6];
    n496[7] = n496d[7];
  }
  if (n501r[0]) {
    n501[0] = 0;
    n501[1] = 0;
    n501[2] = 0;
    n501[3] = 0;
    n501[4] = 0;
    n501[5] = 0;
    n501[6] = 0;
    n501[7] = 0;
  }
  else if (n501e[0]) {
    n501[0] = n501d[0];
    n501[1] = n501d[1];
    n501[2] = n501d[2];
    n501[3] = n501d[3];
    n501[4] = n501d[4];
    n501[5] = n501d[5];
    n501[6] = n501d[6];
    n501[7] = n501d[7];
  }
  if (n506r[0]) {
    n506[0] = 0;
    n506[1] = 0;
    n506[2] = 0;
    n506[3] = 0;
    n506[4] = 0;
    n506[5] = 0;
    n506[6] = 0;
    n506[7] = 0;
  }
  else if (n506e[0]) {
    n506[0] = n506d[0];
    n506[1] = n506d[1];
    n506[2] = n506d[2];
    n506[3] = n506d[3];
    n506[4] = n506d[4];
    n506[5] = n506d[5];
    n506[6] = n506d[6];
    n506[7] = n506d[7];
  }
  if (n511r[0]) {
    n511[0] = 0;
    n511[1] = 0;
    n511[2] = 0;
    n511[3] = 0;
    n511[4] = 0;
    n511[5] = 0;
    n511[6] = 0;
    n511[7] = 0;
  }
  else if (n511e[0]) {
    n511[0] = n511d[0];
    n511[1] = n511d[1];
    n511[2] = n511d[2];
    n511[3] = n511d[3];
    n511[4] = n511d[4];
    n511[5] = n511d[5];
    n511[6] = n511d[6];
    n511[7] = n511d[7];
  }
  if (n516r[0]) {
    n516[0] = 0;
    n516[1] = 0;
    n516[2] = 0;
    n516[3] = 0;
    n516[4] = 0;
    n516[5] = 0;
    n516[6] = 0;
    n516[7] = 0;
  }
  else if (n516e[0]) {
    n516[0] = n516d[0];
    n516[1] = n516d[1];
    n516[2] = n516d[2];
    n516[3] = n516d[3];
    n516[4] = n516d[4];
    n516[5] = n516d[5];
    n516[6] = n516d[6];
    n516[7] = n516d[7];
  }
  if (n521r[0]) {
    n521[0] = 0;
    n521[1] = 0;
    n521[2] = 0;
    n521[3] = 0;
    n521[4] = 0;
    n521[5] = 0;
    n521[6] = 0;
    n521[7] = 0;
  }
  else if (n521e[0]) {
    n521[0] = n521d[0];
    n521[1] = n521d[1];
    n521[2] = n521d[2];
    n521[3] = n521d[3];
    n521[4] = n521d[4];
    n521[5] = n521d[5];
    n521[6] = n521d[6];
    n521[7] = n521d[7];
  }
  if (n526r[0]) {
    n526[0] = 0;
    n526[1] = 0;
    n526[2] = 0;
    n526[3] = 0;
    n526[4] = 0;
    n526[5] = 0;
    n526[6] = 0;
    n526[7] = 0;
  }
  else if (n526e[0]) {
    n526[0] = n526d[0];
    n526[1] = n526d[1];
    n526[2] = n526d[2];
    n526[3] = n526d[3];
    n526[4] = n526d[4];
    n526[5] = n526d[5];
    n526[6] = n526d[6];
    n526[7] = n526d[7];
  }
  if (n595r[0]) {
    n595[0] = 0;
  }
  else if (n595e[0]) {
    n595[0] = n595d[0];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_state_i[1];
static unsigned char sim_cycle_i[1];
static unsigned char sim_instr_data_i[2];
static unsigned char sim_const_data_i[8];
static unsigned char sim_load_write_i[1];
static unsigned char sim_load_addr_i[1];
static unsigned char sim_load_data_i[8];
static unsigned char sim_done_o[1];
static unsigned char sim_instr_addr_o[1];
static unsigned char sim_const_addr_o[1];
static unsigned char sim_reg_0_o[8];
static unsigned char sim_reg_1_o[8];
static unsigned char sim_reg_2_o[8];
static unsigned char sim_reg_3_o[8];
static unsigned char sim_reg_4_o[8];
static unsigned char sim_reg_5_o[8];
static unsigned char sim_reg_6_o[8];
static unsigned char sim_reg_7_o[8];
static unsigned char sim_reg_8_o[8];
static unsigned char sim_reg_9_o[8];
static unsigned char sim_reg_a_o[8];
static unsigned char sim_reg_b_o[8];
static unsigned char sim_reg_c_o[8];
static unsigned char sim_reg_d_o[8];
static unsigned char sim_reg_e_o[8];
static unsigned char sim_reg_f_o[8];

void cf_ssp_64_6_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_ssp_64_6_init();
  sim_reset_state_i[0] = reset_state_i[0];
  sim_cycle_i[0] = cycle_i[0];
  sim_instr_data_i[0] = instr_data_i[0];
  sim_instr_data_i[1] = instr_data_i[1];
  sim_const_data_i[0] = const_data_i[0];
  sim_const_data_i[1] = const_data_i[1];
  sim_const_data_i[2] = const_data_i[2];
  sim_const_data_i[3] = const_data_i[3];
  sim_const_data_i[4] = const_data_i[4];
  sim_const_data_i[5] = const_data_i[5];
  sim_const_data_i[6] = const_data_i[6];
  sim_const_data_i[7] = const_data_i[7];
  sim_load_write_i[0] = load_write_i[0];
  sim_load_addr_i[0] = load_addr_i[0];
  sim_load_data_i[0] = load_data_i[0];
  sim_load_data_i[1] = load_data_i[1];
  sim_load_data_i[2] = load_data_i[2];
  sim_load_data_i[3] = load_data_i[3];
  sim_load_data_i[4] = load_data_i[4];
  sim_load_data_i[5] = load_data_i[5];
  sim_load_data_i[6] = load_data_i[6];
  sim_load_data_i[7] = load_data_i[7];
  sim_done_o[0] = done_o[0];
  sim_instr_addr_o[0] = instr_addr_o[0];
  sim_const_addr_o[0] = const_addr_o[0];
  sim_reg_0_o[0] = reg_0_o[0];
  sim_reg_0_o[1] = reg_0_o[1];
  sim_reg_0_o[2] = reg_0_o[2];
  sim_reg_0_o[3] = reg_0_o[3];
  sim_reg_0_o[4] = reg_0_o[4];
  sim_reg_0_o[5] = reg_0_o[5];
  sim_reg_0_o[6] = reg_0_o[6];
  sim_reg_0_o[7] = reg_0_o[7];
  sim_reg_1_o[0] = reg_1_o[0];
  sim_reg_1_o[1] = reg_1_o[1];
  sim_reg_1_o[2] = reg_1_o[2];
  sim_reg_1_o[3] = reg_1_o[3];
  sim_reg_1_o[4] = reg_1_o[4];
  sim_reg_1_o[5] = reg_1_o[5];
  sim_reg_1_o[6] = reg_1_o[6];
  sim_reg_1_o[7] = reg_1_o[7];
  sim_reg_2_o[0] = reg_2_o[0];
  sim_reg_2_o[1] = reg_2_o[1];
  sim_reg_2_o[2] = reg_2_o[2];
  sim_reg_2_o[3] = reg_2_o[3];
  sim_reg_2_o[4] = reg_2_o[4];
  sim_reg_2_o[5] = reg_2_o[5];
  sim_reg_2_o[6] = reg_2_o[6];
  sim_reg_2_o[7] = reg_2_o[7];
  sim_reg_3_o[0] = reg_3_o[0];
  sim_reg_3_o[1] = reg_3_o[1];
  sim_reg_3_o[2] = reg_3_o[2];
  sim_reg_3_o[3] = reg_3_o[3];
  sim_reg_3_o[4] = reg_3_o[4];
  sim_reg_3_o[5] = reg_3_o[5];
  sim_reg_3_o[6] = reg_3_o[6];
  sim_reg_3_o[7] = reg_3_o[7];
  sim_reg_4_o[0] = reg_4_o[0];
  sim_reg_4_o[1] = reg_4_o[1];
  sim_reg_4_o[2] = reg_4_o[2];
  sim_reg_4_o[3] = reg_4_o[3];
  sim_reg_4_o[4] = reg_4_o[4];
  sim_reg_4_o[5] = reg_4_o[5];
  sim_reg_4_o[6] = reg_4_o[6];
  sim_reg_4_o[7] = reg_4_o[7];
  sim_reg_5_o[0] = reg_5_o[0];
  sim_reg_5_o[1] = reg_5_o[1];
  sim_reg_5_o[2] = reg_5_o[2];
  sim_reg_5_o[3] = reg_5_o[3];
  sim_reg_5_o[4] = reg_5_o[4];
  sim_reg_5_o[5] = reg_5_o[5];
  sim_reg_5_o[6] = reg_5_o[6];
  sim_reg_5_o[7] = reg_5_o[7];
  sim_reg_6_o[0] = reg_6_o[0];
  sim_reg_6_o[1] = reg_6_o[1];
  sim_reg_6_o[2] = reg_6_o[2];
  sim_reg_6_o[3] = reg_6_o[3];
  sim_reg_6_o[4] = reg_6_o[4];
  sim_reg_6_o[5] = reg_6_o[5];
  sim_reg_6_o[6] = reg_6_o[6];
  sim_reg_6_o[7] = reg_6_o[7];
  sim_reg_7_o[0] = reg_7_o[0];
  sim_reg_7_o[1] = reg_7_o[1];
  sim_reg_7_o[2] = reg_7_o[2];
  sim_reg_7_o[3] = reg_7_o[3];
  sim_reg_7_o[4] = reg_7_o[4];
  sim_reg_7_o[5] = reg_7_o[5];
  sim_reg_7_o[6] = reg_7_o[6];
  sim_reg_7_o[7] = reg_7_o[7];
  sim_reg_8_o[0] = reg_8_o[0];
  sim_reg_8_o[1] = reg_8_o[1];
  sim_reg_8_o[2] = reg_8_o[2];
  sim_reg_8_o[3] = reg_8_o[3];
  sim_reg_8_o[4] = reg_8_o[4];
  sim_reg_8_o[5] = reg_8_o[5];
  sim_reg_8_o[6] = reg_8_o[6];
  sim_reg_8_o[7] = reg_8_o[7];
  sim_reg_9_o[0] = reg_9_o[0];
  sim_reg_9_o[1] = reg_9_o[1];
  sim_reg_9_o[2] = reg_9_o[2];
  sim_reg_9_o[3] = reg_9_o[3];
  sim_reg_9_o[4] = reg_9_o[4];
  sim_reg_9_o[5] = reg_9_o[5];
  sim_reg_9_o[6] = reg_9_o[6];
  sim_reg_9_o[7] = reg_9_o[7];
  sim_reg_a_o[0] = reg_a_o[0];
  sim_reg_a_o[1] = reg_a_o[1];
  sim_reg_a_o[2] = reg_a_o[2];
  sim_reg_a_o[3] = reg_a_o[3];
  sim_reg_a_o[4] = reg_a_o[4];
  sim_reg_a_o[5] = reg_a_o[5];
  sim_reg_a_o[6] = reg_a_o[6];
  sim_reg_a_o[7] = reg_a_o[7];
  sim_reg_b_o[0] = reg_b_o[0];
  sim_reg_b_o[1] = reg_b_o[1];
  sim_reg_b_o[2] = reg_b_o[2];
  sim_reg_b_o[3] = reg_b_o[3];
  sim_reg_b_o[4] = reg_b_o[4];
  sim_reg_b_o[5] = reg_b_o[5];
  sim_reg_b_o[6] = reg_b_o[6];
  sim_reg_b_o[7] = reg_b_o[7];
  sim_reg_c_o[0] = reg_c_o[0];
  sim_reg_c_o[1] = reg_c_o[1];
  sim_reg_c_o[2] = reg_c_o[2];
  sim_reg_c_o[3] = reg_c_o[3];
  sim_reg_c_o[4] = reg_c_o[4];
  sim_reg_c_o[5] = reg_c_o[5];
  sim_reg_c_o[6] = reg_c_o[6];
  sim_reg_c_o[7] = reg_c_o[7];
  sim_reg_d_o[0] = reg_d_o[0];
  sim_reg_d_o[1] = reg_d_o[1];
  sim_reg_d_o[2] = reg_d_o[2];
  sim_reg_d_o[3] = reg_d_o[3];
  sim_reg_d_o[4] = reg_d_o[4];
  sim_reg_d_o[5] = reg_d_o[5];
  sim_reg_d_o[6] = reg_d_o[6];
  sim_reg_d_o[7] = reg_d_o[7];
  sim_reg_e_o[0] = reg_e_o[0];
  sim_reg_e_o[1] = reg_e_o[1];
  sim_reg_e_o[2] = reg_e_o[2];
  sim_reg_e_o[3] = reg_e_o[3];
  sim_reg_e_o[4] = reg_e_o[4];
  sim_reg_e_o[5] = reg_e_o[5];
  sim_reg_e_o[6] = reg_e_o[6];
  sim_reg_e_o[7] = reg_e_o[7];
  sim_reg_f_o[0] = reg_f_o[0];
  sim_reg_f_o[1] = reg_f_o[1];
  sim_reg_f_o[2] = reg_f_o[2];
  sim_reg_f_o[3] = reg_f_o[3];
  sim_reg_f_o[4] = reg_f_o[4];
  sim_reg_f_o[5] = reg_f_o[5];
  sim_reg_f_o[6] = reg_f_o[6];
  sim_reg_f_o[7] = reg_f_o[7];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_ssp_64_6 $end\n"
    "$var wire 1 ! reset_state_i $end\n"
    "$var wire 1 \" cycle_i $end\n"
    "$var wire 16 # instr_data_i $end\n"
    "$var wire 64 $ const_data_i $end\n"
    "$var wire 1 %% load_write_i $end\n"
    "$var wire 4 & load_addr_i $end\n"
    "$var wire 64 ' load_data_i $end\n"
    "$var wire 1 ( done_o $end\n"
    "$var wire 6 ) instr_addr_o $end\n"
    "$var wire 8 * const_addr_o $end\n"
    "$var wire 64 + reg_0_o $end\n"
    "$var wire 64 , reg_1_o $end\n"
    "$var wire 64 - reg_2_o $end\n"
    "$var wire 64 . reg_3_o $end\n"
    "$var wire 64 / reg_4_o $end\n"
    "$var wire 64 0 reg_5_o $end\n"
    "$var wire 64 1 reg_6_o $end\n"
    "$var wire 64 2 reg_7_o $end\n"
    "$var wire 64 3 reg_8_o $end\n"
    "$var wire 64 4 reg_9_o $end\n"
    "$var wire 64 5 reg_a_o $end\n"
    "$var wire 64 6 reg_b_o $end\n"
    "$var wire 64 7 reg_c_o $end\n"
    "$var wire 64 8 reg_d_o $end\n"
    "$var wire 64 9 reg_e_o $end\n"
    "$var wire 64 : reg_f_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_state_i[0] ? "1!\n" : "0!\n");
  fprintf(sim_file, cycle_i[0] ? "1\"\n" : "0\"\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & instr_data_i[byte]) ? "1" : "0");
        else if (bit & instr_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & const_data_i[byte]) ? "1" : "0");
        else if (bit & const_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  fprintf(sim_file, load_write_i[0] ? "1%%\n" : "0%%\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & load_addr_i[byte]) ? "1" : "0");
        else if (bit & load_addr_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & load_data_i[byte]) ? "1" : "0");
        else if (bit & load_data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  fprintf(sim_file, done_o[0] ? "1(\n" : "0(\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & instr_addr_o[byte]) ? "1" : "0");
        else if (bit & instr_addr_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & const_addr_o[byte]) ? "1" : "0");
        else if (bit & const_addr_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_0_o[byte]) ? "1" : "0");
        else if (bit & reg_0_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_1_o[byte]) ? "1" : "0");
        else if (bit & reg_1_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ,\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_2_o[byte]) ? "1" : "0");
        else if (bit & reg_2_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " -\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_3_o[byte]) ? "1" : "0");
        else if (bit & reg_3_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " .\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_4_o[byte]) ? "1" : "0");
        else if (bit & reg_4_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " /\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_5_o[byte]) ? "1" : "0");
        else if (bit & reg_5_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 0\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_6_o[byte]) ? "1" : "0");
        else if (bit & reg_6_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 1\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_7_o[byte]) ? "1" : "0");
        else if (bit & reg_7_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 2\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_8_o[byte]) ? "1" : "0");
        else if (bit & reg_8_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 3\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_9_o[byte]) ? "1" : "0");
        else if (bit & reg_9_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 4\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_a_o[byte]) ? "1" : "0");
        else if (bit & reg_a_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 5\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_b_o[byte]) ? "1" : "0");
        else if (bit & reg_b_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 6\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_c_o[byte]) ? "1" : "0");
        else if (bit & reg_c_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 7\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_d_o[byte]) ? "1" : "0");
        else if (bit & reg_d_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 8\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_e_o[byte]) ? "1" : "0");
        else if (bit & reg_e_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 9\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 7; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & reg_f_o[byte]) ? "1" : "0");
        else if (bit & reg_f_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " :\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_ssp_64_6_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_ssp_64_6_sim_sample() {
  int changed = 0;
  if (sim_reset_state_i[0] != reset_state_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_state_i[0] ? "1!\n" : "0!\n");
    sim_reset_state_i[0] = reset_state_i[0];
  }
  if (sim_cycle_i[0] != cycle_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, cycle_i[0] ? "1\"\n" : "0\"\n");
    sim_cycle_i[0] = cycle_i[0];
  }
  if (sim_instr_data_i[1] != instr_data_i[1] || sim_instr_data_i[0] != instr_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & instr_data_i[byte]) ? "1" : "0");
          else if (bit & instr_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_instr_data_i[0] = instr_data_i[0];
    sim_instr_data_i[1] = instr_data_i[1];
  }
  if (sim_const_data_i[7] != const_data_i[7] || sim_const_data_i[6] != const_data_i[6] || sim_const_data_i[5] != const_data_i[5] || sim_const_data_i[4] != const_data_i[4] || sim_const_data_i[3] != const_data_i[3] || sim_const_data_i[2] != const_data_i[2] || sim_const_data_i[1] != const_data_i[1] || sim_const_data_i[0] != const_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & const_data_i[byte]) ? "1" : "0");
          else if (bit & const_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_const_data_i[0] = const_data_i[0];
    sim_const_data_i[1] = const_data_i[1];
    sim_const_data_i[2] = const_data_i[2];
    sim_const_data_i[3] = const_data_i[3];
    sim_const_data_i[4] = const_data_i[4];
    sim_const_data_i[5] = const_data_i[5];
    sim_const_data_i[6] = const_data_i[6];
    sim_const_data_i[7] = const_data_i[7];
  }
  if (sim_load_write_i[0] != load_write_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, load_write_i[0] ? "1%%\n" : "0%%\n");
    sim_load_write_i[0] = load_write_i[0];
  }
  if (sim_load_addr_i[0] != load_addr_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & load_addr_i[byte]) ? "1" : "0");
          else if (bit & load_addr_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_load_addr_i[0] = load_addr_i[0];
  }
  if (sim_load_data_i[7] != load_data_i[7] || sim_load_data_i[6] != load_data_i[6] || sim_load_data_i[5] != load_data_i[5] || sim_load_data_i[4] != load_data_i[4] || sim_load_data_i[3] != load_data_i[3] || sim_load_data_i[2] != load_data_i[2] || sim_load_data_i[1] != load_data_i[1] || sim_load_data_i[0] != load_data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & load_data_i[byte]) ? "1" : "0");
          else if (bit & load_data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_load_data_i[0] = load_data_i[0];
    sim_load_data_i[1] = load_data_i[1];
    sim_load_data_i[2] = load_data_i[2];
    sim_load_data_i[3] = load_data_i[3];
    sim_load_data_i[4] = load_data_i[4];
    sim_load_data_i[5] = load_data_i[5];
    sim_load_data_i[6] = load_data_i[6];
    sim_load_data_i[7] = load_data_i[7];
  }
  if (sim_done_o[0] != done_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, done_o[0] ? "1(\n" : "0(\n");
    sim_done_o[0] = done_o[0];
  }
  if (sim_instr_addr_o[0] != instr_addr_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & instr_addr_o[byte]) ? "1" : "0");
          else if (bit & instr_addr_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_instr_addr_o[0] = instr_addr_o[0];
  }
  if (sim_const_addr_o[0] != const_addr_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & const_addr_o[byte]) ? "1" : "0");
          else if (bit & const_addr_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_const_addr_o[0] = const_addr_o[0];
  }
  if (sim_reg_0_o[7] != reg_0_o[7] || sim_reg_0_o[6] != reg_0_o[6] || sim_reg_0_o[5] != reg_0_o[5] || sim_reg_0_o[4] != reg_0_o[4] || sim_reg_0_o[3] != reg_0_o[3] || sim_reg_0_o[2] != reg_0_o[2] || sim_reg_0_o[1] != reg_0_o[1] || sim_reg_0_o[0] != reg_0_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_0_o[byte]) ? "1" : "0");
          else if (bit & reg_0_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_reg_0_o[0] = reg_0_o[0];
    sim_reg_0_o[1] = reg_0_o[1];
    sim_reg_0_o[2] = reg_0_o[2];
    sim_reg_0_o[3] = reg_0_o[3];
    sim_reg_0_o[4] = reg_0_o[4];
    sim_reg_0_o[5] = reg_0_o[5];
    sim_reg_0_o[6] = reg_0_o[6];
    sim_reg_0_o[7] = reg_0_o[7];
  }
  if (sim_reg_1_o[7] != reg_1_o[7] || sim_reg_1_o[6] != reg_1_o[6] || sim_reg_1_o[5] != reg_1_o[5] || sim_reg_1_o[4] != reg_1_o[4] || sim_reg_1_o[3] != reg_1_o[3] || sim_reg_1_o[2] != reg_1_o[2] || sim_reg_1_o[1] != reg_1_o[1] || sim_reg_1_o[0] != reg_1_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_1_o[byte]) ? "1" : "0");
          else if (bit & reg_1_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ,\n");
    }
    sim_reg_1_o[0] = reg_1_o[0];
    sim_reg_1_o[1] = reg_1_o[1];
    sim_reg_1_o[2] = reg_1_o[2];
    sim_reg_1_o[3] = reg_1_o[3];
    sim_reg_1_o[4] = reg_1_o[4];
    sim_reg_1_o[5] = reg_1_o[5];
    sim_reg_1_o[6] = reg_1_o[6];
    sim_reg_1_o[7] = reg_1_o[7];
  }
  if (sim_reg_2_o[7] != reg_2_o[7] || sim_reg_2_o[6] != reg_2_o[6] || sim_reg_2_o[5] != reg_2_o[5] || sim_reg_2_o[4] != reg_2_o[4] || sim_reg_2_o[3] != reg_2_o[3] || sim_reg_2_o[2] != reg_2_o[2] || sim_reg_2_o[1] != reg_2_o[1] || sim_reg_2_o[0] != reg_2_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_2_o[byte]) ? "1" : "0");
          else if (bit & reg_2_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " -\n");
    }
    sim_reg_2_o[0] = reg_2_o[0];
    sim_reg_2_o[1] = reg_2_o[1];
    sim_reg_2_o[2] = reg_2_o[2];
    sim_reg_2_o[3] = reg_2_o[3];
    sim_reg_2_o[4] = reg_2_o[4];
    sim_reg_2_o[5] = reg_2_o[5];
    sim_reg_2_o[6] = reg_2_o[6];
    sim_reg_2_o[7] = reg_2_o[7];
  }
  if (sim_reg_3_o[7] != reg_3_o[7] || sim_reg_3_o[6] != reg_3_o[6] || sim_reg_3_o[5] != reg_3_o[5] || sim_reg_3_o[4] != reg_3_o[4] || sim_reg_3_o[3] != reg_3_o[3] || sim_reg_3_o[2] != reg_3_o[2] || sim_reg_3_o[1] != reg_3_o[1] || sim_reg_3_o[0] != reg_3_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_3_o[byte]) ? "1" : "0");
          else if (bit & reg_3_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " .\n");
    }
    sim_reg_3_o[0] = reg_3_o[0];
    sim_reg_3_o[1] = reg_3_o[1];
    sim_reg_3_o[2] = reg_3_o[2];
    sim_reg_3_o[3] = reg_3_o[3];
    sim_reg_3_o[4] = reg_3_o[4];
    sim_reg_3_o[5] = reg_3_o[5];
    sim_reg_3_o[6] = reg_3_o[6];
    sim_reg_3_o[7] = reg_3_o[7];
  }
  if (sim_reg_4_o[7] != reg_4_o[7] || sim_reg_4_o[6] != reg_4_o[6] || sim_reg_4_o[5] != reg_4_o[5] || sim_reg_4_o[4] != reg_4_o[4] || sim_reg_4_o[3] != reg_4_o[3] || sim_reg_4_o[2] != reg_4_o[2] || sim_reg_4_o[1] != reg_4_o[1] || sim_reg_4_o[0] != reg_4_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_4_o[byte]) ? "1" : "0");
          else if (bit & reg_4_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " /\n");
    }
    sim_reg_4_o[0] = reg_4_o[0];
    sim_reg_4_o[1] = reg_4_o[1];
    sim_reg_4_o[2] = reg_4_o[2];
    sim_reg_4_o[3] = reg_4_o[3];
    sim_reg_4_o[4] = reg_4_o[4];
    sim_reg_4_o[5] = reg_4_o[5];
    sim_reg_4_o[6] = reg_4_o[6];
    sim_reg_4_o[7] = reg_4_o[7];
  }
  if (sim_reg_5_o[7] != reg_5_o[7] || sim_reg_5_o[6] != reg_5_o[6] || sim_reg_5_o[5] != reg_5_o[5] || sim_reg_5_o[4] != reg_5_o[4] || sim_reg_5_o[3] != reg_5_o[3] || sim_reg_5_o[2] != reg_5_o[2] || sim_reg_5_o[1] != reg_5_o[1] || sim_reg_5_o[0] != reg_5_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_5_o[byte]) ? "1" : "0");
          else if (bit & reg_5_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 0\n");
    }
    sim_reg_5_o[0] = reg_5_o[0];
    sim_reg_5_o[1] = reg_5_o[1];
    sim_reg_5_o[2] = reg_5_o[2];
    sim_reg_5_o[3] = reg_5_o[3];
    sim_reg_5_o[4] = reg_5_o[4];
    sim_reg_5_o[5] = reg_5_o[5];
    sim_reg_5_o[6] = reg_5_o[6];
    sim_reg_5_o[7] = reg_5_o[7];
  }
  if (sim_reg_6_o[7] != reg_6_o[7] || sim_reg_6_o[6] != reg_6_o[6] || sim_reg_6_o[5] != reg_6_o[5] || sim_reg_6_o[4] != reg_6_o[4] || sim_reg_6_o[3] != reg_6_o[3] || sim_reg_6_o[2] != reg_6_o[2] || sim_reg_6_o[1] != reg_6_o[1] || sim_reg_6_o[0] != reg_6_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_6_o[byte]) ? "1" : "0");
          else if (bit & reg_6_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 1\n");
    }
    sim_reg_6_o[0] = reg_6_o[0];
    sim_reg_6_o[1] = reg_6_o[1];
    sim_reg_6_o[2] = reg_6_o[2];
    sim_reg_6_o[3] = reg_6_o[3];
    sim_reg_6_o[4] = reg_6_o[4];
    sim_reg_6_o[5] = reg_6_o[5];
    sim_reg_6_o[6] = reg_6_o[6];
    sim_reg_6_o[7] = reg_6_o[7];
  }
  if (sim_reg_7_o[7] != reg_7_o[7] || sim_reg_7_o[6] != reg_7_o[6] || sim_reg_7_o[5] != reg_7_o[5] || sim_reg_7_o[4] != reg_7_o[4] || sim_reg_7_o[3] != reg_7_o[3] || sim_reg_7_o[2] != reg_7_o[2] || sim_reg_7_o[1] != reg_7_o[1] || sim_reg_7_o[0] != reg_7_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_7_o[byte]) ? "1" : "0");
          else if (bit & reg_7_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 2\n");
    }
    sim_reg_7_o[0] = reg_7_o[0];
    sim_reg_7_o[1] = reg_7_o[1];
    sim_reg_7_o[2] = reg_7_o[2];
    sim_reg_7_o[3] = reg_7_o[3];
    sim_reg_7_o[4] = reg_7_o[4];
    sim_reg_7_o[5] = reg_7_o[5];
    sim_reg_7_o[6] = reg_7_o[6];
    sim_reg_7_o[7] = reg_7_o[7];
  }
  if (sim_reg_8_o[7] != reg_8_o[7] || sim_reg_8_o[6] != reg_8_o[6] || sim_reg_8_o[5] != reg_8_o[5] || sim_reg_8_o[4] != reg_8_o[4] || sim_reg_8_o[3] != reg_8_o[3] || sim_reg_8_o[2] != reg_8_o[2] || sim_reg_8_o[1] != reg_8_o[1] || sim_reg_8_o[0] != reg_8_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_8_o[byte]) ? "1" : "0");
          else if (bit & reg_8_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 3\n");
    }
    sim_reg_8_o[0] = reg_8_o[0];
    sim_reg_8_o[1] = reg_8_o[1];
    sim_reg_8_o[2] = reg_8_o[2];
    sim_reg_8_o[3] = reg_8_o[3];
    sim_reg_8_o[4] = reg_8_o[4];
    sim_reg_8_o[5] = reg_8_o[5];
    sim_reg_8_o[6] = reg_8_o[6];
    sim_reg_8_o[7] = reg_8_o[7];
  }
  if (sim_reg_9_o[7] != reg_9_o[7] || sim_reg_9_o[6] != reg_9_o[6] || sim_reg_9_o[5] != reg_9_o[5] || sim_reg_9_o[4] != reg_9_o[4] || sim_reg_9_o[3] != reg_9_o[3] || sim_reg_9_o[2] != reg_9_o[2] || sim_reg_9_o[1] != reg_9_o[1] || sim_reg_9_o[0] != reg_9_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_9_o[byte]) ? "1" : "0");
          else if (bit & reg_9_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 4\n");
    }
    sim_reg_9_o[0] = reg_9_o[0];
    sim_reg_9_o[1] = reg_9_o[1];
    sim_reg_9_o[2] = reg_9_o[2];
    sim_reg_9_o[3] = reg_9_o[3];
    sim_reg_9_o[4] = reg_9_o[4];
    sim_reg_9_o[5] = reg_9_o[5];
    sim_reg_9_o[6] = reg_9_o[6];
    sim_reg_9_o[7] = reg_9_o[7];
  }
  if (sim_reg_a_o[7] != reg_a_o[7] || sim_reg_a_o[6] != reg_a_o[6] || sim_reg_a_o[5] != reg_a_o[5] || sim_reg_a_o[4] != reg_a_o[4] || sim_reg_a_o[3] != reg_a_o[3] || sim_reg_a_o[2] != reg_a_o[2] || sim_reg_a_o[1] != reg_a_o[1] || sim_reg_a_o[0] != reg_a_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_a_o[byte]) ? "1" : "0");
          else if (bit & reg_a_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 5\n");
    }
    sim_reg_a_o[0] = reg_a_o[0];
    sim_reg_a_o[1] = reg_a_o[1];
    sim_reg_a_o[2] = reg_a_o[2];
    sim_reg_a_o[3] = reg_a_o[3];
    sim_reg_a_o[4] = reg_a_o[4];
    sim_reg_a_o[5] = reg_a_o[5];
    sim_reg_a_o[6] = reg_a_o[6];
    sim_reg_a_o[7] = reg_a_o[7];
  }
  if (sim_reg_b_o[7] != reg_b_o[7] || sim_reg_b_o[6] != reg_b_o[6] || sim_reg_b_o[5] != reg_b_o[5] || sim_reg_b_o[4] != reg_b_o[4] || sim_reg_b_o[3] != reg_b_o[3] || sim_reg_b_o[2] != reg_b_o[2] || sim_reg_b_o[1] != reg_b_o[1] || sim_reg_b_o[0] != reg_b_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_b_o[byte]) ? "1" : "0");
          else if (bit & reg_b_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 6\n");
    }
    sim_reg_b_o[0] = reg_b_o[0];
    sim_reg_b_o[1] = reg_b_o[1];
    sim_reg_b_o[2] = reg_b_o[2];
    sim_reg_b_o[3] = reg_b_o[3];
    sim_reg_b_o[4] = reg_b_o[4];
    sim_reg_b_o[5] = reg_b_o[5];
    sim_reg_b_o[6] = reg_b_o[6];
    sim_reg_b_o[7] = reg_b_o[7];
  }
  if (sim_reg_c_o[7] != reg_c_o[7] || sim_reg_c_o[6] != reg_c_o[6] || sim_reg_c_o[5] != reg_c_o[5] || sim_reg_c_o[4] != reg_c_o[4] || sim_reg_c_o[3] != reg_c_o[3] || sim_reg_c_o[2] != reg_c_o[2] || sim_reg_c_o[1] != reg_c_o[1] || sim_reg_c_o[0] != reg_c_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_c_o[byte]) ? "1" : "0");
          else if (bit & reg_c_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 7\n");
    }
    sim_reg_c_o[0] = reg_c_o[0];
    sim_reg_c_o[1] = reg_c_o[1];
    sim_reg_c_o[2] = reg_c_o[2];
    sim_reg_c_o[3] = reg_c_o[3];
    sim_reg_c_o[4] = reg_c_o[4];
    sim_reg_c_o[5] = reg_c_o[5];
    sim_reg_c_o[6] = reg_c_o[6];
    sim_reg_c_o[7] = reg_c_o[7];
  }
  if (sim_reg_d_o[7] != reg_d_o[7] || sim_reg_d_o[6] != reg_d_o[6] || sim_reg_d_o[5] != reg_d_o[5] || sim_reg_d_o[4] != reg_d_o[4] || sim_reg_d_o[3] != reg_d_o[3] || sim_reg_d_o[2] != reg_d_o[2] || sim_reg_d_o[1] != reg_d_o[1] || sim_reg_d_o[0] != reg_d_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_d_o[byte]) ? "1" : "0");
          else if (bit & reg_d_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 8\n");
    }
    sim_reg_d_o[0] = reg_d_o[0];
    sim_reg_d_o[1] = reg_d_o[1];
    sim_reg_d_o[2] = reg_d_o[2];
    sim_reg_d_o[3] = reg_d_o[3];
    sim_reg_d_o[4] = reg_d_o[4];
    sim_reg_d_o[5] = reg_d_o[5];
    sim_reg_d_o[6] = reg_d_o[6];
    sim_reg_d_o[7] = reg_d_o[7];
  }
  if (sim_reg_e_o[7] != reg_e_o[7] || sim_reg_e_o[6] != reg_e_o[6] || sim_reg_e_o[5] != reg_e_o[5] || sim_reg_e_o[4] != reg_e_o[4] || sim_reg_e_o[3] != reg_e_o[3] || sim_reg_e_o[2] != reg_e_o[2] || sim_reg_e_o[1] != reg_e_o[1] || sim_reg_e_o[0] != reg_e_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_e_o[byte]) ? "1" : "0");
          else if (bit & reg_e_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 9\n");
    }
    sim_reg_e_o[0] = reg_e_o[0];
    sim_reg_e_o[1] = reg_e_o[1];
    sim_reg_e_o[2] = reg_e_o[2];
    sim_reg_e_o[3] = reg_e_o[3];
    sim_reg_e_o[4] = reg_e_o[4];
    sim_reg_e_o[5] = reg_e_o[5];
    sim_reg_e_o[6] = reg_e_o[6];
    sim_reg_e_o[7] = reg_e_o[7];
  }
  if (sim_reg_f_o[7] != reg_f_o[7] || sim_reg_f_o[6] != reg_f_o[6] || sim_reg_f_o[5] != reg_f_o[5] || sim_reg_f_o[4] != reg_f_o[4] || sim_reg_f_o[3] != reg_f_o[3] || sim_reg_f_o[2] != reg_f_o[2] || sim_reg_f_o[1] != reg_f_o[1] || sim_reg_f_o[0] != reg_f_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 7; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & reg_f_o[byte]) ? "1" : "0");
          else if (bit & reg_f_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " :\n");
    }
    sim_reg_f_o[0] = reg_f_o[0];
    sim_reg_f_o[1] = reg_f_o[1];
    sim_reg_f_o[2] = reg_f_o[2];
    sim_reg_f_o[3] = reg_f_o[3];
    sim_reg_f_o[4] = reg_f_o[4];
    sim_reg_f_o[5] = reg_f_o[5];
    sim_reg_f_o[6] = reg_f_o[6];
    sim_reg_f_o[7] = reg_f_o[7];
  }
  sim_count++;
}

